@@ -22,7 +22,7 @@ import java.io.IOException;
 import java.io.InputStream;
 
 /**
- * Archive input streams <b>MUST</b> override the 
+ * Archive input streams <b>MUST</b> override the
  * {@link #read(byte[], int, int)} - or {@link #read()} -
  * method so that reading from the stream generates EOF for the end of
  * data in each entry as well as at the end of the file proper.
@@ -35,15 +35,15 @@ import java.io.InputStream;
  * public static boolean matches(byte[] signature, int length)
  * </pre>
  * which is used by the {@link ArchiveStreamFactory} to autodetect
- * the archive type from the first few bytes of a stream. 
+ * the archive type from the first few bytes of a stream.
  */
 public abstract class ArchiveInputStream extends InputStream {
 
-    private final byte[] SINGLE = new byte[1];
+    private final byte[] single = new byte[1];
     private static final int BYTE_MASK = 0xFF;
 
     /** holds the number of bytes read in this stream */
-    private long bytesRead = 0;
+    private long bytesRead;
 
     /**
      * Returns the next Archive Entry in this Stream.
@@ -66,40 +66,40 @@ public abstract class ArchiveInputStream extends InputStream {
     /**
      * Reads a byte of data. This method will block until enough input is
      * available.
-     * 
+     *
      * Simply calls the {@link #read(byte[], int, int)} method.
-     * 
+     *
      * MUST be overridden if the {@link #read(byte[], int, int)} method
      * is not overridden; may be overridden otherwise.
-     * 
+     *
      * @return the byte read, or -1 if end of input is reached
      * @throws IOException
      *             if an I/O error has occurred
      */
     @Override
     public int read() throws IOException {
-        int num = read(SINGLE, 0, 1);
-        return num == -1 ? -1 : SINGLE[0] & BYTE_MASK;
+        final int num = read(single, 0, 1);
+        return num == -1 ? -1 : single[0] & BYTE_MASK;
     }
 
     /**
      * Increments the counter of already read bytes.
      * Doesn't increment if the EOF has been hit (read == -1)
-     * 
+     *
      * @param read the number of bytes read
      */
-    protected void count(int read) {
+    protected void count(final int read) {
         count((long) read);
     }
 
     /**
      * Increments the counter of already read bytes.
      * Doesn't increment if the EOF has been hit (read == -1)
-     * 
+     *
      * @param read the number of bytes read
      * @since 1.1
      */
-    protected void count(long read) {
+    protected void count(final long read) {
         if (read != -1) {
             bytesRead = bytesRead + read;
         }
@@ -107,11 +107,11 @@ public abstract class ArchiveInputStream extends InputStream {
 
     /**
      * Decrements the counter of already read bytes.
-     * 
+     *
      * @param pushedBack the number of bytes pushed back.
      * @since 1.1
      */
-    protected void pushedBackBytes(long pushedBack) {
+    protected void pushedBackBytes(final long pushedBack) {
         bytesRead -= pushedBack;
     }
 
@@ -137,18 +137,18 @@ public abstract class ArchiveInputStream extends InputStream {
 
     /**
      * Whether this stream is able to read the given entry.
-     * 
+     *
      * <p>
      * Some archive formats support variants or details that are not supported (yet).
      * </p>
-     * 
+     *
      * @param archiveEntry
      *            the entry to test
      * @return This implementation always returns true.
-     * 
+     *
      * @since 1.1
      */
-    public boolean canReadEntryData(ArchiveEntry archiveEntry) {
+    public boolean canReadEntryData(final ArchiveEntry archiveEntry) {
         return true;
     }
 
