@@ -24,10 +24,9 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
-import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.Locale;
+import java.util.ServiceLoader;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
@@ -46,8 +45,6 @@ import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveOutputStream;
 import org.apache.commons.compress.utils.IOUtils;
-import org.apache.commons.compress.utils.Lists;
-import org.apache.commons.compress.utils.ServiceLoaderIterator;
 import org.apache.commons.compress.utils.Sets;
 
 /**
@@ -94,7 +91,51 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     private static final int SIGNATURE_SIZE = 12;
 
-    private static final ArchiveStreamFactory SINGLETON = new ArchiveStreamFactory();
+    /**
+     * The singleton instance using the platform default encoding.
+     * @since 1.21
+     */
+    public static final ArchiveStreamFactory DEFAULT = new ArchiveStreamFactory();
+
+    /**
+     * Constant (value {@value}) used to identify the APK archive format.
+     * <p>
+     * APK file extensions are .apk, .xapk, .apks, .apkm
+     * </p>
+     *
+     * @since 1.22
+     */
+    public static final String APK = "apk";
+
+    /**
+     * Constant (value {@value}) used to identify the XAPK archive format.
+     * <p>
+     * APK file extensions are .apk, .xapk, .apks, .apkm
+     * </p>
+     *
+     * @since 1.22
+     */
+    public static final String XAPK = "xapk";
+
+    /**
+     * Constant (value {@value}) used to identify the APKS archive format.
+     * <p>
+     * APK file extensions are .apk, .xapk, .apks, .apkm
+     * </p>
+     *
+     * @since 1.22
+     */
+    public static final String APKS = "apks";
+
+    /**
+     * Constant (value {@value}) used to identify the APKM archive format.
+     * <p>
+     * APK file extensions are .apk, .xapk, .apks, .apkm
+     * </p>
+     *
+     * @since 1.22
+     */
+    public static final String APKM = "apkm";
 
     /**
      * Constant (value {@value}) used to identify the AR archive format.
@@ -160,21 +201,14 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
 
     private SortedMap<String, ArchiveStreamProvider> archiveOutputStreamProviders;
 
-    private static ArrayList<ArchiveStreamProvider> findArchiveStreamProviders() {
-        return Lists.newArrayList(serviceLoaderIterator());
+    static void putAll(final Set<String> names, final ArchiveStreamProvider provider, final TreeMap<String, ArchiveStreamProvider> map) {
+        names.forEach(name -> map.put(toKey(name), provider));
     }
 
-    static void putAll(Set<String> names, ArchiveStreamProvider provider,
-            TreeMap<String, ArchiveStreamProvider> map) {
-        for (String name : names) {
-            map.put(toKey(name), provider);
-        }
+    private static Iterable<ArchiveStreamProvider> archiveStreamProviderIterable() {
+        return ServiceLoader.load(ArchiveStreamProvider.class, ClassLoader.getSystemClassLoader());
     }
-
-    private static Iterator<ArchiveStreamProvider> serviceLoaderIterator() {
-        return new ServiceLoaderIterator<>(ArchiveStreamProvider.class);
-    }
-
+    
     private static String toKey(final String name) {
         return name.toUpperCase(Locale.ROOT);
     }
@@ -207,16 +241,11 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * @since 1.13
      */
     public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveInputStreamProviders() {
-        return AccessController.doPrivileged(new PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>() {
-            @Override
-            public SortedMap<String, ArchiveStreamProvider> run() {
-                TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
-                putAll(SINGLETON.getInputStreamArchiveNames(), SINGLETON, map);
-                for (ArchiveStreamProvider provider : findArchiveStreamProviders()) {
-                    putAll(provider.getInputStreamArchiveNames(), provider, map);
-                }
-                return map;
-            }
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
+            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
+            putAll(DEFAULT.getInputStreamArchiveNames(), DEFAULT, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getInputStreamArchiveNames(), provider, map));
+            return map;
         });
     }
 
@@ -248,16 +277,11 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * @since 1.13
      */
     public static SortedMap<String, ArchiveStreamProvider> findAvailableArchiveOutputStreamProviders() {
-        return AccessController.doPrivileged(new PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>() {
-            @Override
-            public SortedMap<String, ArchiveStreamProvider> run() {
-                TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
-                putAll(SINGLETON.getOutputStreamArchiveNames(), SINGLETON, map);
-                for (ArchiveStreamProvider provider : findArchiveStreamProviders()) {
-                    putAll(provider.getOutputStreamArchiveNames(), provider, map);
-                }
-                return map;
-            }
+        return AccessController.doPrivileged((PrivilegedAction<SortedMap<String, ArchiveStreamProvider>>) () -> {
+            final TreeMap<String, ArchiveStreamProvider> map = new TreeMap<>();
+            putAll(DEFAULT.getOutputStreamArchiveNames(), DEFAULT, map);
+            archiveStreamProviderIterable().forEach(provider -> putAll(provider.getOutputStreamArchiveNames(), provider, map));
+            return map;
         });
     }
 
@@ -276,7 +300,6 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * @since 1.10
      */
     public ArchiveStreamFactory(final String encoding) {
-        super();
         this.encoding = encoding;
         // Also set the original field so can continue to use it.
         this.entryEncoding = encoding;
@@ -323,8 +346,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * read from a stream
      * @throws IllegalArgumentException if the archiver name or stream is null
      */
-    public ArchiveInputStream createArchiveInputStream(final String archiverName, final InputStream in)
-            throws ArchiveException {
+    public ArchiveInputStream createArchiveInputStream(final String archiverName, final InputStream in) throws ArchiveException {
         return createArchiveInputStream(archiverName, in, entryEncoding);
     }
 
@@ -361,7 +383,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
             }
             return new TarArchiveInputStream(in);
         }
-        if (JAR.equalsIgnoreCase(archiverName)) {
+        if (JAR.equalsIgnoreCase(archiverName) || APK.equalsIgnoreCase(archiverName)) {
             if (actualEncoding != null) {
                 return new JarArchiveInputStream(in, actualEncoding);
             }
@@ -483,7 +505,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
      * @throws ArchiveException if an archiver cannot be detected in the stream
      * @since 1.14
      */
-    public static String detect(InputStream in) throws ArchiveException {
+    public static String detect(final InputStream in) throws ArchiveException {
         if (in == null) {
             throw new IllegalArgumentException("Stream must not be null.");
         }
@@ -498,21 +520,26 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
         try {
             signatureLength = IOUtils.readFully(in, signature);
             in.reset();
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw new ArchiveException("IOException while reading signature.", e);
         }
 
         if (ZipArchiveInputStream.matches(signature, signatureLength)) {
             return ZIP;
-        } else if (JarArchiveInputStream.matches(signature, signatureLength)) {
+        }
+        if (JarArchiveInputStream.matches(signature, signatureLength)) {
             return JAR;
-        } else if (ArArchiveInputStream.matches(signature, signatureLength)) {
+        }
+        if (ArArchiveInputStream.matches(signature, signatureLength)) {
             return AR;
-        } else if (CpioArchiveInputStream.matches(signature, signatureLength)) {
+        }
+        if (CpioArchiveInputStream.matches(signature, signatureLength)) {
             return CPIO;
-        } else if (ArjArchiveInputStream.matches(signature, signatureLength)) {
+        }
+        if (ArjArchiveInputStream.matches(signature, signatureLength)) {
             return ARJ;
-        } else if (SevenZFile.matches(signature, signatureLength)) {
+        }
+        if (SevenZFile.matches(signature, signatureLength)) {
             return SEVEN_Z;
         }
 
@@ -522,7 +549,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
         try {
             signatureLength = IOUtils.readFully(in, dumpsig);
             in.reset();
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw new ArchiveException("IOException while reading dump signature", e);
         }
         if (DumpArchiveInputStream.matches(dumpsig, signatureLength)) {
@@ -535,7 +562,7 @@ public class ArchiveStreamFactory implements ArchiveStreamProvider {
         try {
             signatureLength = IOUtils.readFully(in, tarHeader);
             in.reset();
-        } catch (IOException e) {
+        } catch (final IOException e) {
             throw new ArchiveException("IOException while reading tar signature", e);
         }
         if (TarArchiveInputStream.matches(tarHeader, signatureLength)) {
