@@ -24,7 +24,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.nio.file.Files;
 import java.util.Enumeration;
+
 import org.apache.commons.compress.archivers.sevenz.SevenZFile;
+import org.apache.commons.compress.archivers.tar.TarFile;
 import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipFile;
 
@@ -37,9 +39,23 @@ import org.apache.commons.compress.archivers.zip.ZipFile;
  * @since 1.1
  */
 public final class Lister {
-    private static final ArchiveStreamFactory factory = new ArchiveStreamFactory();
 
-    public static void main(final String[] args) throws Exception {
+    private static final ArchiveStreamFactory FACTORY = ArchiveStreamFactory.DEFAULT;
+
+    /**
+     * Runs this class from the command line.
+     * <p>
+     * The name of the archive must be given as a command line argument.
+     * </p>
+     * <p>
+     * The optional second argument defines the archive type, in case the format is not recognized.
+     * </p>
+     * 
+     * @param args name of the archive and optional argument archive type.
+     * @throws ArchiveException Archiver related Exception.
+     * @throws IOException an I/O exception.
+     */
+    public static void main(final String[] args) throws ArchiveException, IOException {
         if (args.length == 0) {
             usage();
             return;
@@ -49,17 +65,19 @@ public final class Lister {
         if (!f.isFile()) {
             System.err.println(f + " doesn't exist or is a directory");
         }
-        String format = args.length > 1 ? args[1] : detectFormat(f);
+        final String format = args.length > 1 ? args[1] : detectFormat(f);
         if (ArchiveStreamFactory.SEVEN_Z.equalsIgnoreCase(format)) {
             list7z(f);
         } else if ("zipfile".equals(format)) {
             listZipUsingZipFile(f);
+        } else if ("tarfile".equals(format)) {
+            listZipUsingTarFile(f);
         } else {
             listStream(f, args);
         }
     }
 
-    private static void listStream(File f, String[] args) throws ArchiveException, IOException {
+    private static void listStream(final File f, final String[] args) throws ArchiveException, IOException {
         try (final InputStream fis = new BufferedInputStream(Files.newInputStream(f.toPath()));
                 final ArchiveInputStream ais = createArchiveInputStream(args, fis)) {
             System.out.println("Created " + ais.toString());
@@ -73,41 +91,49 @@ public final class Lister {
     private static ArchiveInputStream createArchiveInputStream(final String[] args, final InputStream fis)
             throws ArchiveException {
         if (args.length > 1) {
-            return factory.createArchiveInputStream(args[1], fis);
+            return FACTORY.createArchiveInputStream(args[1], fis);
         }
-        return factory.createArchiveInputStream(fis);
+        return FACTORY.createArchiveInputStream(fis);
     }
 
-    private static String detectFormat(File f) throws ArchiveException, IOException {
+    private static String detectFormat(final File f) throws ArchiveException, IOException {
         try (final InputStream fis = new BufferedInputStream(Files.newInputStream(f.toPath()))) {
-            return factory.detect(fis);
+            return ArchiveStreamFactory.detect(fis);
         }
     }
 
-    private static void list7z(File f) throws ArchiveException, IOException {
+    private static void list7z(final File f) throws IOException {
         try (SevenZFile z = new SevenZFile(f)) {
-            System.out.println("Created " + z.toString());
+            System.out.println("Created " + z);
             ArchiveEntry ae;
             while ((ae = z.getNextEntry()) != null) {
-                String name = ae.getName() == null ? z.getDefaultName() + " (entry name was null)"
+                final String name = ae.getName() == null ? z.getDefaultName() + " (entry name was null)"
                     : ae.getName();
                 System.out.println(name);
             }
         }
     }
 
-    private static void listZipUsingZipFile(File f) throws ArchiveException, IOException {
+    private static void listZipUsingZipFile(final File f) throws IOException {
         try (ZipFile z = new ZipFile(f)) {
-            System.out.println("Created " + z.toString());
-            for (Enumeration<ZipArchiveEntry> en = z.getEntries(); en.hasMoreElements(); ) {
+            System.out.println("Created " + z);
+            for (final Enumeration<ZipArchiveEntry> en = z.getEntries(); en.hasMoreElements(); ) {
                 System.out.println(en.nextElement().getName());
             }
         }
     }
 
+    private static void listZipUsingTarFile(final File f) throws IOException {
+        try (TarFile t = new TarFile(f)) {
+            System.out.println("Created " + t);
+            t.getEntries().forEach(en -> System.out.println(en.getName()));
+        }
+    }
+
     private static void usage() {
         System.out.println("Parameters: archive-name [archive-type]\n");
-        System.out.println("the magic archive-type 'zipfile' prefers ZipFile over ZipArchiveInputStream");
+        System.out.println("The magic archive-type 'zipfile' prefers ZipFile over ZipArchiveInputStream");
+        System.out.println("The magic archive-type 'tarfile' prefers TarFile over TarArchiveInputStream");
     }
 
 }
