@@ -18,10 +18,11 @@
  */
 package org.apache.commons.compress.archivers.ar;
 
+import static java.nio.charset.StandardCharsets.US_ASCII;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.LinkOption;
 import java.nio.file.Path;
 
@@ -125,7 +126,7 @@ public class ArArchiveOutputStream extends ArchiveOutputStream {
     }
 
     private long write(final String data) throws IOException {
-        final byte[] bytes = data.getBytes(StandardCharsets.US_ASCII);
+        final byte[] bytes = data.getBytes(US_ASCII);
         write(bytes);
         return bytes.length;
     }
@@ -143,8 +144,7 @@ public class ArArchiveOutputStream extends ArchiveOutputStream {
         if (LONGFILE_BSD == longFileMode &&
             (nLength > 16 || n.contains(" "))) {
             mustAppendName = true;
-            offset += write(ArArchiveInputStream.BSD_LONGNAME_PREFIX
-                            + String.valueOf(nLength));
+            offset += write(ArArchiveInputStream.BSD_LONGNAME_PREFIX + nLength);
         } else {
             offset += write(n);
         }
