@@ -18,7 +18,6 @@
 package org.apache.commons.compress.archivers.arj;
 
 import java.util.Arrays;
-import java.util.Objects;
 
 class LocalFileHeader {
     int archiverVersionNumber;
@@ -36,17 +35,17 @@ class LocalFileHeader {
     int fileAccessMode;
     int firstChapter;
     int lastChapter;
-
+    
     int extendedFilePosition;
     int dateTimeAccessed;
     int dateTimeCreated;
     int originalSizeEvenForVolumes;
-
+    
     String name;
     String comment;
-
-    byte[][] extendedHeaders;
-
+    
+    byte[][] extendedHeaders = null;
+    
     static class Flags {
         static final int GARBLED = 0x01;
         static final int VOLUME = 0x04;
@@ -54,21 +53,18 @@ class LocalFileHeader {
         static final int PATHSYM = 0x10;
         static final int BACKUP = 0x20;
     }
-
+    
     static class FileTypes {
         static final int BINARY = 0;
         static final int SEVEN_BIT_TEXT = 1;
-        static final int COMMENT_HEADER = 2;
         static final int DIRECTORY = 3;
         static final int VOLUME_LABEL = 4;
         static final int CHAPTER_LABEL = 5;
     }
-
+    
     static class Methods {
         static final int STORED = 0;
         static final int COMPRESSED_MOST = 1;
-        static final int COMPRESSED = 2;
-        static final int COMPRESSED_FASTER = 3;
         static final int COMPRESSED_FASTEST = 4;
         static final int NO_DATA_NO_CRC = 8;
         static final int NO_DATA = 9;
@@ -76,7 +72,7 @@ class LocalFileHeader {
 
     @Override
     public String toString() {
-        final StringBuilder builder = new StringBuilder();
+        StringBuilder builder = new StringBuilder();
         builder.append("LocalFileHeader [archiverVersionNumber=");
         builder.append(archiverVersionNumber);
         builder.append(", minVersionToExtract=");
@@ -124,44 +120,4 @@ class LocalFileHeader {
         builder.append("]");
         return builder.toString();
     }
-
-    @Override
-    public int hashCode() {
-        return name == null ? 0 : name.hashCode();
-    }
-
-    @Override
-    public boolean equals(final Object obj) {
-        if (this == obj) {
-            return true;
-        }
-        if (obj == null || getClass() != obj.getClass()) {
-            return false;
-        }
-        final LocalFileHeader other = (LocalFileHeader) obj;
-        return
-            archiverVersionNumber == other.archiverVersionNumber &&
-            minVersionToExtract == other.minVersionToExtract &&
-            hostOS == other.hostOS &&
-            arjFlags == other.arjFlags &&
-            method == other.method &&
-            fileType == other.fileType &&
-            reserved == other.reserved &&
-            dateTimeModified == other.dateTimeModified &&
-            compressedSize == other.compressedSize &&
-            originalSize == other.originalSize &&
-            originalCrc32 == other.originalCrc32 &&
-            fileSpecPosition == other.fileSpecPosition &&
-            fileAccessMode == other.fileAccessMode &&
-            firstChapter == other.firstChapter &&
-            lastChapter == other.lastChapter &&
-            extendedFilePosition == other.extendedFilePosition &&
-            dateTimeAccessed == other.dateTimeAccessed &&
-            dateTimeCreated == other.dateTimeCreated &&
-            originalSizeEvenForVolumes == other.originalSizeEvenForVolumes &&
-            Objects.equals(name, other.name) &&
-            Objects.equals(comment, other.comment) &&
-            Arrays.deepEquals(extendedHeaders, other.extendedHeaders);
-    }
-
 }
