@@ -19,14 +19,22 @@
 package org.apache.commons.compress.archivers.cpio;
 
 import java.io.File;
+import java.io.IOException;
 import java.nio.charset.Charset;
+import java.nio.file.Files;
+import java.nio.file.LinkOption;
+import java.nio.file.Path;
+import java.nio.file.attribute.FileTime;
 import java.util.Date;
+import java.util.Objects;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.compress.archivers.ArchiveEntry;
+import org.apache.commons.compress.utils.ExactMath;
 
 /**
  * A cpio archive consists of a sequence of files. There are several types of
- * headers defided in two categories of new and old format. The headers are
+ * headers defined in two categories of new and old format. The headers are
  * recognized by magic numbers:
  *
  * <ul>
@@ -50,11 +58,11 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
  * CPIO 2.5 knows also about tar, but it is not recognized here.</p>
  *
  *
- * <h3>OLD FORMAT</h3>
+ * <h2>OLD FORMAT</h2>
  *
  * <p>Each file has a 76 (ascii) / 26 (binary) byte header, a variable
- * length, NUL terminated filename, and variable length file data. A
- * header for a filename "TRAILER!!!" indicates the end of the
+ * length, NUL terminated file name, and variable length file data. A
+ * header for a file name "TRAILER!!!" indicates the end of the
  * archive.</p>
  *
  * <p>All the fields in the header are ISO 646 (approximately ASCII)
@@ -88,7 +96,7 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
  * apart from c_mtime and c_filesize which are 32-bit integer values
  * </pre>
  *
- * <p>If necessary, the filename and file data are padded with a NUL byte to an even length</p>
+ * <p>If necessary, the file name and file data are padded with a NUL byte to an even length</p>
  *
  * <p>Special files, directories, and the trailer are recorded with
  * the h_filesize field equal to 0.</p>
@@ -99,8 +107,8 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
  * <h3>NEW FORMAT</h3>
  *
  * <p>Each file has a 110 byte header, a variable length, NUL
- * terminated filename, and variable length file data. A header for a
- * filename "TRAILER!!!" indicates the end of the archive. All the
+ * terminated file name, and variable length file data. A header for a
+ * file name "TRAILER!!!" indicates the end of the archive. All the
  * fields in the header are ISO 646 (approximately ASCII) strings of
  * hexadecimal numbers, left padded, not NUL terminated.</p>
  *
@@ -149,7 +157,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     // Header description fields - should be same throughout an archive
 
     /**
-     * See constructor documenation for possible values.
+     * See {@link #CpioArchiveEntry(short)} for possible values.
      */
     private final short fileFormat;
 
@@ -161,32 +169,32 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
 
     // Header fields
 
-    private long chksum = 0;
+    private long chksum;
 
     /** Number of bytes in the file */
-    private long filesize = 0;
+    private long filesize;
 
-    private long gid = 0;
+    private long gid;
 
-    private long inode = 0;
+    private long inode;
 
-    private long maj = 0;
+    private long maj;
 
-    private long min = 0;
+    private long min;
 
-    private long mode = 0;
+    private long mode;
 
-    private long mtime = 0;
+    private long mtime;
 
     private String name;
 
-    private long nlink = 0;
+    private long nlink;
 
-    private long rmaj = 0;
+    private long rmaj;
 
-    private long rmin = 0;
+    private long rmin;
 
-    private long uid = 0;
+    private long uid;
 
     /**
      * Creates a CpioArchiveEntry with a specified format.
@@ -221,7 +229,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
             this.alignmentBoundary = 2;
             break;
         default:
-            throw new IllegalArgumentException("Unknown header type");
+            throw new IllegalArgumentException("Unknown header type " + format);
         }
         this.fileFormat = format;
     }
@@ -314,6 +322,23 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
         this(FORMAT_NEW, inputFile, entryName);
     }
 
+    /**
+     * Creates a CpioArchiveEntry with a specified name for a
+     * specified file. The format of this entry will be the new
+     * format.
+     *
+     * @param inputPath
+     *            The file to gather information from.
+     * @param entryName
+     *            The name of this entry.
+     * @param options options indicating how symbolic links are handled.
+     * @throws IOException if an I/O error occurs
+     * @since 1.21
+     */
+    public CpioArchiveEntry(final Path inputPath, final String entryName, final LinkOption... options) throws IOException {
+        this(FORMAT_NEW, inputPath, entryName, options);
+    }
+
     /**
      * Creates a CpioArchiveEntry with a specified name for a
      * specified file.
@@ -351,7 +376,44 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if the method is allowed for the defined format.
+     * Creates a CpioArchiveEntry with a specified name for a
+     * specified path.
+     *
+     * @param format
+     *            The cpio format for this entry.
+     * @param inputPath
+     *            The file to gather information from.
+     * @param entryName
+     *            The name of this entry.
+     * <p>
+     * Possible format values are:
+     * <pre>
+     * CpioConstants.FORMAT_NEW
+     * CpioConstants.FORMAT_NEW_CRC
+     * CpioConstants.FORMAT_OLD_BINARY
+     * CpioConstants.FORMAT_OLD_ASCII
+     * </pre>
+     * @param options options indicating how symbolic links are handled.
+     *
+     * @throws IOException if an I/O error occurs
+     * @since 1.21
+     */
+    public CpioArchiveEntry(final short format, final Path inputPath, final String entryName, final LinkOption... options)
+        throws IOException {
+        this(format, entryName, Files.isRegularFile(inputPath, options) ? Files.size(inputPath) : 0);
+        if (Files.isDirectory(inputPath, options)) {
+            setMode(C_ISDIR);
+        } else if (Files.isRegularFile(inputPath, options)) {
+            setMode(C_ISREG);
+        } else {
+            throw new IllegalArgumentException("Cannot determine type of file " + inputPath);
+        }
+        // TODO set other fields as needed
+        setTime(Files.getLastModifiedTime(inputPath, options));
+    }
+
+    /**
+     * Checks if the method is allowed for the defined format.
      */
     private void checkNewFormat() {
         if ((this.fileFormat & FORMAT_NEW_MASK) == 0) {
@@ -360,7 +422,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if the method is allowed for the defined format.
+     * Checks if the method is allowed for the defined format.
      */
     private void checkOldFormat() {
         if ((this.fileFormat & FORMAT_OLD_MASK) == 0) {
@@ -369,7 +431,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the checksum.
+     * Gets the checksum.
      * Only supported for the new formats.
      *
      * @return Returns the checksum.
@@ -381,7 +443,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the device id.
+     * Gets the device id.
      *
      * @return Returns the device id.
      * @throws UnsupportedOperationException
@@ -394,7 +456,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the major device id.
+     * Gets the major device id.
      *
      * @return Returns the major device id.
      * @throws UnsupportedOperationException
@@ -407,7 +469,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the minor device id
+     * Gets the minor device id
      *
      * @return Returns the minor device id.
      * @throws UnsupportedOperationException if format is not a new format
@@ -418,7 +480,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the filesize.
+     * Gets the filesize.
      *
      * @return Returns the filesize.
      * @see org.apache.commons.compress.archivers.ArchiveEntry#getSize()
@@ -429,7 +491,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the format for this entry.
+     * Gets the format for this entry.
      *
      * @return Returns the format.
      */
@@ -438,7 +500,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the group id.
+     * Gets the group id.
      *
      * @return Returns the group id.
      */
@@ -447,7 +509,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the header size for this CPIO format
+     * Gets the header size for this CPIO format
      *
      * @return Returns the header size in bytes.
      */
@@ -456,7 +518,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the alignment boundary for this CPIO format
+     * Gets the alignment boundary for this CPIO format
      *
      * @return Returns the aligment boundary (0, 2, 4) in bytes
      */
@@ -465,7 +527,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the number of bytes needed to pad the header to the alignment boundary.
+     * Gets the number of bytes needed to pad the header to the alignment boundary.
      *
      * @deprecated This method doesn't properly work for multi-byte encodings. And
      *             creates corrupt archives. Use {@link #getHeaderPadCount(Charset)}
@@ -478,14 +540,14 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the number of bytes needed to pad the header to the alignment boundary.
+     * Gets the number of bytes needed to pad the header to the alignment boundary.
      *
      * @param charset
      *             The character set used to encode the entry name in the stream.
      * @return the number of bytes needed to pad the header (0,1,2,3)
      * @since 1.18
      */
-    public int getHeaderPadCount(Charset charset) {
+    public int getHeaderPadCount(final Charset charset) {
         if (name == null) {
             return 0;
         }
@@ -496,20 +558,22 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the number of bytes needed to pad the header to the alignment boundary.
+     * Gets the number of bytes needed to pad the header to the alignment boundary.
      *
-     * @param namesize
+     * @param nameSize
      *            The length of the name in bytes, as read in the stream.
      *            Without the trailing zero byte.
      * @return the number of bytes needed to pad the header (0,1,2,3)
      *
      * @since 1.18
      */
-    public int getHeaderPadCount(long namesize) {
-        if (this.alignmentBoundary == 0) { return 0; }
-        int size = this.headerSize + 1;  // Name has terminating null
+    public int getHeaderPadCount(final long nameSize) {
+        if (this.alignmentBoundary == 0) {
+            return 0;
+        }
+        int size = this.headerSize + 1; // Name has terminating null
         if (name != null) {
-            size += namesize;
+            size = ExactMath.add(size, nameSize);
         }
         final int remain = size % this.alignmentBoundary;
         if (remain > 0) {
@@ -519,22 +583,24 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the number of bytes needed to pad the data to the alignment boundary.
+     * Gets the number of bytes needed to pad the data to the alignment boundary.
      *
      * @return the number of bytes needed to pad the data (0,1,2,3)
      */
-    public int getDataPadCount(){
-        if (this.alignmentBoundary == 0) { return 0; }
+    public int getDataPadCount() {
+        if (this.alignmentBoundary == 0) {
+            return 0;
+        }
         final long size = this.filesize;
         final int remain = (int) (size % this.alignmentBoundary);
-        if (remain > 0){
+        if (remain > 0) {
             return this.alignmentBoundary - remain;
         }
         return 0;
     }
 
     /**
-     * Set the inode.
+     * Sets the inode.
      *
      * @return Returns the inode.
      */
@@ -543,7 +609,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the mode of this entry (e.g. directory, regular file).
+     * Gets the mode of this entry (e.g. directory, regular file).
      *
      * @return Returns the mode.
      */
@@ -552,7 +618,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the name.
+     * Gets the name.
      *
      * <p>This method returns the raw name as it is stored inside of the archive.</p>
      *
@@ -564,18 +630,16 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the number of links.
+     * Gets the number of links.
      *
      * @return Returns the number of links.
      */
     public long getNumberOfLinks() {
-        return nlink == 0 ?
-            isDirectory() ? 2 : 1
-            : nlink;
+        return nlink == 0 ? isDirectory() ? 2 : 1 : nlink;
     }
 
     /**
-     * Get the remote device id.
+     * Gets the remote device id.
      *
      * @return Returns the remote device id.
      * @throws UnsupportedOperationException
@@ -588,7 +652,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the remote major device id.
+     * Gets the remote major device id.
      *
      * @return Returns the remote major device id.
      * @throws UnsupportedOperationException
@@ -601,7 +665,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the remote minor device id.
+     * Gets the remote minor device id.
      *
      * @return Returns the remote minor device id.
      * @throws UnsupportedOperationException
@@ -614,7 +678,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the time in seconds.
+     * Gets the time in seconds.
      *
      * @return Returns the time.
      */
@@ -628,7 +692,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Get the user id.
+     * Gets the user id.
      *
      * @return Returns the user id.
      */
@@ -637,7 +701,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a block device.
+     * Checks if this entry represents a block device.
      *
      * @return TRUE if this entry is a block device.
      */
@@ -646,7 +710,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a character device.
+     * Checks if this entry represents a character device.
      *
      * @return TRUE if this entry is a character device.
      */
@@ -655,7 +719,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a directory.
+     * Checks if this entry represents a directory.
      *
      * @return TRUE if this entry is a directory.
      */
@@ -665,7 +729,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a network device.
+     * Checks if this entry represents a network device.
      *
      * @return TRUE if this entry is a network device.
      */
@@ -674,7 +738,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a pipe.
+     * Checks if this entry represents a pipe.
      *
      * @return TRUE if this entry is a pipe.
      */
@@ -683,7 +747,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a regular file.
+     * Checks if this entry represents a regular file.
      *
      * @return TRUE if this entry is a regular file.
      */
@@ -692,7 +756,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a socket.
+     * Checks if this entry represents a socket.
      *
      * @return TRUE if this entry is a socket.
      */
@@ -701,7 +765,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Check if this entry represents a symbolic link.
+     * Checks if this entry represents a symbolic link.
      *
      * @return TRUE if this entry is a symbolic link.
      */
@@ -710,7 +774,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the checksum. The checksum is calculated by adding all bytes of a
+     * Sets the checksum. The checksum is calculated by adding all bytes of a
      * file to transfer (crc += buf[pos] &amp; 0xFF).
      *
      * @param chksum
@@ -722,7 +786,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the device id.
+     * Sets the device id.
      *
      * @param device
      *            The device id to set.
@@ -736,7 +800,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set major device id.
+     * Sets major device id.
      *
      * @param maj
      *            The major device id to set.
@@ -747,7 +811,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the minor device id
+     * Sets the minor device id
      *
      * @param min
      *            The minor device id to set.
@@ -758,21 +822,20 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the filesize.
+     * Sets the filesize.
      *
      * @param size
      *            The filesize to set.
      */
     public void setSize(final long size) {
         if (size < 0 || size > 0xFFFFFFFFL) {
-            throw new IllegalArgumentException("invalid entry size <" + size
-                                               + ">");
+            throw new IllegalArgumentException("Invalid entry size <" + size + ">");
         }
         this.filesize = size;
     }
 
     /**
-     * Set the group id.
+     * Sets the group id.
      *
      * @param gid
      *            The group id to set.
@@ -782,7 +845,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the inode.
+     * Sets the inode.
      *
      * @param inode
      *            The inode to set.
@@ -792,7 +855,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the mode of this entry (e.g. directory, regular file).
+     * Sets the mode of this entry (e.g. directory, regular file).
      *
      * @param mode
      *            The mode to set.
@@ -820,7 +883,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the name.
+     * Sets the name.
      *
      * @param name
      *            The name to set.
@@ -830,7 +893,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the number of links.
+     * Sets the number of links.
      *
      * @param nlink
      *            The number of links to set.
@@ -840,7 +903,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the remote device id.
+     * Sets the remote device id.
      *
      * @param device
      *            The remote device id to set.
@@ -854,7 +917,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the remote major device id.
+     * Sets the remote major device id.
      *
      * @param rmaj
      *            The remote major device id to set.
@@ -868,7 +931,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the remote minor device id.
+     * Sets the remote minor device id.
      *
      * @param rmin
      *            The remote minor device id to set.
@@ -882,7 +945,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the time in seconds.
+     * Sets the time in seconds.
      *
      * @param time
      *            The time to set.
@@ -892,7 +955,17 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Set the user id.
+     * Sets the time.
+     *
+     * @param time
+     *            The time to set.
+     */
+    public void setTime(final FileTime time) {
+        this.mtime = time.to(TimeUnit.SECONDS);
+    }
+
+    /**
+     * Sets the user id.
      *
      * @param uid
      *            The user id to set.
@@ -902,18 +975,15 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /* (non-Javadoc)
-     * @see java.lang.Object#hashCode()
+     * @see Object#hashCode()
      */
     @Override
     public int hashCode() {
-        final int prime = 31;
-        int result = 1;
-        result = prime * result + (name == null ? 0 : name.hashCode());
-        return result;
+        return Objects.hash(name);
     }
 
     /* (non-Javadoc)
-     * @see java.lang.Object#equals(java.lang.Object)
+     * @see Object#equals(Object)
      */
     @Override
     public boolean equals(final Object obj) {
@@ -926,8 +996,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
         final CpioArchiveEntry other = (CpioArchiveEntry) obj;
         if (name == null) {
             return other.name == null;
-        } else {
-            return name.equals(other.name);
         }
+        return name.equals(other.name);
     }
 }
