@@ -22,6 +22,8 @@ import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.ByteBuffer;
+import java.nio.file.LinkOption;
+import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.HashMap;
 
@@ -67,20 +69,20 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
 
     private CpioArchiveEntry entry;
 
-    private boolean closed = false;
+    private boolean closed;
 
     /** indicates if this archive is finished */
     private boolean finished;
 
     /**
-     * See {@link CpioArchiveEntry#setFormat(short)} for possible values.
+     * See {@link CpioArchiveEntry#CpioArchiveEntry(short)} for possible values.
      */
     private final short entryFormat;
 
     private final HashMap<String, CpioArchiveEntry> names =
         new HashMap<>();
 
-    private long crc = 0;
+    private long crc;
 
     private long written;
 
@@ -91,7 +93,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
     private long nextArtificalDeviceAndInode = 1;
 
     /**
-     * The encoding to use for filenames and labels.
+     * The encoding to use for file names and labels.
      */
     private final ZipEncoding zipEncoding;
 
@@ -238,7 +240,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         }
 
         if (this.names.put(e.getName(), e) != null) {
-            throw new IOException("duplicate entry: " + e.getName());
+            throw new IOException("Duplicate entry: " + e.getName());
         }
 
         writeHeader(e);
@@ -269,7 +271,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
             writeOldBinaryEntry(e, swapHalfWord);
             break;
         default:
-            throw new IOException("unknown format " + e.getFormat());
+            throw new IOException("Unknown format " + e.getFormat());
         }
     }
 
@@ -278,15 +280,13 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         long devMin = entry.getDeviceMin();
         if (CPIO_TRAILER.equals(entry.getName())) {
             inode = devMin = 0;
+        } else if (inode == 0 && devMin == 0) {
+            inode = nextArtificalDeviceAndInode & 0xFFFFFFFF;
+            devMin = (nextArtificalDeviceAndInode++ >> 32) & 0xFFFFFFFF;
         } else {
-            if (inode == 0 && devMin == 0) {
-                inode = nextArtificalDeviceAndInode & 0xFFFFFFFF;
-                devMin = (nextArtificalDeviceAndInode++ >> 32) & 0xFFFFFFFF;
-            } else {
-                nextArtificalDeviceAndInode =
-                    Math.max(nextArtificalDeviceAndInode,
-                             inode + 0x100000000L * devMin) + 1;
-            }
+            nextArtificalDeviceAndInode =
+                Math.max(nextArtificalDeviceAndInode,
+                         inode + 0x100000000L * devMin) + 1;
         }
 
         writeAsciiLong(inode, 8, 16);
@@ -300,7 +300,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         writeAsciiLong(devMin, 8, 16);
         writeAsciiLong(entry.getRemoteDeviceMaj(), 8, 16);
         writeAsciiLong(entry.getRemoteDeviceMin(), 8, 16);
-        byte[] name = encode(entry.getName());
+        final byte[] name = encode(entry.getName());
         writeAsciiLong(name.length + 1L, 8, 16);
         writeAsciiLong(entry.getChksum(), 8, 16);
         writeCString(name);
@@ -313,15 +313,13 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         long device = entry.getDevice();
         if (CPIO_TRAILER.equals(entry.getName())) {
             inode = device = 0;
+        } else if (inode == 0 && device == 0) {
+            inode = nextArtificalDeviceAndInode & 0777777;
+            device = (nextArtificalDeviceAndInode++ >> 18) & 0777777;
         } else {
-            if (inode == 0 && device == 0) {
-                inode = nextArtificalDeviceAndInode & 0777777;
-                device = (nextArtificalDeviceAndInode++ >> 18) & 0777777;
-            } else {
-                nextArtificalDeviceAndInode =
-                    Math.max(nextArtificalDeviceAndInode,
-                             inode + 01000000 * device) + 1;
-            }
+            nextArtificalDeviceAndInode =
+                Math.max(nextArtificalDeviceAndInode,
+                         inode + 01000000 * device) + 1;
         }
 
         writeAsciiLong(device, 6, 8);
@@ -332,7 +330,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         writeAsciiLong(entry.getNumberOfLinks(), 6, 8);
         writeAsciiLong(entry.getRemoteDevice(), 6, 8);
         writeAsciiLong(entry.getTime(), 11, 8);
-        byte[] name = encode(entry.getName());
+        final byte[] name = encode(entry.getName());
         writeAsciiLong(name.length + 1L, 6, 8);
         writeAsciiLong(entry.getSize(), 11, 8);
         writeCString(name);
@@ -344,15 +342,13 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         long device = entry.getDevice();
         if (CPIO_TRAILER.equals(entry.getName())) {
             inode = device = 0;
+        } else if (inode == 0 && device == 0) {
+            inode = nextArtificalDeviceAndInode & 0xFFFF;
+            device = (nextArtificalDeviceAndInode++ >> 16) & 0xFFFF;
         } else {
-            if (inode == 0 && device == 0) {
-                inode = nextArtificalDeviceAndInode & 0xFFFF;
-                device = (nextArtificalDeviceAndInode++ >> 16) & 0xFFFF;
-            } else {
-                nextArtificalDeviceAndInode =
-                    Math.max(nextArtificalDeviceAndInode,
-                             inode + 0x10000 * device) + 1;
-            }
+            nextArtificalDeviceAndInode =
+                Math.max(nextArtificalDeviceAndInode,
+                         inode + 0x10000 * device) + 1;
         }
 
         writeBinaryLong(device, 2, swapHalfWord);
@@ -363,7 +359,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         writeBinaryLong(entry.getNumberOfLinks(), 2, swapHalfWord);
         writeBinaryLong(entry.getRemoteDevice(), 2, swapHalfWord);
         writeBinaryLong(entry.getTime(), 4, swapHalfWord);
-        byte[] name = encode(entry.getName());
+        final byte[] name = encode(entry.getName());
         writeBinaryLong(name.length + 1L, 2, swapHalfWord);
         writeBinaryLong(entry.getSize(), 4, swapHalfWord);
         writeCString(name);
@@ -389,7 +385,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         }
 
         if (this.entry.getSize() != this.written) {
-            throw new IOException("invalid entry size (expected "
+            throw new IOException("Invalid entry size (expected "
                     + this.entry.getSize() + " but got " + this.written
                     + " bytes)");
         }
@@ -423,15 +419,16 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         ensureOpen();
         if (off < 0 || len < 0 || off > b.length - len) {
             throw new IndexOutOfBoundsException();
-        } else if (len == 0) {
+        }
+        if (len == 0) {
             return;
         }
 
         if (this.entry == null) {
-            throw new IOException("no current CPIO entry");
+            throw new IOException("No current CPIO entry");
         }
         if (this.written + len > this.entry.getSize()) {
-            throw new IOException("attempt to write past end of STORED entry");
+            throw new IOException("Attempt to write past end of STORED entry");
         }
         out.write(b, off, len);
         this.written += len;
@@ -500,7 +497,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
 
     private void pad(final int count) throws IOException{
         if (count > 0){
-            final byte buff[] = new byte[count];
+            final byte[] buff = new byte[count];
             out.write(buff);
             count(count);
         }
@@ -508,7 +505,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
 
     private void writeBinaryLong(final long number, final int length,
             final boolean swapHalfWord) throws IOException {
-        final byte tmp[] = CpioUtil.long2byteArray(number, length, swapHalfWord);
+        final byte[] tmp = CpioUtil.long2byteArray(number, length, swapHalfWord);
         out.write(tmp);
         count(tmp.length);
     }
@@ -516,13 +513,13 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
     private void writeAsciiLong(final long number, final int length,
             final int radix) throws IOException {
         final StringBuilder tmp = new StringBuilder();
-        String tmpStr;
+        final String tmpStr;
         if (radix == 16) {
             tmp.append(Long.toHexString(number));
         } else if (radix == 8) {
             tmp.append(Long.toOctalString(number));
         } else {
-            tmp.append(Long.toString(number));
+            tmp.append(number);
         }
 
         if (tmp.length() <= length) {
@@ -557,7 +554,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
      * @param str the String to write
      * @throws IOException if the string couldn't be written
      */
-    private void writeCString(byte[] str) throws IOException {
+    private void writeCString(final byte[] str) throws IOException {
         out.write(str);
         out.write('\0');
         count(str.length + 1);
@@ -566,7 +563,7 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
     /**
      * Creates a new ArchiveEntry. The entryName must be an ASCII encoded string.
      *
-     * @see org.apache.commons.compress.archivers.ArchiveOutputStream#createArchiveEntry(java.io.File, java.lang.String)
+     * @see org.apache.commons.compress.archivers.ArchiveOutputStream#createArchiveEntry(java.io.File, String)
      */
     @Override
     public ArchiveEntry createArchiveEntry(final File inputFile, final String entryName)
@@ -577,4 +574,18 @@ public class CpioArchiveOutputStream extends ArchiveOutputStream implements
         return new CpioArchiveEntry(inputFile, entryName);
     }
 
+    /**
+     * Creates a new ArchiveEntry. The entryName must be an ASCII encoded string.
+     *
+     * @see org.apache.commons.compress.archivers.ArchiveOutputStream#createArchiveEntry(java.io.File, String)
+     */
+    @Override
+    public ArchiveEntry createArchiveEntry(final Path inputPath, final String entryName, final LinkOption... options)
+            throws IOException {
+        if(finished) {
+            throw new IOException("Stream has already been finished");
+        }
+        return new CpioArchiveEntry(inputPath, entryName, options);
+    }
+
 }
