@@ -18,16 +18,9 @@
  */
 package org.apache.commons.compress.archivers.dump;
 
-import org.apache.commons.compress.archivers.ArchiveException;
-import org.apache.commons.compress.archivers.ArchiveInputStream;
-import org.apache.commons.compress.archivers.zip.ZipEncoding;
-import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
-import org.apache.commons.compress.utils.IOUtils;
-
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
-
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
@@ -35,6 +28,12 @@ import java.util.PriorityQueue;
 import java.util.Queue;
 import java.util.Stack;
 
+import org.apache.commons.compress.archivers.ArchiveException;
+import org.apache.commons.compress.archivers.ArchiveInputStream;
+import org.apache.commons.compress.archivers.zip.ZipEncoding;
+import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
+import org.apache.commons.compress.utils.IOUtils;
+
 /**
  * The DumpArchiveInputStream reads a UNIX dump archive as an InputStream.
  * Methods are provided to position at each successive entry in
@@ -374,22 +373,19 @@ public class DumpArchiveInputStream extends ArchiveInputStream {
                 names.put(ino, d);
 
                 // check whether this allows us to fill anything in the pending list.
-                for (final Map.Entry<Integer, DumpArchiveEntry> e : pending.entrySet()) {
-                    final String path = getPath(e.getValue());
+                pending.forEach((k, v) -> {
+                    final String path = getPath(v);
 
                     if (path != null) {
-                        e.getValue().setName(path);
-                        e.getValue()
-                         .setSimpleName(names.get(e.getKey()).getName());
-                        queue.add(e.getValue());
+                        v.setName(path);
+                        v.setSimpleName(names.get(k).getName());
+                        queue.add(v);
                     }
-                }
+                });
 
                 // remove anything that we found. (We can't do it earlier
                 // because of concurrent modification exceptions.)
-                for (final DumpArchiveEntry e : queue) {
-                    pending.remove(e.getIno());
-                }
+                queue.forEach(e -> pending.remove(e.getIno()));
             }
 
             final byte[] peekBytes = raw.peek();
@@ -481,8 +477,7 @@ public class DumpArchiveInputStream extends ArchiveInputStream {
         }
 
         while (len > 0) {
-            final int sz = len > readBuf.length - recordOffset
-                ? readBuf.length - recordOffset : len;
+            final int sz = Math.min(len, readBuf.length - recordOffset);
 
             // copy any data we have
             if (recordOffset + sz <= readBuf.length) {
