@@ -22,17 +22,19 @@ import java.io.InputStream;
 import java.security.GeneralSecurityException;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
+
 import javax.crypto.Cipher;
 import javax.crypto.CipherInputStream;
 import javax.crypto.SecretKey;
 import javax.crypto.spec.IvParameterSpec;
 import javax.crypto.spec.SecretKeySpec;
+
 import org.apache.commons.compress.PasswordRequiredException;
 
 class AES256SHA256Decoder extends CoderBase {
     @Override
     InputStream decode(final String archiveName, final InputStream in, final long uncompressedLength,
-            final Coder coder, final byte[] passwordBytes, final int maxMemoryLimitInKb) throws IOException {
+            final Coder coder, final byte[] passwordBytes, final int maxMemoryLimitInKb) {
         return new InputStream() {
             private boolean isInitialized;
             private CipherInputStream cipherInputStream;
