@@ -22,8 +22,8 @@ import java.io.InputStream;
 import java.io.OutputStream;
 
 import org.apache.commons.compress.MemoryLimitException;
-import org.tukaani.xz.FinishableWrapperOutputStream;
 import org.tukaani.xz.FinishableOutputStream;
+import org.tukaani.xz.FinishableWrapperOutputStream;
 import org.tukaani.xz.LZMA2InputStream;
 import org.tukaani.xz.LZMA2Options;
 
@@ -34,7 +34,7 @@ class LZMA2Decoder extends CoderBase {
 
     @Override
     InputStream decode(final String archiveName, final InputStream in, final long uncompressedLength,
-            final Coder coder, final byte[] password, int maxMemoryLimitInKb) throws IOException {
+            final Coder coder, final byte[] password, final int maxMemoryLimitInKb) throws IOException {
         try {
             final int dictionarySize = getDictionarySize(coder);
             final int memoryUsageInKb = LZMA2InputStream.getMemoryUsage(dictionarySize);
