@@ -20,6 +20,7 @@ package org.apache.commons.compress.archivers.zip;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.zip.ZipException;
 
@@ -35,10 +36,10 @@ public class ExtraFieldUtils {
     /**
      * Static registry of known extra fields.
      */
-    private static final Map<ZipShort, Class<?>> implementations;
+    private static final Map<ZipShort, Class<?>> IMPLEMENTATIONS;
 
     static {
-        implementations = new ConcurrentHashMap<>();
+        IMPLEMENTATIONS = new ConcurrentHashMap<>();
         register(AsiExtraField.class);
         register(X5455_ExtendedTimestamp.class);
         register(X7875_NewUnix.class);
@@ -65,13 +66,13 @@ public class ExtraFieldUtils {
     public static void register(final Class<?> c) {
         try {
             final ZipExtraField ze = (ZipExtraField) c.newInstance();
-            implementations.put(ze.getHeaderId(), c);
-        } catch (final ClassCastException cc) {
-            throw new RuntimeException(c + " doesn\'t implement ZipExtraField"); //NOSONAR
-        } catch (final InstantiationException ie) {
-            throw new RuntimeException(c + " is not a concrete class"); //NOSONAR
-        } catch (final IllegalAccessException ie) {
-            throw new RuntimeException(c + "\'s no-arg constructor is not public"); //NOSONAR
+            IMPLEMENTATIONS.put(ze.getHeaderId(), c);
+        } catch (final ClassCastException cc) { // NOSONAR
+            throw new IllegalArgumentException(c + " doesn't implement ZipExtraField"); //NOSONAR
+        } catch (final InstantiationException ie) { // NOSONAR
+            throw new IllegalArgumentException(c + " is not a concrete class"); //NOSONAR
+        } catch (final IllegalAccessException ie) { // NOSONAR
+            throw new IllegalArgumentException(c + "'s no-arg constructor is not public"); //NOSONAR
         }
     }
 
@@ -85,15 +86,33 @@ public class ExtraFieldUtils {
      */
     public static ZipExtraField createExtraField(final ZipShort headerId)
         throws InstantiationException, IllegalAccessException {
-        final Class<?> c = implementations.get(headerId);
-        if (c != null) {
-            return (ZipExtraField) c.newInstance();
+        final ZipExtraField field = createExtraFieldNoDefault(headerId);
+        if (field != null) {
+            return field;
         }
         final UnrecognizedExtraField u = new UnrecognizedExtraField();
         u.setHeaderId(headerId);
         return u;
     }
 
+    /**
+     * Create an instance of the appropriate ExtraField.
+     * @param headerId the header identifier
+     * @return an instance of the appropriate ExtraField or null if
+     * the id is not supported
+     * @throws InstantiationException if unable to instantiate the class
+     * @throws IllegalAccessException if not allowed to instantiate the class
+     * @since 1.19
+     */
+    public static ZipExtraField createExtraFieldNoDefault(final ZipShort headerId)
+        throws InstantiationException, IllegalAccessException {
+        final Class<?> c = IMPLEMENTATIONS.get(headerId);
+        if (c != null) {
+            return (ZipExtraField) c.newInstance();
+        }
+        return null;
+    }
+
     /**
      * Split the array into ExtraFields and populate them with the
      * given data as local file data, throwing an exception if the
@@ -136,64 +155,72 @@ public class ExtraFieldUtils {
     public static ZipExtraField[] parse(final byte[] data, final boolean local,
                                         final UnparseableExtraField onUnparseableData)
         throws ZipException {
+        return parse(data, local, new ExtraFieldParsingBehavior() {
+            @Override
+            public ZipExtraField onUnparseableExtraField(final byte[] data, final int off, final int len, final boolean local,
+                final int claimedLength) throws ZipException {
+                return onUnparseableData.onUnparseableExtraField(data, off, len, local, claimedLength);
+            }
+
+            @Override
+            public ZipExtraField createExtraField(final ZipShort headerId)
+                throws ZipException, InstantiationException, IllegalAccessException {
+                return ExtraFieldUtils.createExtraField(headerId);
+            }
+
+            @Override
+            public ZipExtraField fill(final ZipExtraField field, final byte[] data, final int off, final int len, final boolean local)
+                throws ZipException {
+                return fillExtraField(field, data, off, len, local);
+            }
+        });
+    }
+
+    /**
+     * Split the array into ExtraFields and populate them with the
+     * given data.
+     * @param data an array of bytes
+     * @param parsingBehavior controls parsing of extra fields.
+     * @param local whether data originates from the local file data
+     * or the central directory
+     * @return an array of ExtraFields
+     * @throws ZipException on error
+     *
+     * @since 1.19
+     */
+    public static ZipExtraField[] parse(final byte[] data, final boolean local,
+                                        final ExtraFieldParsingBehavior parsingBehavior)
+        throws ZipException {
         final List<ZipExtraField> v = new ArrayList<>();
         int start = 0;
+        final int dataLength = data.length;
         LOOP:
-        while (start <= data.length - WORD) {
+        while (start <= dataLength - WORD) {
             final ZipShort headerId = new ZipShort(data, start);
             final int length = new ZipShort(data, start + 2).getValue();
-            if (start + WORD + length > data.length) {
-                switch(onUnparseableData.getKey()) {
-                case UnparseableExtraField.THROW_KEY:
-                    throw new ZipException("bad extra field starting at "
-                                           + start + ".  Block length of "
-                                           + length + " bytes exceeds remaining"
-                                           + " data of "
-                                           + (data.length - start - WORD)
-                                           + " bytes.");
-                case UnparseableExtraField.READ_KEY:
-                    final UnparseableExtraFieldData field =
-                        new UnparseableExtraFieldData();
-                    if (local) {
-                        field.parseFromLocalFileData(data, start,
-                                                     data.length - start);
-                    } else {
-                        field.parseFromCentralDirectoryData(data, start,
-                                                            data.length - start);
-                    }
+            if (start + WORD + length > dataLength) {
+                final ZipExtraField field = parsingBehavior.onUnparseableExtraField(data, start, dataLength - start,
+                    local, length);
+                if (field != null) {
                     v.add(field);
-                    //$FALL-THROUGH$
-                case UnparseableExtraField.SKIP_KEY:
-                    // since we cannot parse the data we must assume
-                    // the extra field consumes the whole rest of the
-                    // available data
-                    break LOOP;
-                default:
-                    throw new ZipException("unknown UnparseableExtraField key: "
-                                           + onUnparseableData.getKey());
                 }
+                // since we cannot parse the data we must assume
+                // the extra field consumes the whole rest of the
+                // available data
+                break LOOP;
             }
             try {
-                final ZipExtraField ze = createExtraField(headerId);
-                try {
-                    if (local) {
-                        ze.parseFromLocalFileData(data, start + WORD, length);
-                    } else {
-                        ze.parseFromCentralDirectoryData(data, start + WORD, length);
-                    }
-                } catch (ArrayIndexOutOfBoundsException aiobe) {
-                    throw (ZipException) new ZipException("Failed to parse corrupt ZIP extra field of type "
-                        + Integer.toHexString(headerId.getValue())).initCause(aiobe);
-                }
-                v.add(ze);
+                final ZipExtraField ze = Objects.requireNonNull(parsingBehavior.createExtraField(headerId),
+                    "createExtraField must not return null");
+                v.add(Objects.requireNonNull(parsingBehavior.fill(ze, data, start + WORD, length, local),
+                    "fill must not return null"));
+                start += length + WORD;
             } catch (final InstantiationException | IllegalAccessException ie) {
                 throw (ZipException) new ZipException(ie.getMessage()).initCause(ie);
             }
-            start += length + WORD;
         }
 
-        final ZipExtraField[] result = new ZipExtraField[v.size()];
-        return v.toArray(result);
+        return v.toArray(EMPTY_ZIP_EXTRA_FIELD_ARRAY);
     }
 
     /**
@@ -202,10 +229,11 @@ public class ExtraFieldUtils {
      * @return an array of bytes
      */
     public static byte[] mergeLocalFileDataData(final ZipExtraField[] data) {
-        final boolean lastIsUnparseableHolder = data.length > 0
-            && data[data.length - 1] instanceof UnparseableExtraFieldData;
+        final int dataLength = data.length;
+        final boolean lastIsUnparseableHolder = dataLength > 0
+            && data[dataLength - 1] instanceof UnparseableExtraFieldData;
         final int regularExtraFieldCount =
-            lastIsUnparseableHolder ? data.length - 1 : data.length;
+            lastIsUnparseableHolder ? dataLength - 1 : dataLength;
 
         int sum = WORD * regularExtraFieldCount;
         for (final ZipExtraField element : data) {
@@ -227,7 +255,7 @@ public class ExtraFieldUtils {
             }
         }
         if (lastIsUnparseableHolder) {
-            final byte[] local = data[data.length - 1].getLocalFileDataData();
+            final byte[] local = data[dataLength - 1].getLocalFileDataData();
             if (local != null) {
                 System.arraycopy(local, 0, result, start, local.length);
             }
@@ -241,10 +269,11 @@ public class ExtraFieldUtils {
      * @return an array of bytes
      */
     public static byte[] mergeCentralDirectoryData(final ZipExtraField[] data) {
-        final boolean lastIsUnparseableHolder = data.length > 0
-            && data[data.length - 1] instanceof UnparseableExtraFieldData;
+        final int dataLength = data.length;
+        final boolean lastIsUnparseableHolder = dataLength > 0
+            && data[dataLength - 1] instanceof UnparseableExtraFieldData;
         final int regularExtraFieldCount =
-            lastIsUnparseableHolder ? data.length - 1 : data.length;
+            lastIsUnparseableHolder ? dataLength - 1 : dataLength;
 
         int sum = WORD * regularExtraFieldCount;
         for (final ZipExtraField element : data) {
@@ -258,28 +287,63 @@ public class ExtraFieldUtils {
             System.arraycopy(data[i].getCentralDirectoryLength().getBytes(),
                              0, result, start + 2, 2);
             start += WORD;
-            final byte[] local = data[i].getCentralDirectoryData();
-            if (local != null) {
-                System.arraycopy(local, 0, result, start, local.length);
-                start += local.length;
+            final byte[] central = data[i].getCentralDirectoryData();
+            if (central != null) {
+                System.arraycopy(central, 0, result, start, central.length);
+                start += central.length;
             }
         }
         if (lastIsUnparseableHolder) {
-            final byte[] local = data[data.length - 1].getCentralDirectoryData();
-            if (local != null) {
-                System.arraycopy(local, 0, result, start, local.length);
+            final byte[] central = data[dataLength - 1].getCentralDirectoryData();
+            if (central != null) {
+                System.arraycopy(central, 0, result, start, central.length);
             }
         }
         return result;
     }
 
+    /**
+     * Fills in the extra field data into the given instance.
+     *
+     * <p>Calls {@link ZipExtraField#parseFromCentralDirectoryData} or {@link ZipExtraField#parseFromLocalFileData} internally and wraps any {@link ArrayIndexOutOfBoundsException} thrown into a {@link ZipException}.</p>
+     *
+     * @param ze the extra field instance to fill
+     * @param data the array of extra field data
+     * @param off offset into data where this field's data starts
+     * @param len the length of this field's data
+     * @param local whether the extra field data stems from the local
+     * file header. If this is false then the data is part if the
+     * central directory header extra data.
+     * @return the filled field, will never be {@code null}
+     * @throws ZipException if an error occurs
+     *
+     * @since 1.19
+     */
+    public static ZipExtraField fillExtraField(final ZipExtraField ze, final byte[] data, final int off,
+        final int len, final boolean local) throws ZipException {
+        try {
+            if (local) {
+                ze.parseFromLocalFileData(data, off, len);
+            } else {
+                ze.parseFromCentralDirectoryData(data, off, len);
+            }
+            return ze;
+        } catch (final ArrayIndexOutOfBoundsException aiobe) {
+            throw (ZipException) new ZipException("Failed to parse corrupt ZIP extra field of type "
+                + Integer.toHexString(ze.getHeaderId().getValue())).initCause(aiobe);
+        }
+    }
+
     /**
      * "enum" for the possible actions to take if the extra field
      * cannot be parsed.
      *
+     * <p>This class has been created long before Java 5 and would
+     * have been a real enum ever since.</p>
+     *
      * @since 1.1
      */
-    public static final class UnparseableExtraField {
+    public static final class UnparseableExtraField implements UnparseableExtraFieldBehavior {
         /**
          * Key for "throw an exception" action.
          */
@@ -324,5 +388,34 @@ public class ExtraFieldUtils {
          * @return the key
          */
         public int getKey() { return key; }
+
+        @Override
+        public ZipExtraField onUnparseableExtraField(final byte[] data, final int off, final int len, final boolean local,
+            final int claimedLength) throws ZipException {
+            switch(key) {
+            case THROW_KEY:
+                throw new ZipException("Bad extra field starting at "
+                                       + off + ".  Block length of "
+                                       + claimedLength + " bytes exceeds remaining"
+                                       + " data of "
+                                       + (len - WORD)
+                                       + " bytes.");
+            case READ_KEY:
+                final UnparseableExtraFieldData field = new UnparseableExtraFieldData();
+                if (local) {
+                    field.parseFromLocalFileData(data, off, len);
+                } else {
+                    field.parseFromCentralDirectoryData(data, off, len);
+                }
+                return field;
+            case SKIP_KEY:
+                return null;
+            default:
+                throw new ZipException("Unknown UnparseableExtraField key: " + key);
+            }
+        }
+
     }
+
+    static final ZipExtraField[] EMPTY_ZIP_EXTRA_FIELD_ARRAY = new ZipExtraField[0];
 }
