@@ -69,10 +69,10 @@ public final class GeneralPurposeBit implements Cloneable {
      */
     public static final int UFT8_NAMES_FLAG = 1 << 11;
 
-    private boolean languageEncodingFlag = false;
-    private boolean dataDescriptorFlag = false;
-    private boolean encryptionFlag = false;
-    private boolean strongEncryptionFlag = false;
+    private boolean languageEncodingFlag;
+    private boolean dataDescriptorFlag;
+    private boolean encryptionFlag;
+    private boolean strongEncryptionFlag;
     private int slidingDictionarySize;
     private int numberOfShannonFanoTrees;
 
@@ -181,7 +181,7 @@ public final class GeneralPurposeBit implements Cloneable {
      * @param buf the output buffer
      * @param  offset
      *         The offset within the output buffer of the first byte to be written.
-     *         must be non-negative and no larger than <tt>buf.length-2</tt>
+     *         must be non-negative and no larger than {@code buf.length-2}
      */
     public void encode(final byte[] buf, final int offset) {
                 ZipShort.putShort((dataDescriptorFlag ? DATA_DESCRIPTOR_FLAG : 0)
@@ -239,7 +239,7 @@ public final class GeneralPurposeBit implements Cloneable {
             return super.clone();
         } catch (final CloneNotSupportedException ex) {
             // impossible
-            throw new RuntimeException("GeneralPurposeBit is not Cloneable?", ex); //NOSONAR
+            throw new IllegalStateException("GeneralPurposeBit is not Cloneable?", ex); //NOSONAR
         }
     }
 }
