@@ -21,10 +21,10 @@ package org.apache.commons.compress.archivers.zip;
 /**
  * Info-ZIP Unicode Path Extra Field (0x7075):
  *
- * <p>Stores the UTF-8 version of the file name field as stored in the 
+ * <p>Stores the UTF-8 version of the file name field as stored in the
  * local header and central directory header.</p>
  *
- * @see <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">PKWARE's
+ * @see <a href="https://www.pkware.com/documents/casestudies/APPNOTE.TXT">PKWARE
  * APPNOTE.TXT, section 4.6.9</a>
  *
  * @NotThreadSafe super-class is not thread-safe
@@ -33,34 +33,35 @@ public class UnicodePathExtraField extends AbstractUnicodeExtraField {
 
     public static final ZipShort UPATH_ID = new ZipShort(0x7075);
 
-    public UnicodePathExtraField () { 
+    public UnicodePathExtraField () {
     }
 
     /**
      * Assemble as unicode path extension from the name given as
      * text as well as the encoded bytes actually written to the archive.
-     * 
+     *
      * @param text The file name
      * @param bytes the bytes actually written to the archive
-     * @param off The offset of the encoded filename in <code>bytes</code>.
-     * @param len The length of the encoded filename or comment in
-     * <code>bytes</code>.
+     * @param off The offset of the encoded file name in {@code bytes}.
+     * @param len The length of the encoded file name or comment in
+     * {@code bytes}.
      */
-    public UnicodePathExtraField(String text, byte[] bytes, int off, int len) {
+    public UnicodePathExtraField(final String text, final byte[] bytes, final int off, final int len) {
         super(text, bytes, off, len);
     }
 
     /**
      * Assemble as unicode path extension from the name given as
      * text as well as the encoded bytes actually written to the archive.
-     * 
+     *
      * @param name The file name
      * @param bytes the bytes actually written to the archive
      */
-    public UnicodePathExtraField(String name, byte[] bytes) {
+    public UnicodePathExtraField(final String name, final byte[] bytes) {
         super(name, bytes);
     }
 
+    @Override
     public ZipShort getHeaderId() {
         return UPATH_ID;
     }
