@@ -18,6 +18,7 @@
 
 package org.apache.commons.compress.archivers.zip;
 
+import java.io.Serializable;
 import java.util.zip.ZipException;
 
 /**
@@ -38,7 +39,7 @@ public class UnsupportedZipFeatureException extends ZipException {
      */
     public UnsupportedZipFeatureException(final Feature reason,
                                           final ZipArchiveEntry entry) {
-        super("unsupported feature " + reason +  " used in entry "
+        super("Unsupported feature " + reason +  " used in entry "
               + entry.getName());
         this.reason = reason;
         this.entry = entry;
@@ -53,8 +54,8 @@ public class UnsupportedZipFeatureException extends ZipException {
      */
     public UnsupportedZipFeatureException(final ZipMethod method,
                                           final ZipArchiveEntry entry) {
-        super("unsupported feature method '" + method.name()
-              +  "' used in entry " + entry.getName());
+        super("Unsupported compression method " + entry.getMethod()
+              + " (" + method.name() + ") used in entry " + entry.getName());
         this.reason = Feature.METHOD;
         this.entry = entry;
     }
@@ -67,7 +68,7 @@ public class UnsupportedZipFeatureException extends ZipException {
      * @since 1.5
      */
     public UnsupportedZipFeatureException(final Feature reason) {
-        super("unsupported feature " + reason +  " used in archive.");
+        super("Unsupported feature " + reason +  " used in archive.");
         this.reason = reason;
         this.entry = null;
     }
@@ -92,7 +93,7 @@ public class UnsupportedZipFeatureException extends ZipException {
      * ZIP Features that may or may not be supported.
      * @since 1.1
      */
-    public static class Feature implements java.io.Serializable {
+    public static class Feature implements Serializable {
 
         private static final long serialVersionUID = 4112582948775420359L;
         /**
