@@ -19,20 +19,22 @@
 package org.apache.commons.compress.archivers.zip;
 
 import java.io.Serializable;
+import java.util.Arrays;
 import java.util.Date;
+import java.util.Objects;
 import java.util.zip.ZipException;
 
 /**
  * <p>An extra field that stores additional file and directory timestamp data
  * for zip entries.   Each zip entry can include up to three timestamps
- * (modify, access, create*).  The timestamps are stored as 32 bit unsigned
+ * (modify, access, create*).  The timestamps are stored as 32 bit signed
  * integers representing seconds since UNIX epoch (Jan 1st, 1970, UTC).
  * This field improves on zip's default timestamp granularity, since it
  * allows one to store additional timestamps, and, in addition, the timestamps
- * are stored using per-second granularity (zip's default behaviour can only store
+ * are stored using per-second granularity (zip's default behavior can only store
  * timestamps to the nearest <em>even</em> second).
  * </p><p>
- * Unfortunately, 32 (unsigned) bits can only store dates up to the year 2106,
+ * Unfortunately, 32 (signed) bits can only store dates up to the year 2037,
  * and so this extra field will eventually be obsolete.  Enjoy it while it lasts!
  * </p>
  * <ul>
@@ -45,7 +47,7 @@ import java.util.zip.ZipException;
  * most recent time file/directory was opened
  * (e.g., read from disk).  Many people disable
  * their operating systems from updating this value
- * using the NOATIME mount option to optimize disk behaviour,
+ * using the NOATIME mount option to optimize disk behavior,
  * and thus it's not always reliable.  In those cases
  * it's always equal to modifyTime.
  * </li>
@@ -135,7 +137,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      * Length of the extra field in the local file data - without
      * Header-ID or length specifier.
      *
-     * @return a <code>ZipShort</code> for the length of the data of this extra field
+     * @return a {@code ZipShort} for the length of the data of this extra field
      */
     @Override
     public ZipShort getLocalFileDataLength() {
@@ -154,7 +156,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      * local length, because central cannot contain access or create
      * timestamps.</p>
      *
-     * @return a <code>ZipShort</code> for the length of the data of this extra field
+     * @return a {@code ZipShort} for the length of the data of this extra field
      */
     @Override
     public ZipShort getCentralDirectoryLength() {
@@ -187,7 +189,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
         if (bit2_createTimePresent && createTime != null) {
             data[0] |= CREATE_TIME_BIT;
             System.arraycopy(createTime.getBytes(), 0, data, pos, 4);
-            pos += 4;
+            pos += 4; // NOSONAR - assignment as documentation
         }
         return data;
     }
@@ -200,13 +202,9 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      */
     @Override
     public byte[] getCentralDirectoryData() {
-        final byte[] centralData = new byte[getCentralDirectoryLength().getValue()];
-        final byte[] localData = getLocalFileDataData();
-
         // Truncate out create & access time (last 8 bytes) from
         // the copy of the local data we obtained:
-        System.arraycopy(localData, 0, centralData, 0, centralData.length);
-        return centralData;
+        return Arrays.copyOf(getLocalFileDataData(), getCentralDirectoryLength().getValue());
     }
 
     /**
@@ -222,22 +220,28 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
             final byte[] data, int offset, final int length
     ) throws ZipException {
         reset();
+        if (length < 1) {
+            throw new ZipException("X5455_ExtendedTimestamp too short, only " + length + " bytes");
+        }
         final int len = offset + length;
         setFlags(data[offset++]);
-        if (bit0_modifyTimePresent) {
+        if (bit0_modifyTimePresent && offset + 4 <= len) {
             modifyTime = new ZipLong(data, offset);
             offset += 4;
+        } else {
+            bit0_modifyTimePresent = false;
         }
-
-        // Notice the extra length check in case we are parsing the shorter
-        // central data field (for both access and create timestamps).
         if (bit1_accessTimePresent && offset + 4 <= len) {
             accessTime = new ZipLong(data, offset);
             offset += 4;
+        } else {
+            bit1_accessTimePresent = false;
         }
         if (bit2_createTimePresent && offset + 4 <= len) {
             createTime = new ZipLong(data, offset);
-            offset += 4;
+            offset += 4; // NOSONAR - assignment as documentation
+        } else {
+            bit2_createTimePresent = false;
         }
     }
 
@@ -370,7 +374,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      * @return modify time as java.util.Date or null.
      */
     public Date getModifyJavaTime() {
-        return modifyTime != null ? new Date(modifyTime.getValue() * 1000) : null;
+        return zipLongToDate(modifyTime);
     }
 
     /**
@@ -382,7 +386,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      * @return access time as java.util.Date or null.
      */
     public Date getAccessJavaTime() {
-        return accessTime != null ? new Date(accessTime.getValue() * 1000) : null;
+        return zipLongToDate(accessTime);
     }
 
     /**
@@ -400,7 +404,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
      * @return create time as java.util.Date or null.
      */
     public Date getCreateJavaTime() {
-        return createTime != null ? new Date(createTime.getValue() * 1000) : null;
+        return zipLongToDate(createTime);
     }
 
     /**
@@ -518,12 +522,7 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
     private static ZipLong dateToZipLong(final Date d) {
         if (d == null) { return null; }
 
-        final long TWO_TO_32 = 0x100000000L;
-        final long l = d.getTime() / 1000;
-        if (l >= TWO_TO_32) {
-            throw new IllegalArgumentException("Cannot set an X5455 timestamp larger than 2^32: " + l);
-        }
-        return new ZipLong(l);
+        return unixTimeToZipLong(d.getTime() / 1000);
     }
 
     /**
@@ -566,9 +565,9 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
             // The ZipLong==ZipLong clauses handle the cases where both are null.
             // and only last 3 bits of flags matter.
             return ((flags & 0x07) == (xf.flags & 0x07)) &&
-                    (modifyTime == xf.modifyTime || (modifyTime != null && modifyTime.equals(xf.modifyTime))) &&
-                    (accessTime == xf.accessTime || (accessTime != null && accessTime.equals(xf.accessTime))) &&
-                    (createTime == xf.createTime || (createTime != null && createTime.equals(xf.createTime)));
+                    Objects.equals(modifyTime, xf.modifyTime) &&
+                    Objects.equals(accessTime, xf.accessTime) &&
+                    Objects.equals(createTime, xf.createTime);
         }
         return false;
     }
@@ -590,4 +589,15 @@ public class X5455_ExtendedTimestamp implements ZipExtraField, Cloneable, Serial
         return hc;
     }
 
+    private static Date zipLongToDate(final ZipLong unixTime) {
+        return unixTime != null ? new Date(unixTime.getIntValue() * 1000L) : null;
+    }
+
+    private static ZipLong unixTimeToZipLong(final long l) {
+        if (l < Integer.MIN_VALUE || l > Integer.MAX_VALUE) {
+            throw new IllegalArgumentException("X5455 timestamps must fit in a signed 32 bit integer: " + l);
+        }
+        return new ZipLong(l);
+    }
+
 }
