@@ -18,11 +18,13 @@
  */
 package org.apache.commons.compress.archivers.zip;
 
-import java.util.zip.ZipException;
-
 import static org.apache.commons.compress.archivers.zip.ZipConstants.DWORD;
 import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
 
+import java.util.zip.ZipException;
+
+import org.apache.commons.compress.utils.ByteUtils;
+
 /**
  * Holds size and other extended information for entries that use Zip64
  * features.
@@ -34,7 +36,7 @@ import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
  * <p>The implementation relies on data being read from the local file
  * header and assumes that both size values are always present.</p>
  *
- * @see <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">PKWARE's
+ * @see <a href="https://www.pkware.com/documents/casestudies/APPNOTE.TXT">PKWARE
  * APPNOTE.TXT, section 4.5.3</a>
  *
  * @since 1.2
@@ -47,8 +49,6 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
     private static final String LFH_MUST_HAVE_BOTH_SIZES_MSG =
         "Zip64 extended information must contain"
         + " both size values in the local file header.";
-    private static final byte[] EMPTY = new byte[0];
-
     private ZipEightByteInteger size, compressedSize, relativeHeaderOffset;
     private ZipLong diskStart;
 
@@ -78,8 +78,8 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
      *
      * @throws IllegalArgumentException if size or compressedSize is null
      */
-    public Zip64ExtendedInformationExtraField(ZipEightByteInteger size,
-                                              ZipEightByteInteger compressedSize) {
+    public Zip64ExtendedInformationExtraField(final ZipEightByteInteger size,
+                                              final ZipEightByteInteger compressedSize) {
         this(size, compressedSize, null, null);
     }
 
@@ -88,27 +88,32 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
      *
      * @param size the entry's original size
      * @param compressedSize the entry's compressed size
+     * @param relativeHeaderOffset the entry's offset
+     * @param diskStart the disk start
      *
      * @throws IllegalArgumentException if size or compressedSize is null
      */
-    public Zip64ExtendedInformationExtraField(ZipEightByteInteger size,
-                                              ZipEightByteInteger compressedSize,
-                                              ZipEightByteInteger relativeHeaderOffset,
-                                              ZipLong diskStart) {
+    public Zip64ExtendedInformationExtraField(final ZipEightByteInteger size,
+                                              final ZipEightByteInteger compressedSize,
+                                              final ZipEightByteInteger relativeHeaderOffset,
+                                              final ZipLong diskStart) {
         this.size = size;
         this.compressedSize = compressedSize;
         this.relativeHeaderOffset = relativeHeaderOffset;
         this.diskStart = diskStart;
     }
 
+    @Override
     public ZipShort getHeaderId() {
         return HEADER_ID;
     }
 
+    @Override
     public ZipShort getLocalFileDataLength() {
         return new ZipShort(size != null ? 2 * DWORD : 0);
     }
 
+    @Override
     public ZipShort getCentralDirectoryLength() {
         return new ZipShort((size != null ? DWORD : 0)
                             + (compressedSize != null ? DWORD : 0)
@@ -116,20 +121,22 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
                             + (diskStart != null ? WORD : 0));
     }
 
+    @Override
     public byte[] getLocalFileDataData() {
         if (size != null || compressedSize != null) {
             if (size == null || compressedSize == null) {
                 throw new IllegalArgumentException(LFH_MUST_HAVE_BOTH_SIZES_MSG);
             }
-            byte[] data = new byte[2 * DWORD];
+            final byte[] data = new byte[2 * DWORD];
             addSizes(data);
             return data;
         }
-        return EMPTY;
+        return ByteUtils.EMPTY_BYTE_ARRAY;
     }
 
+    @Override
     public byte[] getCentralDirectoryData() {
-        byte[] data = new byte[getCentralDirectoryLength().getValue()];
+        final byte[] data = new byte[getCentralDirectoryLength().getValue()];
         int off = addSizes(data);
         if (relativeHeaderOffset != null) {
             System.arraycopy(relativeHeaderOffset.getBytes(), 0, data, off, DWORD);
@@ -137,12 +144,13 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
         }
         if (diskStart != null) {
             System.arraycopy(diskStart.getBytes(), 0, data, off, WORD);
-            off += WORD;
+            off += WORD; // NOSONAR - assignment as documentation
         }
         return data;
     }
 
-    public void parseFromLocalFileData(byte[] buffer, int offset, int length)
+    @Override
+    public void parseFromLocalFileData(final byte[] buffer, int offset, final int length)
         throws ZipException {
         if (length == 0) {
             // no local file data at all, may happen if an archive
@@ -166,13 +174,14 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
         }
         if (remaining >= WORD) {
             diskStart = new ZipLong(buffer, offset);
-            offset += WORD;
-            remaining -= WORD;
+            offset += WORD; // NOSONAR - assignment as documentation
+            remaining -= WORD; // NOSONAR - assignment as documentation
         }
     }
 
-    public void parseFromCentralDirectoryData(byte[] buffer, int offset,
-                                              int length)
+    @Override
+    public void parseFromCentralDirectoryData(final byte[] buffer, int offset,
+                                              final int length)
         throws ZipException {
         // store for processing in reparseCentralDirectoryData
         rawCentralDirectoryData = new byte[length];
@@ -205,19 +214,25 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
      * field are optional and must only be present if their corresponding
      * entry inside the central directory contains the correct magic
      * value.</p>
+     *
+     * @param hasUncompressedSize flag to read from central directory
+     * @param hasCompressedSize flag to read from central directory
+     * @param hasRelativeHeaderOffset flag to read from central directory
+     * @param hasDiskStart flag to read from central directory
+     * @throws ZipException on error
      */
-    public void reparseCentralDirectoryData(boolean hasUncompressedSize,
-                                            boolean hasCompressedSize,
-                                            boolean hasRelativeHeaderOffset,
-                                            boolean hasDiskStart)
+    public void reparseCentralDirectoryData(final boolean hasUncompressedSize,
+                                            final boolean hasCompressedSize,
+                                            final boolean hasRelativeHeaderOffset,
+                                            final boolean hasDiskStart)
         throws ZipException {
         if (rawCentralDirectoryData != null) {
-            int expectedLength = (hasUncompressedSize ? DWORD : 0)
+            final int expectedLength = (hasUncompressedSize ? DWORD : 0)
                 + (hasCompressedSize ? DWORD : 0)
                 + (hasRelativeHeaderOffset ? DWORD : 0)
                 + (hasDiskStart ? WORD : 0);
             if (rawCentralDirectoryData.length < expectedLength) {
-                throw new ZipException("central directory zip64 extended"
+                throw new ZipException("Central directory zip64 extended"
                                        + " information extra field's length"
                                        + " doesn't match central directory"
                                        + " data.  Expected length "
@@ -241,13 +256,14 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
             }
             if (hasDiskStart) {
                 diskStart = new ZipLong(rawCentralDirectoryData, offset);
-                offset += WORD;
+                offset += WORD; // NOSONAR - assignment as documentation
             }
         }
     }
 
     /**
      * The uncompressed size stored in this extra field.
+     * @return The uncompressed size stored in this extra field.
      */
     public ZipEightByteInteger getSize() {
         return size;
@@ -255,13 +271,15 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
 
     /**
      * The uncompressed size stored in this extra field.
+     * @param size The uncompressed size stored in this extra field.
      */
-    public void setSize(ZipEightByteInteger size) {
+    public void setSize(final ZipEightByteInteger size) {
         this.size = size;
     }
 
     /**
      * The compressed size stored in this extra field.
+     * @return The compressed size stored in this extra field.
      */
     public ZipEightByteInteger getCompressedSize() {
         return compressedSize;
@@ -269,13 +287,15 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
 
     /**
      * The uncompressed size stored in this extra field.
+     * @param compressedSize The uncompressed size stored in this extra field.
      */
-    public void setCompressedSize(ZipEightByteInteger compressedSize) {
+    public void setCompressedSize(final ZipEightByteInteger compressedSize) {
         this.compressedSize = compressedSize;
     }
 
     /**
      * The relative header offset stored in this extra field.
+     * @return The relative header offset stored in this extra field.
      */
     public ZipEightByteInteger getRelativeHeaderOffset() {
         return relativeHeaderOffset;
@@ -283,13 +303,15 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
 
     /**
      * The relative header offset stored in this extra field.
+     * @param rho The relative header offset stored in this extra field.
      */
-    public void setRelativeHeaderOffset(ZipEightByteInteger rho) {
+    public void setRelativeHeaderOffset(final ZipEightByteInteger rho) {
         relativeHeaderOffset = rho;
     }
 
     /**
      * The disk start number stored in this extra field.
+     * @return The disk start number stored in this extra field.
      */
     public ZipLong getDiskStartNumber() {
         return diskStart;
@@ -297,12 +319,13 @@ public class Zip64ExtendedInformationExtraField implements ZipExtraField {
 
     /**
      * The disk start number stored in this extra field.
+     * @param ds The disk start number stored in this extra field.
      */
-    public void setDiskStartNumber(ZipLong ds) {
+    public void setDiskStartNumber(final ZipLong ds) {
         diskStart = ds;
     }
 
-    private int addSizes(byte[] data) {
+    private int addSizes(final byte[] data) {
         int off = 0;
         if (size != null) {
             System.arraycopy(size.getBytes(), 0, data, 0, DWORD);
