@@ -17,16 +17,23 @@
  */
 package org.apache.commons.compress.archivers.zip;
 
-import org.apache.commons.compress.archivers.ArchiveEntry;
-import org.apache.commons.compress.archivers.EntryStreamOffsets;
-
 import java.io.File;
+import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.LinkOption;
+import java.nio.file.Path;
+import java.nio.file.attribute.FileTime;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.List;
+import java.util.Objects;
 import java.util.zip.ZipException;
 
+import org.apache.commons.compress.archivers.ArchiveEntry;
+import org.apache.commons.compress.archivers.EntryStreamOffsets;
+import org.apache.commons.compress.utils.ByteUtils;
+
 /**
  * Extension that adds better handling of extra fields and provides
  * access to the internal and external file attributes.
@@ -57,8 +64,6 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     public static final int CRC_UNKNOWN = -1;
     private static final int SHORT_MASK = 0xFFFF;
     private static final int SHORT_SHIFT = 16;
-    private static final byte[] EMPTY = new byte[0];
-
     /**
      * Indicates how the name of this entry has been determined.
      * @since 1.16
@@ -126,25 +131,25 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      */
     private long size = SIZE_UNKNOWN;
 
-    private int internalAttributes = 0;
+    private int internalAttributes;
     private int versionRequired;
     private int versionMadeBy;
     private int platform = PLATFORM_FAT;
     private int rawFlag;
-    private long externalAttributes = 0;
-    private int alignment = 0;
+    private long externalAttributes;
+    private int alignment;
     private ZipExtraField[] extraFields;
-    private UnparseableExtraFieldData unparseableExtra = null;
-    private String name = null;
-    private byte[] rawName = null;
+    private UnparseableExtraFieldData unparseableExtra;
+    private String name;
+    private byte[] rawName;
     private GeneralPurposeBit gpb = new GeneralPurposeBit();
-    private static final ZipExtraField[] noExtraFields = new ZipExtraField[0];
     private long localHeaderOffset = OFFSET_UNKNOWN;
     private long dataOffset = OFFSET_UNKNOWN;
-    private boolean isStreamContiguous = false;
+    private boolean isStreamContiguous;
     private NameSource nameSource = NameSource.NAME;
     private CommentSource commentSource = CommentSource.COMMENT;
     private long diskNumberStart;
+    static final ZipArchiveEntry[] EMPTY_ZIP_ARCHIVE_ENTRY_ARRAY = {};
 
     /**
      * Creates a new zip entry with the specified name.
@@ -228,6 +233,39 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         // TODO are there any other fields we can set here?
     }
 
+    /**
+     * Creates a new zip entry taking some information from the given
+     * path and using the provided name.
+     *
+     * <p>The name will be adjusted to end with a forward slash "/" if
+     * the file is a directory.  If the file is not a directory a
+     * potential trailing forward slash will be stripped from the
+     * entry name.</p>
+     * @param inputPath path to create the entry from.
+     * @param entryName name of the entry.
+     * @param options options indicating how symbolic links are handled.
+     * @throws IOException if an I/O error occurs.
+     * @since 1.21
+     */
+    public ZipArchiveEntry(final Path inputPath, final String entryName, final LinkOption... options) throws IOException {
+        this(Files.isDirectory(inputPath, options) && !entryName.endsWith("/") ?
+             entryName + "/" : entryName);
+        if (Files.isRegularFile(inputPath, options)){
+            setSize(Files.size(inputPath));
+        }
+        setTime(Files.getLastModifiedTime(inputPath, options));
+        // TODO are there any other fields we can set here?
+    }
+
+    /**
+     * Sets the modification time of the entry.
+     * @param fileTime the entry modification time.
+     * @since 1.21
+     */
+    public void setTime(final FileTime fileTime) {
+        setTime(fileTime.toMillis());
+    }
+
     /**
      * Overwrite clone.
      * @return a cloned copy of this ZipArchiveEntry
@@ -286,7 +324,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * Sets the internal file attributes.
-     * @param value an <code>int</code> value
+     * @param value an {@code int} value
      */
     public void setInternalAttributes(final int value) {
         internalAttributes = value;
@@ -307,7 +345,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * Sets the external file attributes.
-     * @param value an <code>long</code> value
+     * @param value an {@code long} value
      */
     public void setExternalAttributes(final long value) {
         externalAttributes = value;
@@ -316,7 +354,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     /**
      * Sets Unix permissions in a way that is understood by Info-Zip's
      * unzip command.
-     * @param mode an <code>int</code> value
+     * @param mode an {@code int} value
      */
     public void setUnixMode(final int mode) {
         // CheckStyle:MagicNumberCheck OFF - no point
@@ -363,7 +401,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * Set the platform (UNIX or FAT).
-     * @param platform an <code>int</code> value - 0 is FAT, 3 is UNIX
+     * @param platform an {@code int} value - 0 is FAT, 3 is UNIX
      */
     protected void setPlatform(final int platform) {
         this.platform = platform;
@@ -387,7 +425,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      *      requested alignment, 0 for default.
      * @since 1.14
      */
-    public void setAlignment(int alignment) {
+    public void setAlignment(final int alignment) {
         if ((alignment & (alignment - 1)) != 0 || alignment > 0xffff) {
             throw new IllegalArgumentException("Invalid value for alignment, must be power of two and no bigger than "
                 + 0xffff + " but is " + alignment);
@@ -411,7 +449,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
                 }
             }
         }
-        extraFields = newFields.toArray(noExtraFields);
+        extraFields = newFields.toArray(ExtraFieldUtils.EMPTY_ZIP_EXTRA_FIELD_ARRAY);
         setExtra();
     }
 
@@ -462,14 +500,14 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         if (parsingBehavior == ExtraFieldParsingMode.ONLY_PARSEABLE_LENIENT) {
             return getExtraFields(false);
         }
-        byte[] local = getExtra();
-        List<ZipExtraField> localFields = new ArrayList<>(Arrays.asList(ExtraFieldUtils.parse(local, true,
+        final byte[] local = getExtra();
+        final List<ZipExtraField> localFields = new ArrayList<>(Arrays.asList(ExtraFieldUtils.parse(local, true,
             parsingBehavior)));
-        byte[] central = getCentralDirectoryExtra();
-        List<ZipExtraField> centralFields = new ArrayList<>(Arrays.asList(ExtraFieldUtils.parse(central, false,
+        final byte[] central = getCentralDirectoryExtra();
+        final List<ZipExtraField> centralFields = new ArrayList<>(Arrays.asList(ExtraFieldUtils.parse(central, false,
             parsingBehavior)));
-        List<ZipExtraField> merged = new ArrayList<>();
-        for (ZipExtraField l : localFields) {
+        final List<ZipExtraField> merged = new ArrayList<>();
+        for (final ZipExtraField l : localFields) {
             ZipExtraField c = null;
             if (l instanceof UnparseableExtraFieldData) {
                 c = findUnparseable(centralFields);
@@ -477,7 +515,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
                 c = findMatching(l.getHeaderId(), centralFields);
             }
             if (c != null) {
-                byte[] cd = c.getCentralDirectoryData();
+                final byte[] cd = c.getCentralDirectoryData();
                 if (cd != null && cd.length > 0) {
                     l.parseFromCentralDirectoryData(cd, 0, cd.length);
                 }
@@ -486,12 +524,12 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
             merged.add(l);
         }
         merged.addAll(centralFields);
-        return merged.toArray(noExtraFields);
+        return merged.toArray(ExtraFieldUtils.EMPTY_ZIP_EXTRA_FIELD_ARRAY);
     }
 
     private ZipExtraField[] getParseableExtraFieldsNoCopy() {
         if (extraFields == null) {
-            return noExtraFields;
+            return ExtraFieldUtils.EMPTY_ZIP_EXTRA_FIELD_ARRAY;
         }
         return extraFields;
     }
@@ -520,7 +558,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     }
 
     private ZipExtraField[] getUnparseableOnly() {
-        return unparseableExtra == null ? noExtraFields : new ZipExtraField[] { unparseableExtra };
+        return unparseableExtra == null ? ExtraFieldUtils.EMPTY_ZIP_EXTRA_FIELD_ARRAY : new ZipExtraField[] { unparseableExtra };
     }
 
     private ZipExtraField[] getAllExtraFields() {
@@ -529,22 +567,12 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
             : allExtraFieldsNoCopy;
     }
 
-    private ZipExtraField findUnparseable(List<ZipExtraField> fs) {
-        for (ZipExtraField f : fs) {
-            if (f instanceof UnparseableExtraFieldData) {
-                return f;
-            }
-        }
-        return null;
+    private ZipExtraField findUnparseable(final List<ZipExtraField> fs) {
+        return fs.stream().filter(UnparseableExtraFieldData.class::isInstance).findFirst().orElse(null);
     }
 
-    private ZipExtraField findMatching(ZipShort headerId, List<ZipExtraField> fs) {
-        for (ZipExtraField f : fs) {
-            if (headerId.equals(f.getHeaderId())) {
-                return f;
-            }
-        }
-        return null;
+    private ZipExtraField findMatching(final ZipShort headerId, final List<ZipExtraField> fs) {
+        return fs.stream().filter(f -> headerId.equals(f.getHeaderId())).findFirst().orElse(null);
     }
 
     /**
@@ -558,17 +586,15 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     public void addExtraField(final ZipExtraField ze) {
         if (ze instanceof UnparseableExtraFieldData) {
             unparseableExtra = (UnparseableExtraFieldData) ze;
+        } else if (extraFields == null) {
+            extraFields = new ZipExtraField[]{ ze };
         } else {
-            if (extraFields == null) {
-                extraFields = new ZipExtraField[]{ ze };
-            } else {
-                if (getExtraField(ze.getHeaderId()) != null) {
-                    removeExtraField(ze.getHeaderId());
-                }
-                final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
-                zipExtraFields[zipExtraFields.length - 1] = ze;
-                extraFields = zipExtraFields;
+            if (getExtraField(ze.getHeaderId()) != null) {
+                removeExtraField(ze.getHeaderId());
             }
+            final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
+            zipExtraFields[zipExtraFields.length - 1] = ze;
+            extraFields = zipExtraFields;
         }
         setExtra();
     }
@@ -616,7 +642,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         if (extraFields.length == newResult.size()) {
             throw new java.util.NoSuchElementException();
         }
-        extraFields = newResult.toArray(noExtraFields);
+        extraFields = newResult.toArray(ExtraFieldUtils.EMPTY_ZIP_EXTRA_FIELD_ARRAY);
         setExtra();
     }
 
@@ -670,16 +696,15 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @throws RuntimeException on error
      */
     @Override
-    public void setExtra(final byte[] extra) throws RuntimeException {
-        try {
-            final ZipExtraField[] local = ExtraFieldUtils.parse(extra, true, ExtraFieldParsingMode.BEST_EFFORT);
-            mergeExtraFields(local, true);
-        } catch (final ZipException e) {
-            // actually this is not possible as of Commons Compress 1.1
-            throw new RuntimeException("Error parsing extra fields for entry: " //NOSONAR
-                                       + getName() + " - " + e.getMessage(), e);
-        }
-    }
+	public void setExtra(final byte[] extra) throws RuntimeException {
+		try {
+			mergeExtraFields(ExtraFieldUtils.parse(extra, true, ExtraFieldParsingMode.BEST_EFFORT), true);
+		} catch (final ZipException e) {
+			// actually this is not possible as of Commons Compress 1.1
+			throw new IllegalArgumentException("Error parsing extra fields for entry: " // NOSONAR
+					+ getName() + " - " + e.getMessage(), e);
+		}
+	}
 
     /**
      * Unfortunately {@link java.util.zip.ZipOutputStream
@@ -695,15 +720,14 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * Sets the central directory part of extra fields.
      * @param b an array of bytes to be parsed into extra fields
      */
-    public void setCentralDirectoryExtra(final byte[] b) {
-        try {
-            final ZipExtraField[] central = ExtraFieldUtils.parse(b, false, ExtraFieldParsingMode.BEST_EFFORT);
-            mergeExtraFields(central, false);
-        } catch (final ZipException e) {
-            // actually this is not possible as of Commons Compress 1.19
-            throw new RuntimeException(e.getMessage(), e); //NOSONAR
-        }
-    }
+	public void setCentralDirectoryExtra(final byte[] b) {
+		try {
+			mergeExtraFields(ExtraFieldUtils.parse(b, false, ExtraFieldParsingMode.BEST_EFFORT), false);
+		} catch (final ZipException e) {
+			// actually this is not possible as of Commons Compress 1.19
+			throw new IllegalArgumentException(e.getMessage(), e); // NOSONAR
+		}
+	}
 
     /**
      * Retrieves the extra data for the local file data.
@@ -711,7 +735,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      */
     public byte[] getLocalFileDataExtra() {
         final byte[] extra = getExtra();
-        return extra != null ? extra : EMPTY;
+        return extra != null ? extra : ByteUtils.EMPTY_BYTE_ARRAY;
     }
 
     /**
@@ -740,8 +764,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      */
     @Override
     public boolean isDirectory() {
-        final String n = getName();
-        return n != null && n.endsWith("/");
+        return getName().endsWith("/");
     }
 
     /**
@@ -819,7 +842,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         return this.localHeaderOffset;
     }
 
-    protected void setLocalHeaderOffset(long localHeaderOffset) {
+    protected void setLocalHeaderOffset(final long localHeaderOffset) {
         this.localHeaderOffset = localHeaderOffset;
     }
 
@@ -834,7 +857,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @param dataOffset
      *      new value of data offset.
      */
-    protected void setDataOffset(long dataOffset) {
+    protected void setDataOffset(final long dataOffset) {
         this.dataOffset = dataOffset;
     }
 
@@ -843,7 +866,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         return isStreamContiguous;
     }
 
-    protected void setStreamContiguous(boolean isStreamContiguous) {
+    protected void setStreamContiguous(final boolean isStreamContiguous) {
         this.isStreamContiguous = isStreamContiguous;
     }
 
@@ -856,10 +879,9 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     public int hashCode() {
         // this method has severe consequences on performance. We cannot rely
         // on the super.hashCode() method since super.getName() always return
-        // the empty string in the current implemention (there's no setter)
+        // the empty string in the current implementation (there's no setter)
         // so it is basically draining the performance of a hashmap lookup
-        final String n = getName();
-        return (n == null ? "" : n).hashCode();
+        return getName().hashCode();
     }
 
     /**
@@ -893,7 +915,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
             setExtraFields(f);
         } else {
             for (final ZipExtraField element : f) {
-                ZipExtraField existing;
+                final ZipExtraField existing;
                 if (element instanceof UnparseableExtraFieldData) {
                     existing = unparseableExtra;
                 } else {
@@ -910,7 +932,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
                         } else {
                             existing.parseFromCentralDirectoryData(b, 0, b.length);
                         }
-                    } catch (ZipException ex) {
+                    } catch (final ZipException ex) {
                         // emulate ExtraFieldParsingMode.fillAndMakeUnrecognizedOnError
                         final UnrecognizedExtraField u = new UnrecognizedExtraField();
                         u.setHeaderId(existing.getHeaderId());
@@ -944,7 +966,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     }
 
     /* (non-Javadoc)
-     * @see java.lang.Object#equals(java.lang.Object)
+     * @see Object#equals(Object)
      */
     @Override
     public boolean equals(final Object obj) {
@@ -957,11 +979,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         final ZipArchiveEntry other = (ZipArchiveEntry) obj;
         final String myName = getName();
         final String otherName = other.getName();
-        if (myName == null) {
-            if (otherName != null) {
-                return false;
-            }
-        } else if (!myName.equals(otherName)) {
+        if (!Objects.equals(myName, otherName)) {
             return false;
         }
         String myComment = getComment();
@@ -1058,7 +1076,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @param nameSource source of the name field value
      * @since 1.16
      */
-    public void setNameSource(NameSource nameSource) {
+    public void setNameSource(final NameSource nameSource) {
         this.nameSource = nameSource;
     }
 
@@ -1076,7 +1094,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @param commentSource source of the comment field value
      * @since 1.16
      */
-    public void setCommentSource(CommentSource commentSource) {
+    public void setCommentSource(final CommentSource commentSource) {
         this.commentSource = commentSource;
     }
 
@@ -1096,7 +1114,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @param diskNumberStart the number of the split segment this entry starts at.
      * @since 1.20
      */
-    public void setDiskNumberStart(long diskNumberStart) {
+    public void setDiskNumberStart(final long diskNumberStart) {
         this.diskNumberStart = diskNumberStart;
     }
 
@@ -1109,7 +1127,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     /**
      * How to try to parse the extra fields.
      *
-     * <p>Configures the bahvior for:</p>
+     * <p>Configures the behavior for:</p>
      * <ul>
      *   <li>What shall happen if the extra field content doesn't
      *   follow the recommended pattern of two-byte id followed by a
@@ -1138,7 +1156,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
          */
         BEST_EFFORT(ExtraFieldUtils.UnparseableExtraField.READ) {
             @Override
-            public ZipExtraField fill(ZipExtraField field, byte[] data, int off, int len, boolean local) {
+            public ZipExtraField fill(final ZipExtraField field, final byte[] data, final int off, final int len, final boolean local) {
                 return fillAndMakeUnrecognizedOnError(field, data, off, len, local);
             }
         },
@@ -1167,7 +1185,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
          */
         ONLY_PARSEABLE_LENIENT(ExtraFieldUtils.UnparseableExtraField.SKIP) {
             @Override
-            public ZipExtraField fill(ZipExtraField field, byte[] data, int off, int len, boolean local) {
+            public ZipExtraField fill(final ZipExtraField field, final byte[] data, final int off, final int len, final boolean local) {
                 return fillAndMakeUnrecognizedOnError(field, data, off, len, local);
             }
         },
@@ -1191,13 +1209,13 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
         private final ExtraFieldUtils.UnparseableExtraField onUnparseableData;
 
-        private ExtraFieldParsingMode(ExtraFieldUtils.UnparseableExtraField onUnparseableData) {
+        ExtraFieldParsingMode(final ExtraFieldUtils.UnparseableExtraField onUnparseableData) {
             this.onUnparseableData = onUnparseableData;
         }
 
         @Override
-        public ZipExtraField onUnparseableExtraField(byte[] data, int off, int len, boolean local,
-            int claimedLength) throws ZipException {
+        public ZipExtraField onUnparseableExtraField(final byte[] data, final int off, final int len, final boolean local,
+            final int claimedLength) throws ZipException {
             return onUnparseableData.onUnparseableExtraField(data, off, len, local, claimedLength);
         }
 
@@ -1208,16 +1226,16 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         }
 
         @Override
-        public ZipExtraField fill(ZipExtraField field, byte[] data, int off, int len, boolean local)
+        public ZipExtraField fill(final ZipExtraField field, final byte[] data, final int off, final int len, final boolean local)
             throws ZipException {
             return ExtraFieldUtils.fillExtraField(field, data, off, len, local);
         }
 
-        private static ZipExtraField fillAndMakeUnrecognizedOnError(ZipExtraField field, byte[] data, int off,
-            int len, boolean local) {
+        private static ZipExtraField fillAndMakeUnrecognizedOnError(final ZipExtraField field, final byte[] data, final int off,
+            final int len, final boolean local) {
             try {
                 return ExtraFieldUtils.fillExtraField(field, data, off, len, local);
-            } catch (ZipException ex) {
+            } catch (final ZipException ex) {
                 final UnrecognizedExtraField u = new UnrecognizedExtraField();
                 u.setHeaderId(field.getHeaderId());
                 if (local) {
