@@ -18,6 +18,11 @@
  */
 package org.apache.commons.compress.archivers.zip;
 
+import static org.apache.commons.compress.archivers.zip.ZipConstants.DWORD;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.SHORT;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.EOFException;
@@ -27,6 +32,7 @@ import java.io.PushbackInputStream;
 import java.math.BigInteger;
 import java.nio.ByteBuffer;
 import java.util.Arrays;
+import java.util.Objects;
 import java.util.zip.CRC32;
 import java.util.zip.DataFormatException;
 import java.util.zip.Inflater;
@@ -41,11 +47,6 @@ import org.apache.commons.compress.utils.ArchiveUtils;
 import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.InputStreamStatistics;
 
-import static org.apache.commons.compress.archivers.zip.ZipConstants.DWORD;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.SHORT;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC;
-
 /**
  * Implements an input stream that can read Zip archives.
  *
@@ -90,7 +91,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
     private final boolean useUnicodeExtraFields;
 
     /** Wrapped stream, will always be a PushbackInputStream. */
-    private final InputStream in;
+    private final InputStream inputStream;
 
     /** Inflater used for all deflated entries. */
     private final Inflater inf = new Inflater(true);
@@ -125,7 +126,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
      * https://issues.apache.org/jira/projects/COMPRESS/issues/COMPRESS-555
      * https://github.com/apache/commons-compress/pull/137#issuecomment-690835644
      */
-    private boolean allowStoredEntriesWithDataDescriptor;
+    private final boolean allowStoredEntriesWithDataDescriptor;
 
     /** Count decompressed bytes for current entry */
     private long uncompressedCount;
@@ -247,13 +248,12 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
                                  final String encoding,
                                  final boolean useUnicodeExtraFields,
                                  final boolean allowStoredEntriesWithDataDescriptor,
-                                 final boolean skipSplitSig) {
+            final boolean skipSplitSig) {
         this.encoding = encoding;
         zipEncoding = ZipEncodingHelper.getZipEncoding(encoding);
         this.useUnicodeExtraFields = useUnicodeExtraFields;
-        in = new PushbackInputStream(inputStream, buf.capacity());
-        this.allowStoredEntriesWithDataDescriptor =
-            allowStoredEntriesWithDataDescriptor;
+        this.inputStream = new PushbackInputStream(inputStream, buf.capacity());
+        this.allowStoredEntriesWithDataDescriptor = allowStoredEntriesWithDataDescriptor;
         this.skipSplitSig = skipSplitSig;
         // haven't read anything so far
         buf.limit(0);
@@ -293,7 +293,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
                 skipRemainderOfArchive();
                 return null;
             }
-            throw new ZipException(String.format("Unexpected record signature: 0X%X", sig.getValue()));
+            throw new ZipException(String.format("Unexpected record signature: 0x%x", sig.getValue()));
         }
 
         int off = WORD;
@@ -367,14 +367,14 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         final ZipMethod m = ZipMethod.getMethodByCode(current.entry.getMethod());
         if (current.entry.getCompressedSize() != ArchiveEntry.SIZE_UNKNOWN) {
             if (ZipUtil.canHandleEntryData(current.entry) && m != ZipMethod.STORED && m != ZipMethod.DEFLATED) {
-                final InputStream bis = new BoundedInputStream(in, current.entry.getCompressedSize());
+                final InputStream bis = new BoundedInputStream(inputStream, current.entry.getCompressedSize());
                 switch (m) {
                 case UNSHRINKING:
-                    current.in = new UnshrinkingInputStream(bis);
+                    current.inputStream = new UnshrinkingInputStream(bis);
                     break;
                 case IMPLODING:
                     try {
-                        current.in = new ExplodingInputStream(
+                        current.inputStream = new ExplodingInputStream(
                             current.entry.getGeneralPurposeBit().getSlidingDictionarySize(),
                             current.entry.getGeneralPurposeBit().getNumberOfShannonFanoTrees(),
                             bis);
@@ -383,10 +383,10 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
                     }
                     break;
                 case BZIP2:
-                    current.in = new BZip2CompressorInputStream(bis);
+                    current.inputStream = new BZip2CompressorInputStream(bis);
                     break;
                 case ENHANCED_DEFLATED:
-                    current.in = new Deflate64CompressorInputStream(bis);
+                    current.inputStream = new Deflate64CompressorInputStream(bis);
                     break;
                 default:
                     // we should never get here as all supported methods have been covered
@@ -396,7 +396,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
                 }
             }
         } else if (m == ZipMethod.ENHANCED_DEFLATED) {
-            current.in = new Deflate64CompressorInputStream(in);
+            current.inputStream = new Deflate64CompressorInputStream(inputStream);
         }
 
         entriesRead++;
@@ -530,7 +530,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
                 || current.entry.getMethod() == ZipMethod.IMPLODING.getCode()
                 || current.entry.getMethod() == ZipMethod.ENHANCED_DEFLATED.getCode()
                 || current.entry.getMethod() == ZipMethod.BZIP2.getCode()) {
-            read = current.in.read(buffer, offset, length);
+            read = current.inputStream.read(buffer, offset, length);
         } else {
             throw new UnsupportedZipFeatureException(ZipMethod.getMethodByCode(current.entry.getMethod()),
                     current.entry);
@@ -547,25 +547,21 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
     /**
      * @since 1.17
      */
+    @SuppressWarnings("resource") // checkInputStream() does not allocate.
     @Override
     public long getCompressedCount() {
-        if (current.entry.getMethod() == ZipArchiveOutputStream.STORED) {
+        final int method = current.entry.getMethod();
+        if (method == ZipArchiveOutputStream.STORED) {
             return current.bytesRead;
         }
-        if (current.entry.getMethod() == ZipArchiveOutputStream.DEFLATED) {
+        if (method == ZipArchiveOutputStream.DEFLATED) {
             return getBytesInflated();
         }
-        if (current.entry.getMethod() == ZipMethod.UNSHRINKING.getCode()) {
-            return ((UnshrinkingInputStream) current.in).getCompressedCount();
-        }
-        if (current.entry.getMethod() == ZipMethod.IMPLODING.getCode()) {
-            return ((ExplodingInputStream) current.in).getCompressedCount();
-        }
-        if (current.entry.getMethod() == ZipMethod.ENHANCED_DEFLATED.getCode()) {
-            return ((Deflate64CompressorInputStream) current.in).getCompressedCount();
-        }
-        if (current.entry.getMethod() == ZipMethod.BZIP2.getCode()) {
-            return ((BZip2CompressorInputStream) current.in).getCompressedCount();
+        if (method == ZipMethod.UNSHRINKING.getCode() 
+            || method == ZipMethod.IMPLODING.getCode() 
+            || method == ZipMethod.ENHANCED_DEFLATED.getCode()
+            || method == ZipMethod.BZIP2.getCode()) {
+            return ((InputStreamStatistics) current.checkInputStream()).getCompressedCount();
         }
         return -1;
     }
@@ -597,7 +593,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
 
         if (buf.position() >= buf.limit()) {
             buf.position(0);
-            final int l = in.read(buf.array());
+            final int l = inputStream.read(buf.array());
             if (l == -1) {
                 buf.limit(0);
                 throw new IOException("Truncated ZIP file");
@@ -670,7 +666,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         if (!closed) {
             closed = true;
             try {
-                in.close();
+                inputStream.close();
             } finally {
                 inf.end();
             }
@@ -819,7 +815,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
     private void drainCurrentEntryData() throws IOException {
         long remaining = current.entry.getCompressedSize() - current.bytesReadFromStream;
         while (remaining > 0) {
-            final long n = in.read(buf.array(), 0, (int) Math.min(buf.capacity(), remaining));
+            final long n = inputStream.read(buf.array(), 0, (int) Math.min(buf.capacity(), remaining));
             if (n < 0) {
                 throw new EOFException("Truncated ZIP entry: "
                                        + ArchiveUtils.sanitize(current.entry.getName()));
@@ -858,7 +854,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         if (closed) {
             throw new IOException("The stream is closed");
         }
-        final int length = in.read(buf.array());
+        final int length = inputStream.read(buf.array());
         if (length > 0) {
             buf.limit(length);
             count(buf.limit());
@@ -873,7 +869,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
 
     private void readFully(final byte[] b, final int off) throws IOException {
         final int len = b.length - off;
-        final int count = IOUtils.readFully(in, b, off, len);
+        final int count = IOUtils.readFully(inputStream, b, off, len);
         count(count);
         if (count < len) {
             throw new EOFException();
@@ -881,7 +877,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
     }
 
     private byte[] readRange(int len) throws IOException {
-        final byte[] ret = IOUtils.readRange(in, len);
+        final byte[] ret = IOUtils.readRange(inputStream, len);
         count(ret.length);
         if (ret.length < len) {
             throw new EOFException();
@@ -947,7 +943,6 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
      */
     private boolean supportsDataDescriptorFor(final ZipArchiveEntry entry) {
         return !entry.getGeneralPurposeBit().usesDataDescriptor()
-
                 || (allowStoredEntriesWithDataDescriptor && entry.getMethod() == ZipEntry.STORED)
                 || entry.getMethod() == ZipEntry.DEFLATED
                 || entry.getMethod() == ZipMethod.ENHANCED_DEFLATED.getCode();
@@ -998,7 +993,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         final int ddLen = current.usesZip64 ? WORD + 2 * DWORD : 3 * WORD;
 
         while (!done) {
-            final int r = in.read(buf.array(), off, ZipArchiveOutputStream.BUFFER_SIZE - off);
+            final int r = inputStream.read(buf.array(), off, ZipArchiveOutputStream.BUFFER_SIZE - off);
             if (r <= 0) {
                 // read the whole archive without ever finding a
                 // central directory
@@ -1093,7 +1088,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
     }
 
     private void pushback(final byte[] buf, final int offset, final int length) throws IOException {
-        ((PushbackInputStream) in).unread(buf, offset, length);
+        ((PushbackInputStream) inputStream).unread(buf, offset, length);
         pushedBackBytes(length);
     }
 
@@ -1191,7 +1186,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
             long skipped = 0;
             while (skipped < value) {
                 final long rem = value - skipped;
-                final int x = in.read(skipBuf, 0, (int) (skipBuf.length > rem ? rem : skipBuf.length));
+                final int x = inputStream.read(skipBuf, 0, (int) (skipBuf.length > rem ? rem : skipBuf.length));
                 if (x == -1) {
                     return;
                 }
@@ -1210,7 +1205,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
      * Also updates bytes-read counter.
      */
     private int readOneByte() throws IOException {
-        final int b = in.read();
+        final int b = inputStream.read();
         if (b != -1) {
             count(1);
         }
@@ -1321,7 +1316,12 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         /**
          * The input stream decompressing the data for shrunk and imploded entries.
          */
-        private InputStream in;
+        private InputStream inputStream;
+        
+        @SuppressWarnings("unchecked") // Caller beware
+        private <T extends InputStream> T checkInputStream() {
+            return (T) Objects.requireNonNull(inputStream, "inputStream");
+        }
     }
 
     /**
@@ -1339,7 +1339,7 @@ public class ZipArchiveInputStream extends ArchiveInputStream implements InputSt
         private long pos;
 
         /**
-         * Creates a new <code>BoundedInputStream</code> that wraps the given input
+         * Creates a new {@code BoundedInputStream} that wraps the given input
          * stream and limits it to a certain size.
          *
          * @param in The wrapped input stream
