@@ -17,6 +17,12 @@
  */
 package org.apache.commons.compress.archivers.zip;
 
+import static org.apache.commons.compress.archivers.zip.ZipConstants.DWORD;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.SHORT;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC;
+import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC_SHORT;
+
 import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
 import java.io.Closeable;
@@ -29,12 +35,13 @@ import java.nio.ByteBuffer;
 import java.nio.channels.FileChannel;
 import java.nio.channels.SeekableByteChannel;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.StandardOpenOption;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Comparator;
-import java.util.Enumeration;
 import java.util.EnumSet;
+import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
@@ -51,38 +58,32 @@ import org.apache.commons.compress.utils.CountingInputStream;
 import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.InputStreamStatistics;
 
-import static org.apache.commons.compress.archivers.zip.ZipConstants.DWORD;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.SHORT;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.WORD;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC;
-import static org.apache.commons.compress.archivers.zip.ZipConstants.ZIP64_MAGIC_SHORT;
-
 /**
- * Replacement for <code>java.util.ZipFile</code>.
+ * Replacement for {@code java.util.ZipFile}.
  *
  * <p>This class adds support for file name encodings other than UTF-8
  * (which is required to work on ZIP files created by native zip tools
  * and is able to skip a preamble like the one found in self
  * extracting archives.  Furthermore it returns instances of
- * <code>org.apache.commons.compress.archivers.zip.ZipArchiveEntry</code>
- * instead of <code>java.util.zip.ZipEntry</code>.</p>
+ * {@code org.apache.commons.compress.archivers.zip.ZipArchiveEntry}
+ * instead of {@code java.util.zip.ZipEntry}.</p>
  *
- * <p>It doesn't extend <code>java.util.zip.ZipFile</code> as it would
+ * <p>It doesn't extend {@code java.util.zip.ZipFile} as it would
  * have to reimplement all methods anyway.  Like
- * <code>java.util.ZipFile</code>, it uses SeekableByteChannel under the
+ * {@code java.util.ZipFile}, it uses SeekableByteChannel under the
  * covers and supports compressed and uncompressed entries.  As of
  * Apache Commons Compress 1.3 it also transparently supports Zip64
  * extensions and thus individual entries and archives larger than 4
  * GB or with more than 65536 entries.</p>
  *
  * <p>The method signatures mimic the ones of
- * <code>java.util.zip.ZipFile</code>, with a couple of exceptions:
+ * {@code java.util.zip.ZipFile}, with a couple of exceptions:
  *
  * <ul>
  *   <li>There is no getName method.</li>
  *   <li>entries has been renamed to getEntries.</li>
  *   <li>getEntries and getEntry return
- *   <code>org.apache.commons.compress.archivers.zip.ZipArchiveEntry</code>
+ *   {@code org.apache.commons.compress.archivers.zip.ZipArchiveEntry}
  *   instances.</li>
  *   <li>close is allowed to throw IOException.</li>
  * </ul>
@@ -174,6 +175,16 @@ public class ZipFile implements Closeable {
         this(f, ZipEncodingHelper.UTF8);
     }
 
+    /**
+     * Opens the given path for reading, assuming "UTF8" for file names.
+     * @param path path to the archive.
+     * @throws IOException if an error occurs while reading the file.
+     * @since 1.22
+     */
+    public ZipFile(final Path path) throws IOException {
+        this(path, ZipEncodingHelper.UTF8);
+    }
+
     /**
      * Opens the given file for reading, assuming "UTF8".
      *
@@ -182,7 +193,7 @@ public class ZipFile implements Closeable {
      * @throws IOException if an error occurs while reading the file.
      */
     public ZipFile(final String name) throws IOException {
-        this(new File(name), ZipEncodingHelper.UTF8);
+        this(new File(name).toPath(), ZipEncodingHelper.UTF8);
     }
 
     /**
@@ -196,7 +207,7 @@ public class ZipFile implements Closeable {
      * @throws IOException if an error occurs while reading the file.
      */
     public ZipFile(final String name, final String encoding) throws IOException {
-        this(new File(name), encoding, true);
+        this(new File(name).toPath(), encoding, true);
     }
 
     /**
@@ -210,7 +221,20 @@ public class ZipFile implements Closeable {
      * @throws IOException if an error occurs while reading the file.
      */
     public ZipFile(final File f, final String encoding) throws IOException {
-        this(f, encoding, true);
+        this(f.toPath(), encoding, true);
+    }
+
+    /**
+     * Opens the given path for reading, assuming the specified
+     * encoding for file names and scanning for unicode extra fields.
+     * @param path path to the archive.
+     * @param encoding the encoding to use for file names, use null
+     * for the platform's default encoding
+     * @throws IOException if an error occurs while reading the file.
+     * @since 1.22
+     */
+    public ZipFile(final Path path, final String encoding) throws IOException {
+        this(path, encoding, true);
     }
 
     /**
@@ -227,7 +251,23 @@ public class ZipFile implements Closeable {
      */
     public ZipFile(final File f, final String encoding, final boolean useUnicodeExtraFields)
         throws IOException {
-        this(f, encoding, useUnicodeExtraFields, false);
+        this(f.toPath(), encoding, useUnicodeExtraFields, false);
+    }
+
+    /**
+     * Opens the given path for reading, assuming the specified
+     * encoding for file names.
+     * @param path path to the archive.
+     * @param encoding the encoding to use for file names, use null
+     * for the platform's default encoding
+     * @param useUnicodeExtraFields whether to use InfoZIP Unicode
+     * Extra Fields (if present) to set the file names.
+     * @throws IOException if an error occurs while reading the file.
+     * @since 1.22
+     */
+    public ZipFile(final Path path, final String encoding, final boolean useUnicodeExtraFields)
+            throws IOException {
+        this(path, encoding, useUnicodeExtraFields, false);
     }
 
     /**
@@ -262,6 +302,35 @@ public class ZipFile implements Closeable {
              f.getAbsolutePath(), encoding, useUnicodeExtraFields, true, ignoreLocalFileHeader);
     }
 
+    /**
+     * Opens the given path for reading, assuming the specified
+     * encoding for file names.
+     * <p>By default the central directory record and all local file headers of the archive will be read immediately
+     * which may take a considerable amount of time when the archive is big. The {@code ignoreLocalFileHeader} parameter
+     * can be set to {@code true} which restricts parsing to the central directory. Unfortunately the local file header
+     * may contain information not present inside of the central directory which will not be available when the argument
+     * is set to {@code true}. This includes the content of the Unicode extra field, so setting {@code
+     * ignoreLocalFileHeader} to {@code true} means {@code useUnicodeExtraFields} will be ignored effectively. Also
+     * {@link #getRawInputStream} is always going to return {@code null} if {@code ignoreLocalFileHeader} is {@code
+     * true}.</p>
+     * @param path path to the archive.
+     * @param encoding the encoding to use for file names, use null
+     * for the platform's default encoding
+     * @param useUnicodeExtraFields whether to use InfoZIP Unicode
+     * Extra Fields (if present) to set the file names.
+     * @param ignoreLocalFileHeader whether to ignore information
+     * stored inside the local file header (see the notes in this method's javadoc)
+     * @throws IOException if an error occurs while reading the file.
+     * @since 1.22
+     */
+    public ZipFile(final Path path, final String encoding, final boolean useUnicodeExtraFields,
+                   final boolean ignoreLocalFileHeader)
+            throws IOException {
+        this(Files.newByteChannel(path, EnumSet.of(StandardOpenOption.READ)),
+                path.toAbsolutePath().toString(), encoding, useUnicodeExtraFields,
+                true, ignoreLocalFileHeader);
+    }
+
     /**
      * Opens the given channel for reading, assuming "UTF8" for file names.
      *
@@ -874,10 +943,8 @@ public class ZipFile implements Closeable {
                 && ze.getLocalHeaderOffset() > centralDirectoryStartRelativeOffset) {
                 throw new IOException("local file header for " + ze.getName() + " starts after central directory");
             }
-        } else {
-            if (ze.getLocalHeaderOffset() > centralDirectoryStartOffset) {
-                throw new IOException("local file header for " + ze.getName() + " starts after central directory");
-            }
+        } else if (ze.getLocalHeaderOffset() > centralDirectoryStartOffset) {
+            throw new IOException("local file header for " + ze.getName() + " starts after central directory");
         }
     }
 
@@ -1333,13 +1400,13 @@ public class ZipFile implements Closeable {
     }
 
     private void fillNameMap() {
-        for (final ZipArchiveEntry ze : entries) {
+        entries.forEach(ze -> {
             // entries is filled in populateFromCentralDirectory and
             // never modified
             final String name = ze.getName();
             LinkedList<ZipArchiveEntry> entriesOfThatName = nameMap.computeIfAbsent(name, k -> new LinkedList<>());
             entriesOfThatName.addLast(ze);
-        }
+        });
     }
 
     private int[] setDataOffset(final ZipArchiveEntry ze) throws IOException {
