@@ -20,6 +20,7 @@ package org.apache.commons.compress.compressors.bzip2;
 
 import java.io.IOException;
 import java.io.OutputStream;
+import java.util.Arrays;
 
 import org.apache.commons.compress.compressors.CompressorOutputStream;
 
@@ -244,10 +245,7 @@ public class BZip2CompressorOutputStream extends CompressorOutputStream
                 final int weight_n2 = weight[n2];
                 weight[nNodes] = ((weight_n1 & 0xffffff00)
                                   + (weight_n2 & 0xffffff00))
-                    | (1 + (((weight_n1 & 0x000000ff)
-                             > (weight_n2 & 0x000000ff))
-                            ? (weight_n1 & 0x000000ff)
-                            : (weight_n2 & 0x000000ff)));
+                    | (1 + Math.max(weight_n1 & 0x000000ff, weight_n2 & 0x000000ff));
 
                 parent[nNodes] = -1;
                 nHeap++;
@@ -351,7 +349,7 @@ public class BZip2CompressorOutputStream extends CompressorOutputStream
      * @throws IOException
      *             if an I/O error occurs in the specified stream.
      * @throws NullPointerException
-     *             if <code>out == null</code>.
+     *             if {@code out == null}.
      */
     public BZip2CompressorOutputStream(final OutputStream out)
         throws IOException {
@@ -369,9 +367,9 @@ public class BZip2CompressorOutputStream extends CompressorOutputStream
      * @throws IOException
      *             if an I/O error occurs in the specified stream.
      * @throws IllegalArgumentException
-     *             if <code>(blockSize &lt; 1) || (blockSize &gt; 9)</code>.
+     *             if {@code (blockSize &lt; 1) || (blockSize &gt; 9)}.
      * @throws NullPointerException
-     *             if <code>out == null</code>.
+     *             if {@code out == null}.
      *
      * @see #MIN_BLOCKSIZE
      * @see #MAX_BLOCKSIZE
@@ -1194,14 +1192,12 @@ public class BZip2CompressorOutputStream extends CompressorOutputStream
 
         final int eob = nInUseShadow + 1;
 
-        for (int i = eob; i >= 0; i--) {
-            mtfFreq[i] = 0;
-        }
+        Arrays.fill(mtfFreq, 0, eob + 1, 0);
 
         for (int i = nInUseShadow; --i >= 0;) {
             yy[i] = (byte) i;
         }
-
+        
         int wr = 0;
         int zPend = 0;
 
