@@ -18,6 +18,7 @@
  */
 package org.apache.commons.compress.compressors.bzip2;
 
+import java.util.Arrays;
 import java.util.BitSet;
 
 /**
@@ -28,7 +29,7 @@ import java.util.BitSet;
  * blocksort.c in his libbzip2</p>
  *
  * <p>The Burrows-Wheeler transform is a reversible transform of the
- * original data that is supposed to group similiar bytes close to
+ * original data that is supposed to group similar bytes close to
  * each other.  The idea is to sort all permutations of the input and
  * only keep the last byte of each permutation.  E.g. for "Commons
  * Compress" you'd get:</p>
@@ -36,7 +37,7 @@ import java.util.BitSet;
  * <pre>
  *  CompressCommons
  * Commons Compress
- * CompressCommons 
+ * CompressCommons
  * essCommons Compr
  * mmons CompressCo
  * mons CompressCom
@@ -107,6 +108,8 @@ class BlockSort {
      * I've also removed the now unused randomization code.
      */
 
+    private static final int FTAB_LENGTH = 65537; // 262148 byte
+
     /*
      * LBZ2: If you are ever unlucky/improbable enough to get a stack
      * overflow whilst sorting, increase the following constant and
@@ -118,8 +121,7 @@ class BlockSort {
     private static final int FALLBACK_QSORT_STACK_SIZE = 100;
 
     private static final int STACK_SIZE =
-        QSORT_STACK_SIZE < FALLBACK_QSORT_STACK_SIZE
-        ? FALLBACK_QSORT_STACK_SIZE : QSORT_STACK_SIZE;
+            Math.max(QSORT_STACK_SIZE, FALLBACK_QSORT_STACK_SIZE);
 
     /*
      * Used when sorting. If too many long comparisons happen, we stop sorting,
@@ -137,7 +139,7 @@ class BlockSort {
     private final int[] mainSort_copy = new int[256]; // 1024 byte
     private final boolean[] mainSort_bigDone = new boolean[256]; // 256 byte
 
-    private final int[] ftab = new int[65537]; // 262148 byte
+    private final int[] ftab = new int[FTAB_LENGTH]; // 262148 byte
 
     /**
      * Array instance identical to Data's sfmap, both are used only
@@ -251,7 +253,7 @@ class BlockSort {
      * bucket 'ra' with sort index 5.  The fully sorted order then becomes.
      *
      * fmap = { 5, 3, 0, 4, 1, 2 }
-     * 
+     *
      */
 
     /**
@@ -261,12 +263,12 @@ class BlockSort {
      * @param eclass points from the index of a character inside the
      *        block to the first index in fmap that contains the
      *        bucket of its suffix that is sorted in this step.
-     * @param lo lower boundary of the fmap-interval to be sorted 
-     * @param hi upper boundary of the fmap-interval to be sorted 
+     * @param lo lower boundary of the fmap-interval to be sorted
+     * @param hi upper boundary of the fmap-interval to be sorted
      */
-    private void fallbackSimpleSort(final int[] fmap, 
-                                    final int[] eclass, 
-                                    final int lo, 
+    private void fallbackSimpleSort(final int[] fmap,
+                                    final int[] eclass,
+                                    final int lo,
                                     final int hi) {
         if (lo == hi) {
             return;
@@ -316,10 +318,6 @@ class BlockSort {
         }
     }
 
-    private int fmin(final int a, final int b) {
-        return a < b ? a : b;
-    }
-
     private void fpush(final int sp, final int lz, final int hz) {
         stack_ll[sp] = lz;
         stack_hh[sp] = hz;
@@ -336,12 +334,12 @@ class BlockSort {
      * @param eclass points from the index of a character inside the
      *        block to the first index in fmap that contains the
      *        bucket of its suffix that is sorted in this step.
-     * @param loSt lower boundary of the fmap-interval to be sorted 
-     * @param hiSt upper boundary of the fmap-interval to be sorted 
+     * @param loSt lower boundary of the fmap-interval to be sorted
+     * @param hiSt upper boundary of the fmap-interval to be sorted
      */
-    private void fallbackQSort3(final int[] fmap, 
-                                final int[] eclass, 
-                                final int loSt, 
+    private void fallbackQSort3(final int[] fmap,
+                                final int[] eclass,
+                                final int loSt,
                                 final int hiSt) {
         int lo, unLo, ltLo, hi, unHi, gtHi, n;
 
@@ -359,17 +357,17 @@ class BlockSort {
             }
 
             /* LBZ2: Random partitioning.  Median of 3 sometimes fails to
-               avoid bad cases.  Median of 9 seems to help but 
+               avoid bad cases.  Median of 9 seems to help but
                looks rather expensive.  This too seems to work but
-               is cheaper.  Guidance for the magic constants 
+               is cheaper.  Guidance for the magic constants
                7621 and 32768 is taken from Sedgewick's algorithms
                book, chapter 35.
             */
             r = ((r * 7621) + 1) % 32768;
             final long r3 = r % 3;
-            long med;
+            final long med;
             if (r3 == 0) {
-                med = eclass[fmap[lo]]; 
+                med = eclass[fmap[lo]];
             } else if (r3 == 1) {
                 med = eclass[fmap[(lo + hi) >>> 1]];
             } else {
@@ -387,10 +385,10 @@ class BlockSort {
                         break;
                     }
                     n = eclass[fmap[unLo]] - (int) med;
-                    if (n == 0) { 
-                        fswap(fmap, unLo, ltLo); 
-                        ltLo++; unLo++; 
-                        continue; 
+                    if (n == 0) {
+                        fswap(fmap, unLo, ltLo);
+                        ltLo++; unLo++;
+                        continue;
                     }
                     if (n > 0) {
                         break;
@@ -403,9 +401,9 @@ class BlockSort {
                     }
                     n = eclass[fmap[unHi]] - (int) med;
                     if (n == 0) {
-                        fswap(fmap, unHi, gtHi); 
-                        gtHi--; unHi--; 
-                        continue; 
+                        fswap(fmap, unHi, gtHi);
+                        gtHi--; unHi--;
+                        continue;
                     }
                     if (n < 0) {
                         break;
@@ -422,9 +420,9 @@ class BlockSort {
                 continue;
             }
 
-            n = fmin(ltLo - lo, unLo - ltLo);
+            n = Math.min(ltLo - lo, unLo - ltLo);
             fvswap(fmap, lo, unLo - n, n);
-            int m = fmin(hi - gtHi, gtHi - unHi);
+            int m = Math.min(hi - gtHi, gtHi - unHi);
             fvswap(fmap, unHi + 1, hi - m + 1, m);
 
             n = lo + unLo - ltLo - 1;
@@ -468,13 +466,12 @@ class BlockSort {
      *        partially sorted order
      * @param block the original data
      * @param nblock size of the block
-     * @param off offset of first byte to sort in block
      */
     final void fallbackSort(final int[] fmap, final byte[] block, final int nblock) {
         final int[] ftab = new int[257];
         int H, i, j, k, l, r, cc, cc1;
         int nNotDone;
-        int nBhtab;
+        final int nBhtab;
         final int[] eclass = getEclass();
 
         for (i = 0; i < nblock; i++) {
@@ -511,7 +508,7 @@ class BlockSort {
           --*/
 
         /*-- LBZ2: set sentinel bits for block-end detection --*/
-        for (i = 0; i < 32; i++) { 
+        for (i = 0; i < 32; i++) {
             bhtab.set(nblock + 2 * i);
             bhtab.clear(nblock + 2 * i + 1);
         }
@@ -667,7 +664,6 @@ class BlockSort {
                                                 int x = lastShadow;
                                                 X: while (x > 0) {
                                                     x -= 4;
-
                                                     if (block[i1 + 1] == block[i2 + 1]) {
                                                         if (quadrant[i1] == quadrant[i2]) {
                                                             if (block[i1 + 2] == block[i2 + 2]) {
@@ -684,46 +680,46 @@ class BlockSort {
                                                                                     }
                                                                                     workDoneShadow++;
                                                                                     continue X;
-                                                                                } else if ((quadrant[i1 + 3] > quadrant[i2 + 3])) {
-                                                                                    continue HAMMER;
-                                                                                } else {
-                                                                                    break HAMMER;
                                                                                 }
-                                                                            } else if ((block[i1 + 4] & 0xff) > (block[i2 + 4] & 0xff)) {
-                                                                                continue HAMMER;
-                                                                            } else {
+                                                                                if ((quadrant[i1 + 3] > quadrant[i2 + 3])) {
+                                                                                    continue HAMMER;
+                                                                                }
                                                                                 break HAMMER;
                                                                             }
-                                                                        } else if ((quadrant[i1 + 2] > quadrant[i2 + 2])) {
-                                                                            continue HAMMER;
-                                                                        } else {
+                                                                            if ((block[i1 + 4] & 0xff) > (block[i2 + 4] & 0xff)) {
+                                                                                continue HAMMER;
+                                                                            }
                                                                             break HAMMER;
                                                                         }
-                                                                    } else if ((block[i1 + 3] & 0xff) > (block[i2 + 3] & 0xff)) {
-                                                                        continue HAMMER;
-                                                                    } else {
+                                                                        if ((quadrant[i1 + 2] > quadrant[i2 + 2])) {
+                                                                            continue HAMMER;
+                                                                        }
                                                                         break HAMMER;
                                                                     }
-                                                                } else if ((quadrant[i1 + 1] > quadrant[i2 + 1])) {
-                                                                    continue HAMMER;
-                                                                } else {
+                                                                    if ((block[i1 + 3] & 0xff) > (block[i2 + 3] & 0xff)) {
+                                                                        continue HAMMER;
+                                                                    }
                                                                     break HAMMER;
                                                                 }
-                                                            } else if ((block[i1 + 2] & 0xff) > (block[i2 + 2] & 0xff)) {
-                                                                continue HAMMER;
-                                                            } else {
+                                                                if ((quadrant[i1 + 1] > quadrant[i2 + 1])) {
+                                                                    continue HAMMER;
+                                                                }
                                                                 break HAMMER;
                                                             }
-                                                        } else if ((quadrant[i1] > quadrant[i2])) {
-                                                            continue HAMMER;
-                                                        } else {
+                                                            if ((block[i1 + 2] & 0xff) > (block[i2 + 2] & 0xff)) {
+                                                                continue HAMMER;
+                                                            }
                                                             break HAMMER;
                                                         }
-                                                    } else if ((block[i1 + 1] & 0xff) > (block[i2 + 1] & 0xff)) {
-                                                        continue HAMMER;
-                                                    } else {
+                                                        if ((quadrant[i1] > quadrant[i2])) {
+                                                            continue HAMMER;
+                                                        }
                                                         break HAMMER;
                                                     }
+                                                    if ((block[i1 + 1] & 0xff) > (block[i2 + 1] & 0xff)) {
+                                                        continue HAMMER;
+                                                    }
+                                                    break HAMMER;
 
                                                 }
                                                 break HAMMER;
@@ -732,31 +728,31 @@ class BlockSort {
                                                 continue HAMMER;
                                             }
                                             break HAMMER;
-                                        } else if ((block[i1 + 5] & 0xff) > (block[i2 + 5] & 0xff)) {
-                                            continue HAMMER;
-                                        } else {
-                                            break HAMMER;
                                         }
-                                    } else if ((block[i1 + 4] & 0xff) > (block[i2 + 4] & 0xff)) {
-                                        continue HAMMER;
-                                    } else {
+                                        if ((block[i1 + 5] & 0xff) > (block[i2 + 5] & 0xff)) {
+                                            continue HAMMER;
+                                        }
                                         break HAMMER;
                                     }
-                                } else if ((block[i1 + 3] & 0xff) > (block[i2 + 3] & 0xff)) {
-                                    continue HAMMER;
-                                } else {
+                                    if ((block[i1 + 4] & 0xff) > (block[i2 + 4] & 0xff)) {
+                                        continue HAMMER;
+                                    }
                                     break HAMMER;
                                 }
-                            } else if ((block[i1 + 2] & 0xff) > (block[i2 + 2] & 0xff)) {
-                                continue HAMMER;
-                            } else {
+                                if ((block[i1 + 3] & 0xff) > (block[i2 + 3] & 0xff)) {
+                                    continue HAMMER;
+                                }
                                 break HAMMER;
                             }
-                        } else if ((block[i1 + 1] & 0xff) > (block[i2 + 1] & 0xff)) {
-                            continue HAMMER;
-                        } else {
+                            if ((block[i1 + 2] & 0xff) > (block[i2 + 2] & 0xff)) {
+                                continue HAMMER;
+                            }
                             break HAMMER;
                         }
+                        if ((block[i1 + 1] & 0xff) > (block[i2 + 1] & 0xff)) {
+                            continue HAMMER;
+                        }
+                        break HAMMER;
 
                     } // HAMMER
                     // end inline mainGTU
@@ -792,7 +788,7 @@ class BlockSort {
         }
     }
 
-    private static byte med3(final byte a, final byte b, final byte c) {
+    private static int med3(final int a, final int b, final int c) {
         return (a < b) ? (b < c ? b : a < c ? c : a) : (b > c ? b : a > c ? c
                                                         : a);
     }
@@ -828,8 +824,9 @@ class BlockSort {
                 }
             } else {
                 final int d1 = d + 1;
-                final int med = med3(block[fmap[lo] + d1],
-                                     block[fmap[hi] + d1], block[fmap[(lo + hi) >>> 1] + d1]) & 0xff;
+                final int med = med3(block[fmap[lo] + d1] & 0xff,
+                                     block[fmap[hi] + d1] & 0xff,
+                                     block[fmap[(lo + hi) >>> 1] + d1] & 0xff);
 
                 int unLo = lo;
                 int unHi = hi;
@@ -865,13 +862,12 @@ class BlockSort {
                         }
                     }
 
-                    if (unLo <= unHi) {
-                        final int temp = fmap[unLo];
-                        fmap[unLo++] = fmap[unHi];
-                        fmap[unHi--] = temp;
-                    } else {
+                    if (unLo > unHi) {
                         break;
                     }
+                    final int temp = fmap[unLo];
+                    fmap[unLo++] = fmap[unHi];
+                    fmap[unHi--] = temp;
                 }
 
                 if (gtHi < ltLo) {
@@ -880,11 +876,9 @@ class BlockSort {
                     stack_dd[sp] = d1;
                     sp++;
                 } else {
-                    int n = ((ltLo - lo) < (unLo - ltLo)) ? (ltLo - lo)
-                        : (unLo - ltLo);
+                    int n = Math.min(ltLo - lo, unLo - ltLo);
                     vswap(fmap, lo, unLo - n, n);
-                    int m = ((hi - gtHi) < (gtHi - unHi)) ? (hi - gtHi)
-                        : (gtHi - unHi);
+                    int m = Math.min(hi - gtHi, gtHi - unHi);
                     vswap(fmap, unLo, hi - m + 1, m);
 
                     n = lo + unLo - ltLo - 1;
@@ -925,9 +919,7 @@ class BlockSort {
         final boolean firstAttemptShadow = this.firstAttempt;
 
         // LBZ2: Set up the 2-byte frequency table
-        for (int i = 65537; --i >= 0;) {
-            ftab[i] = 0;
-        }
+        Arrays.fill(ftab, 0);
 
         /*
          * In the various block-sized structures, live data runs from 0 to
