@@ -18,21 +18,22 @@
  */
 package org.apache.commons.compress.compressors.gzip;
 
+import static java.nio.charset.StandardCharsets.ISO_8859_1;
+
+import java.io.BufferedInputStream;
 import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.EOFException;
-import java.io.InputStream;
 import java.io.DataInput;
 import java.io.DataInputStream;
-import java.io.BufferedInputStream;
+import java.io.EOFException;
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.zip.CRC32;
 import java.util.zip.DataFormatException;
 import java.util.zip.Deflater;
 import java.util.zip.Inflater;
-import java.util.zip.CRC32;
 
 import org.apache.commons.compress.compressors.CompressorInputStream;
 import org.apache.commons.compress.utils.ByteUtils;
-import org.apache.commons.compress.utils.CharsetNames;
 import org.apache.commons.compress.utils.CountingInputStream;
 import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.InputStreamStatistics;
@@ -52,7 +53,7 @@ import org.apache.commons.compress.utils.InputStreamStatistics;
  * </p>
  *
  * <p>
- * Instead of using <code>GZIPInputStream</code>, this class has its own .gz
+ * Instead of using {@code GZIPInputStream}, this class has its own .gz
  * container format decoder. The actual decompression is done with
  * {@link java.util.zip.Inflater}.
  * </p>
@@ -106,7 +107,7 @@ public class GzipCompressorInputStream extends CompressorInputStream
     private final CRC32 crc = new CRC32();
 
     // True once everything has been decompressed
-    private boolean endReached = false;
+    private boolean endReached;
 
     // used in no-arg read method
     private final byte[] oneByte = new byte[1];
@@ -118,7 +119,7 @@ public class GzipCompressorInputStream extends CompressorInputStream
      * from the specified input stream.
      * <p>
      * This is equivalent to
-     * <code>GzipCompressorInputStream(inputStream, false)</code> and thus
+     * {@code GzipCompressorInputStream(inputStream, false)} and thus
      * will not decompress concatenated .gz files.
      *
      * @param inputStream  the InputStream from which this object should
@@ -135,12 +136,12 @@ public class GzipCompressorInputStream extends CompressorInputStream
      * Constructs a new input stream that decompresses gzip-compressed data
      * from the specified input stream.
      * <p>
-     * If <code>decompressConcatenated</code> is {@code false}:
+     * If {@code decompressConcatenated} is {@code false}:
      * This decompressor might read more input than it will actually use.
-     * If <code>inputStream</code> supports <code>mark</code> and
-     * <code>reset</code>, then the input position will be adjusted
+     * If {@code inputStream} supports {@code mark} and
+     * {@code reset}, then the input position will be adjusted
      * so that it is right after the last byte of the compressed stream.
-     * If <code>mark</code> isn't supported, the input position will be
+     * If {@code mark} isn't supported, the input position will be
      * undefined.
      *
      * @param inputStream  the InputStream from which this object should
@@ -238,14 +239,12 @@ public class GzipCompressorInputStream extends CompressorInputStream
 
         // Original file name
         if ((flg & FNAME) != 0) {
-            parameters.setFilename(new String(readToNull(inData),
-                                              CharsetNames.ISO_8859_1));
+            parameters.setFilename(new String(readToNull(inData), ISO_8859_1));
         }
 
         // Comment
         if ((flg & FCOMMENT) != 0) {
-            parameters.setComment(new String(readToNull(inData),
-                                             CharsetNames.ISO_8859_1));
+            parameters.setComment(new String(readToNull(inData), ISO_8859_1));
         }
 
         // Header "CRC16" which is actually a truncated CRC32 (which isn't
@@ -309,7 +308,7 @@ public class GzipCompressorInputStream extends CompressorInputStream
                 inf.setInput(buf, 0, bufUsed);
             }
 
-            int ret;
+            final int ret;
             try {
                 ret = inf.inflate(b, off, len);
             } catch (final DataFormatException e) { // NOSONAR
