@@ -19,6 +19,7 @@
 
 package org.apache.commons.compress.compressors.gzip;
 
+import java.io.OutputStream;
 import java.util.zip.Deflater;
 
 /**
@@ -33,6 +34,7 @@ public class GzipParameters {
     private String filename;
     private String comment;
     private int operatingSystem = 255; // Unknown OS by default
+    private int bufferSize = 512;
 
     public int getCompressionLevel() {
         return compressionLevel;
@@ -74,10 +76,10 @@ public class GzipParameters {
     /**
      * Sets the name of the compressed file.
      *
-     * @param filename the name of the file without the directory path
+     * @param fileName the name of the file without the directory path
      */
-    public void setFilename(final String filename) {
-        this.filename = filename;
+    public void setFilename(final String fileName) {
+        this.filename = fileName;
     }
 
     public String getComment() {
@@ -96,18 +98,18 @@ public class GzipParameters {
      * Sets the operating system on which the compression took place.
      * The defined values are:
      * <ul>
-     *   <li>0: FAT filesystem (MS-DOS, OS/2, NT/Win32)</li>
+     *   <li>0: FAT file system (MS-DOS, OS/2, NT/Win32)</li>
      *   <li>1: Amiga</li>
      *   <li>2: VMS (or OpenVMS)</li>
      *   <li>3: Unix</li>
      *   <li>4: VM/CMS</li>
      *   <li>5: Atari TOS</li>
-     *   <li>6: HPFS filesystem (OS/2, NT)</li>
+     *   <li>6: HPFS file system (OS/2, NT)</li>
      *   <li>7: Macintosh</li>
      *   <li>8: Z-System</li>
      *   <li>9: CP/M</li>
      *   <li>10: TOPS-20</li>
-     *   <li>11: NTFS filesystem (NT)</li>
+     *   <li>11: NTFS file system (NT)</li>
      *   <li>12: QDOS</li>
      *   <li>13: Acorn RISCOS</li>
      *   <li>255: Unknown</li>
@@ -118,4 +120,28 @@ public class GzipParameters {
     public void setOperatingSystem(final int operatingSystem) {
         this.operatingSystem = operatingSystem;
     }
+
+    /**
+     * Gets size of the buffer used to retrieve compressed data.
+     * @return The size of the buffer used to retrieve compressed data.
+     * @since 1.21
+     * @see #setBufferSize(int)
+     */
+    public int getBufferSize() {
+        return this.bufferSize;
+    }
+
+    /**
+     * Sets size of the buffer used to retrieve compressed data from
+     * {@link Deflater} and write to underlying {@link OutputStream}.
+     *
+     * @param bufferSize the bufferSize to set. Must be a positive value.
+     * @since 1.21
+     */
+    public void setBufferSize(int bufferSize) {
+        if (bufferSize <= 0) {
+            throw new IllegalArgumentException("invalid buffer size: " + bufferSize);
+        }
+        this.bufferSize = bufferSize;
+    }
 }
