@@ -27,9 +27,9 @@ import java.util.Objects;
  *
  * <p>Most LZ77 derived algorithms split input data into blocks of
  * uncompressed data (called literal blocks) and back-references
- * (pairs of offsets and lengths) that state "add <code>length</code>
+ * (pairs of offsets and lengths) that state "add {@code length}
  * bytes that are the same as those already written starting
- * <code>offset</code> bytes before the current position. The details
+ * {@code offset} bytes before the current position. The details
  * of how those blocks and back-references are encoded are quite
  * different between the algorithms and some algorithms perform
  * additional steps (Huffman encoding in the case of DEFLATE for
@@ -47,7 +47,7 @@ import java.util.Objects;
  * talk about it :-), LZSS would likely be closer to the truth but
  * LZ77 has become the synonym for a whole family of algorithms.</p>
  *
- * <p>The API consists of a compressor that is fed <code>byte</code>s
+ * <p>The API consists of a compressor that is fed {@code byte}s
  * and emits {@link Block}s to a registered callback where the blocks
  * represent either {@link LiteralBlock literal blocks}, {@link
  * BackReference back-references} or {@link EOD end of data
@@ -58,24 +58,24 @@ import java.util.Objects;
  * <p>Several parameters influence the outcome of the "compression":</p>
  * <dl>
  *
- *  <dt><code>windowSize</code></dt> <dd>the size of the sliding
+ *  <dt>{@code windowSize}</dt> <dd>the size of the sliding
  *  window, must be a power of two - this determines the maximum
  *  offset a back-reference can take. The compressor maintains a
- *  buffer of twice of <code>windowSize</code> - real world values are
+ *  buffer of twice of {@code windowSize} - real world values are
  *  in the area of 32k.</dd>
  *
- *  <dt><code>minBackReferenceLength</code></dt>
+ *  <dt>{@code minBackReferenceLength}</dt>
  *  <dd>Minimal length of a back-reference found. A true minimum of 3 is
- *  hard-coded inside of this implemention but bigger lengths can be
+ *  hard-coded inside of this implementation but bigger lengths can be
  *  configured.</dd>
  *
- *  <dt><code>maxBackReferenceLength</code></dt>
+ *  <dt>{@code maxBackReferenceLength}</dt>
  *  <dd>Maximal length of a back-reference found.</dd>
  *
- *  <dt><code>maxOffset</code></dt>
+ *  <dt>{@code maxOffset}</dt>
  *  <dd>Maximal offset of a back-reference.</dd>
  *
- *  <dt><code>maxLiteralLength</code></dt>
+ *  <dt>{@code maxLiteralLength}</dt>
  *  <dd>Maximal length of a literal block.</dd>
  * </dl>
  *
@@ -112,7 +112,7 @@ public class LZ77Compressor {
     public static final class LiteralBlock extends Block {
         private final byte[] data;
         private final int offset, length;
-        public LiteralBlock(byte[] data, int offset, int length) {
+        public LiteralBlock(final byte[] data, final int offset, final int length) {
             this.data = data;
             this.offset = offset;
             this.length = length;
@@ -156,7 +156,7 @@ public class LZ77Compressor {
      */
     public static final class BackReference extends Block {
         private final int offset, length;
-        public BackReference(int offset, int length) {
+        public BackReference(final int offset, final int length) {
             this.offset = offset;
             this.length = length;
         }
@@ -231,34 +231,34 @@ public class LZ77Compressor {
     // bit mask used when indexing into prev
     private final int wMask;
 
-    private boolean initialized = false;
+    private boolean initialized;
     // the position inside of window that shall be encoded right now
     private int currentPosition;
     // the number of bytes available to compress including the one at
     // currentPosition
-    private int lookahead = 0;
+    private int lookahead;
     // the hash of the three bytes stating at the current position
-    private int insertHash = 0;
+    private int insertHash;
     // the position inside of the window where the current literal
     // block starts (in case we are inside of a literal block).
-    private int blockStart = 0;
+    private int blockStart;
     // position of the current match
     private int matchStart = NO_MATCH;
     // number of missed insertString calls for the up to three last
     // bytes of the last match that can only be performed once more
     // data has been read
-    private int missedInserts = 0;
+    private int missedInserts;
 
     /**
      * Initializes a compressor with parameters and a callback.
      * @param params the parameters
      * @param callback the callback
-     * @throws NullPointerException if either parameter is <code>null</code>
+     * @throws NullPointerException if either parameter is {@code null}
      */
-    public LZ77Compressor(Parameters params, Callback callback) {
+    public LZ77Compressor(final Parameters params, final Callback callback) {
         Objects.requireNonNull(params, "params");
         Objects.requireNonNull(callback, "callback");
-        
+
         this.params = params;
         this.callback = callback;
 
@@ -277,7 +277,7 @@ public class LZ77Compressor {
      * @param data the data to compress - must not be null
      * @throws IOException if the callback throws an exception
      */
-    public void compress(byte[] data) throws IOException {
+    public void compress(final byte[] data) throws IOException {
         compress(data, 0, data.length);
     }
 
@@ -290,7 +290,7 @@ public class LZ77Compressor {
      * @param len the number of bytes to compress
      * @throws IOException if the callback throws an exception
      */
-    public void compress(byte[] data, int off, int len) throws IOException {
+    public void compress(final byte[] data, int off, int len) throws IOException {
         final int wSize = params.getWindowSize();
         while (len > wSize) { // chop into windowSize sized chunks
             doCompress(data, off, wSize);
@@ -330,7 +330,7 @@ public class LZ77Compressor {
      * @param data the data to fill the window with.
      * @throws IllegalStateException if the compressor has already started to accept data
      */
-    public void prefill(byte[] data) {
+    public void prefill(final byte[] data) {
         if (currentPosition != 0 || lookahead != 0) {
             throw new IllegalStateException("The compressor has already started to accept data, can't prefill anymore");
         }
@@ -365,14 +365,14 @@ public class LZ77Compressor {
      * <p>The hash is shifted by five bits on each update so all
      * effects of A have been swapped after the third update.</p>
      */
-    private int nextHash(int oldHash, byte nextByte) {
+    private int nextHash(final int oldHash, final byte nextByte) {
         final int nextVal = nextByte & 0xFF;
         return ((oldHash << H_SHIFT) ^ nextVal) & HASH_MASK;
     }
 
     // performs the actual algorithm with the pre-condition len <= windowSize
-    private void doCompress(byte[] data, int off, int len) throws IOException {
-        int spaceLeft = window.length - currentPosition - lookahead;
+    private void doCompress(final byte[] data, final int off, final int len) throws IOException {
+        final int spaceLeft = window.length - currentPosition - lookahead;
         if (len > spaceLeft) {
             slide();
         }
@@ -397,11 +397,11 @@ public class LZ77Compressor {
         matchStart -= wSize;
         blockStart -= wSize;
         for (int i = 0; i < HASH_SIZE; i++) {
-            int h = head[i];
+            final int h = head[i];
             head[i] = h >= wSize ? h - wSize : NO_MATCH;
         }
         for (int i = 0; i < wSize; i++) {
-            int p = prev[i];
+            final int p = prev[i];
             prev[i] = p >= wSize ? p - wSize : NO_MATCH;
         }
     }
@@ -421,7 +421,7 @@ public class LZ77Compressor {
         while (lookahead >= minMatch) {
             catchUpMissedInserts();
             int matchLength = 0;
-            int hashHead = insertString(currentPosition);
+            final int hashHead = insertString(currentPosition);
             if (hashHead != NO_MATCH && hashHead - currentPosition <= params.getMaxOffset()) {
                 // sets matchStart as a side effect
                 matchLength = longestMatch(hashHead);
@@ -458,12 +458,12 @@ public class LZ77Compressor {
      * Inserts the current three byte sequence into the dictionary and
      * returns the previous head of the hash-chain.
      *
-     * <p>Updates <code>insertHash</code> and <code>prev</code> as a
+     * <p>Updates {@code insertHash} and {@code prev} as a
      * side effect.</p>
      */
-    private int insertString(int pos) {
+    private int insertString(final int pos) {
         insertHash = nextHash(insertHash, window[pos - 1 + NUMBER_OF_BYTES_IN_HASH]);
-        int hashHead = head[insertHash];
+        final int hashHead = head[insertHash];
         prev[pos & wMask] = hashHead;
         head[insertHash] = pos;
         return hashHead;
@@ -476,7 +476,7 @@ public class LZ77Compressor {
 
         lookahead--;
         currentPosition++;
-        int hashHead = insertString(currentPosition);
+        final int hashHead = insertString(currentPosition);
         final int prevHashHead = prev[currentPosition & wMask];
         int matchLength = longestMatch(hashHead);
 
@@ -494,7 +494,7 @@ public class LZ77Compressor {
         return matchLength;
     }
 
-    private void insertStringsInMatch(int matchLength) {
+    private void insertStringsInMatch(final int matchLength) {
         // inserts strings contained in current match
         // insertString inserts the byte 2 bytes after position, which may not yet be available -> missedInserts
         final int stop = Math.min(matchLength - 1, lookahead - NUMBER_OF_BYTES_IN_HASH);
@@ -511,7 +511,7 @@ public class LZ77Compressor {
         }
     }
 
-    private void flushBackReference(int matchLength) throws IOException {
+    private void flushBackReference(final int matchLength) throws IOException {
         callback.accept(new BackReference(currentPosition - matchStart, matchLength));
     }
 
