@@ -23,19 +23,18 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.util.Map;
 import java.util.jar.JarInputStream;
-import java.util.jar.Pack200;
 
 import org.apache.commons.compress.compressors.CompressorOutputStream;
-import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.compress.java.util.jar.Pack200;
 
 /**
  * An output stream that compresses using the Pack200 format.
- * 
+ *
  * @NotThreadSafe
  * @since 1.3
  */
 public class Pack200CompressorOutputStream extends CompressorOutputStream {
-    private boolean finished = false;
+    private boolean finished;
     private final OutputStream originalOutput;
     private final StreamBridge streamBridge;
     private final Map<String, String> properties;
@@ -43,6 +42,9 @@ public class Pack200CompressorOutputStream extends CompressorOutputStream {
     /**
      * Compresses the given stream, caching the compressed data in
      * memory.
+     *
+     * @param out the stream to write to
+     * @throws IOException if writing fails
      */
     public Pack200CompressorOutputStream(final OutputStream out)
         throws IOException {
@@ -52,6 +54,10 @@ public class Pack200CompressorOutputStream extends CompressorOutputStream {
     /**
      * Compresses the given stream using the given strategy to cache
      * the results.
+     *
+     * @param out the stream to write to
+     * @param mode the strategy to use
+     * @throws IOException if writing fails
      */
     public Pack200CompressorOutputStream(final OutputStream out,
                                          final Pack200Strategy mode)
@@ -62,6 +68,10 @@ public class Pack200CompressorOutputStream extends CompressorOutputStream {
     /**
      * Compresses the given stream, caching the compressed data in
      * memory and using the given properties.
+     *
+     * @param out the stream to write to
+     * @param props Pack200 properties to use
+     * @throws IOException if writing fails
      */
     public Pack200CompressorOutputStream(final OutputStream out,
                                          final Map<String, String> props)
@@ -72,6 +82,11 @@ public class Pack200CompressorOutputStream extends CompressorOutputStream {
     /**
      * Compresses the given stream using the given strategy to cache
      * the results and the given properties.
+     *
+     * @param out the stream to write to
+     * @param mode the strategy to use
+     * @param props Pack200 properties to use
+     * @throws IOException if writing fails
      */
     public Pack200CompressorOutputStream(final OutputStream out,
                                          final Pack200Strategy mode,
@@ -83,47 +98,42 @@ public class Pack200CompressorOutputStream extends CompressorOutputStream {
     }
 
     @Override
-    public void write(int b) throws IOException {
+    public void write(final int b) throws IOException {
         streamBridge.write(b);
     }
 
     @Override
-    public void write(byte[] b) throws IOException {
+    public void write(final byte[] b) throws IOException {
         streamBridge.write(b);
     }
 
     @Override
-    public void write(byte[] b, int from, int length) throws IOException {
+    public void write(final byte[] b, final int from, final int length) throws IOException {
         streamBridge.write(b, from, length);
     }
 
     @Override
     public void close() throws IOException {
-        finish();
         try {
-            streamBridge.stop();
+            finish();
         } finally {
-            originalOutput.close();
+            try {
+                streamBridge.stop();
+            } finally {
+                originalOutput.close();
+            }
         }
     }
 
     public void finish() throws IOException {
         if (!finished) {
             finished = true;
-            Pack200.Packer p = Pack200.newPacker();
+            final Pack200.Packer p = Pack200.newPacker();
             if (properties != null) {
                 p.properties().putAll(properties);
             }
-            JarInputStream ji = null;
-            boolean success = false;
-            try {
-                p.pack(ji = new JarInputStream(streamBridge.getInput()),
-                       originalOutput);
-                success = true;
-            } finally {
-                if (!success) {
-                    IOUtils.closeQuietly(ji);
-                }
+            try (JarInputStream ji = new JarInputStream(streamBridge.getInput())) {
+                p.pack(ji, originalOutput);
             }
         }
     }
