@@ -55,7 +55,7 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
     /** Current state of the stream */
     private State state = State.NO_BLOCK;
 
-    private boolean endReached = false;
+    private boolean endReached;
 
     /**
      * Constructor using the default buffer size of 32k.
@@ -78,6 +78,7 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
      *            The block size used in compression
      *
      * @throws IOException if reading fails
+     * @throws IllegalArgumentException if blockSize is not bigger than 0
      */
     public SnappyCompressorInputStream(final InputStream is, final int blockSize)
             throws IOException {
@@ -90,6 +91,9 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
      */
     @Override
     public int read(final byte[] b, final int off, final int len) throws IOException {
+        if (len == 0) {
+            return 0;
+        }
         if (endReached) {
             return -1;
         }
@@ -98,13 +102,13 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
             fill();
             return read(b, off, len);
         case IN_LITERAL:
-            int litLen = readLiteral(b, off, len);
+            final int litLen = readLiteral(b, off, len);
             if (!hasMoreDataInBlock()) {
                 state = State.NO_BLOCK;
             }
             return litLen > 0 ? litLen : read(b, off, len);
         case IN_BACK_REFERENCE:
-            int backReferenceLen = readBackReference(b, off, len);
+            final int backReferenceLen = readBackReference(b, off, len);
             if (!hasMoreDataInBlock()) {
                 state = State.NO_BLOCK;
             }
@@ -135,6 +139,9 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
         case 0x00:
 
             length = readLiteralLength(b);
+            if (length < 0) {
+                throw new IOException("Illegal block with a negative literal size found");
+            }
             uncompressedBytesRemaining -= length;
             startLiteral(length);
             state = State.IN_LITERAL;
@@ -160,7 +167,11 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
             }
             offset |= b;
 
-            startBackReference(offset, length);
+            try {
+                startBackReference(offset, length);
+            } catch (final IllegalArgumentException ex) {
+                throw new IOException("Illegal block with bad offset found", ex);
+            }
             state = State.IN_BACK_REFERENCE;
             break;
 
@@ -175,11 +186,18 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
              */
 
             length = (b >> 2) + 1;
+            if (length < 0) {
+                throw new IOException("Illegal block with a negative match length found");
+            }
             uncompressedBytesRemaining -= length;
 
             offset = (int) ByteUtils.fromLittleEndian(supplier, 2);
 
-            startBackReference(offset, length);
+            try {
+                startBackReference(offset, length);
+            } catch (final IllegalArgumentException ex) {
+                throw new IOException("Illegal block with bad offset found", ex);
+            }
             state = State.IN_BACK_REFERENCE;
             break;
 
@@ -193,11 +211,18 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
              */
 
             length = (b >> 2) + 1;
+            if (length < 0) {
+                throw new IOException("Illegal block with a negative match length found");
+            }
             uncompressedBytesRemaining -= length;
 
             offset = (int) ByteUtils.fromLittleEndian(supplier, 4) & 0x7fffffff;
 
-            startBackReference(offset, length);
+            try {
+                startBackReference(offset, length);
+            } catch (final IllegalArgumentException ex) {
+                throw new IOException("Illegal block with bad offset found", ex);
+            }
             state = State.IN_BACK_REFERENCE;
             break;
         default:
@@ -217,7 +242,7 @@ public class SnappyCompressorInputStream extends AbstractLZ77CompressorInputStre
      * after the length.
      */
     private int readLiteralLength(final int b) throws IOException {
-        int length;
+        final int length;
         switch (b >> 2) {
         case 60:
             length = readOneByte();
