@@ -19,9 +19,9 @@ package org.apache.commons.compress.harmony.pack200;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -35,30 +35,30 @@ import org.objectweb.asm.Type;
 public class CpBands extends BandSet {
 
     // Don't need to include default attribute names in the constant pool bands
-    private final Set defaultAttributeNames = new HashSet();
+    private final Set<String> defaultAttributeNames = new HashSet<>();
 
-    private final Set cp_Utf8 = new TreeSet();
-    private final Set cp_Int = new TreeSet();
-    private final Set cp_Float = new TreeSet();
-    private final Set cp_Long = new TreeSet();
-    private final Set cp_Double = new TreeSet();
-    private final Set cp_String = new TreeSet();
-    private final Set cp_Class = new TreeSet();
-    private final Set cp_Signature = new TreeSet();
-    private final Set cp_Descr = new TreeSet();
-    private final Set cp_Field = new TreeSet();
-    private final Set cp_Method = new TreeSet();
-    private final Set cp_Imethod = new TreeSet();
+    private final Set<CPUTF8> cp_Utf8 = new TreeSet<>();
+    private final Set<CPInt> cp_Int = new TreeSet<>();
+    private final Set<CPFloat> cp_Float = new TreeSet<>();
+    private final Set<CPLong> cp_Long = new TreeSet<>();
+    private final Set<CPDouble> cp_Double = new TreeSet<>();
+    private final Set<CPString> cp_String = new TreeSet<>();
+    private final Set<CPClass> cp_Class = new TreeSet<>();
+    private final Set<CPSignature> cp_Signature = new TreeSet<>();
+    private final Set<CPNameAndType> cp_Descr = new TreeSet<>();
+    private final Set<CPMethodOrField> cp_Field = new TreeSet<>();
+    private final Set<CPMethodOrField> cp_Method = new TreeSet<>();
+    private final Set<CPMethodOrField> cp_Imethod = new TreeSet<>();
 
-    private final Map stringsToCpUtf8 = new HashMap();
-    private final Map stringsToCpNameAndType = new HashMap();
-    private final Map stringsToCpClass = new HashMap();
-    private final Map stringsToCpSignature = new HashMap();
-    private final Map stringsToCpMethod = new HashMap();
-    private final Map stringsToCpField = new HashMap();
-    private final Map stringsToCpIMethod = new HashMap();
+    private final Map<String, CPUTF8> stringsToCpUtf8 = new HashMap<>();
+    private final Map<String, CPNameAndType> stringsToCpNameAndType = new HashMap<>();
+    private final Map<String, CPClass> stringsToCpClass = new HashMap<>();
+    private final Map<String, CPSignature> stringsToCpSignature = new HashMap<>();
+    private final Map<String, CPMethodOrField> stringsToCpMethod = new HashMap<>();
+    private final Map<String, CPMethodOrField> stringsToCpField = new HashMap<>();
+    private final Map<String, CPMethodOrField> stringsToCpIMethod = new HashMap<>();
 
-    private final Map objectsToCPConstant = new HashMap();
+    private final Map<Object, CPConstant<?>> objectsToCPConstant = new HashMap<>();
 
     private final Segment segment;
 
@@ -104,9 +104,9 @@ public class CpBands extends BandSet {
         PackingUtils.log("Writing " + cp_Utf8.size() + " UTF8 entries...");
         final int[] cpUtf8Prefix = new int[cp_Utf8.size() - 2];
         final int[] cpUtf8Suffix = new int[cp_Utf8.size() - 1];
-        final List chars = new ArrayList();
-        final List bigSuffix = new ArrayList();
-        final List bigChars = new ArrayList();
+        final List<Character> chars = new ArrayList<>();
+        final List<Integer> bigSuffix = new ArrayList<>();
+        final List<Character> bigChars = new ArrayList<>();
         final Object[] cpUtf8Array = cp_Utf8.toArray();
         final String first = ((CPUTF8) cpUtf8Array[1]).getUnderlyingString();
         cpUtf8Suffix[0] = first.length();
@@ -138,16 +138,12 @@ public class CpBands extends BandSet {
         final int[] cpUtf8Chars = new int[chars.size()];
         final int[] cpUtf8BigSuffix = new int[bigSuffix.size()];
         final int[][] cpUtf8BigChars = new int[bigSuffix.size()][];
-        for (int i = 0; i < cpUtf8Chars.length; i++) {
-            cpUtf8Chars[i] = ((Character) chars.get(i)).charValue();
-        }
+        Arrays.setAll(cpUtf8Chars, i -> chars.get(i).charValue());
         for (int i = 0; i < cpUtf8BigSuffix.length; i++) {
-            final int numBigChars = ((Integer) bigSuffix.get(i)).intValue();
+            final int numBigChars = bigSuffix.get(i).intValue();
             cpUtf8BigSuffix[i] = numBigChars;
             cpUtf8BigChars[i] = new int[numBigChars];
-            for (int j = 0; j < numBigChars; j++) {
-                cpUtf8BigChars[i][j] = ((Character) bigChars.remove(0)).charValue();
-            }
+            Arrays.setAll(cpUtf8BigChars[i], j -> bigChars.remove(0).charValue());
         }
 
         byte[] encodedBand = encodeBandInt("cpUtf8Prefix", cpUtf8Prefix, Codec.DELTA5);
@@ -174,9 +170,9 @@ public class CpBands extends BandSet {
         }
     }
 
-    private void addCharacters(final List chars, final char[] charArray) {
-        for (int i = 0; i < charArray.length; i++) {
-            chars.add(Character.valueOf(charArray[i]));
+    private void addCharacters(final List<Character> chars, final char[] charArray) {
+        for (char element : charArray) {
+            chars.add(Character.valueOf(element));
         }
     }
 
@@ -184,8 +180,7 @@ public class CpBands extends BandSet {
         PackingUtils.log("Writing " + cp_Int.size() + " Integer entries...");
         final int[] cpInt = new int[cp_Int.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Int.iterator(); iterator.hasNext();) {
-            final CPInt integer = (CPInt) iterator.next();
+        for (final CPInt integer : cp_Int) {
             cpInt[i] = integer.getInt();
             i++;
         }
@@ -198,8 +193,7 @@ public class CpBands extends BandSet {
         PackingUtils.log("Writing " + cp_Float.size() + " Float entries...");
         final int[] cpFloat = new int[cp_Float.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Float.iterator(); iterator.hasNext();) {
-            final CPFloat fl = (CPFloat) iterator.next();
+        for (final CPFloat fl : cp_Float) {
             cpFloat[i] = Float.floatToIntBits(fl.getFloat());
             i++;
         }
@@ -213,8 +207,7 @@ public class CpBands extends BandSet {
         final int[] highBits = new int[cp_Long.size()];
         final int[] loBits = new int[cp_Long.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Long.iterator(); iterator.hasNext();) {
-            final CPLong lng = (CPLong) iterator.next();
+        for (final CPLong lng : cp_Long) {
             final long l = lng.getLong();
             highBits[i] = (int) (l >> 32);
             loBits[i] = (int) l;
@@ -234,8 +227,7 @@ public class CpBands extends BandSet {
         final int[] highBits = new int[cp_Double.size()];
         final int[] loBits = new int[cp_Double.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Double.iterator(); iterator.hasNext();) {
-            final CPDouble dbl = (CPDouble) iterator.next();
+        for (final CPDouble dbl : cp_Double) {
             final long l = Double.doubleToLongBits(dbl.getDouble());
             highBits[i] = (int) (l >> 32);
             loBits[i] = (int) l;
@@ -254,8 +246,7 @@ public class CpBands extends BandSet {
         PackingUtils.log("Writing " + cp_String.size() + " String entries...");
         final int[] cpString = new int[cp_String.size()];
         int i = 0;
-        for (final Iterator iterator = cp_String.iterator(); iterator.hasNext();) {
-            final CPString cpStr = (CPString) iterator.next();
+        for (final CPString cpStr : cp_String) {
             cpString[i] = cpStr.getIndexInCpUtf8();
             i++;
         }
@@ -268,8 +259,7 @@ public class CpBands extends BandSet {
         PackingUtils.log("Writing " + cp_Class.size() + " Class entries...");
         final int[] cpClass = new int[cp_Class.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Class.iterator(); iterator.hasNext();) {
-            final CPClass cpCl = (CPClass) iterator.next();
+        for (final CPClass cpCl : cp_Class) {
             cpClass[i] = cpCl.getIndexInCpUtf8();
             i++;
         }
@@ -281,18 +271,15 @@ public class CpBands extends BandSet {
     private void writeCpSignature(final OutputStream out) throws IOException, Pack200Exception {
         PackingUtils.log("Writing " + cp_Signature.size() + " Signature entries...");
         final int[] cpSignatureForm = new int[cp_Signature.size()];
-        final List classes = new ArrayList();
+        final List<CPClass> classes = new ArrayList<>();
         int i = 0;
-        for (final Iterator iterator = cp_Signature.iterator(); iterator.hasNext();) {
-            final CPSignature cpS = (CPSignature) iterator.next();
+        for (final CPSignature cpS : cp_Signature) {
             classes.addAll(cpS.getClasses());
             cpSignatureForm[i] = cpS.getIndexInCpUtf8();
             i++;
         }
         final int[] cpSignatureClasses = new int[classes.size()];
-        for (int j = 0; j < cpSignatureClasses.length; j++) {
-            cpSignatureClasses[j] = ((CPClass) classes.get(j)).getIndex();
-        }
+        Arrays.setAll(cpSignatureClasses, j -> classes.get(j).getIndex());
 
         byte[] encodedBand = encodeBandInt("cpSignatureForm", cpSignatureForm, Codec.DELTA5);
         out.write(encodedBand);
@@ -309,8 +296,7 @@ public class CpBands extends BandSet {
         final int[] cpDescrName = new int[cp_Descr.size()];
         final int[] cpDescrType = new int[cp_Descr.size()];
         int i = 0;
-        for (final Iterator iterator = cp_Descr.iterator(); iterator.hasNext();) {
-            final CPNameAndType nameAndType = (CPNameAndType) iterator.next();
+        for (final CPNameAndType nameAndType : cp_Descr) {
             cpDescrName[i] = nameAndType.getNameIndex();
             cpDescrType[i] = nameAndType.getTypeIndex();
             i++;
@@ -325,14 +311,13 @@ public class CpBands extends BandSet {
         PackingUtils.log("Wrote " + encodedBand.length + " bytes from cp_Descr_Type[" + cpDescrType.length + "]");
     }
 
-    private void writeCpMethodOrField(final Set cp, final OutputStream out, final String name)
+    private void writeCpMethodOrField(final Set<CPMethodOrField> cp, final OutputStream out, final String name)
         throws IOException, Pack200Exception {
         PackingUtils.log("Writing " + cp.size() + " Method and Field entries...");
         final int[] cp_methodOrField_class = new int[cp.size()];
         final int[] cp_methodOrField_desc = new int[cp.size()];
         int i = 0;
-        for (final Iterator iterator = cp.iterator(); iterator.hasNext();) {
-            final CPMethodOrField mOrF = (CPMethodOrField) iterator.next();
+        for (final CPMethodOrField mOrF : cp) {
             cp_methodOrField_class[i] = mOrF.getClassIndex();
             cp_methodOrField_desc[i] = mOrF.getDescIndex();
             i++;
@@ -371,72 +356,67 @@ public class CpBands extends BandSet {
     }
 
     private void removeSignaturesFromCpUTF8() {
-        for (final Iterator iterator = cp_Signature.iterator(); iterator.hasNext();) {
-            final CPSignature signature = (CPSignature) iterator.next();
+        cp_Signature.forEach(signature -> {
             final String sigStr = signature.getUnderlyingString();
             final CPUTF8 utf8 = signature.getSignatureForm();
             final String form = utf8.getUnderlyingString();
             if (!sigStr.equals(form)) {
                 removeCpUtf8(sigStr);
             }
-        }
+        });
     }
 
-    private void addIndices() {
-        final Set[] sets = {cp_Utf8, cp_Int, cp_Float, cp_Long, cp_Double, cp_String, cp_Class, cp_Signature, cp_Descr,
-            cp_Field, cp_Method, cp_Imethod};
-        for (int i = 0; i < sets.length; i++) {
-            int j = 0;
-            for (final Iterator iterator = sets[i].iterator(); iterator.hasNext();) {
-                final ConstantPoolEntry entry = (ConstantPoolEntry) iterator.next();
-                entry.setIndex(j);
-                j++;
-            }
-        }
-        final Map classNameToIndex = new HashMap();
-        for (final Iterator iterator = cp_Field.iterator(); iterator.hasNext();) {
-            final CPMethodOrField mOrF = (CPMethodOrField) iterator.next();
-            final CPClass className = mOrF.getClassName();
-            final Integer index = (Integer) classNameToIndex.get(className);
-            if (index == null) {
-                classNameToIndex.put(className, Integer.valueOf(1));
-                mOrF.setIndexInClass(0);
-            } else {
-                final int theIndex = index.intValue();
-                mOrF.setIndexInClass(theIndex);
-                classNameToIndex.put(className, Integer.valueOf(theIndex + 1));
-            }
-        }
-        classNameToIndex.clear();
-        final Map classNameToConstructorIndex = new HashMap();
-        for (final Iterator iterator = cp_Method.iterator(); iterator.hasNext();) {
-            final CPMethodOrField mOrF = (CPMethodOrField) iterator.next();
-            final CPClass className = mOrF.getClassName();
-            final Integer index = (Integer) classNameToIndex.get(className);
-            if (index == null) {
-                classNameToIndex.put(className, Integer.valueOf(1));
-                mOrF.setIndexInClass(0);
-            } else {
-                final int theIndex = index.intValue();
-                mOrF.setIndexInClass(theIndex);
-                classNameToIndex.put(className, Integer.valueOf(theIndex + 1));
-            }
-            if (mOrF.getDesc().getName().equals("<init>")) {
-                final Integer constructorIndex = (Integer) classNameToConstructorIndex.get(className);
-                if (constructorIndex == null) {
-                    classNameToConstructorIndex.put(className, Integer.valueOf(1));
-                    mOrF.setIndexInClassForConstructor(0);
-                } else {
-                    final int theIndex = constructorIndex.intValue();
-                    mOrF.setIndexInClassForConstructor(theIndex);
-                    classNameToConstructorIndex.put(className, Integer.valueOf(theIndex + 1));
-                }
-            }
-        }
-    }
+	private void addIndices() {
+		for (Set<? extends ConstantPoolEntry> set : Arrays.asList(cp_Utf8, cp_Int, cp_Float, cp_Long, cp_Double,
+				cp_String, cp_Class, cp_Signature, cp_Descr, cp_Field, cp_Method, cp_Imethod)) {
+			int j = 0;
+			for (final ConstantPoolEntry entry : set) {
+				entry.setIndex(j);
+				j++;
+			}
+		}
+		final Map<CPClass, Integer> classNameToIndex = new HashMap<>();
+		cp_Field.forEach(mOrF -> {
+			final CPClass cpClassName = mOrF.getClassName();
+			final Integer index = classNameToIndex.get(cpClassName);
+			if (index == null) {
+				classNameToIndex.put(cpClassName, Integer.valueOf(1));
+				mOrF.setIndexInClass(0);
+			} else {
+				final int theIndex = index.intValue();
+				mOrF.setIndexInClass(theIndex);
+				classNameToIndex.put(cpClassName, Integer.valueOf(theIndex + 1));
+			}
+		});
+		classNameToIndex.clear();
+		final Map<CPClass, Integer> classNameToConstructorIndex = new HashMap<>();
+		cp_Method.forEach(mOrF -> {
+			final CPClass cpClassName = mOrF.getClassName();
+			final Integer index = classNameToIndex.get(cpClassName);
+			if (index == null) {
+				classNameToIndex.put(cpClassName, Integer.valueOf(1));
+				mOrF.setIndexInClass(0);
+			} else {
+				final int theIndex = index.intValue();
+				mOrF.setIndexInClass(theIndex);
+				classNameToIndex.put(cpClassName, Integer.valueOf(theIndex + 1));
+			}
+			if (mOrF.getDesc().getName().equals("<init>")) {
+				final Integer constructorIndex = classNameToConstructorIndex.get(cpClassName);
+				if (constructorIndex == null) {
+					classNameToConstructorIndex.put(cpClassName, Integer.valueOf(1));
+					mOrF.setIndexInClassForConstructor(0);
+				} else {
+					final int theIndex = constructorIndex.intValue();
+					mOrF.setIndexInClassForConstructor(theIndex);
+					classNameToConstructorIndex.put(cpClassName, Integer.valueOf(theIndex + 1));
+				}
+			}
+		});
+	}
 
     private void removeCpUtf8(final String string) {
-        final CPUTF8 utf8 = (CPUTF8) stringsToCpUtf8.get(string);
+        final CPUTF8 utf8 = stringsToCpUtf8.get(string);
         if ((utf8 != null) && (stringsToCpClass.get(string) == null)) { // don't remove if strings are also in cpclass
             stringsToCpUtf8.remove(string);
             cp_Utf8.remove(utf8);
@@ -451,7 +431,7 @@ public class CpBands extends BandSet {
         if (utf8 == null) {
             return null;
         }
-        CPUTF8 cpUtf8 = (CPUTF8) stringsToCpUtf8.get(utf8);
+        CPUTF8 cpUtf8 = stringsToCpUtf8.get(utf8);
         if (cpUtf8 == null) {
             cpUtf8 = new CPUTF8(utf8);
             cp_Utf8.add(cpUtf8);
@@ -464,18 +444,18 @@ public class CpBands extends BandSet {
         if (signature == null) {
             return null;
         }
-        CPSignature cpS = (CPSignature) stringsToCpSignature.get(signature);
+        CPSignature cpS = stringsToCpSignature.get(signature);
         if (cpS == null) {
-            final List cpClasses = new ArrayList();
+            final List<CPClass> cpClasses = new ArrayList<>();
             CPUTF8 signatureUTF8;
             if (signature.length() > 1 && signature.indexOf('L') != -1) {
-                final List classes = new ArrayList();
+                final List<String> classes = new ArrayList<>();
                 final char[] chars = signature.toCharArray();
-                final StringBuffer signatureString = new StringBuffer();
+                final StringBuilder signatureString = new StringBuilder();
                 for (int i = 0; i < chars.length; i++) {
                     signatureString.append(chars[i]);
                     if (chars[i] == 'L') {
-                        final StringBuffer className = new StringBuffer();
+                        final StringBuilder className = new StringBuilder();
                         for (int j = i + 1; j < chars.length; j++) {
                             final char c = chars[j];
                             if (!Character.isLetter(c) && !Character.isDigit(c) && (c != '/') && (c != '$')
@@ -489,12 +469,11 @@ public class CpBands extends BandSet {
                     }
                 }
                 removeCpUtf8(signature);
-                for (final Iterator iterator2 = classes.iterator(); iterator2.hasNext();) {
-                    String className = (String) iterator2.next();
+                for (String className : classes) {
                     CPClass cpClass = null;
                     if (className != null) {
                         className = className.replace('.', '/');
-                        cpClass = (CPClass) stringsToCpClass.get(className);
+                        cpClass = stringsToCpClass.get(className);
                         if (cpClass == null) {
                             final CPUTF8 cpUtf8 = getCPUtf8(className);
                             cpClass = new CPClass(cpUtf8);
@@ -521,7 +500,7 @@ public class CpBands extends BandSet {
             return null;
         }
         className = className.replace('.', '/');
-        CPClass cpClass = (CPClass) stringsToCpClass.get(className);
+        CPClass cpClass = stringsToCpClass.get(className);
         if (cpClass == null) {
             final CPUTF8 cpUtf8 = getCPUtf8(className);
             cpClass = new CPClass(cpUtf8);
@@ -540,7 +519,7 @@ public class CpBands extends BandSet {
 
     public CPNameAndType getCPNameAndType(final String name, final String signature) {
         final String descr = name + ":" + signature;
-        CPNameAndType nameAndType = (CPNameAndType) stringsToCpNameAndType.get(descr);
+        CPNameAndType nameAndType = stringsToCpNameAndType.get(descr);
         if (nameAndType == null) {
             nameAndType = new CPNameAndType(getCPUtf8(name), getCPSignature(signature));
             stringsToCpNameAndType.put(descr, nameAndType);
@@ -551,7 +530,7 @@ public class CpBands extends BandSet {
 
     public CPMethodOrField getCPField(final CPClass cpClass, final String name, final String desc) {
         final String key = cpClass.toString() + ":" + name + ":" + desc;
-        CPMethodOrField cpF = (CPMethodOrField) stringsToCpField.get(key);
+        CPMethodOrField cpF = stringsToCpField.get(key);
         if (cpF == null) {
             final CPNameAndType nAndT = getCPNameAndType(name, desc);
             cpF = new CPMethodOrField(cpClass, nAndT);
@@ -561,24 +540,24 @@ public class CpBands extends BandSet {
         return cpF;
     }
 
-    public CPConstant getConstant(final Object value) {
-        CPConstant constant = (CPConstant) objectsToCPConstant.get(value);
+    public CPConstant<?> getConstant(final Object value) {
+        CPConstant<?> constant = objectsToCPConstant.get(value);
         if (constant == null) {
             if (value instanceof Integer) {
                 constant = new CPInt(((Integer) value).intValue());
-                cp_Int.add(constant);
+                cp_Int.add((CPInt) constant);
             } else if (value instanceof Long) {
                 constant = new CPLong(((Long) value).longValue());
-                cp_Long.add(constant);
+                cp_Long.add((CPLong) constant);
             } else if (value instanceof Float) {
                 constant = new CPFloat(((Float) value).floatValue());
-                cp_Float.add(constant);
+                cp_Float.add((CPFloat) constant);
             } else if (value instanceof Double) {
                 constant = new CPDouble(((Double) value).doubleValue());
-                cp_Double.add(constant);
+                cp_Double.add((CPDouble) constant);
             } else if (value instanceof String) {
                 constant = new CPString(getCPUtf8((String) value));
-                cp_String.add(constant);
+                cp_String.add((CPString) constant);
             } else if (value instanceof Type) {
                 String className = ((Type) value).getClassName();
                 if (className.endsWith("[]")) {
@@ -597,7 +576,7 @@ public class CpBands extends BandSet {
 
     public CPMethodOrField getCPMethod(final CPClass cpClass, final String name, final String desc) {
         final String key = cpClass.toString() + ":" + name + ":" + desc;
-        CPMethodOrField cpM = (CPMethodOrField) stringsToCpMethod.get(key);
+        CPMethodOrField cpM = stringsToCpMethod.get(key);
         if (cpM == null) {
             final CPNameAndType nAndT = getCPNameAndType(name, desc);
             cpM = new CPMethodOrField(cpClass, nAndT);
@@ -609,7 +588,7 @@ public class CpBands extends BandSet {
 
     public CPMethodOrField getCPIMethod(final CPClass cpClass, final String name, final String desc) {
         final String key = cpClass.toString() + ":" + name + ":" + desc;
-        CPMethodOrField cpIM = (CPMethodOrField) stringsToCpIMethod.get(key);
+        CPMethodOrField cpIM = stringsToCpIMethod.get(key);
         if (cpIM == null) {
             final CPNameAndType nAndT = getCPNameAndType(name, desc);
             cpIM = new CPMethodOrField(cpClass, nAndT);
@@ -632,7 +611,7 @@ public class CpBands extends BandSet {
     }
 
     public boolean existsCpClass(final String className) {
-        final CPClass cpClass = (CPClass) stringsToCpClass.get(className);
+        final CPClass cpClass = stringsToCpClass.get(className);
         return cpClass != null;
     }
 
