@@ -21,9 +21,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.StringReader;
+import java.io.UncheckedIOException;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
@@ -36,7 +36,7 @@ import org.objectweb.asm.Label;
  */
 public class NewAttributeBands extends BandSet {
 
-    protected List attributeLayoutElements;
+    protected List<AttributeLayoutElement> attributeLayoutElements;
     private int[] backwardsCallCounts;
     private final CpBands cpBands;
     private final AttributeDefinition def;
@@ -56,17 +56,15 @@ public class NewAttributeBands extends BandSet {
     public void addAttribute(final NewAttribute attribute) {
         usedAtLeastOnce = true;
         final InputStream stream = new ByteArrayInputStream(attribute.getBytes());
-        for (final Iterator iterator = attributeLayoutElements.iterator(); iterator.hasNext();) {
-            final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-            layoutElement.addAttributeToBand(attribute, stream);
+        for (AttributeLayoutElement attributeLayoutElement : attributeLayoutElements) {
+            attributeLayoutElement.addAttributeToBand(attribute, stream);
         }
     }
 
     @Override
-    public void pack(final OutputStream out) throws IOException, Pack200Exception {
-        for (final Iterator iterator = attributeLayoutElements.iterator(); iterator.hasNext();) {
-            final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-            layoutElement.pack(out);
+    public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
+        for (AttributeLayoutElement attributeLayoutElement : attributeLayoutElements) {
+            attributeLayoutElement.pack(outputStream);
         }
     }
 
@@ -89,10 +87,10 @@ public class NewAttributeBands extends BandSet {
     private void parseLayout() throws IOException {
         final String layout = def.layout.getUnderlyingString();
         if (attributeLayoutElements == null) {
-            attributeLayoutElements = new ArrayList();
-            final StringReader stream = new StringReader(layout);
+            attributeLayoutElements = new ArrayList<>();
+            final StringReader reader = new StringReader(layout);
             AttributeLayoutElement e;
-            while ((e = readNextAttributeElement(stream)) != null) {
+            while ((e = readNextAttributeElement(reader)) != null) {
                 attributeLayoutElements.add(e);
             }
             resolveCalls();
@@ -106,22 +104,20 @@ public class NewAttributeBands extends BandSet {
      */
     private void resolveCalls() {
         for (int i = 0; i < attributeLayoutElements.size(); i++) {
-            final AttributeLayoutElement element = (AttributeLayoutElement) attributeLayoutElements.get(i);
+            final AttributeLayoutElement element = attributeLayoutElements.get(i);
             if (element instanceof Callable) {
                 final Callable callable = (Callable) element;
-                final List body = callable.body; // Look for calls in the body
-                for (int iIndex = 0; iIndex < body.size(); iIndex++) {
-                    final LayoutElement layoutElement = (LayoutElement) body.get(iIndex);
+                final List<LayoutElement> body = callable.body; // Look for calls in the body
+                for (LayoutElement layoutElement : body) {
                     // Set the callable for each call
                     resolveCallsForElement(i, callable, layoutElement);
                 }
             }
         }
         int backwardsCallableIndex = 0;
-        for (int i = 0; i < attributeLayoutElements.size(); i++) {
-            final AttributeLayoutElement element = (AttributeLayoutElement) attributeLayoutElements.get(i);
-            if (element instanceof Callable) {
-                final Callable callable = (Callable) element;
+        for (AttributeLayoutElement attributeLayoutElement : attributeLayoutElements) {
+            if (attributeLayoutElement instanceof Callable) {
+                final Callable callable = (Callable) attributeLayoutElement;
                 if (callable.isBackwardsCallable) {
                     callable.setBackwardsCallableIndex(backwardsCallableIndex);
                     backwardsCallableIndex++;
@@ -140,7 +136,7 @@ public class NewAttributeBands extends BandSet {
                 call.setCallable(currentCallable);
             } else if (index > 0) { // Forwards call
                 for (int k = i + 1; k < attributeLayoutElements.size(); k++) {
-                    final AttributeLayoutElement el = (AttributeLayoutElement) attributeLayoutElements.get(k);
+                    final AttributeLayoutElement el = attributeLayoutElements.get(k);
                     if (el instanceof Callable) {
                         index--;
                         if (index == 0) {
@@ -151,7 +147,7 @@ public class NewAttributeBands extends BandSet {
                 }
             } else { // Backwards call
                 for (int k = i - 1; k >= 0; k--) {
-                    final AttributeLayoutElement el = (AttributeLayoutElement) attributeLayoutElements.get(k);
+                    final AttributeLayoutElement el = attributeLayoutElements.get(k);
                     if (el instanceof Callable) {
                         index++;
                         if (index == 0) {
@@ -162,30 +158,28 @@ public class NewAttributeBands extends BandSet {
                 }
             }
         } else if (layoutElement instanceof Replication) {
-            final List children = ((Replication) layoutElement).layoutElements;
-            for (final Iterator iterator = children.iterator(); iterator.hasNext();) {
-                final LayoutElement object = (LayoutElement) iterator.next();
-                resolveCallsForElement(i, currentCallable, object);
+            final List<LayoutElement> children = ((Replication) layoutElement).layoutElements;
+            for (LayoutElement child : children) {
+                resolveCallsForElement(i, currentCallable, child);
             }
         }
     }
 
-    private AttributeLayoutElement readNextAttributeElement(final StringReader stream) throws IOException {
-        stream.mark(1);
-        final int nextChar = stream.read();
-        if (nextChar == -1) {
+    private AttributeLayoutElement readNextAttributeElement(final StringReader reader) throws IOException {
+        reader.mark(1);
+        final int next = reader.read();
+        if (next == -1) {
             return null;
         }
-        if (nextChar == '[') {
-            final List body = readBody(getStreamUpToMatchingBracket(stream));
-            return new Callable(body);
+        if (next == '[') {
+            return new Callable(readBody(getStreamUpToMatchingBracket(reader)));
         }
-        stream.reset();
-        return readNextLayoutElement(stream);
+        reader.reset();
+        return readNextLayoutElement(reader);
     }
 
-    private LayoutElement readNextLayoutElement(final StringReader stream) throws IOException {
-        final int nextChar = stream.read();
+    private LayoutElement readNextLayoutElement(final StringReader reader) throws IOException {
+        final int nextChar = reader.read();
         if (nextChar == -1) {
             return null;
         }
@@ -199,69 +193,67 @@ public class NewAttributeBands extends BandSet {
             return new Integral(new String(new char[] {(char) nextChar}));
         case 'S':
         case 'F':
-            return new Integral(new String(new char[] {(char) nextChar, (char) stream.read()}));
+            return new Integral(new String(new char[] {(char) nextChar, (char) reader.read()}));
         case 'P':
-            stream.mark(1);
-            if (stream.read() != 'O') {
-                stream.reset();
-                lastPIntegral = new Integral("P" + (char) stream.read());
-                return lastPIntegral;
-            } else {
-                lastPIntegral = new Integral("PO" + (char) stream.read(), lastPIntegral);
+            reader.mark(1);
+            if (reader.read() != 'O') {
+                reader.reset();
+                lastPIntegral = new Integral("P" + (char) reader.read());
                 return lastPIntegral;
             }
+            lastPIntegral = new Integral("PO" + (char) reader.read(), lastPIntegral);
+            return lastPIntegral;
         case 'O':
-            stream.mark(1);
-            if (stream.read() != 'S') {
-                stream.reset();
-                return new Integral("O" + (char) stream.read(), lastPIntegral);
-            } else {
-                return new Integral("OS" + (char) stream.read(), lastPIntegral);
+            reader.mark(1);
+            if (reader.read() != 'S') {
+                reader.reset();
+                return new Integral("O" + (char) reader.read(), lastPIntegral);
             }
+            return new Integral("OS" + (char) reader.read(), lastPIntegral);
 
             // Replication
         case 'N':
-            final char uint_type = (char) stream.read();
-            stream.read(); // '['
-            final String str = readUpToMatchingBracket(stream);
+            final char uint_type = (char) reader.read();
+            reader.read(); // '['
+            final String str = readUpToMatchingBracket(reader);
             return new Replication("" + uint_type, str);
 
         // Union
         case 'T':
-            String int_type = "" + (char) stream.read();
+            String int_type = String.valueOf((char) reader.read());
             if (int_type.equals("S")) {
-                int_type += (char) stream.read();
+                int_type += (char) reader.read();
             }
-            final List unionCases = new ArrayList();
+            final List<UnionCase> unionCases = new ArrayList<>();
             UnionCase c;
-            while ((c = readNextUnionCase(stream)) != null) {
+            while ((c = readNextUnionCase(reader)) != null) {
                 unionCases.add(c);
             }
-            stream.read(); // '('
-            stream.read(); // ')'
-            stream.read(); // '['
-            List body = null;
-            stream.mark(1);
-            final char next = (char) stream.read();
+            reader.read(); // '('
+            reader.read(); // ')'
+            reader.read(); // '['
+            List<LayoutElement> body = null;
+            reader.mark(1);
+            final char next = (char) reader.read();
             if (next != ']') {
-                stream.reset();
-                body = readBody(getStreamUpToMatchingBracket(stream));
+                reader.reset();
+                body = readBody(getStreamUpToMatchingBracket(reader));
             }
             return new Union(int_type, unionCases, body);
 
         // Call
         case '(':
-            final int number = readNumber(stream).intValue();
-            stream.read(); // ')'
+            final int number = readNumber(reader).intValue();
+            reader.read(); // ')'
             return new Call(number);
         // Reference
         case 'K':
         case 'R':
-            final StringBuilder string = new StringBuilder("").append((char) nextChar).append((char) stream.read());
-            final char nxt = (char) stream.read();
+            final StringBuilder string = new StringBuilder("").append((char) nextChar).append((char) reader.read());
+            final char nxt = (char) reader.read();
             string.append(nxt);
             if (nxt == 'N') {
-                string.append((char) stream.read());
+                string.append((char) reader.read());
             }
             return new Reference(string.toString());
         }
@@ -271,37 +263,38 @@ public class NewAttributeBands extends BandSet {
     /**
      * Read a UnionCase from the stream
      *
-     * @param stream
+     * @param reader
      * @return
      * @throws IOException If an I/O error occurs.
      */
-    private UnionCase readNextUnionCase(final StringReader stream) throws IOException {
-        stream.mark(2);
-        stream.read(); // '('
-        char next = (char) stream.read();
-        if (next == ')') {
-            stream.reset();
+    private UnionCase readNextUnionCase(final StringReader reader) throws IOException {
+        reader.mark(2);
+        reader.read(); // '('
+        final int next = reader.read();
+        char ch = (char) next;
+        if (ch == ')' || next == -1) {
+            reader.reset();
             return null;
         }
-        stream.reset();
-        stream.read(); // '('
-        final List tags = new ArrayList();
+        reader.reset();
+        reader.read(); // '('
+        final List<Integer> tags = new ArrayList<>();
         Integer nextTag;
         do {
-            nextTag = readNumber(stream);
+            nextTag = readNumber(reader);
             if (nextTag != null) {
                 tags.add(nextTag);
-                stream.read(); // ',' or ')'
+                reader.read(); // ',' or ')'
             }
         } while (nextTag != null);
-        stream.read(); // '['
-        stream.mark(1);
-        next = (char) stream.read();
-        if (next == ']') {
+        reader.read(); // '['
+        reader.mark(1);
+        ch = (char) reader.read();
+        if (ch == ']') {
             return new UnionCase(tags);
         }
-        stream.reset();
-        return new UnionCase(tags, readBody(getStreamUpToMatchingBracket(stream)));
+        reader.reset();
+        return new UnionCase(tags, readBody(getStreamUpToMatchingBracket(reader)));
     }
 
     /**
@@ -310,11 +303,11 @@ public class NewAttributeBands extends BandSet {
      */
     public interface AttributeLayoutElement {
 
-        void addAttributeToBand(NewAttribute attribute, InputStream stream);
+        void addAttributeToBand(NewAttribute attribute, InputStream inputStream);
 
-        void pack(OutputStream out) throws IOException, Pack200Exception;
+        void pack(OutputStream ouputStream) throws IOException, Pack200Exception;
 
-        void renumberBci(IntList bciRenumbering, Map labelsToOffsets);
+        void renumberBci(IntList bciRenumbering, Map<Label, Integer> labelsToOffsets);
 
     }
 
@@ -367,40 +360,40 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
             Object val = null;
             int value = 0;
             if (tag.equals("B") || tag.equals("FB")) {
-                value = readInteger(1, stream) & 0xFF; // unsigned byte
+                value = readInteger(1, inputStream) & 0xFF; // unsigned byte
             } else if (tag.equals("SB")) {
-                value = readInteger(1, stream);
+                value = readInteger(1, inputStream);
             } else if (tag.equals("H") || tag.equals("FH")) {
-                value = readInteger(2, stream) & 0xFFFF; // unsigned short
+                value = readInteger(2, inputStream) & 0xFFFF; // unsigned short
             } else if (tag.equals("SH")) {
-                value = readInteger(2, stream);
+                value = readInteger(2, inputStream);
             } else if (tag.equals("I") || tag.equals("FI")) {
-                value = readInteger(4, stream);
+                value = readInteger(4, inputStream);
             } else if (tag.equals("SI")) {
-                value = readInteger(4, stream);
+                value = readInteger(4, inputStream);
             } else if (tag.equals("V") || tag.equals("FV") || tag.equals("SV")) {
                 // Not currently supported
             } else if (tag.startsWith("PO") || tag.startsWith("OS")) {
                 final char uint_type = tag.substring(2).toCharArray()[0];
                 final int length = getLength(uint_type);
-                value = readInteger(length, stream);
+                value = readInteger(length, inputStream);
                 value += previousIntegral.previousPValue;
                 val = attribute.getLabel(value);
                 previousPValue = value;
             } else if (tag.startsWith("P")) {
                 final char uint_type = tag.substring(1).toCharArray()[0];
                 final int length = getLength(uint_type);
-                value = readInteger(length, stream);
+                value = readInteger(length, inputStream);
                 val = attribute.getLabel(value);
                 previousPValue = value;
             } else if (tag.startsWith("O")) {
                 final char uint_type = tag.substring(1).toCharArray()[0];
                 final int length = getLength(uint_type);
-                value = readInteger(length, stream);
+                value = readInteger(length, inputStream);
                 value += previousIntegral.previousPValue;
                 val = attribute.getLabel(value);
                 previousPValue = value;
@@ -412,10 +405,10 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void pack(final OutputStream out) throws IOException, Pack200Exception {
+        public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
             PackingUtils.log("Writing new attribute bands...");
             final byte[] encodedBand = encodeBandInt(tag, integerListToArray(band), defaultCodec);
-            out.write(encodedBand);
+            outputStream.write(encodedBand);
             PackingUtils.log("Wrote " + encodedBand.length + " bytes from " + tag + "[" + band.size() + "]");
         }
 
@@ -424,7 +417,7 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
             if (tag.startsWith("O") || tag.startsWith("PO")) {
                 renumberOffsetBci(previousIntegral.band, bciRenumbering, labelsToOffsets);
             } else if (tag.startsWith("P")) {
@@ -435,14 +428,14 @@ public class NewAttributeBands extends BandSet {
                     }
                     if (label instanceof Label) {
                         band.remove(i);
-                        final Integer bytecodeIndex = (Integer) labelsToOffsets.get(label);
+                        final Integer bytecodeIndex = labelsToOffsets.get(label);
                         band.add(i, Integer.valueOf(bciRenumbering.get(bytecodeIndex.intValue())));
                     }
                 }
             }
         }
 
-        private void renumberOffsetBci(final List relative, final IntList bciRenumbering, final Map labelsToOffsets) {
+        private void renumberOffsetBci(final List relative, final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
             for (int i = band.size() - 1; i >= 0; i--) {
                 final Object label = band.get(i);
                 if (label instanceof Integer) {
@@ -450,7 +443,7 @@ public class NewAttributeBands extends BandSet {
                 }
                 if (label instanceof Label) {
                     band.remove(i);
-                    final Integer bytecodeIndex = (Integer) labelsToOffsets.get(label);
+                    final Integer bytecodeIndex = labelsToOffsets.get(label);
                     final Integer renumberedOffset = Integer
                         .valueOf(bciRenumbering.get(bytecodeIndex.intValue()) - ((Integer) relative.get(i)).intValue());
                     band.add(i, renumberedOffset);
@@ -467,13 +460,13 @@ public class NewAttributeBands extends BandSet {
 
         private final Integral countElement;
 
-        private final List layoutElements = new ArrayList();
+        private final List<LayoutElement> layoutElements = new ArrayList<>();
 
         public Integral getCountElement() {
             return countElement;
         }
 
-        public List getLayoutElements() {
+        public List<LayoutElement> getLayoutElements() {
             return layoutElements;
         }
 
@@ -487,13 +480,12 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            countElement.addAttributeToBand(attribute, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            countElement.addAttributeToBand(attribute, inputStream);
             final int count = countElement.latestValue();
             for (int i = 0; i < count; i++) {
-                for (final Iterator iterator = layoutElements.iterator(); iterator.hasNext();) {
-                    final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                    layoutElement.addAttributeToBand(attribute, stream);
+                for (AttributeLayoutElement layoutElement : layoutElements) {
+                    layoutElement.addAttributeToBand(attribute, inputStream);
                 }
             }
         }
@@ -501,16 +493,14 @@ public class NewAttributeBands extends BandSet {
         @Override
         public void pack(final OutputStream out) throws IOException, Pack200Exception {
             countElement.pack(out);
-            for (final Iterator iterator = layoutElements.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
+            for (AttributeLayoutElement layoutElement : layoutElements) {
                 layoutElement.pack(out);
             }
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
-            for (final Iterator iterator = layoutElements.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
+            for (AttributeLayoutElement layoutElement : layoutElements) {
                 layoutElement.renumberBci(bciRenumbering, labelsToOffsets);
             }
         }
@@ -522,57 +512,51 @@ public class NewAttributeBands extends BandSet {
     public class Union extends LayoutElement {
 
         private final Integral unionTag;
-        private final List unionCases;
-        private final List defaultCaseBody;
+        private final List<UnionCase> unionCases;
+        private final List<LayoutElement> defaultCaseBody;
 
-        public Union(final String tag, final List unionCases, final List body) {
+        public Union(final String tag, final List<UnionCase> unionCases, final List<LayoutElement> body) {
             this.unionTag = new Integral(tag);
             this.unionCases = unionCases;
             this.defaultCaseBody = body;
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            unionTag.addAttributeToBand(attribute, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            unionTag.addAttributeToBand(attribute, inputStream);
             final long tag = unionTag.latestValue();
             boolean defaultCase = true;
-            for (int i = 0; i < unionCases.size(); i++) {
-                final UnionCase element = (UnionCase) unionCases.get(i);
-                if (element.hasTag(tag)) {
+            for (UnionCase unionCase : unionCases) {
+                if (unionCase.hasTag(tag)) {
                     defaultCase = false;
-                    element.addAttributeToBand(attribute, stream);
+                    unionCase.addAttributeToBand(attribute, inputStream);
                 }
             }
             if (defaultCase) {
-                for (int i = 0; i < defaultCaseBody.size(); i++) {
-                    final LayoutElement element = (LayoutElement) defaultCaseBody.get(i);
-                    element.addAttributeToBand(attribute, stream);
+                for (LayoutElement layoutElement : defaultCaseBody) {
+                    layoutElement.addAttributeToBand(attribute, inputStream);
                 }
             }
         }
 
         @Override
-        public void pack(final OutputStream out) throws IOException, Pack200Exception {
-            unionTag.pack(out);
-            for (final Iterator iterator = unionCases.iterator(); iterator.hasNext();) {
-                final UnionCase unionCase = (UnionCase) iterator.next();
-                unionCase.pack(out);
+        public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
+            unionTag.pack(outputStream);
+            for (UnionCase unionCase : unionCases) {
+                unionCase.pack(outputStream);
             }
-            for (final Iterator iterator = defaultCaseBody.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                layoutElement.pack(out);
+            for (LayoutElement element : defaultCaseBody) {
+                element.pack(outputStream);
             }
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
-            for (final Iterator iterator = unionCases.iterator(); iterator.hasNext();) {
-                final UnionCase unionCase = (UnionCase) iterator.next();
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
+            for (UnionCase unionCase : unionCases) {
                 unionCase.renumberBci(bciRenumbering, labelsToOffsets);
             }
-            for (final Iterator iterator = defaultCaseBody.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                layoutElement.renumberBci(bciRenumbering, labelsToOffsets);
+            for (LayoutElement element : defaultCaseBody) {
+                element.renumberBci(bciRenumbering, labelsToOffsets);
             }
         }
 
@@ -580,11 +564,11 @@ public class NewAttributeBands extends BandSet {
             return unionTag;
         }
 
-        public List getUnionCases() {
+        public List<UnionCase> getUnionCases() {
             return unionCases;
         }
 
-        public List getDefaultCaseBody() {
+        public List<LayoutElement> getDefaultCaseBody() {
             return defaultCaseBody;
         }
     }
@@ -606,20 +590,20 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            callable.addAttributeToBand(attribute, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            callable.addAttributeToBand(attribute, inputStream);
             if (callableIndex < 1) {
                 callable.addBackwardsCall();
             }
         }
 
         @Override
-        public void pack(final OutputStream out) {
+        public void pack(final OutputStream outputStream) {
             // do nothing here as pack will be called on the callable at another time
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
             // do nothing here as renumberBci will be called on the callable at another time
         }
 
@@ -639,7 +623,7 @@ public class NewAttributeBands extends BandSet {
 
         private final String tag;
 
-        private List band;
+        private List<ConstantPoolEntry> band;
 
         private boolean nullsAllowed = false;
 
@@ -649,8 +633,8 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            final int index = readInteger(4, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            final int index = readInteger(4, inputStream);
             if (tag.startsWith("RC")) { // Class
                 band.add(cpBands.getCPClass(attribute.readClass(index)));
             } else if (tag.startsWith("RU")) { // UTF8 String
@@ -668,7 +652,7 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void pack(final OutputStream out) throws IOException, Pack200Exception {
+        public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
             int[] ints;
             if (nullsAllowed) {
                 ints = cpEntryOrNullListToArray(band);
@@ -676,12 +660,12 @@ public class NewAttributeBands extends BandSet {
                 ints = cpEntryListToArray(band);
             }
             final byte[] encodedBand = encodeBandInt(tag, ints, Codec.UNSIGNED5);
-            out.write(encodedBand);
+            outputStream.write(encodedBand);
             PackingUtils.log("Wrote " + encodedBand.length + " bytes from " + tag + "[" + ints.length + "]");
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
             // nothing to do here
         }
 
@@ -689,13 +673,13 @@ public class NewAttributeBands extends BandSet {
 
     public class Callable implements AttributeLayoutElement {
 
-        private final List body;
+        private final List<LayoutElement> body;
 
         private boolean isBackwardsCallable;
 
         private int backwardsCallableIndex;
 
-        public Callable(final List body) throws IOException {
+        public Callable(final List<LayoutElement> body) {
             this.body = body;
         }
 
@@ -719,30 +703,27 @@ public class NewAttributeBands extends BandSet {
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            for (final Iterator iterator = body.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                layoutElement.addAttributeToBand(attribute, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            for (AttributeLayoutElement element : body) {
+                element.addAttributeToBand(attribute, inputStream);
             }
         }
 
         @Override
-        public void pack(final OutputStream out) throws IOException, Pack200Exception {
-            for (final Iterator iterator = body.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                layoutElement.pack(out);
+        public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
+            for (AttributeLayoutElement element : body) {
+                element.pack(outputStream);
             }
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
-            for (final Iterator iterator = body.iterator(); iterator.hasNext();) {
-                final AttributeLayoutElement layoutElement = (AttributeLayoutElement) iterator.next();
-                layoutElement.renumberBci(bciRenumbering, labelsToOffsets);
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
+            for (AttributeLayoutElement element : body) {
+                element.renumberBci(bciRenumbering, labelsToOffsets);
             }
         }
 
-        public List getBody() {
+        public List<LayoutElement> getBody() {
             return body;
         }
     }
@@ -752,11 +733,11 @@ public class NewAttributeBands extends BandSet {
      */
     public class UnionCase extends LayoutElement {
 
-        private final List body;
+        private final List<LayoutElement> body;
 
-        private final List tags;
+        private final List<Integer> tags;
 
-        public UnionCase(final List tags) {
+        public UnionCase(final List<Integer> tags) {
             this.tags = tags;
             this.body = Collections.EMPTY_LIST;
         }
@@ -765,36 +746,33 @@ public class NewAttributeBands extends BandSet {
             return tags.contains(Integer.valueOf((int) l));
         }
 
-        public UnionCase(final List tags, final List body) throws IOException {
+        public UnionCase(final List<Integer> tags, final List<LayoutElement> body) {
             this.tags = tags;
             this.body = body;
         }
 
         @Override
-        public void addAttributeToBand(final NewAttribute attribute, final InputStream stream) {
-            for (int i = 0; i < body.size(); i++) {
-                final LayoutElement element = (LayoutElement) body.get(i);
-                element.addAttributeToBand(attribute, stream);
+        public void addAttributeToBand(final NewAttribute attribute, final InputStream inputStream) {
+            for (LayoutElement element : body) {
+                element.addAttributeToBand(attribute, inputStream);
             }
         }
 
         @Override
-        public void pack(final OutputStream out) throws IOException, Pack200Exception {
-            for (int i = 0; i < body.size(); i++) {
-                final LayoutElement element = (LayoutElement) body.get(i);
-                element.pack(out);
+        public void pack(final OutputStream outputStream) throws IOException, Pack200Exception {
+            for (LayoutElement element : body) {
+                element.pack(outputStream);
             }
         }
 
         @Override
-        public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
-            for (int i = 0; i < body.size(); i++) {
-                final LayoutElement element = (LayoutElement) body.get(i);
+        public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
+            for (LayoutElement element : body) {
                 element.renumberBci(bciRenumbering, labelsToOffsets);
             }
         }
 
-        public List getBody() {
+        public List<LayoutElement> getBody() {
             return body;
         }
     }
@@ -803,15 +781,19 @@ public class NewAttributeBands extends BandSet {
      * Utility method to get the contents of the given stream, up to the next ']', (ignoring pairs of brackets '[' and
      * ']')
      *
-     * @param stream
+     * @param reader
      * @return
      * @throws IOException If an I/O error occurs.
      */
-    private StringReader getStreamUpToMatchingBracket(final StringReader stream) throws IOException {
-        final StringBuffer sb = new StringBuffer();
+    private StringReader getStreamUpToMatchingBracket(final StringReader reader) throws IOException {
+        final StringBuilder sb = new StringBuilder();
         int foundBracket = -1;
         while (foundBracket != 0) {
-            final char c = (char) stream.read();
+            int read = reader.read();
+            if (read == -1) {
+            	break;
+            }
+			final char c = (char) read;
             if (c == ']') {
                 foundBracket++;
             }
@@ -825,13 +807,13 @@ public class NewAttributeBands extends BandSet {
         return new StringReader(sb.toString());
     }
 
-    private int readInteger(final int i, final InputStream stream) {
+    private int readInteger(final int i, final InputStream inputStream) {
         int result = 0;
         for (int j = 0; j < i; j++) {
             try {
-                result = result << 8 | stream.read();
+                result = result << 8 | inputStream.read();
             } catch (final IOException e) {
-                throw new RuntimeException("Error reading unknown attribute");
+                throw new UncheckedIOException("Error reading unknown attribute", e);
             }
         }
         // use casting to preserve sign
@@ -870,15 +852,19 @@ public class NewAttributeBands extends BandSet {
      * Utility method to get the contents of the given stream, up to the next ']', (ignoring pairs of brackets '[' and
      * ']')
      *
-     * @param stream
+     * @param reader
      * @return
      * @throws IOException If an I/O error occurs.
      */
-    private String readUpToMatchingBracket(final StringReader stream) throws IOException {
-        final StringBuffer sb = new StringBuffer();
+    private String readUpToMatchingBracket(final StringReader reader) throws IOException {
+        final StringBuilder sb = new StringBuilder();
         int foundBracket = -1;
         while (foundBracket != 0) {
-            final char c = (char) stream.read();
+            int read = reader.read();
+            if (read == -1) {
+            	break;
+            }
+			final char c = (char) read;
             if (c == ']') {
                 foundBracket++;
             }
@@ -927,14 +913,14 @@ public class NewAttributeBands extends BandSet {
     /**
      * Read a 'body' section of the layout from the given stream
      *
-     * @param stream
+     * @param reader
      * @return List of LayoutElements
      * @throws IOException If an I/O error occurs.
      */
-    private List readBody(final StringReader stream) throws IOException {
-        final List layoutElements = new ArrayList();
+    private List<LayoutElement> readBody(final StringReader reader) throws IOException {
+        final List<LayoutElement> layoutElements = new ArrayList<>();
         LayoutElement e;
-        while ((e = readNextLayoutElement(stream)) != null) {
+        while ((e = readNextLayoutElement(reader)) != null) {
             layoutElements.add(e);
         }
         return layoutElements;
@@ -946,10 +932,9 @@ public class NewAttributeBands extends BandSet {
      * @param bciRenumbering TODO
      * @param labelsToOffsets TODO
      */
-    public void renumberBci(final IntList bciRenumbering, final Map labelsToOffsets) {
-        for (final Iterator iterator = attributeLayoutElements.iterator(); iterator.hasNext();) {
-            final AttributeLayoutElement element = (AttributeLayoutElement) iterator.next();
-            element.renumberBci(bciRenumbering, labelsToOffsets);
+    public void renumberBci(final IntList bciRenumbering, final Map<Label, Integer> labelsToOffsets) {
+        for (AttributeLayoutElement attributeLayoutElement : attributeLayoutElements) {
+            attributeLayoutElement.renumberBci(bciRenumbering, labelsToOffsets);
         }
     }
 
