@@ -36,6 +36,7 @@ import org.apache.commons.compress.harmony.unpack200.bytecode.CPMethodRef;
 import org.apache.commons.compress.harmony.unpack200.bytecode.CPNameAndType;
 import org.apache.commons.compress.harmony.unpack200.bytecode.CPString;
 import org.apache.commons.compress.harmony.unpack200.bytecode.CPUTF8;
+import org.apache.commons.compress.utils.ExactMath;
 
 /**
  * Abstract superclass for a set of bands
@@ -61,13 +62,13 @@ public abstract class BandSet {
     }
 
     /**
-     * Decode a band and return an array of <code>int</code> values
+     * Decode a band and return an array of {@code int} values
      *
      * @param name the name of the band (primarily for logging/debugging purposes)
      * @param in the InputStream to decode from
      * @param codec the default Codec for this band
      * @param count the number of elements to read
-     * @return an array of decoded <code>int</code> values
+     * @return an array of decoded {@code int} values
      * @throws IOException if there is a problem reading from the underlying input stream
      * @throws Pack200Exception if there is a problem decoding the value or that the value is invalid
      */
@@ -106,7 +107,7 @@ public abstract class BandSet {
         // }
         if (codecUsed instanceof PopulationCodec) {
             final PopulationCodec popCodec = (PopulationCodec) codecUsed;
-            final int[] favoured = (int[]) popCodec.getFavoured().clone();
+            final int[] favoured = popCodec.getFavoured().clone();
             Arrays.sort(favoured);
             for (int i = 0; i < band.length; i++) {
                 final boolean favouredValue = Arrays.binarySearch(favoured, band[i]) > -1;
@@ -118,7 +119,7 @@ public abstract class BandSet {
                         band[i] -= cardinality;
                     }
                     while (band[i] < bhsd.smallest()) {
-                        band[i] += cardinality;
+                        band[i] = ExactMath.add(band[i], cardinality);
                     }
                 }
             }
@@ -127,13 +128,13 @@ public abstract class BandSet {
     }
 
     /**
-     * Decode a band and return an array of <code>int[]</code> values
+     * Decode a band and return an array of {@code int[]} values
      *
      * @param name the name of the band (primarily for logging/debugging purposes)
      * @param in the InputStream to decode from
      * @param defaultCodec the default codec for this band
      * @param counts the numbers of elements to read for each int array within the array to be returned
-     * @return an array of decoded <code>int[]</code> values
+     * @return an array of decoded {@code int[]} values
      * @throws IOException if there is a problem reading from the underlying input stream
      * @throws Pack200Exception if there is a problem decoding the value or that the value is invalid
      */
@@ -141,8 +142,8 @@ public abstract class BandSet {
         final int[] counts) throws IOException, Pack200Exception {
         final int[][] result = new int[counts.length][];
         int totalCount = 0;
-        for (int i = 0; i < counts.length; i++) {
-            totalCount += counts[i];
+        for (int count : counts) {
+            totalCount += count;
         }
         final int[] twoDResult = decodeBandInt(name, in, defaultCodec, totalCount);
         int index = 0;
@@ -161,7 +162,7 @@ public abstract class BandSet {
         return parseFlags(name, in, new int[] {count}, (hasHi ? codec : null), codec)[0];
     }
 
-    public long[][] parseFlags(final String name, final InputStream in, final int counts[], final BHSDCodec codec,
+    public long[][] parseFlags(final String name, final InputStream in, final int[] counts, final BHSDCodec codec,
         final boolean hasHi) throws IOException, Pack200Exception {
         return parseFlags(name, in, counts, (hasHi ? codec : null), codec);
     }
@@ -171,7 +172,7 @@ public abstract class BandSet {
         return parseFlags(name, in, new int[] {count}, hiCodec, loCodec)[0];
     }
 
-    public long[][] parseFlags(final String name, final InputStream in, final int counts[], final BHSDCodec hiCodec,
+    public long[][] parseFlags(final String name, final InputStream in, final int[] counts, final BHSDCodec hiCodec,
         final BHSDCodec loCodec) throws IOException, Pack200Exception {
         final int count = counts.length;
         if (count == 0) {
@@ -207,8 +208,8 @@ public abstract class BandSet {
     }
 
     /**
-     * Parses <i>count</i> references from <code>in</code>, using <code>codec</code> to decode the values as indexes
-     * into <code>reference</code> (which is populated prior to this call). An exception is thrown if a decoded index
+     * Parses <i>count</i> references from {@code in}, using {@code codec} to decode the values as indexes
+     * into {@code reference} (which is populated prior to this call). An exception is thrown if a decoded index
      * falls outside the range [0..reference.length-1].
      *
      * @param name the band name
@@ -227,8 +228,8 @@ public abstract class BandSet {
     }
 
     /**
-     * Parses <i>count</i> references from <code>in</code>, using <code>codec</code> to decode the values as indexes
-     * into <code>reference</code> (which is populated prior to this call). An exception is thrown if a decoded index
+     * Parses <i>count</i> references from {@code in}, using {@code codec} to decode the values as indexes
+     * into {@code reference} (which is populated prior to this call). An exception is thrown if a decoded index
      * falls outside the range [0..reference.length-1]. Unlike the other parseReferences, this post-processes the result
      * into an array of results.
      *
@@ -243,7 +244,7 @@ public abstract class BandSet {
      * @throws Pack200Exception if a problem occurs with an unexpected value or unsupported Codec
      */
     public String[][] parseReferences(final String name, final InputStream in, final BHSDCodec codec,
-        final int counts[], final String[] reference) throws IOException, Pack200Exception {
+        final int[] counts, final String[] reference) throws IOException, Pack200Exception {
         final int count = counts.length;
         if (count == 0) {
             return new String[][] {{}};
@@ -265,13 +266,12 @@ public abstract class BandSet {
             }
             result1[i1] = reference[index];
         }
-        final String[] refs = result1;
         // TODO Merge the decode and parsing of a multiple structure into one
         int pos = 0;
         for (int i = 0; i < count; i++) {
             final int num = counts[i];
             result[i] = new String[num];
-            System.arraycopy(refs, pos, result[i], 0, num);
+            System.arraycopy(result1, pos, result[i], 0, num);
             pos += num;
         }
         return result;
@@ -298,8 +298,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPDouble[] result = new CPDouble[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpDoubleValue(index);
+            result[i1] = segment.getCpBands().cpDoubleValue(indices[i1]);
         }
         return result;
     }
@@ -309,8 +308,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPFloat[] result = new CPFloat[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpFloatValue(index);
+            result[i1] = segment.getCpBands().cpFloatValue(indices[i1]);
         }
         return result;
     }
@@ -356,12 +354,11 @@ public abstract class BandSet {
             final int index = indices[i1];
             result1[i1] = segment.getCpBands().cpUTF8Value(index);
         }
-        final CPUTF8[] refs = result1;
         int pos = 0;
         for (int i = 0; i < counts.length; i++) {
             final int num = counts[i];
             result[i] = new CPUTF8[num];
-            System.arraycopy(refs, pos, result[i], 0, num);
+            System.arraycopy(result1, pos, result[i], 0, num);
             pos += num;
         }
         return result;
@@ -372,8 +369,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPString[] result = new CPString[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpStringValue(index);
+            result[i1] = segment.getCpBands().cpStringValue(indices[i1]);
         }
         return result;
     }
@@ -384,8 +380,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPInterfaceMethodRef[] result = new CPInterfaceMethodRef[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = cpBands.cpIMethodValue(index);
+            result[i1] = cpBands.cpIMethodValue(indices[i1]);
         }
         return result;
     }
@@ -396,8 +391,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPMethodRef[] result = new CPMethodRef[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = cpBands.cpMethodValue(index);
+            result[i1] = cpBands.cpMethodValue(indices[i1]);
         }
         return result;
     }
@@ -431,8 +425,7 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPUTF8[] result = new CPUTF8[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpSignatureValue(index);
+            result[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
         }
         return result;
     }
@@ -448,15 +441,13 @@ public abstract class BandSet {
         final CPUTF8[] result1 = new CPUTF8[sum];
         final int[] indices = decodeBandInt(name, in, codec, sum);
         for (int i1 = 0; i1 < sum; i1++) {
-            final int index = indices[i1];
-            result1[i1] = segment.getCpBands().cpSignatureValue(index);
+            result1[i1] = segment.getCpBands().cpSignatureValue(indices[i1]);
         }
-        final CPUTF8[] refs = result1;
         int pos = 0;
         for (int i = 0; i < counts.length; i++) {
             final int num = counts[i];
             result[i] = new CPUTF8[num];
-            System.arraycopy(refs, pos, result[i], 0, num);
+            System.arraycopy(result1, pos, result[i], 0, num);
             pos += num;
         }
         return result;
@@ -467,17 +458,14 @@ public abstract class BandSet {
         final int[] indices = decodeBandInt(name, in, codec, count);
         final CPClass[] result = new CPClass[indices.length];
         for (int i1 = 0; i1 < count; i1++) {
-            final int index = indices[i1];
-            result[i1] = segment.getCpBands().cpClassValue(index);
+            result[i1] = segment.getCpBands().cpClassValue(indices[i1]);
         }
         return result;
     }
 
     protected String[] getReferences(final int[] ints, final String[] reference) {
         final String[] result = new String[ints.length];
-        for (int i = 0; i < result.length; i++) {
-            result[i] = reference[ints[i]];
-        }
+        Arrays.setAll(result, i -> reference[ints[i]]);
         return result;
     }
 
@@ -487,7 +475,6 @@ public abstract class BandSet {
             result[i] = new String[ints[i].length];
             for (int j = 0; j < result[i].length; j++) {
                 result[i][j] = reference[ints[i][j]];
-
             }
         }
         return result;
