@@ -28,11 +28,20 @@ import java.util.zip.Checksum;
  * @since 1.7
  */
 public class ChecksumVerifyingInputStream extends InputStream {
+
     private final InputStream in;
     private long bytesRemaining;
     private final long expectedChecksum;
     private final Checksum checksum;
 
+    /**
+     * Constructs a new instance.
+     *
+     * @param checksum Checksum implementation.
+     * @param in the stream to wrap
+     * @param size the of the stream's content
+     * @param expectedChecksum the expected checksum
+     */
     public ChecksumVerifyingInputStream(final Checksum checksum, final InputStream in,
                                         final long size, final long expectedChecksum) {
         this.checksum = checksum;
@@ -41,6 +50,19 @@ public class ChecksumVerifyingInputStream extends InputStream {
         this.bytesRemaining = size;
     }
 
+    @Override
+    public void close() throws IOException {
+        in.close();
+    }
+
+    /**
+     * @return bytes remaining to read
+     * @since 1.21
+     */
+    public long getBytesRemaining() {
+        return bytesRemaining;
+    }
+
     /**
      * Reads a single byte from the stream
      * @throws IOException if the underlying stream throws or the
@@ -57,9 +79,7 @@ public class ChecksumVerifyingInputStream extends InputStream {
             checksum.update(ret);
             --bytesRemaining;
         }
-        if (bytesRemaining == 0 && expectedChecksum != checksum.getValue()) {
-            throw new IOException("Checksum verification failed");
-        }
+        verify();
         return ret;
     }
 
@@ -82,28 +102,27 @@ public class ChecksumVerifyingInputStream extends InputStream {
      */
     @Override
     public int read(final byte[] b, final int off, final int len) throws IOException {
+        if (len == 0) {
+            return 0;
+        }
         final int ret = in.read(b, off, len);
         if (ret >= 0) {
             checksum.update(b, off, ret);
             bytesRemaining -= ret;
         }
-        if (bytesRemaining <= 0 && expectedChecksum != checksum.getValue()) {
-            throw new IOException("Checksum verification failed");
-        }
+        verify();
         return ret;
     }
 
     @Override
     public long skip(final long n) throws IOException {
         // Can't really skip, we have to hash everything to verify the checksum
-        if (read() >= 0) {
-            return 1;
-        }
-        return 0;
+        return read() >= 0 ? 1 : 0;
     }
 
-    @Override
-    public void close() throws IOException {
-        in.close();
+    private void verify() throws IOException {
+        if (bytesRemaining <= 0 && expectedChecksum != checksum.getValue()) {
+            throw new IOException("Checksum verification failed");
+        }
     }
 }
