@@ -20,26 +20,16 @@ package org.apache.commons.compress.utils;
 
 import java.io.ByteArrayOutputStream;
 import java.io.Closeable;
-import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.nio.ByteBuffer;
-import java.nio.channels.ReadableByteChannel;
 
 /**
  * Utility functions
- * @Immutable (has mutable data but it is write-only)
+ * @Immutable
  */
 public final class IOUtils {
 
-    private static final int COPY_BUF_SIZE = 8024;
-    private static final int SKIP_BUF_SIZE = 4096;
-
-    // This buffer does not need to be synchronised because it is write only; the contents are ignored
-    // Does not affect Immutability
-    private static final byte[] SKIP_BUF = new byte[SKIP_BUF_SIZE];
-
     /** Private constructor to prevent instantiation of this utility class. */
     private IOUtils(){
     }
@@ -52,12 +42,11 @@ public final class IOUtils {
      *            the InputStream to copy
      * @param output
      *            the target Stream
-     * @return the number of bytes copied
      * @throws IOException
      *             if an error occurs
      */
     public static long copy(final InputStream input, final OutputStream output) throws IOException {
-        return copy(input, output, COPY_BUF_SIZE);
+        return copy(input, output, 8024);
     }
 
     /**
@@ -68,17 +57,11 @@ public final class IOUtils {
      * @param output
      *            the target Stream
      * @param buffersize
-     *            the buffer size to use, must be bigger than 0
-     * @return the number of bytes copied
+     *            the buffer size to use
      * @throws IOException
      *             if an error occurs
-     * @throws IllegalArgumentException
-     *             if buffersize is smaller than or equal to 0
      */
-    public static long copy(final InputStream input, final OutputStream output, final int buffersize) throws IOException {
-        if (buffersize < 1) {
-            throw new IllegalArgumentException("buffersize must be bigger than 0");
-        }
+    public static long copy(final InputStream input, final OutputStream output, int buffersize) throws IOException {
         final byte[] buffer = new byte[buffersize];
         int n = 0;
         long count=0;
@@ -88,41 +71,28 @@ public final class IOUtils {
         }
         return count;
     }
-
+    
     /**
      * Skips the given number of bytes by repeatedly invoking skip on
      * the given input stream if necessary.
      *
-     * <p>In a case where the stream's skip() method returns 0 before
-     * the requested number of bytes has been skip this implementation
-     * will fall back to using the read() method.</p>
-     *
      * <p>This method will only skip less than the requested number of
      * bytes if the end of the input stream has been reached.</p>
      *
      * @param input stream to skip bytes in
      * @param numToSkip the number of bytes to skip
      * @return the number of bytes actually skipped
-     * @throws IOException on error
+     * @throws IOException
      */
-    public static long skip(final InputStream input, long numToSkip) throws IOException {
-        final long available = numToSkip;
+    public static long skip(InputStream input, long numToSkip) throws IOException {
+        long available = numToSkip;
         while (numToSkip > 0) {
-            final long skipped = input.skip(numToSkip);
+            long skipped = input.skip(numToSkip);
             if (skipped == 0) {
                 break;
             }
             numToSkip -= skipped;
         }
-
-        while (numToSkip > 0) {
-            final int read = readFully(input, SKIP_BUF, 0,
-                                 (int) Math.min(numToSkip, SKIP_BUF_SIZE));
-            if (read < 1) {
-                break;
-            }
-            numToSkip -= read;
-        }
         return available - numToSkip;
     }
 
@@ -136,9 +106,9 @@ public final class IOUtils {
      * @param input stream to read from
      * @param b buffer to fill
      * @return the number of bytes actually read
-     * @throws IOException on error
+     * @throws IOException
      */
-    public static int readFully(final InputStream input, final byte[] b) throws IOException {
+    public static int readFully(InputStream input, byte[] b) throws IOException {
         return readFully(input, b, 0, b.length);
     }
 
@@ -158,7 +128,7 @@ public final class IOUtils {
      * @throws IOException
      *             if an I/O error has occurred
      */
-    public static int readFully(final InputStream input, final byte[] b, final int offset, final int len)
+    public static int readFully(InputStream input, byte[] b, int offset, int len)
         throws IOException {
         if (len < 0 || offset < 0 || len + offset > b.length) {
             throw new IndexOutOfBoundsException();
@@ -174,35 +144,6 @@ public final class IOUtils {
         return count;
     }
 
-    /**
-     * Reads {@code b.remaining()} bytes from the given channel
-     * starting at the current channel's position.
-     *
-     * <p>This method reads repeatedly from the channel until the
-     * requested number of bytes are read. This method blocks until
-     * the requested number of bytes are read, the end of the channel
-     * is detected, or an exception is thrown.</p>
-     *
-     * @param channel the channel to read from
-     * @param b the buffer into which the data is read.
-     * @throws IOException - if an I/O error occurs.
-     * @throws EOFException - if the channel reaches the end before reading all the bytes.
-     */
-    public static void readFully(ReadableByteChannel channel, ByteBuffer b) throws IOException {
-        final int expectedLength = b.remaining();
-        int read = 0;
-        while (read < expectedLength) {
-            int readNow = channel.read(b);
-            if (readNow <= 0) {
-                break;
-            }
-            read += readNow;
-        }
-        if (read < expectedLength) {
-            throw new EOFException();
-        }
-    }
-
     // toByteArray(InputStream) copied from:
     // commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java?revision=1428941
     // January 8th, 2013
@@ -232,11 +173,11 @@ public final class IOUtils {
      * @param c Closeable to close, can be null
      * @since 1.7
      */
-    public static void closeQuietly(final Closeable c) {
+    public static void closeQuietly(Closeable c) {
         if (c != null) {
             try {
                 c.close();
-            } catch (final IOException ignored) { // NOPMD
+            } catch (IOException ignored) { // NOPMD
             }
         }
     }
