@@ -18,19 +18,20 @@
  */
 package org.apache.commons.compress;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
 import java.io.BufferedInputStream;
 import java.io.Closeable;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.URI;
 import java.net.URL;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -41,8 +42,8 @@ import org.apache.commons.compress.archivers.ArchiveInputStream;
 import org.apache.commons.compress.archivers.ArchiveOutputStream;
 import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.After;
-import org.junit.Before;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
 
 public abstract class AbstractTestCase {
 
@@ -52,9 +53,9 @@ public abstract class AbstractTestCase {
     private File archive; // used to delete the archive in tearDown
     protected List<String> archiveList; // Lists the content of the archive as originally created
 
-    protected ArchiveStreamFactory factory = new ArchiveStreamFactory();
+    protected final ArchiveStreamFactory factory = ArchiveStreamFactory.DEFAULT;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         dir = mkdir("dir");
         resultDir = mkdir("dir-result");
@@ -79,7 +80,11 @@ public abstract class AbstractTestCase {
         return new File(uri);
     }
 
-    @After
+    public static Path getPath(final String path) throws IOException {
+        return getFile(path).toPath();
+    }
+
+    @AfterEach
     public void tearDown() throws Exception {
         rmdir(dir);
         rmdir(resultDir);
@@ -118,8 +123,9 @@ public abstract class AbstractTestCase {
      * Others possible. If the delete does not work, call System.gc(),
      * wait a little and try again.
      *
+     * Copied from FileUtils in Ant 1.8.0.
+     *
      * @return whether deletion was successful
-     * @since Stolen from FileUtils in Ant 1.8.0
      */
     public static boolean tryHardToDelete(final File f) {
         if (f != null && f.exists() && !f.delete()) {
@@ -138,7 +144,7 @@ public abstract class AbstractTestCase {
 
     /**
      * Creates an archive of textbased files in several directories. The
-     * archivername is the factory identifier for the archiver, for example zip,
+     * archivename is the factory identifier for the archiver, for example zip,
      * tar, cpio, jar, ar. The archive is created as a temp file.
      *
      * The archive contains the following files:
@@ -168,7 +174,7 @@ public abstract class AbstractTestCase {
             archive.deleteOnExit();
             archiveList = new ArrayList<>();
 
-            stream = new FileOutputStream(archive);
+            stream = Files.newOutputStream(archive.toPath());
             out = factory.createArchiveOutputStream(archivename, stream);
 
             final File file1 = getFile("test1.xml");
@@ -203,7 +209,8 @@ public abstract class AbstractTestCase {
      * Add an entry to the archive, and keep track of the names in archiveList.
      *
      * @param out
-     * @param file1
+     * @param filename
+     * @param infile
      * @throws IOException
      * @throws FileNotFoundException
      */
@@ -211,7 +218,7 @@ public abstract class AbstractTestCase {
             throws IOException, FileNotFoundException {
         final ArchiveEntry entry = out.createArchiveEntry(infile, filename);
         out.putArchiveEntry(entry);
-        IOUtils.copy(new FileInputStream(infile), out);
+        IOUtils.copy(infile, out);
         out.closeArchiveEntry();
         archiveList.add(filename);
     }
@@ -229,7 +236,7 @@ public abstract class AbstractTestCase {
         try {
             archive = File.createTempFile("empty", "." + archivename);
             archive.deleteOnExit();
-            stream = new FileOutputStream(archive);
+            stream = Files.newOutputStream(archive.toPath());
             out = factory.createArchiveOutputStream(archivename, stream);
             out.finish();
         } finally {
@@ -256,7 +263,7 @@ public abstract class AbstractTestCase {
         try {
             archive = File.createTempFile("empty", "." + archivename);
             archive.deleteOnExit();
-            stream = new FileOutputStream(archive);
+            stream = Files.newOutputStream(archive.toPath());
             out = factory.createArchiveOutputStream(archivename, stream);
             // Use short file name so does not cause problems for ar
             addArchiveEntry(out, "test1.xml", getFile("test1.xml"));
@@ -282,7 +289,7 @@ public abstract class AbstractTestCase {
      */
     protected void checkArchiveContent(final File archive, final List<String> expected)
             throws Exception {
-        try (InputStream is = new FileInputStream(archive)) {
+        try (InputStream is = Files.newInputStream(archive.toPath())) {
             final BufferedInputStream buf = new BufferedInputStream(is);
             final ArchiveInputStream in = factory.createArchiveInputStream(buf);
             this.checkArchiveContent(in, expected);
@@ -325,7 +332,7 @@ public abstract class AbstractTestCase {
                     outfile.mkdirs();
                 } else {
                     outfile.getParentFile().mkdirs();
-                    try (OutputStream out = new FileOutputStream(outfile)) {
+                    try (OutputStream out = Files.newOutputStream(outfile.toPath())) {
                         copied = IOUtils.copy(in, out);
                     }
                 }
@@ -342,7 +349,7 @@ public abstract class AbstractTestCase {
                 }
             }
             in.close();
-            if (expected != null && expected.size() > 0) {
+            if (expected != null && !expected.isEmpty()) {
                 fail(expected.size() + " missing entries: " + Arrays.toString(expected.toArray()));
             }
             if (expected != null) {
@@ -376,7 +383,7 @@ public abstract class AbstractTestCase {
         final File tmpDir = createTempDir();
         final File tmpFile = File.createTempFile("testfile", "", tmpDir);
         tmpFile.deleteOnExit();
-        try (FileOutputStream fos = new FileOutputStream(tmpFile)) {
+        try (OutputStream fos = Files.newOutputStream(tmpFile.toPath())) {
             fos.write(new byte[] { 'f', 'o', 'o' });
             return new File[] { tmpDir, tmpFile };
         }
@@ -398,7 +405,7 @@ public abstract class AbstractTestCase {
         }
     }
 
-    protected static interface StreamWrapper<I extends InputStream> {
+    protected interface StreamWrapper<I extends InputStream> {
         I wrap(InputStream in) throws Exception;
     }
 }
