@@ -21,6 +21,7 @@ package org.apache.commons.compress.archivers;
 import static org.apache.commons.compress.AbstractTestCase.getFile;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -41,7 +42,7 @@ import org.apache.commons.compress.archivers.jar.JarArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
 import org.apache.commons.compress.utils.ByteUtils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class ArchiveStreamFactoryTest {
 
@@ -88,18 +89,16 @@ public class ArchiveStreamFactoryTest {
         }
     }
 
-    @Test(expected = StreamingNotSupportedException.class)
+    @Test
     public void cantRead7zFromStream() throws Exception {
-        ArchiveStreamFactory.DEFAULT
-            .createArchiveInputStream(ArchiveStreamFactory.SEVEN_Z,
-                                      new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY));
+        assertThrows(StreamingNotSupportedException.class,
+            () -> ArchiveStreamFactory.DEFAULT.createArchiveInputStream(ArchiveStreamFactory.SEVEN_Z, new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY)));
     }
 
-    @Test(expected = StreamingNotSupportedException.class)
+    @Test
     public void cantWrite7zToStream() throws Exception {
-        ArchiveStreamFactory.DEFAULT
-            .createArchiveOutputStream(ArchiveStreamFactory.SEVEN_Z,
-                                       new ByteArrayOutputStream());
+        assertThrows(StreamingNotSupportedException.class,
+            () -> ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.SEVEN_Z, new ByteArrayOutputStream()));
     }
 
     /**
