@@ -1,8 +1,3 @@
-package org.apache.commons.compress.archivers;
-
-import org.junit.Assert;
-import junit.framework.TestCase;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -21,7 +16,15 @@ import junit.framework.TestCase;
  * specific language governing permissions and limitations
  * under the License.
  */
-public class ExceptionMessageTest extends TestCase {
+
+package org.apache.commons.compress.archivers;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
+import org.junit.jupiter.api.Test;
+
+public class ExceptionMessageTest {
 
     private static final String ARCHIVER_NULL_MESSAGE = "Archivername must not be null.";
 
@@ -30,46 +33,50 @@ public class ExceptionMessageTest extends TestCase {
     private static final String OUTPUTSTREAM_NULL_MESSAGE = "OutputStream must not be null.";
 
 
+    @Test
     public void testMessageWhenArchiverNameIsNull_1(){
         try{
-            new ArchiveStreamFactory().createArchiveInputStream(null, System.in);
+            ArchiveStreamFactory.DEFAULT.createArchiveInputStream(null, System.in);
             fail("Should raise an IllegalArgumentException.");
-        }catch (IllegalArgumentException e) {
-            Assert.assertEquals(ARCHIVER_NULL_MESSAGE, e.getMessage());
-        } catch (ArchiveException e) {
+        }catch (final IllegalArgumentException e) {
+            assertEquals(ARCHIVER_NULL_MESSAGE, e.getMessage());
+        } catch (final ArchiveException e) {
             fail("ArchiveException not expected");
         }
     }
 
+    @Test
     public void testMessageWhenInputStreamIsNull(){
         try{
-            new ArchiveStreamFactory().createArchiveInputStream("zip", null);
+            ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", null);
             fail("Should raise an IllegalArgumentException.");
-        }catch (IllegalArgumentException e) {
-            Assert.assertEquals(INPUTSTREAM_NULL_MESSAGE, e.getMessage());
-        } catch (ArchiveException e) {
+        }catch (final IllegalArgumentException e) {
+            assertEquals(INPUTSTREAM_NULL_MESSAGE, e.getMessage());
+        } catch (final ArchiveException e) {
             fail("ArchiveException not expected");
         }
     }
 
+    @Test
     public void testMessageWhenArchiverNameIsNull_2(){
         try{
-            new ArchiveStreamFactory().createArchiveOutputStream(null, System.out);
+            ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(null, System.out);
             fail("Should raise an IllegalArgumentException.");
-        } catch (IllegalArgumentException e) {
-            Assert.assertEquals(ARCHIVER_NULL_MESSAGE, e.getMessage());
-        } catch (ArchiveException e){
+        } catch (final IllegalArgumentException e) {
+            assertEquals(ARCHIVER_NULL_MESSAGE, e.getMessage());
+        } catch (final ArchiveException e){
             fail("ArchiveException not expected");
         }
     }
 
+    @Test
     public void testMessageWhenOutputStreamIsNull(){
         try{
-            new ArchiveStreamFactory().createArchiveOutputStream("zip", null);
+            ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("zip", null);
             fail("Should raise an IllegalArgumentException.");
-        } catch (IllegalArgumentException e) {
-            Assert.assertEquals(OUTPUTSTREAM_NULL_MESSAGE, e.getMessage());
-        } catch (ArchiveException e) {
+        } catch (final IllegalArgumentException e) {
+            assertEquals(OUTPUTSTREAM_NULL_MESSAGE, e.getMessage());
+        } catch (final ArchiveException e) {
             fail("ArchiveException not expected");
         }
     }
