@@ -24,33 +24,31 @@ import static org.junit.Assert.fail;
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileReader;
-import java.io.FilenameFilter;
 import java.net.URISyntaxException;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.stream.Stream;
 
-import junit.framework.AssertionFailedError;
 import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.archivers.ar.ArArchiveInputStream;
 import org.apache.commons.compress.archivers.cpio.CpioArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
+
+import junit.framework.AssertionFailedError;
 
 /**
  * Test that can read various tar file examples.
  *
-  * Files must be in resources/longpath, and there must be a file.txt containing
+ * Files must be in resources/longpath, and there must be a file.txt containing
  * the list of files in the archives.
-*/
-@RunWith(Parameterized.class)
+ */
 public class LongPathTest extends AbstractTestCase {
 
     private static final ClassLoader CLASSLOADER = LongPathTest.class.getClassLoader();
@@ -60,47 +58,32 @@ public class LongPathTest extends AbstractTestCase {
     static {
         try {
             ARCDIR = new File(CLASSLOADER.getResource("longpath").toURI());
-        } catch (URISyntaxException e) {
-            throw new RuntimeException(e);
+        } catch (final URISyntaxException e) {
+            throw new AssertionError(e);
         }
     }
 
-    private final File file;
-
-
-
-    public LongPathTest(final String file){
-        this.file = new File(ARCDIR, file);
-    }
-
-    @BeforeClass
+    @BeforeAll
     public static void setUpFileList() throws Exception {
         assertTrue(ARCDIR.exists());
-        final File listing= new File(ARCDIR,"files.txt");
-        assertTrue("files.txt is readable",listing.canRead());
-        final BufferedReader br = new BufferedReader(new FileReader(listing));
+        final File listing = new File(ARCDIR, "files.txt");
+        assertTrue("files.txt is readable", listing.canRead());
+        final BufferedReader br = new BufferedReader(Files.newBufferedReader(listing.toPath()));
         String line;
-        while ((line=br.readLine())!=null){
-            if (!line.startsWith("#")){
+        while ((line = br.readLine()) != null) {
+            if (!line.startsWith("#")) {
                 FILELIST.add(line);
             }
         }
         br.close();
     }
 
-    @Parameters(name = "file={0}")
-    public static Collection<Object[]> data() {
-        final Collection<Object[]> params = new ArrayList<>();
-        for (final String f : ARCDIR.list(new FilenameFilter() {
-            @Override
-            public boolean accept(final File dir, final String name) {
-                return !name.endsWith(".txt");
-            }
-        }))
-        {
-            params.add(new Object[] { f });
+    public static Stream<Arguments> data() {
+        final Collection<Arguments> params = new ArrayList<>();
+        for (final String fileName : ARCDIR.list((dir, name) -> !name.endsWith(".txt"))) {
+            params.add(Arguments.of(new File(ARCDIR, fileName)));
         }
-      return params;
+        return params.stream();
     }
 
     @Override
@@ -114,8 +97,9 @@ public class LongPathTest extends AbstractTestCase {
         return entry.getName();
     }
 
-    @Test
-    public void testArchive() throws Exception {
+    @ParameterizedTest
+    @MethodSource("data")
+    public void testArchive(final File file) throws Exception {
         @SuppressWarnings("unchecked") // fileList is of correct type
         final
         ArrayList<String> expected = (ArrayList<String>) FILELIST.clone();
@@ -124,7 +108,7 @@ public class LongPathTest extends AbstractTestCase {
             expected.add("META-INF/");
             expected.add("META-INF/MANIFEST.MF");
         }
-        final ArchiveInputStream ais = factory.createArchiveInputStream(new BufferedInputStream(new FileInputStream(file)));
+        final ArchiveInputStream ais = factory.createArchiveInputStream(new BufferedInputStream(Files.newInputStream(file.toPath())));
         // check if expected type recognized
         if (name.endsWith(".tar")){
             assertTrue(ais instanceof TarArchiveInputStream);
@@ -147,7 +131,7 @@ public class LongPathTest extends AbstractTestCase {
                 if (!ent.endsWith("/")) {// not a directory
                     final int lastSlash = ent.lastIndexOf('/');
                     if (lastSlash >= 0) { // extract path name
-                        expected.add(ent.substring(lastSlash + 1, ent.length()));
+                        expected.add(ent.substring(lastSlash + 1));
                     } else {
                         expected.add(ent);
                     }
