@@ -28,19 +28,20 @@ import java.net.URISyntaxException;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.stream.Stream;
 
-import junit.framework.AssertionFailedError;
 import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.archivers.ar.ArArchiveInputStream;
 import org.apache.commons.compress.archivers.cpio.CpioArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
+
+import junit.framework.AssertionFailedError;
 
 /**
  * Test that can read various tar file examples.
@@ -48,7 +49,6 @@ import org.junit.runners.Parameterized.Parameters;
   * Files must be in resources/longsymlink, and there must be a file.txt containing
  * the list of files in the archives.
 */
-@RunWith(Parameterized.class)
 public class LongSymLinkTest extends AbstractTestCase {
 
     private static final ClassLoader CLASSLOADER = LongSymLinkTest.class.getClassLoader();
@@ -59,17 +59,11 @@ public class LongSymLinkTest extends AbstractTestCase {
         try {
             ARCDIR = new File(CLASSLOADER.getResource("longsymlink").toURI());
         } catch (final URISyntaxException e) {
-            throw new RuntimeException(e);
+            throw new AssertionError(e);
         }
     }
 
-    private final File file;
-
-    public LongSymLinkTest(final String file){
-        this.file = new File(ARCDIR, file);
-    }
-
-    @BeforeClass
+    @BeforeAll
     public static void setUpFileList() throws Exception {
         assertTrue(ARCDIR.exists());
         final File listing= new File(ARCDIR,"files.txt");
@@ -84,14 +78,12 @@ public class LongSymLinkTest extends AbstractTestCase {
         br.close();
     }
 
-    @Parameters(name = "file={0}")
-    public static Collection<Object[]> data() {
-        final Collection<Object[]> params = new ArrayList<>();
-        for (final String f : ARCDIR.list((dir, name) -> !name.endsWith(".txt")))
-        {
-            params.add(new Object[] { f });
+    public static Stream<Arguments> data() {
+        final Collection<Arguments> params = new ArrayList<>();
+        for (final String fileName : ARCDIR.list((dir, name) -> !name.endsWith(".txt"))) {
+            params.add(Arguments.of(new File(ARCDIR, fileName)));
         }
-      return params;
+        return params.stream();
     }
 
 
@@ -106,8 +98,9 @@ public class LongSymLinkTest extends AbstractTestCase {
         return entry.getName();
     }
 
-    @Test
-    public void testArchive() throws Exception {
+    @ParameterizedTest
+    @MethodSource("data")
+    public void testArchive(final File file) throws Exception {
         @SuppressWarnings("unchecked") // fileList is of correct type
         final
         ArrayList<String> expected = (ArrayList<String>) FILELIST.clone();
