@@ -24,6 +24,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.nio.file.Files;
 import java.security.NoSuchAlgorithmException;
+
 import javax.crypto.Cipher;
 
 import org.apache.commons.compress.AbstractTestCase;
@@ -32,8 +33,8 @@ import org.apache.commons.compress.archivers.sevenz.SevenZFile;
 import org.apache.commons.compress.archivers.sevenz.SevenZMethod;
 import org.apache.commons.compress.archivers.sevenz.SevenZOutputFile;
 import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class SevenZTestCase extends AbstractTestCase {
 
@@ -46,7 +47,7 @@ public class SevenZTestCase extends AbstractTestCase {
     }
 
     @Override
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         super.setUp();
         output = new File(dir, "bla.7z");
