@@ -21,9 +21,10 @@ package org.apache.commons.compress.archivers.ar;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.CoreMatchers.nullValue;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertThrows;
 
 import java.io.BufferedInputStream;
 import java.io.IOException;
@@ -34,7 +35,7 @@ import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.utils.ArchiveUtils;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class ArArchiveInputStreamTest extends AbstractTestCase {
 
@@ -119,20 +120,20 @@ public class ArArchiveInputStreamTest extends AbstractTestCase {
         }
     }
 
-    @Test(expected=IllegalStateException.class)
+    @Test
     public void cantReadWithoutOpeningAnEntry() throws Exception {
         try (InputStream in = Files.newInputStream(getFile("bla.ar").toPath());
              ArArchiveInputStream archive = new ArArchiveInputStream(in)) {
-            archive.read();
+            assertThrows(IllegalStateException.class, () -> archive.read());
         }
     }
 
-    @Test(expected=IllegalStateException.class)
+    @Test
     public void cantReadAfterClose() throws Exception {
         try (InputStream in = Files.newInputStream(getFile("bla.ar").toPath());
              ArArchiveInputStream archive = new ArArchiveInputStream(in)) {
             archive.close();
-            archive.read();
+            assertThrows(IllegalStateException.class, () -> archive.read());
         }
     }
 }
