@@ -18,66 +18,48 @@
  */
 package org.apache.commons.compress.archivers.cpio;
 
-import org.junit.Test;
-
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
+
+import org.junit.jupiter.api.Test;
 
 public class CpioUtilTest {
 
     @Test
     public void oldBinMagic2ByteArrayNotSwapped() {
-        assertArrayEquals(new byte[] { (byte) 0xc7, 0x71 },
-                          CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY,
-                                                  2, false));
+        assertArrayEquals(new byte[] {(byte) 0xc7, 0x71}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, false));
     }
 
     @Test
     public void oldBinMagic2ByteArraySwapped() {
-        assertArrayEquals(new byte[] { 0x71, (byte) 0xc7,  },
-                          CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY,
-                                                  2, true));
+        assertArrayEquals(new byte[] {0x71, (byte) 0xc7,}, CpioUtil.long2byteArray(CpioConstants.MAGIC_OLD_BINARY, 2, true));
     }
 
     @Test
     public void oldBinMagicFromByteArrayNotSwapped() {
-        assertEquals(CpioConstants.MAGIC_OLD_BINARY,
-                     CpioUtil.byteArray2long(new byte[] { (byte) 0xc7, 0x71 },
-                                             false));
+        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {(byte) 0xc7, 0x71}, false));
     }
 
     @Test
     public void oldBinMagicFromByteArraySwapped() {
-        assertEquals(CpioConstants.MAGIC_OLD_BINARY,
-                     CpioUtil.byteArray2long(new byte[] { 0x71, (byte) 0xc7 },
-                                             true));
+        assertEquals(CpioConstants.MAGIC_OLD_BINARY, CpioUtil.byteArray2long(new byte[] {0x71, (byte) 0xc7}, true));
     }
 
-
-    @Test(expected = UnsupportedOperationException.class)
-    public void testLong2byteArrayWithZeroThrowsUnsupportedOperationException() {
-
-        CpioUtil.long2byteArray(0L, 0, false);
-
-    }
-
-
-    @Test(expected = UnsupportedOperationException.class)
-    public void testLong2byteArrayWithPositiveThrowsUnsupportedOperationException() {
-
-        CpioUtil.long2byteArray(0L, 1021, false);
-
-    }
-
-
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void testByteArray2longThrowsUnsupportedOperationException() {
-
-        final byte[] byteArray = new byte[1];
-
-        CpioUtil.byteArray2long(byteArray, true);
+        assertThrows(UnsupportedOperationException.class, () -> CpioUtil.byteArray2long(new byte[1], true));
 
     }
 
+    @Test
+    public void testLong2byteArrayWithPositiveThrowsUnsupportedOperationException() {
+        assertThrows(UnsupportedOperationException.class, () -> CpioUtil.long2byteArray(0L, 1021, false));
+    }
 
-}
\ No newline at end of file
+    @Test
+    public void testLong2byteArrayWithZeroThrowsUnsupportedOperationException() {
+        assertThrows(UnsupportedOperationException.class, () -> CpioUtil.long2byteArray(0L, 0, false));
+    }
+
+}
