@@ -18,6 +18,9 @@
  */
 package org.apache.commons.compress.archivers.examples;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.Assert.assertThrows;
+
 import java.io.BufferedInputStream;
 import java.io.File;
 import java.io.IOException;
@@ -25,7 +28,6 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.channels.FileChannel;
 import java.nio.channels.SeekableByteChannel;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.StandardOpenOption;
 
@@ -36,19 +38,15 @@ import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.archivers.StreamingNotSupportedException;
 import org.apache.commons.compress.archivers.sevenz.SevenZFile;
 import org.apache.commons.compress.archivers.sevenz.SevenZOutputFile;
+import org.apache.commons.compress.archivers.tar.TarFile;
 import org.apache.commons.compress.archivers.zip.ZipFile;
 import org.apache.commons.compress.utils.IOUtils;
 import org.junit.Assert;
 import org.junit.Assume;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import org.junit.jupiter.api.Test;
 
 public class ExpanderTest extends AbstractTestCase {
 
-    @Rule
-    public ExpectedException thrown = ExpectedException.none();
-
     private File archive;
 
     @Test
@@ -65,19 +63,19 @@ public class ExpanderTest extends AbstractTestCase {
         verifyTargetDir();
     }
 
-    @Test(expected = StreamingNotSupportedException.class)
+    @Test
     public void sevenZInputStreamVersion() throws IOException, ArchiveException {
         setup7z();
         try (InputStream i = new BufferedInputStream(Files.newInputStream(archive.toPath()))) {
-            new Expander().expand("7z", i, resultDir);
+            assertThrows(StreamingNotSupportedException.class, () -> new Expander().expand("7z", i, resultDir));
         }
     }
 
-    @Test(expected = StreamingNotSupportedException.class)
+    @Test
     public void sevenZInputStreamVersionWithAutoDetection() throws IOException, ArchiveException {
         setup7z();
         try (InputStream i = new BufferedInputStream(Files.newInputStream(archive.toPath()))) {
-            new Expander().expand(i, resultDir);
+            assertThrows(StreamingNotSupportedException.class, () -> new Expander().expand(i, resultDir));
         }
     }
 
@@ -112,44 +110,58 @@ public class ExpanderTest extends AbstractTestCase {
     public void fileCantEscapeViaAbsolutePath() throws IOException, ArchiveException {
         setupZip("/tmp/foo");
         try (ZipFile f = new ZipFile(archive)) {
-            new Expander().expand(f, resultDir);
+            assertThrows(IOException.class, () -> new Expander().expand(f, resultDir));
         }
-        assertHelloWorld("tmp/foo", "1");
+        Assert.assertFalse(new File(resultDir, "tmp/foo").isFile());
     }
 
     @Test
     public void fileCantEscapeDoubleDotPath() throws IOException, ArchiveException {
-        thrown.expect(IOException.class);
-        thrown.expectMessage("Expanding ../foo would create file outside of");
         setupZip("../foo");
         try (ZipFile f = new ZipFile(archive)) {
-            new Expander().expand(f, resultDir);
+            assertThrows(IOException.class, () -> new Expander().expand(f, resultDir));
         }
     }
 
     @Test
     public void fileCantEscapeDoubleDotPathWithSimilarSibling() throws IOException, ArchiveException {
-        String sibling = resultDir.getName() + "x";
-        File s = new File(resultDir.getParentFile(), sibling);
+        final String sibling = resultDir.getName() + "x";
+        final File s = new File(resultDir.getParentFile(), sibling);
         Assume.assumeFalse(s.exists());
         s.mkdirs();
         Assume.assumeTrue(s.exists());
         s.deleteOnExit();
         try {
-            thrown.expect(IOException.class);
-            thrown.expectMessage("Expanding ../" + sibling + "/a would create file outside of");
             setupZip("../" + sibling + "/a");
             try (ZipFile f = new ZipFile(archive)) {
-                new Expander().expand(f, resultDir);
+                assertThrows(IOException.class, () -> new Expander().expand(f, resultDir));
             }
         } finally {
             tryHardToDelete(s);
         }
     }
 
-    private void setup7z() throws IOException, ArchiveException {
+    @Test
+    public void tarFileVersion() throws IOException, ArchiveException {
+        setupTar();
+        try (TarFile f = new TarFile(archive)) {
+            new Expander().expand(f, resultDir);
+        }
+        verifyTargetDir();
+    }
+
+    @Test
+    public void testCompress603Tar() throws IOException, ArchiveException {
+        setupTarForCompress603();
+        try (TarFile f = new TarFile(archive)) {
+            new Expander().expand(f, resultDir);
+        }
+        verifyTargetDir();
+    }
+
+    private void setup7z() throws IOException {
         archive = new File(dir, "test.7z");
-        File dummy = new File(dir, "x");
+        final File dummy = new File(dir, "x");
         try (OutputStream o = Files.newOutputStream(dummy.toPath())) {
             o.write(new byte[14]);
         }
@@ -161,10 +173,10 @@ public class ExpanderTest extends AbstractTestCase {
             aos.putArchiveEntry(aos.createArchiveEntry(dir, "a/b/c"));
             aos.closeArchiveEntry();
             aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/d.txt"));
-            aos.write("Hello, world 1".getBytes(StandardCharsets.UTF_8));
+            aos.write("Hello, world 1".getBytes(UTF_8));
             aos.closeArchiveEntry();
             aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/c/e.txt"));
-            aos.write("Hello, world 2".getBytes(StandardCharsets.UTF_8));
+            aos.write("Hello, world 2".getBytes(UTF_8));
             aos.closeArchiveEntry();
             aos.finish();
         }
@@ -172,11 +184,11 @@ public class ExpanderTest extends AbstractTestCase {
 
     private void setupZip() throws IOException, ArchiveException {
         archive = new File(dir, "test.zip");
-        File dummy = new File(dir, "x");
+        final File dummy = new File(dir, "x");
         try (OutputStream o = Files.newOutputStream(dummy.toPath())) {
             o.write(new byte[14]);
         }
-        try (ArchiveOutputStream aos = new ArchiveStreamFactory()
+        try (ArchiveOutputStream aos = ArchiveStreamFactory.DEFAULT
              .createArchiveOutputStream("zip", Files.newOutputStream(archive.toPath()))) {
             aos.putArchiveEntry(aos.createArchiveEntry(dir, "a"));
             aos.closeArchiveEntry();
@@ -185,25 +197,75 @@ public class ExpanderTest extends AbstractTestCase {
             aos.putArchiveEntry(aos.createArchiveEntry(dir, "a/b/c"));
             aos.closeArchiveEntry();
             aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/d.txt"));
-            aos.write("Hello, world 1".getBytes(StandardCharsets.UTF_8));
+            aos.write("Hello, world 1".getBytes(UTF_8));
             aos.closeArchiveEntry();
             aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/c/e.txt"));
-            aos.write("Hello, world 2".getBytes(StandardCharsets.UTF_8));
+            aos.write("Hello, world 2".getBytes(UTF_8));
             aos.closeArchiveEntry();
             aos.finish();
         }
     }
 
-    private void setupZip(String entry) throws IOException, ArchiveException {
-        archive = new File(dir, "test.zip");
-        File dummy = new File(dir, "x");
+    private void setupTar() throws IOException, ArchiveException {
+        archive = new File(dir, "test.tar");
+        final File dummy = new File(dir, "x");
         try (OutputStream o = Files.newOutputStream(dummy.toPath())) {
             o.write(new byte[14]);
         }
-        try (ArchiveOutputStream aos = new ArchiveStreamFactory()
+        try (ArchiveOutputStream aos = ArchiveStreamFactory.DEFAULT
+             .createArchiveOutputStream("tar", Files.newOutputStream(archive.toPath()))) {
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "a"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "a/b"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "a/b/c"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/d.txt"));
+            aos.write("Hello, world 1".getBytes(UTF_8));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dummy, "a/b/c/e.txt"));
+            aos.write("Hello, world 2".getBytes(UTF_8));
+            aos.closeArchiveEntry();
+            aos.finish();
+        }
+    }
+
+    private void setupTarForCompress603() throws IOException, ArchiveException {
+        archive = new File(dir, "test.tar");
+        final File dummy = new File(dir, "x");
+        try (OutputStream o = Files.newOutputStream(dummy.toPath())) {
+            o.write(new byte[14]);
+        }
+        try (ArchiveOutputStream aos = ArchiveStreamFactory.DEFAULT
+                .createArchiveOutputStream("tar", Files.newOutputStream(archive.toPath()))) {
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "./"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "./a"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "./a/b"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dir, "./a/b/c"));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dummy, "./a/b/d.txt"));
+            aos.write("Hello, world 1".getBytes(UTF_8));
+            aos.closeArchiveEntry();
+            aos.putArchiveEntry(aos.createArchiveEntry(dummy, "./a/b/c/e.txt"));
+            aos.write("Hello, world 2".getBytes(UTF_8));
+            aos.closeArchiveEntry();
+            aos.finish();
+        }
+    }
+
+    private void setupZip(final String entry) throws IOException, ArchiveException {
+        archive = new File(dir, "test.zip");
+        final File dummy = new File(dir, "x");
+        try (OutputStream o = Files.newOutputStream(dummy.toPath())) {
+            o.write(new byte[14]);
+        }
+        try (ArchiveOutputStream aos = ArchiveStreamFactory.DEFAULT
              .createArchiveOutputStream("zip", Files.newOutputStream(archive.toPath()))) {
             aos.putArchiveEntry(aos.createArchiveEntry(dummy, entry));
-            aos.write("Hello, world 1".getBytes(StandardCharsets.UTF_8));
+            aos.write("Hello, world 1".getBytes(UTF_8));
             aos.closeArchiveEntry();
             aos.finish();
         }
@@ -217,11 +279,11 @@ public class ExpanderTest extends AbstractTestCase {
         assertHelloWorld("a/b/c/e.txt", "2");
     }
 
-    private void assertHelloWorld(String fileName, String suffix) throws IOException {
+    private void assertHelloWorld(final String fileName, final String suffix) throws IOException {
         Assert.assertTrue(fileName + " does not exist", new File(resultDir, fileName).isFile());
-        byte[] expected = ("Hello, world " + suffix).getBytes(StandardCharsets.UTF_8);
+        final byte[] expected = ("Hello, world " + suffix).getBytes(UTF_8);
         try (InputStream is = Files.newInputStream(new File(resultDir, fileName).toPath())) {
-            byte[] actual = IOUtils.toByteArray(is);
+            final byte[] actual = IOUtils.toByteArray(is);
             Assert.assertArrayEquals(expected, actual);
         }
     }
