@@ -18,12 +18,15 @@
  */
 package org.apache.commons.compress.archivers.examples;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.Assert.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.channels.FileChannel;
 import java.nio.channels.SeekableByteChannel;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.StandardOpenOption;
 
@@ -33,23 +36,23 @@ import org.apache.commons.compress.archivers.ArchiveException;
 import org.apache.commons.compress.archivers.StreamingNotSupportedException;
 import org.apache.commons.compress.archivers.sevenz.SevenZFile;
 import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class SevenZArchiverTest extends AbstractTestCase {
     private File target;
 
-    @Before
+    @BeforeEach
     @Override
     public void setUp() throws Exception {
         super.setUp();
         final File c = new File(dir, "a/b/c");
         c.mkdirs();
         try (OutputStream os = Files.newOutputStream(new File(dir, "a/b/d.txt").toPath())) {
-            os.write("Hello, world 1".getBytes(StandardCharsets.UTF_8));
+            os.write("Hello, world 1".getBytes(UTF_8));
         }
         try (OutputStream os = Files.newOutputStream(new File(dir, "a/b/c/e.txt").toPath())) {
-            os.write("Hello, world 2".getBytes(StandardCharsets.UTF_8));
+            os.write("Hello, world 2".getBytes(UTF_8));
         }
         target = new File(resultDir, "test.7z");
     }
@@ -60,10 +63,10 @@ public class SevenZArchiverTest extends AbstractTestCase {
         verifyContent();
     }
 
-    @Test(expected = StreamingNotSupportedException.class)
+    @Test
     public void outputStreamVersion() throws IOException, ArchiveException {
         try (OutputStream os = Files.newOutputStream(target.toPath())) {
-            new Archiver().create("7z", os, dir);
+            assertThrows(StreamingNotSupportedException.class, () -> new Archiver().create("7z", os, dir));
         }
     }
 
@@ -77,15 +80,15 @@ public class SevenZArchiverTest extends AbstractTestCase {
     }
 
     // not really a 7z test but I didn't feel like adding a new test just for this
-    @Test(expected = ArchiveException.class)
+    @Test
     public void unknownFormat() throws IOException, ArchiveException {
-        try (SeekableByteChannel c = FileChannel.open(target.toPath(), StandardOpenOption.WRITE,
-            StandardOpenOption.CREATE, StandardOpenOption.TRUNCATE_EXISTING)) {
-            new Archiver().create("unknown format", c, dir);
+        try (SeekableByteChannel c = FileChannel.open(target.toPath(), StandardOpenOption.WRITE, StandardOpenOption.CREATE,
+            StandardOpenOption.TRUNCATE_EXISTING)) {
+            assertThrows(ArchiveException.class, () -> new Archiver().create("unknown format", c, dir));
         }
     }
 
-    private void verifyContent() throws IOException, ArchiveException {
+    private void verifyContent() throws IOException {
         try (SevenZFile z = new SevenZFile(target)) {
             assertDir("a", z.getNextEntry());
             assertDir("a/b", z.getNextEntry());
@@ -105,17 +108,17 @@ public class SevenZArchiverTest extends AbstractTestCase {
     }
 
     private void assertDir(final String expectedName, final ArchiveEntry entry) {
-        Assert.assertNotNull(expectedName + " does not exists", entry);
+        assertNotNull(entry, () -> expectedName + " does not exists");
         Assert.assertEquals(expectedName + "/", entry.getName());
         Assert.assertTrue(expectedName + " is not a directory", entry.isDirectory());
     }
 
     private void assertHelloWorld(final String expectedName, final String suffix, final ArchiveEntry entry, final SevenZFile z)
         throws IOException {
-        Assert.assertNotNull(expectedName + " does not exists", entry);
+        assertNotNull(entry, () -> expectedName + " does not exists");
         Assert.assertEquals(expectedName, entry.getName());
         Assert.assertFalse(expectedName + " is a directory", entry.isDirectory());
-        final byte[] expected = ("Hello, world " + suffix).getBytes(StandardCharsets.UTF_8);
+        final byte[] expected = ("Hello, world " + suffix).getBytes(UTF_8);
         final byte[] actual = new byte[expected.length];
         Assert.assertEquals(actual.length, z.read(actual));
         Assert.assertEquals(-1, z.read());
