@@ -19,24 +19,21 @@
 package org.apache.commons.compress.archivers.sevenz;
 
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class CoverageTest {
 
-    @Test public void testNidInstance() {
+    @Test
+    public void testNidInstance() {
         assertNotNull(new NID());
     }
 
-    @Test public void testCLIInstance() {
+    @Test
+    public void testCLIInstance() {
         final CLI foo = new CLI();
         assertNotNull(foo);
-        try {
-            CLI.main(new String[]{"/dev/null/not-there"});
-            fail("shouldn't be able to list contents of  a file that isn't there");
-        } catch (final Exception ignored) {
-
-        }
+        assertThrows(Exception.class, () -> CLI.main(new String[] { "/dev/null/not-there" }));
     }
 }
