@@ -17,12 +17,15 @@
  */
 package org.apache.commons.compress.archivers.sevenz;
 
+import static java.nio.charset.StandardCharsets.UTF_16LE;
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -30,7 +33,6 @@ import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.security.NoSuchAlgorithmException;
@@ -51,17 +53,12 @@ import org.apache.commons.compress.PasswordRequiredException;
 import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.MultiReadOnlySeekableByteChannel;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import org.junit.jupiter.api.Test;
 
 public class SevenZFileTest extends AbstractTestCase {
     private static final String TEST2_CONTENT = "<?xml version = '1.0'?>\r\n<!DOCTYPE"
         + " connections>\r\n<meinxml>\r\n\t<leer />\r\n</meinxml>\n";
 
-    @Rule
-    public final ExpectedException thrown = ExpectedException.none();
-
     // https://issues.apache.org/jira/browse/COMPRESS-320
     @Test
     public void testRandomlySkippingEntries() throws Exception {
@@ -160,7 +157,7 @@ public class SevenZFileTest extends AbstractTestCase {
     public void test7zDecryptUnarchive() throws Exception {
         if (isStrongCryptoAvailable()) {
             test7zUnarchive(getFile("bla.encrypted.7z"), SevenZMethod.LZMA, // stack LZMA + AES
-                            "foo".getBytes(StandardCharsets.UTF_16LE));
+                            "foo".getBytes(UTF_16LE));
         }
     }
 
@@ -319,12 +316,13 @@ public class SevenZFileTest extends AbstractTestCase {
         }
     }
 
-    @Test(expected = MemoryLimitException.class)
+    @Test
     public void limitExtractionMemory() throws IOException {
-        try (SevenZFile sevenZFile = new SevenZFile(getFile("bla.7z"),
-            SevenZFileOptions.builder().withMaxMemoryLimitInKb(1).build())) {
-            // Do nothing. Exception should be thrown
-        }
+        assertThrows(MemoryLimitException.class, () -> {
+            try (SevenZFile sevenZFile = new SevenZFile(getFile("bla.7z"), SevenZFileOptions.builder().withMaxMemoryLimitInKb(1).build())) {
+                // Do nothing. Exception should be thrown
+            }
+        });
     }
 
     @Test
@@ -419,8 +417,7 @@ public class SevenZFileTest extends AbstractTestCase {
 
     @Test
     public void test7zUnarchiveWithDefectHeaderFailsByDefault() throws Exception {
-        thrown.expect(IOException.class);
-        test7zUnarchive(getFile("bla.noendheaderoffset.7z"), SevenZMethod.LZMA);
+        assertThrows(IOException.class, () -> test7zUnarchive(getFile("bla.noendheaderoffset.7z"), SevenZMethod.LZMA));
     }
 
     @Test
@@ -452,7 +449,7 @@ public class SevenZFileTest extends AbstractTestCase {
                         assert (bytesRead >= 0);
                         off += bytesRead;
                     }
-                    assertEquals(testTxtContents, new String(contents, StandardCharsets.UTF_8));
+                    assertEquals(testTxtContents, new String(contents, UTF_8));
                     break;
                 }
             }
@@ -506,7 +503,7 @@ public class SevenZFileTest extends AbstractTestCase {
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, entry.getContentMethods().iterator().next().getMethod());
-                    assertEquals(filesTxtContents, new String(contents, StandardCharsets.UTF_8));
+                    assertEquals(filesTxtContents, new String(contents, UTF_8));
                     break;
                 }
             }
@@ -525,7 +522,7 @@ public class SevenZFileTest extends AbstractTestCase {
                 off += bytesRead;
             }
             assertEquals(SevenZMethod.LZMA2, nextEntry.getContentMethods().iterator().next().getMethod());
-            assertEquals(testTxtContents, new String(contents, StandardCharsets.UTF_8));
+            assertEquals(testTxtContents, new String(contents, UTF_8));
         }
     }
 
@@ -572,7 +569,7 @@ public class SevenZFileTest extends AbstractTestCase {
                     off += bytesRead;
                 }
                 assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
-                assertEquals(testTxtContents, new String(contents, StandardCharsets.UTF_8));
+                assertEquals(testTxtContents, new String(contents, UTF_8));
             }
 
             // then read the next entry using getNextEntry
@@ -637,7 +634,7 @@ public class SevenZFileTest extends AbstractTestCase {
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
-                    assertEquals(testTxtContents, new String(contents, StandardCharsets.UTF_8));
+                    assertEquals(testTxtContents, new String(contents, UTF_8));
                 }
             }
         }
@@ -677,7 +674,7 @@ public class SevenZFileTest extends AbstractTestCase {
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
-                    assertEquals(testTxtContents, new String(contents, StandardCharsets.UTF_8));
+                    assertEquals(testTxtContents, new String(contents, UTF_8));
                 }
             }
         }
@@ -685,11 +682,9 @@ public class SevenZFileTest extends AbstractTestCase {
 
     @Test
     public void extractNonExistSpecifiedFile() throws Exception {
-        try (SevenZFile sevenZFile = new SevenZFile(getFile("COMPRESS-256.7z"));
-            SevenZFile anotherSevenZFile = new SevenZFile(getFile("bla.7z"))) {
+        try (SevenZFile sevenZFile = new SevenZFile(getFile("COMPRESS-256.7z")); SevenZFile anotherSevenZFile = new SevenZFile(getFile("bla.7z"))) {
             for (final SevenZArchiveEntry nonExistEntry : anotherSevenZFile.getEntries()) {
-                thrown.expect(IllegalArgumentException.class);
-                sevenZFile.getInputStream(nonExistEntry);
+                assertThrows(IllegalArgumentException.class, () -> sevenZFile.getInputStream(nonExistEntry));
             }
         }
     }
@@ -712,7 +707,7 @@ public class SevenZFileTest extends AbstractTestCase {
 
             final SevenZArchiveEntry entry = out.createArchiveEntry(inputFile.toFile(), "test.txt");
             out.putArchiveEntry(entry);
-            out.write("Test".getBytes(StandardCharsets.UTF_8));
+            out.write("Test".getBytes(UTF_8));
             out.closeArchiveEntry();
 
             Files.deleteIfExists(inputFile);
@@ -756,7 +751,32 @@ public class SevenZFileTest extends AbstractTestCase {
         }
     }
 
-    private void test7zUnarchive(final File f, final SevenZMethod m, final byte[] password) throws Exception {
+    @Test
+    public void testSevenZWithEOS() throws IOException {
+        try(final SevenZFile sevenZFile = new SevenZFile(getFile("lzma-with-eos.7z"))) {
+            final List<SevenZArchiveEntry> entries = (List<SevenZArchiveEntry>) sevenZFile.getEntries();
+            for (final SevenZArchiveEntry entry : entries) {
+                IOUtils.toByteArray(sevenZFile.getInputStream(entry));
+            }
+        }
+    }
+
+    @Test
+    public void readBigSevenZipFile() throws IOException {
+        try (SevenZFile sevenZFile = new SevenZFile(getFile("COMPRESS-592.7z"))) {
+            SevenZArchiveEntry entry = sevenZFile.getNextEntry();
+            while (entry != null) {
+                if (entry.hasStream()) {
+                    byte[] content = new byte[(int) entry.getSize()];
+                    sevenZFile.read(content);
+                }
+                entry = sevenZFile.getNextEntry();
+            }
+        }
+    }
+
+
+        private void test7zUnarchive(final File f, final SevenZMethod m, final byte[] password) throws Exception {
         try (SevenZFile sevenZFile = new SevenZFile(f, password)) {
             test7zUnarchive(sevenZFile, m);
         }
@@ -788,7 +808,7 @@ public class SevenZFileTest extends AbstractTestCase {
             assert (bytesRead >= 0);
             off += bytesRead;
         }
-        assertEquals(TEST2_CONTENT, new String(contents, StandardCharsets.UTF_8));
+        assertEquals(TEST2_CONTENT, new String(contents, UTF_8));
         assertNull(sevenZFile.getNextEntry());
     }
 
@@ -803,7 +823,7 @@ public class SevenZFileTest extends AbstractTestCase {
                 assert (bytesRead >= 0);
                 off += bytesRead;
             }
-            assertEquals("Hello, world!\n", new String(contents, StandardCharsets.UTF_8));
+            assertEquals("Hello, world!\n", new String(contents, UTF_8));
             assertNull(sevenZFile.getNextEntry());
         }
     }
