@@ -23,22 +23,22 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
-import org.junit.Test;
-
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.nio.file.Files;
 import java.nio.file.Paths;
-import java.util.Arrays;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Collections;
 import java.util.Date;
 import java.util.Iterator;
+
 import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.utils.ByteUtils;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
+import org.junit.jupiter.api.Test;
 import org.tukaani.xz.LZMA2Options;
 
 public class SevenZOutputFileTest extends AbstractTestCase {
@@ -261,7 +261,7 @@ public class SevenZOutputFileTest extends AbstractTestCase {
     }
 
     @Test
-    public void testCantFinishTwice() throws Exception {
+    public void testCantFinishTwice() {
         output = new File(dir, "finish.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.finish();
@@ -595,11 +595,9 @@ public class SevenZOutputFileTest extends AbstractTestCase {
     private static void assertContentMethodsEquals(final Iterable<? extends SevenZMethodConfiguration> expected,
                                                    final Iterable<? extends SevenZMethodConfiguration> actual) {
         assertNotNull(actual);
-        final Iterator<? extends SevenZMethodConfiguration> expectedIter = expected.iterator();
         final Iterator<? extends SevenZMethodConfiguration> actualIter = actual.iterator();
-        while (expectedIter.hasNext()) {
+        for (SevenZMethodConfiguration expConfig : expected) {
             assertTrue(actualIter.hasNext());
-            final SevenZMethodConfiguration expConfig = expectedIter.next();
             final SevenZMethodConfiguration actConfig = actualIter.next();
             assertEquals(expConfig.getMethod(), actConfig.getMethod());
         }
