@@ -23,6 +23,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotSame;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -45,7 +46,7 @@ import org.apache.commons.compress.archivers.ArchiveException;
 import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.utils.CharsetNames;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TarArchiveInputStreamTest extends AbstractTestCase {
 
@@ -85,7 +86,7 @@ public class TarArchiveInputStreamTest extends AbstractTestCase {
     }
 
     @Test
-    public void testCompress197() throws Exception {
+    public void testCompress197() {
         try (TarArchiveInputStream tar = getTestStream("/COMPRESS-197.tar")) {
             TarArchiveEntry entry = tar.getNextTarEntry();
             while (entry != null) {
@@ -143,7 +144,7 @@ public class TarArchiveInputStreamTest extends AbstractTestCase {
     }
 
     @Test
-    public void readsArchiveCompletely_COMPRESS245() throws Exception {
+    public void readsArchiveCompletely_COMPRESS245() {
         try (InputStream is = TarArchiveInputStreamTest.class
                 .getResourceAsStream("/COMPRESS-245.tar.gz")) {
             final InputStream gin = new GZIPInputStream(is);
@@ -161,27 +162,24 @@ public class TarArchiveInputStreamTest extends AbstractTestCase {
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void shouldThrowAnExceptionOnTruncatedEntries() throws Exception {
         final File dir = mkdir("COMPRESS-279");
         final TarArchiveInputStream is = getTestStream("/COMPRESS-279.tar");
-        OutputStream out = null;
         try {
-            TarArchiveEntry entry = is.getNextTarEntry();
-            int count = 0;
-            while (entry != null) {
-                out = Files.newOutputStream(new File(dir, String.valueOf(count)).toPath());
-                IOUtils.copy(is, out);
-                out.close();
-                out = null;
-                count++;
-                entry = is.getNextTarEntry();
-            }
+            assertThrows(IOException.class, () -> {
+                TarArchiveEntry entry = is.getNextTarEntry();
+                int count = 0;
+                while (entry != null) {
+                    try (OutputStream out = Files.newOutputStream(new File(dir, String.valueOf(count)).toPath())) {
+                        IOUtils.copy(is, out);
+                    }
+                    count++;
+                    entry = is.getNextTarEntry();
+                }
+            });
         } finally {
             is.close();
-            if (out != null) {
-                out.close();
-            }
             rmdir(dir);
         }
     }
@@ -327,83 +325,85 @@ public class TarArchiveInputStreamTest extends AbstractTestCase {
             // -----------------------
             final String fileName = "/" + dirDirectory + "/" + subDir;
             final File tarF = new File(rootPath + "/tar" + i + ".tar");
-            final OutputStream dest = Files.newOutputStream(tarF.toPath());
-            final TarArchiveOutputStream out = new TarArchiveOutputStream(new BufferedOutputStream(dest));
-            out.setBigNumberMode(TarArchiveOutputStream.BIGNUMBER_STAR);
-            out.setLongFileMode(TarArchiveOutputStream.LONGFILE_GNU);
+            try (final OutputStream dest = Files.newOutputStream(tarF.toPath())) {
+                final TarArchiveOutputStream out = new TarArchiveOutputStream(new BufferedOutputStream(dest));
+                out.setBigNumberMode(TarArchiveOutputStream.BIGNUMBER_STAR);
+                out.setLongFileMode(TarArchiveOutputStream.LONGFILE_GNU);
 
-            final File file = new File(rootPath, fileName);
-            final TarArchiveEntry entry = new TarArchiveEntry(file);
-            entry.setName(fileName);
-            out.putArchiveEntry(entry);
-            out.closeArchiveEntry();
-            out.flush();
-            out.close();
+                final File file = new File(rootPath, fileName);
+                final TarArchiveEntry entry = new TarArchiveEntry(file);
+                entry.setName(fileName);
+                out.putArchiveEntry(entry);
+                out.closeArchiveEntry();
+                out.flush();
+            }
 
             // -----------------------
             // untar these tars
             // -----------------------
-            final InputStream is = Files.newInputStream(tarF.toPath());
-            final TarArchiveInputStream debInputStream = (TarArchiveInputStream) ArchiveStreamFactory.DEFAULT
-                    .createArchiveInputStream("tar", is);
-            TarArchiveEntry outEntry;
-            while ((outEntry = (TarArchiveEntry) debInputStream.getNextEntry()) != null) {
-                assertTrue(outEntry.getName().endsWith("/"));
+            try (final InputStream is = Files.newInputStream(tarF.toPath());
+                final TarArchiveInputStream debInputStream = (TarArchiveInputStream) ArchiveStreamFactory.DEFAULT.createArchiveInputStream("tar", is)) {
+                TarArchiveEntry outEntry;
+                while ((outEntry = (TarArchiveEntry) debInputStream.getNextEntry()) != null) {
+                    assertTrue(outEntry.getName(), outEntry.getName().endsWith("/"));
+                }
             }
-            debInputStream.close();
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void testParseTarWithSpecialPaxHeaders() throws IOException {
         try (InputStream in = Files.newInputStream(getFile("COMPRESS-530.tar").toPath());
              TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            archive.getNextEntry();
-            IOUtils.toByteArray(archive);
+            assertThrows(IOException.class, () -> archive.getNextEntry());
+            assertThrows(IOException.class, () -> IOUtils.toByteArray(archive));
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void testParseTarWithNonNumberPaxHeaders() throws IOException {
-        try (InputStream in = Files.newInputStream(getFile("COMPRESS-529.tar").toPath());
-             TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            archive.getNextEntry();
+        try (InputStream in = Files.newInputStream(getFile("COMPRESS-529.tar").toPath()); TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
+            assertThrows(IOException.class, () -> archive.getNextEntry());
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void testParseTarTruncatedInPadding() throws IOException {
         try (InputStream in = Files.newInputStream(getFile("COMPRESS-544_truncated_in_padding.tar").toPath());
-             TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            while (archive.getNextTarEntry() != null) {
-            }
+            TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
+            getNextEntryUntilIOException(archive);
         }
     }
 
-    @Test(expected = IOException.class)
+    private void getNextEntryUntilIOException(TarArchiveInputStream archive) {
+        assertThrows(IOException.class, () -> {
+            while (archive.getNextTarEntry() != null) {
+                // noop
+            }
+        });
+    }
+
+    @Test
     public void testParseTarTruncatedInContent() throws IOException {
         try (InputStream in = Files.newInputStream(getFile("COMPRESS-544_truncated_in_content.tar").toPath());
-             TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            while (archive.getNextTarEntry() != null) {
-            }
+            TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
+            getNextEntryUntilIOException(archive);
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void testThrowExceptionWithNullEntry() throws IOException {
         try (InputStream in = Files.newInputStream(getFile("COMPRESS-554.tar").toPath());
              TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            while (archive.getNextTarEntry() != null) {
-            }
+            getNextEntryUntilIOException(archive);
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void testThrowException() throws IOException {
         try (InputStream in = Files.newInputStream(getFile("COMPRESS-553.tar").toPath());
              TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            while (archive.getNextTarEntry() != null) {
-            }
+            getNextEntryUntilIOException(archive);
         }
     }
 
@@ -433,12 +433,10 @@ public class TarArchiveInputStreamTest extends AbstractTestCase {
         }
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void rejectsArchivesWithNegativeSizes() throws Exception {
-        try (InputStream in = Files.newInputStream(getFile("COMPRESS-569.tar").toPath());
-             TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
-            while (archive.getNextTarEntry() != null) {
-            }
+        try (InputStream in = Files.newInputStream(getFile("COMPRESS-569.tar").toPath()); TarArchiveInputStream archive = new TarArchiveInputStream(in)) {
+            getNextEntryUntilIOException(archive);
         }
     }
 
