@@ -18,10 +18,12 @@
 
 package org.apache.commons.compress.archivers.tar;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -33,7 +35,6 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.Reader;
-import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.security.MessageDigest;
 import java.util.Calendar;
@@ -41,13 +42,14 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.TimeZone;
+
 import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.archivers.ArchiveOutputStream;
 import org.apache.commons.compress.archivers.ArchiveStreamFactory;
 import org.apache.commons.compress.utils.IOUtils;
 import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TarArchiveOutputStreamTest extends AbstractTestCase {
 
@@ -95,13 +97,13 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         }
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testBigNumberErrorMode() throws Exception {
         final TarArchiveEntry t = new TarArchiveEntry("foo");
         t.setSize(0100000000000L);
         final ByteArrayOutputStream bos = new ByteArrayOutputStream();
         final TarArchiveOutputStream tos = new TarArchiveOutputStream(bos);
-        tos.putArchiveEntry(t);
+        assertThrows(IllegalArgumentException.class, () -> tos.putArchiveEntry(t));
     }
 
     @Test
@@ -147,7 +149,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
                     + TarConstants.MODELEN
                     + TarConstants.UIDLEN
                     + TarConstants.GIDLEN, 12,
-                    StandardCharsets.UTF_8));
+                    UTF_8));
         final TarArchiveInputStream tin =
             new TarArchiveInputStream(new ByteArrayInputStream(data));
         final TarArchiveEntry e = tin.getNextTarEntry();
@@ -168,8 +170,8 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
                 + TarConstants.MODELEN
                 + TarConstants.UIDLEN
                 + TarConstants.GIDLEN, 12,
-                    StandardCharsets.UTF_8));
-        assertEquals("6 a=b\n", new String(data, 512, 6, StandardCharsets.UTF_8));
+                    UTF_8));
+        assertEquals("6 a=b\n", new String(data, 512, 6, UTF_8));
     }
 
     @Test
@@ -185,10 +187,10 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
                 + TarConstants.MODELEN
                 + TarConstants.UIDLEN
                 + TarConstants.GIDLEN, 12,
-                    StandardCharsets.UTF_8));
+                    UTF_8));
         assertEquals("99 a=0123456789012345678901234567890123456789"
             + "01234567890123456789012345678901234567890123456789"
-            + "012\n", new String(data, 512, 99, StandardCharsets.UTF_8));
+            + "012\n", new String(data, 512, 99, UTF_8));
     }
 
     @Test
@@ -204,10 +206,10 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
                 + TarConstants.MODELEN
                 + TarConstants.UIDLEN
                 + TarConstants.GIDLEN, 12,
-                    StandardCharsets.UTF_8));
+                    UTF_8));
         assertEquals("101 a=0123456789012345678901234567890123456789"
             + "01234567890123456789012345678901234567890123456789"
-            + "0123\n", new String(data, 512, 101, StandardCharsets.UTF_8));
+            + "0123\n", new String(data, 512, 101, UTF_8));
     }
 
     private byte[] writePaxHeader(final Map<String, String> m) throws Exception {
@@ -242,7 +244,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         tos.closeArchiveEntry();
         final byte[] data = bos.toByteArray();
         assertEquals("160 path=" + n + "\n",
-            new String(data, 512, 160, StandardCharsets.UTF_8));
+            new String(data, 512, 160, UTF_8));
         final TarArchiveInputStream tin =
             new TarArchiveInputStream(new ByteArrayInputStream(data));
         final TarArchiveEntry e = tin.getNextTarEntry();
@@ -301,7 +303,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
                     + TarConstants.UIDLEN
                     + TarConstants.GIDLEN
                     + TarConstants.SIZELEN, 12,
-                    StandardCharsets.UTF_8));
+                    UTF_8));
         final TarArchiveInputStream tin =
             new TarArchiveInputStream(new ByteArrayInputStream(data));
         final TarArchiveEntry e = tin.getNextTarEntry();
@@ -344,7 +346,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         tos.close();
         final byte[] data = bos.toByteArray();
         assertEquals("11 path=" + n + "\n",
-            new String(data, 512, 11, StandardCharsets.UTF_8));
+            new String(data, 512, 11, UTF_8));
         final TarArchiveInputStream tin =
             new TarArchiveInputStream(new ByteArrayInputStream(data));
         final TarArchiveEntry e = tin.getNextTarEntry();
@@ -367,7 +369,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         tos.close();
         final byte[] data = bos.toByteArray();
         assertEquals("15 linkpath=" + n + "\n",
-            new String(data, 512, 15, StandardCharsets.UTF_8));
+            new String(data, 512, 15, UTF_8));
         final TarArchiveInputStream tin =
             new TarArchiveInputStream(new ByteArrayInputStream(data));
         final TarArchiveEntry e = tin.getNextTarEntry();
@@ -648,6 +650,7 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
             assertEquals("recordSize",512,tos.getRecordSize());
         }
     }
+
     @Test
     public void testBlockSizes() throws Exception {
         final String fileName = "/test1.xml";
@@ -656,22 +659,17 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         testPadding(5120, fileName, contents); // PAX default
         testPadding(1<<15, fileName, contents); //PAX max
         testPadding(-2, fileName, contents);    // don't specify a block size -> use minimum length
-        try {
-            testPadding(511, fileName, contents);    // don't specify a block size -> use minimum length
-            fail("should have thrown an illegal argument exception");
-        } catch (final IllegalArgumentException e) {
-            //expected
-        }
-        try {
-            testPadding(0, fileName, contents);    // don't specify a block size -> use minimum length
-            fail("should have thrown an illegal argument exception");
-        } catch (final IllegalArgumentException e) {
-            //expected
-        }
+
+        // don't specify a block size -> use minimum length
+        assertThrows(IllegalArgumentException.class, () -> testPadding(511, fileName, contents));    
+            
+        // don't specify a block size -> use minimum length
+        assertThrows(IllegalArgumentException.class, () -> testPadding(0, fileName, contents));    
+        
         // test with "content" that is an exact multiple of record length
-        contents = new byte[2048];
-        java.util.Arrays.fill(contents, (byte) 42);
-        testPadding(TarConstants.DEFAULT_BLKSIZE, fileName, contents);
+        byte[] contents2 = new byte[2048];
+        java.util.Arrays.fill(contents2, (byte) 42);
+        testPadding(TarConstants.DEFAULT_BLKSIZE, fileName, contents2);
     }
 
     private void testPadding(int blockSize, final String fileName, final byte[] contents) throws IOException {
@@ -708,46 +706,48 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         }
         return bos.toByteArray();
     }
-    @Test public void testPutGlobalPaxHeaderEntry() throws IOException {
-        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        final TarArchiveOutputStream tos = new TarArchiveOutputStream(bos);
-        final int pid = 73;
-        final int globCount = 1;
-        final byte lfPaxGlobalExtendedHeader = TarConstants.LF_PAX_GLOBAL_EXTENDED_HEADER;
-        final TarArchiveEntry globalHeader = new TarArchiveEntry("/tmp/GlobalHead." + pid + "." + globCount,
-            lfPaxGlobalExtendedHeader);
-        globalHeader.addPaxHeader("SCHILLY.xattr.user.org.apache.weasels","global-weasels");
-        tos.putArchiveEntry(globalHeader);
-        TarArchiveEntry entry = new TarArchiveEntry("message");
-        final String x = "If at first you don't succeed, give up";
-        entry.setSize(x.length());
-        tos.putArchiveEntry(entry);
-        tos.write(x.getBytes());
-        tos.closeArchiveEntry();
-        entry = new TarArchiveEntry("counter-message");
-        final String y = "Nothing succeeds like excess";
-        entry.setSize(y.length());
-        entry.addPaxHeader("SCHILLY.xattr.user.org.apache.weasels.species","unknown");
-        tos.putArchiveEntry(entry);
-        tos.write(y.getBytes());
-        tos.closeArchiveEntry();
-        tos.close();
-        final TarArchiveInputStream in = new TarArchiveInputStream(new ByteArrayInputStream(bos.toByteArray()));
-        TarArchiveEntry entryIn = in.getNextTarEntry();
-        assertNotNull(entryIn);
-        assertEquals("message",entryIn.getName());
-        assertEquals("global-weasels",entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels"));
-        final Reader reader = new InputStreamReader(in);
-        for(int i=0;i<x.length();i++) {
-            assertEquals(x.charAt(i),reader.read());
-        }
-        assertEquals(-1,reader.read());
-        entryIn = in.getNextTarEntry();
-        assertEquals("counter-message",entryIn.getName());
-        assertEquals("global-weasels",entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels"));
-        assertEquals("unknown",entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels.species"));
-        assertNull(in.getNextTarEntry());
-    }
+
+	@Test
+	public void testPutGlobalPaxHeaderEntry() throws IOException {
+		final ByteArrayOutputStream bos = new ByteArrayOutputStream();
+		final TarArchiveOutputStream tos = new TarArchiveOutputStream(bos);
+		final int pid = 73;
+		final int globCount = 1;
+		final byte lfPaxGlobalExtendedHeader = TarConstants.LF_PAX_GLOBAL_EXTENDED_HEADER;
+		final TarArchiveEntry globalHeader = new TarArchiveEntry("/tmp/GlobalHead." + pid + "." + globCount,
+				lfPaxGlobalExtendedHeader);
+		globalHeader.addPaxHeader("SCHILLY.xattr.user.org.apache.weasels", "global-weasels");
+		tos.putArchiveEntry(globalHeader);
+		TarArchiveEntry entry = new TarArchiveEntry("message");
+		final String x = "If at first you don't succeed, give up";
+		entry.setSize(x.length());
+		tos.putArchiveEntry(entry);
+		tos.write(x.getBytes());
+		tos.closeArchiveEntry();
+		entry = new TarArchiveEntry("counter-message");
+		final String y = "Nothing succeeds like excess";
+		entry.setSize(y.length());
+		entry.addPaxHeader("SCHILLY.xattr.user.org.apache.weasels.species", "unknown");
+		tos.putArchiveEntry(entry);
+		tos.write(y.getBytes());
+		tos.closeArchiveEntry();
+		tos.close();
+		final TarArchiveInputStream in = new TarArchiveInputStream(new ByteArrayInputStream(bos.toByteArray()));
+		TarArchiveEntry entryIn = in.getNextTarEntry();
+		assertNotNull(entryIn);
+		assertEquals("message", entryIn.getName());
+		assertEquals("global-weasels", entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels"));
+		final Reader reader = new InputStreamReader(in);
+		for (int i = 0; i < x.length(); i++) {
+			assertEquals(x.charAt(i), reader.read());
+		}
+		assertEquals(-1, reader.read());
+		entryIn = in.getNextTarEntry();
+		assertEquals("counter-message", entryIn.getName());
+		assertEquals("global-weasels", entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels"));
+		assertEquals("unknown", entryIn.getExtraPaxHeader("SCHILLY.xattr.user.org.apache.weasels.species"));
+		assertNull(in.getNextTarEntry());
+	}
 
     /**
      * When using long file names the longLinkEntry included the current timestamp as the Entry
@@ -785,14 +785,14 @@ public class TarArchiveOutputStreamTest extends AbstractTestCase {
         tarIn.close();
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testWriteLongFileNameThrowsException() throws Exception {
         final String n = "01234567890123456789012345678901234567890123456789"
                 + "01234567890123456789012345678901234567890123456789"
                 + "01234567890123456789012345678901234567890123456789";
         final TarArchiveEntry t = new TarArchiveEntry(n);
         final TarArchiveOutputStream tos = new TarArchiveOutputStream(new ByteArrayOutputStream(), "ASCII");
-        tos.putArchiveEntry(t);
+        assertThrows(IllegalArgumentException.class, () -> tos.putArchiveEntry(t));
     }
 
     private static byte[] createTarArchiveContainingOneDirectory(final String fname,
