@@ -20,8 +20,8 @@ package org.apache.commons.compress.archivers.tar;
 
 import java.io.BufferedInputStream;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.InputStream;
+import java.nio.file.Files;
 
 /**
  * Simple command line application that lists the contents of a tar archive.
@@ -43,14 +43,14 @@ public final class TarLister {
         if (!f.isFile()) {
             System.err.println(f + " doesn't exist or is a directory");
         }
-        final InputStream fis = new BufferedInputStream(new FileInputStream(f));
-        TarArchiveInputStream ais;
+        final InputStream fis = new BufferedInputStream(Files.newInputStream(f.toPath()));
+        final TarArchiveInputStream ais;
         if (args.length > 1) {
             ais = new TarArchiveInputStream(fis, args[1]);
         } else {
             ais = new TarArchiveInputStream(fis);
         }
-        System.out.println("Created " + ais.toString());
+        System.out.println("Created " + ais);
         TarArchiveEntry ae;
         while((ae=ais.getNextTarEntry()) != null){
             log(ae);
@@ -67,14 +67,14 @@ public final class TarLister {
         final StringBuilder sb = new StringBuilder(Integer.toOctalString(ae.getMode()))
             .append(" ");
         String name = ae.getUserName();
-        if (name != null && name.length() > 0) {
+        if (name != null && !name.isEmpty()) {
             sb.append(name);
         } else {
             sb.append(ae.getLongUserId());
         }
         sb.append("/");
         name = ae.getGroupName();
-        if (name != null && name.length() > 0) {
+        if (name != null && !name.isEmpty()) {
             sb.append(name);
         } else {
             sb.append(ae.getLongGroupId());
