@@ -19,27 +19,22 @@
 
 package org.apache.commons.compress.archivers.zip;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
-
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.junit.Test;
+import junit.framework.TestCase;
 
-public class BinaryTreeTest {
+public class BinaryTreeTest extends TestCase {
 
-    @Test
     public void testDecode() throws IOException {
-        final InputStream in = new ByteArrayInputStream(new byte[] { 0x02, 0x42, 0x01, 0x13 });
-
-        final BinaryTree tree = BinaryTree.decode(in, 8);
-
+        InputStream in = new ByteArrayInputStream(new byte[] { 0x02, 0x42, 0x01, 0x13 });
+        
+        BinaryTree tree = BinaryTree.decode(in, 8);
+        
         assertNotNull(tree);
-
-        final BitStream stream = new BitStream(new ByteArrayInputStream(new byte[] { (byte) 0x8D, (byte) 0xC5, (byte) 0x11, 0x00 }));
+        
+        BitStream stream = new BitStream(new ByteArrayInputStream(new byte[] { (byte) 0x8D, (byte) 0xC5, (byte) 0x11, 0x00 }));
         assertEquals(0, tree.read(stream));
         assertEquals(1, tree.read(stream));
         assertEquals(2, tree.read(stream));
@@ -49,28 +44,4 @@ public class BinaryTreeTest {
         assertEquals(6, tree.read(stream));
         assertEquals(7, tree.read(stream));
     }
-    @Test
-    public void testExceptions()  {
-         BinaryTree binaryFinary = new BinaryTree(4);
-         binaryFinary.addLeaf(0,0,0,1);
-        try {
-            binaryFinary.addLeaf(0,0,0,1);
-            fail("should have thrown illegalArgumentException");
-        } catch (final IllegalArgumentException e) {
-        }
-
-        final InputStream is = new ByteArrayInputStream(new byte[]{});
-        try {
-            BinaryTree.decode(is,0);
-            fail("should have thrown IOException");
-        } catch (final IOException e) {
-
-        }
-        binaryFinary = new BinaryTree(4);
-        try {
-            binaryFinary.read(new BitStream(new ByteArrayInputStream(new byte[] {0})));
-            fail("expected read fail");
-        } catch (final IOException e) {
-        }
-    }
 }
