@@ -23,12 +23,12 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class CircularBufferTest {
 
     @Test
-    public void testPutAndGet() throws Exception {
+    public void testPutAndGet() {
         final int size = 16;
         final CircularBuffer buffer = new CircularBuffer(size);
         for (int i = 0; i < size / 2; i++) {
@@ -46,7 +46,7 @@ public class CircularBufferTest {
     }
 
     @Test
-    public void testCopy() throws Exception {
+    public void testCopy() {
         final CircularBuffer buffer = new CircularBuffer(16);
 
         buffer.put(1);
