@@ -19,29 +19,35 @@
 package org.apache.commons.compress.archivers.zip;
 
 import static org.apache.commons.compress.AbstractTestCase.getFile;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
+import java.nio.file.Files;
 
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
 
-public class EncryptedArchiveTest extends TestCase {
+public class EncryptedArchiveTest {
 
+    @Test
     public void testReadPasswordEncryptedEntryViaZipFile()
         throws IOException {
-        File file = getFile("password-encrypted.zip");
+        final File file = getFile("password-encrypted.zip");
         ZipFile zf = null;
         try {
             zf = new ZipFile(file);
-            ZipArchiveEntry zae = zf.getEntry("LICENSE.txt");
+            final ZipArchiveEntry zae = zf.getEntry("LICENSE.txt");
             assertTrue(zae.getGeneralPurposeBit().usesEncryption());
             assertFalse(zae.getGeneralPurposeBit().usesStrongEncryption());
             assertFalse(zf.canReadEntryData(zae));
             try {
                 zf.getInputStream(zae);
                 fail("expected an exception");
-            } catch (UnsupportedZipFeatureException ex) {
+            } catch (final UnsupportedZipFeatureException ex) {
                 assertSame(UnsupportedZipFeatureException.Feature.ENCRYPTION,
                            ex.getFeature());
             }
@@ -50,29 +56,24 @@ public class EncryptedArchiveTest extends TestCase {
         }
     }
 
+    @Test
     public void testReadPasswordEncryptedEntryViaStream()
         throws IOException {
-        File file = getFile("password-encrypted.zip");
-        ZipArchiveInputStream zin = null;
-        try {
-            zin = new ZipArchiveInputStream(new FileInputStream(file));
-            ZipArchiveEntry zae = zin.getNextZipEntry();
+        final File file = getFile("password-encrypted.zip");
+        try (ZipArchiveInputStream zin = new ZipArchiveInputStream(Files.newInputStream(file.toPath()))) {
+            final ZipArchiveEntry zae = zin.getNextZipEntry();
             assertEquals("LICENSE.txt", zae.getName());
             assertTrue(zae.getGeneralPurposeBit().usesEncryption());
             assertFalse(zae.getGeneralPurposeBit().usesStrongEncryption());
             assertFalse(zin.canReadEntryData(zae));
             try {
-                byte[] buf = new byte[1024];
+                final byte[] buf = new byte[1024];
                 zin.read(buf, 0, buf.length);
                 fail("expected an exception");
-            } catch (UnsupportedZipFeatureException ex) {
+            } catch (final UnsupportedZipFeatureException ex) {
                 assertSame(UnsupportedZipFeatureException.Feature.ENCRYPTION,
                            ex.getFeature());
             }
-        } finally {
-            if (zin != null) {
-                zin.close();
-            }
         }
     }
 }
