@@ -19,14 +19,16 @@
 package org.apache.commons.compress.archivers.zip;
 
 import static org.apache.commons.compress.AbstractTestCase.getFile;
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
+import static org.junit.Assert.fail;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
 
 import org.apache.commons.compress.archivers.ArchiveEntry;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * JUnit testcase for a multi-volume zip file.
@@ -44,7 +46,8 @@ import org.junit.Test;
  */
 public class Maven221MultiVolumeTest {
 
-    private static final String [] ENTRIES = new String [] {
+    private static final String[] ENTRIES = {
+        // @formatter:off
         "apache-maven-2.2.1/",
         "apache-maven-2.2.1/LICENSE.txt",
         "apache-maven-2.2.1/NOTICE.txt",
@@ -60,6 +63,7 @@ public class Maven221MultiVolumeTest {
         "apache-maven-2.2.1/conf/",
         "apache-maven-2.2.1/conf/settings.xml",
         "apache-maven-2.2.1/lib/"
+        // @formatter:on
     };
 
     private static final String LAST_ENTRY_NAME =
@@ -68,11 +72,8 @@ public class Maven221MultiVolumeTest {
     @Test
     public void testRead7ZipMultiVolumeArchiveForStream() throws IOException {
 
-        final FileInputStream archive =
-            new FileInputStream(getFile("apache-maven-2.2.1.zip.001"));
-        ZipArchiveInputStream zi = null;
-        try {
-            zi = new ZipArchiveInputStream(archive,null,false);
+        try (final InputStream archive = Files.newInputStream(getFile("apache-maven-2.2.1.zip.001").toPath());
+             ZipArchiveInputStream zi = new ZipArchiveInputStream(archive, null, false)) {
 
             // these are the entries that are supposed to be processed
             // correctly without any problems
@@ -83,14 +84,16 @@ public class Maven221MultiVolumeTest {
             // this is the last entry that is truncated
             final ArchiveEntry lastEntry = zi.getNextEntry();
             assertEquals(LAST_ENTRY_NAME, lastEntry.getName());
-            final byte [] buffer = new byte [4096];
+            final byte[] buffer = new byte[4096];
 
             // before the fix, we'd get 0 bytes on this read and all
             // subsequent reads thus a client application might enter
             // an infinite loop after the fix, we should get an
             // exception
             try {
-                while (zi.read(buffer) > 0) { }
+                while (zi.read(buffer) > 0) {
+                    // empty
+                }
                 fail("shouldn't be able to read from truncated entry");
             } catch (final IOException e) {
                 assertEquals("Truncated ZIP file", e.getMessage());
@@ -107,22 +110,15 @@ public class Maven221MultiVolumeTest {
             // an exception
             try {
                 zi.getNextEntry();
-                fail("shouldn't be able to read another entry from truncated"
-                     + " file");
+                fail("shouldn't be able to read another entry from truncated" + " file");
             } catch (final IOException e) {
                 // this is to be expected
             }
-        } finally {
-            if (zi != null) {
-                zi.close();
-            }
         }
     }
 
-    @Test(expected=IOException.class)
+    @Test
     public void testRead7ZipMultiVolumeArchiveForFile() throws IOException {
-        final File file = getFile("apache-maven-2.2.1.zip.001");
-        ZipFile zf = new ZipFile(file);
-        zf.close();
+        assertThrows(IOException.class, () -> new ZipFile(getFile("apache-maven-2.2.1.zip.001")));
     }
 }
