@@ -19,15 +19,20 @@
 package org.apache.commons.compress.archivers.zip;
 
 import static org.apache.commons.compress.AbstractTestCase.getFile;
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertThrows;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayOutputStream;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipException;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import org.apache.commons.compress.utils.ByteUtils;
+import org.junit.jupiter.api.Test;
 
 /**
  * JUnit testcases for org.apache.commons.compress.archivers.zip.ZipEntry.
@@ -35,9 +40,6 @@ import org.junit.rules.ExpectedException;
  */
 public class ZipArchiveEntryTest {
 
-    @Rule
-    public ExpectedException thrown = ExpectedException.none();
-
     /**
      * test handling of extra fields
      */
@@ -48,7 +50,7 @@ public class ZipArchiveEntryTest {
         a.setMode(0755);
         final UnrecognizedExtraField u = new UnrecognizedExtraField();
         u.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u.setLocalFileDataData(new byte[0]);
+        u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
         ze.setExtraFields(new ZipExtraField[] {a, u});
@@ -102,7 +104,7 @@ public class ZipArchiveEntryTest {
         a.setMode(0755);
         final UnrecognizedExtraField u = new UnrecognizedExtraField();
         u.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u.setLocalFileDataData(new byte[0]);
+        u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
         ze.setExtraFields(new ZipExtraField[] {a, u});
@@ -149,7 +151,7 @@ public class ZipArchiveEntryTest {
         a.setMode(0755);
         final UnrecognizedExtraField u = new UnrecognizedExtraField();
         u.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u.setLocalFileDataData(new byte[0]);
+        u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
 
         final ZipArchiveEntry ze = new ZipArchiveEntry("test/");
         ze.setExtraFields(new ZipExtraField[] {a, u});
@@ -246,7 +248,7 @@ public class ZipArchiveEntryTest {
     public void testNotEquals() {
         final ZipArchiveEntry entry1 = new ZipArchiveEntry("foo");
         final ZipArchiveEntry entry2 = new ZipArchiveEntry("bar");
-        assertFalse(entry1.equals(entry2));
+        assertNotEquals(entry1, entry2);
     }
 
     /**
@@ -262,8 +264,8 @@ public class ZipArchiveEntryTest {
         entry2.setComment("");
         entry3.setComment("bar");
         assertEquals(entry1, entry2);
-        assertFalse(entry1.equals(entry3));
-        assertFalse(entry2.equals(entry3));
+        assertNotEquals(entry1, entry3);
+        assertNotEquals(entry2, entry3);
     }
 
     @Test
@@ -282,14 +284,14 @@ public class ZipArchiveEntryTest {
     @Test
     public void isUnixSymlinkIsFalseIfMoreThanOneFlagIsSet() throws Exception {
         try (ZipFile zf = new ZipFile(getFile("COMPRESS-379.jar"))) {
-            ZipArchiveEntry ze = zf.getEntry("META-INF/maven/");
+            final ZipArchiveEntry ze = zf.getEntry("META-INF/maven/");
             assertFalse(ze.isUnixSymlink());
         }
     }
 
     @Test
     public void testIsUnixSymlink() {
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setUnixMode(UnixStat.LINK_FLAG);
         assertTrue(ze.isUnixSymlink());
         ze.setUnixMode(UnixStat.LINK_FLAG | UnixStat.DIR_FLAG);
@@ -300,57 +302,53 @@ public class ZipArchiveEntryTest {
     public void reparsingUnicodeExtraWithUnsupportedversionThrowsInStrictMode()
         throws Exception {
         try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
-            ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
-            thrown.expect(ZipException.class);
-            thrown.expectMessage("Unsupported version [116] for UniCode path extra data.");
-            ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS);
+            final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
+            assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS));
         }
     }
 
     @Test
     public void bestEffortIncludesUnparseableExtraData() throws Exception {
-        ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setExtraFields(extraFields);
-        ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.BEST_EFFORT);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.BEST_EFFORT);
         assertEquals(extraFields.length, read.length);
     }
 
     @Test
     public void onlyParseableLenientExcludesUnparseableExtraData() throws Exception {
-        ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setExtraFields(extraFields);
-        ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_LENIENT);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_LENIENT);
         assertEquals(extraFields.length, read.length + 1);
     }
 
     @Test
     public void strictForKnowExtraFieldsIncludesUnparseableExtraData() throws Exception {
-        ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setExtraFields(extraFields);
-        ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.STRICT_FOR_KNOW_EXTRA_FIELDS);
         assertEquals(extraFields.length, read.length);
     }
 
     @Test
     public void onlyParseableStrictExcludesUnparseableExtraData() throws Exception {
-        ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setExtraFields(extraFields);
-        ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_STRICT);
+        final ZipExtraField[] read = ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.ONLY_PARSEABLE_STRICT);
         assertEquals(extraFields.length, read.length + 1);
     }
 
     @Test
     public void draconicThrowsOnUnparseableExtraData() throws Exception {
-        ZipExtraField[] extraFields = parsingModeBehaviorTestData();
-        ZipArchiveEntry ze = new ZipArchiveEntry("foo");
+        final ZipExtraField[] extraFields = parsingModeBehaviorTestData();
+        final ZipArchiveEntry ze = new ZipArchiveEntry("foo");
         ze.setExtraFields(extraFields);
-        thrown.expect(ZipException.class);
-        thrown.expectMessage("Bad extra field starting at");
-        ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.DRACONIC);
+        assertThrows(ZipException.class, () -> ze.getExtraFields(ZipArchiveEntry.ExtraFieldParsingMode.DRACONIC));
     }
 
     private ZipExtraField[] parsingModeBehaviorTestData() {
@@ -359,12 +357,21 @@ public class ZipArchiveEntryTest {
         a.setMode(0755);
         final UnrecognizedExtraField u = new UnrecognizedExtraField();
         u.setHeaderId(ExtraFieldUtilsTest.UNRECOGNIZED_HEADER);
-        u.setLocalFileDataData(new byte[0]);
+        u.setLocalFileDataData(ByteUtils.EMPTY_BYTE_ARRAY);
         final UnparseableExtraFieldData x = new UnparseableExtraFieldData();
-        byte[] unparseable = new byte[] {
+        final byte[] unparseable = new byte[] {
             0, 0, (byte) 0xff, (byte) 0xff, 0, 0, 0
         };
         x.parseFromLocalFileData(unparseable, 0, unparseable.length);
         return new ZipExtraField[] { a, u, x };
     }
+
+    @Test
+    public void testZipArchiveClone() throws Exception {
+        try (ZipFile zf = new ZipFile(getFile("COMPRESS-479.zip"))) {
+            final ZipArchiveEntry ze = zf.getEntry("%U20AC_for_Dollar.txt");
+            final ZipArchiveEntry clonedZe = (ZipArchiveEntry) ze.clone();
+            assertEquals(ze, clonedZe);
+        }
+    }
 }
