@@ -18,31 +18,30 @@
 
 package org.apache.commons.compress.archivers.zip;
 
-import org.apache.commons.compress.AbstractTestCase;
-import org.apache.commons.compress.utils.IOUtils;
-
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-
 import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.file.Files;
 import java.util.Enumeration;
 
+import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.utils.IOUtils;
+import org.junit.Assert;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
 public class ZipFileIgnoringLocalFileHeaderTest {
 
     private File dir;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         dir = AbstractTestCase.mkdir("dir");
     }
 
-    @After
-    public void tearDown() throws Exception {
+    @AfterEach
+    public void tearDown() {
         AbstractTestCase.rmdir(dir);
     }
 
