@@ -18,38 +18,50 @@
 
 package org.apache.commons.compress.archivers.zip;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.commons.compress.AbstractTestCase.getFile;
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThrows;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.nio.charset.Charset;
+import java.nio.channels.SeekableByteChannel;
+import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.TreeMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.zip.CRC32;
+import java.util.zip.Deflater;
 import java.util.zip.ZipEntry;
 
+import org.apache.commons.compress.utils.ByteUtils;
 import org.apache.commons.compress.utils.IOUtils;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
-import org.junit.After;
 import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 
 public class ZipFileTest {
     private ZipFile zf = null;
 
-    @After
+    @AfterEach
     public void tearDown() {
         ZipFile.closeQuietly(zf);
     }
@@ -86,7 +98,7 @@ public class ZipFileTest {
     @Test
     public void testCDOrderInMemory() throws Exception {
         byte[] data = null;
-        try (FileInputStream fis = new FileInputStream(getFile("ordertest.zip"))) {
+        try (InputStream fis = Files.newInputStream(getFile("ordertest.zip").toPath())) {
             data = IOUtils.toByteArray(fis);
         }
 
@@ -146,6 +158,18 @@ public class ZipFileTest {
         assertEntryName(l, 22, "ZipUtil");
     }
 
+    @Test
+    public void testPhysicalOrderOfSpecificFile() throws Exception {
+        readOrderTest();
+        final String entryName = "src/main/java/org/apache/commons/compress/archivers/zip/ZipExtraField.java";
+        final Iterable<ZipArchiveEntry> entries = zf.getEntriesInPhysicalOrder(entryName);
+        final Iterator<ZipArchiveEntry> iter = entries.iterator();
+        final ZipArchiveEntry entry = iter.next();
+
+        assertEquals(entryName, entry.getName());
+        assertFalse(iter.hasNext());
+    }
+
     @Test
     public void testDoubleClose() throws Exception {
         readOrderTest();
@@ -164,12 +188,12 @@ public class ZipFileTest {
         OutputStream o = null;
         InputStream i = null;
         try {
-            o = new FileOutputStream(f);
+            o = Files.newOutputStream(f.toPath());
             final ZipArchiveOutputStream zo = new ZipArchiveOutputStream(o);
             ZipArchiveEntry ze = new ZipArchiveEntry("foo");
             ze.setMethod(ZipEntry.STORED);
             ze.setSize(4);
-            ze.setCrc(0xb63cfbcdl);
+            ze.setCrc(0xb63cfbcdL);
             zo.putArchiveEntry(ze);
             zo.write(new byte[] { 1, 2, 3, 4 });
             zo.closeArchiveEntry();
@@ -296,7 +320,7 @@ public class ZipFileTest {
     public void testUnshrinking() throws Exception {
         zf = new ZipFile(getFile("SHRUNK.ZIP"));
         ZipArchiveEntry test = zf.getEntry("TEST1.XML");
-        FileInputStream original = new FileInputStream(getFile("test1.xml"));
+        InputStream original = Files.newInputStream(getFile("test1.xml").toPath());
         try {
             assertArrayEquals(IOUtils.toByteArray(original),
                               IOUtils.toByteArray(zf.getInputStream(test)));
@@ -304,7 +328,7 @@ public class ZipFileTest {
             original.close();
         }
         test = zf.getEntry("TEST2.XML");
-        original = new FileInputStream(getFile("test2.xml"));
+        original = Files.newInputStream(getFile("test2.xml").toPath());
         try {
             assertArrayEquals(IOUtils.toByteArray(original),
                               IOUtils.toByteArray(zf.getInputStream(test)));
@@ -343,28 +367,25 @@ public class ZipFileTest {
     public void testConcurrentReadSeekable() throws Exception {
         // mixed.zip contains both inflated and stored files
         byte[] data = null;
-        try (FileInputStream fis = new FileInputStream(getFile("mixed.zip"))) {
+        try (InputStream fis = Files.newInputStream(getFile("mixed.zip").toPath())) {
             data = IOUtils.toByteArray(fis);
         }
         zf = new ZipFile(new SeekableInMemoryByteChannel(data), ZipEncodingHelper.UTF8);
 
-        final Map<String, byte[]> content = new HashMap<String, byte[]>();
-        for (ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
+        final Map<String, byte[]> content = new HashMap<>();
+        for (final ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
             content.put(entry.getName(), IOUtils.toByteArray(zf.getInputStream(entry)));
         }
 
         final AtomicInteger passedCount = new AtomicInteger();
-        Runnable run = new Runnable() {
-            @Override
-            public void run() {
-                for (ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
-                    assertAllReadMethods(content.get(entry.getName()), zf, entry);
-                }
-                passedCount.incrementAndGet();
+        final Runnable run = () -> {
+            for (final ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
+                assertAllReadMethods(content.get(entry.getName()), zf, entry);
             }
+            passedCount.incrementAndGet();
         };
-        Thread t0 = new Thread(run);
-        Thread t1 = new Thread(run);
+        final Thread t0 = new Thread(run);
+        final Thread t1 = new Thread(run);
         t0.start();
         t1.start();
         t0.join();
@@ -378,23 +399,20 @@ public class ZipFileTest {
         final File archive = getFile("mixed.zip");
         zf = new ZipFile(archive);
 
-        final Map<String, byte[]> content = new HashMap<String, byte[]>();
-        for (ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
+        final Map<String, byte[]> content = new HashMap<>();
+        for (final ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
             content.put(entry.getName(), IOUtils.toByteArray(zf.getInputStream(entry)));
         }
 
         final AtomicInteger passedCount = new AtomicInteger();
-        Runnable run = new Runnable() {
-            @Override
-            public void run() {
-                for (ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
-                    assertAllReadMethods(content.get(entry.getName()), zf, entry);
-                }
-                passedCount.incrementAndGet();
+        final Runnable run = () -> {
+            for (final ZipArchiveEntry entry: Collections.list(zf.getEntries())) {
+                assertAllReadMethods(content.get(entry.getName()), zf, entry);
             }
+            passedCount.incrementAndGet();
         };
-        Thread t0 = new Thread(run);
-        Thread t1 = new Thread(run);
+        final Thread t0 = new Thread(run);
+        final Thread t1 = new Thread(run);
         t0.start();
         t1.start();
         t0.join();
@@ -410,11 +428,11 @@ public class ZipFileTest {
         // mixed.zip contains both inflated and stored files
         final File archive = getFile("mixed.zip");
         try (ZipFile zf = new ZipFile(archive)) {
-            ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
+            final ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
             Assert.assertEquals(0x0000, inflatedEntry.getLocalHeaderOffset());
             Assert.assertEquals(0x0046, inflatedEntry.getDataOffset());
             Assert.assertTrue(inflatedEntry.isStreamContiguous());
-            ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
+            final ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
             Assert.assertEquals(0x5892, storedEntry.getLocalHeaderOffset());
             Assert.assertEquals(0x58d6, storedEntry.getDataOffset());
             Assert.assertTrue(inflatedEntry.isStreamContiguous());
@@ -426,16 +444,16 @@ public class ZipFileTest {
      */
     @Test
     public void testDelayedOffsetsAndSizes() throws Exception {
-        ByteArrayOutputStream zipContent = new ByteArrayOutputStream();
+        final ByteArrayOutputStream zipContent = new ByteArrayOutputStream();
         try (ZipArchiveOutputStream zipOutput = new ZipArchiveOutputStream(zipContent)) {
-            ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
+            final ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
             inflatedEntry.setMethod(ZipEntry.DEFLATED);
             zipOutput.putArchiveEntry(inflatedEntry);
             zipOutput.write("Hello Deflated\n".getBytes());
             zipOutput.closeArchiveEntry();
 
-            byte[] storedContent = "Hello Stored\n".getBytes();
-            ZipArchiveEntry storedEntry = new ZipArchiveEntry("stored.txt");
+            final byte[] storedContent = "Hello Stored\n".getBytes();
+            final ZipArchiveEntry storedEntry = new ZipArchiveEntry("stored.txt");
             storedEntry.setMethod(ZipEntry.STORED);
             storedEntry.setSize(storedContent.length);
             storedEntry.setCrc(calculateCrc32(storedContent));
@@ -446,13 +464,13 @@ public class ZipFileTest {
         }
 
         try (ZipFile zf = new ZipFile(new SeekableInMemoryByteChannel(zipContent.toByteArray()))) {
-            ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
+            final ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
             Assert.assertNotEquals(-1L, inflatedEntry.getLocalHeaderOffset());
             Assert.assertNotEquals(-1L, inflatedEntry.getDataOffset());
             Assert.assertTrue(inflatedEntry.isStreamContiguous());
             Assert.assertNotEquals(-1L, inflatedEntry.getCompressedSize());
             Assert.assertNotEquals(-1L, inflatedEntry.getSize());
-            ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
+            final ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
             Assert.assertNotEquals(-1L, storedEntry.getLocalHeaderOffset());
             Assert.assertNotEquals(-1L, storedEntry.getDataOffset());
             Assert.assertTrue(inflatedEntry.isStreamContiguous());
@@ -466,35 +484,35 @@ public class ZipFileTest {
      */
     @Test
     public void testEntryAlignment() throws Exception {
-        SeekableInMemoryByteChannel zipContent = new SeekableInMemoryByteChannel();
+        final SeekableInMemoryByteChannel zipContent = new SeekableInMemoryByteChannel();
         try (ZipArchiveOutputStream zipOutput = new ZipArchiveOutputStream(zipContent)) {
-            ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
+            final ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
             inflatedEntry.setMethod(ZipEntry.DEFLATED);
             inflatedEntry.setAlignment(1024);
             zipOutput.putArchiveEntry(inflatedEntry);
-            zipOutput.write("Hello Deflated\n".getBytes(Charset.forName("UTF-8")));
+            zipOutput.write("Hello Deflated\n".getBytes(UTF_8));
             zipOutput.closeArchiveEntry();
 
-            ZipArchiveEntry storedEntry = new ZipArchiveEntry("stored.txt");
+            final ZipArchiveEntry storedEntry = new ZipArchiveEntry("stored.txt");
             storedEntry.setMethod(ZipEntry.STORED);
             storedEntry.setAlignment(1024);
             zipOutput.putArchiveEntry(storedEntry);
-            zipOutput.write("Hello Stored\n".getBytes(Charset.forName("UTF-8")));
+            zipOutput.write("Hello Stored\n".getBytes(UTF_8));
             zipOutput.closeArchiveEntry();
 
-            ZipArchiveEntry storedEntry2 = new ZipArchiveEntry("stored2.txt");
+            final ZipArchiveEntry storedEntry2 = new ZipArchiveEntry("stored2.txt");
             storedEntry2.setMethod(ZipEntry.STORED);
             storedEntry2.setAlignment(1024);
             storedEntry2.addExtraField(new ResourceAlignmentExtraField(1));
             zipOutput.putArchiveEntry(storedEntry2);
-            zipOutput.write("Hello overload-alignment Stored\n".getBytes(Charset.forName("UTF-8")));
+            zipOutput.write("Hello overload-alignment Stored\n".getBytes(UTF_8));
             zipOutput.closeArchiveEntry();
 
-            ZipArchiveEntry storedEntry3 = new ZipArchiveEntry("stored3.txt");
+            final ZipArchiveEntry storedEntry3 = new ZipArchiveEntry("stored3.txt");
             storedEntry3.setMethod(ZipEntry.STORED);
             storedEntry3.addExtraField(new ResourceAlignmentExtraField(1024));
             zipOutput.putArchiveEntry(storedEntry3);
-            zipOutput.write("Hello copy-alignment Stored\n".getBytes(Charset.forName("UTF-8")));
+            zipOutput.write("Hello copy-alignment Stored\n".getBytes(UTF_8));
             zipOutput.closeArchiveEntry();
 
         }
@@ -502,8 +520,8 @@ public class ZipFileTest {
         try (ZipFile zf = new ZipFile(new SeekableInMemoryByteChannel(
                         Arrays.copyOfRange(zipContent.array(), 0, (int)zipContent.size())
         ))) {
-            ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
-            ResourceAlignmentExtraField inflatedAlignmentEx =
+            final ZipArchiveEntry inflatedEntry = zf.getEntry("inflated.txt");
+            final ResourceAlignmentExtraField inflatedAlignmentEx =
                             (ResourceAlignmentExtraField)inflatedEntry.getExtraField(ResourceAlignmentExtraField.ID);
             assertNotEquals(-1L, inflatedEntry.getCompressedSize());
             assertNotEquals(-1L, inflatedEntry.getSize());
@@ -513,10 +531,10 @@ public class ZipFileTest {
             assertFalse(inflatedAlignmentEx.allowMethodChange());
             try (InputStream stream = zf.getInputStream(inflatedEntry)) {
                 Assert.assertEquals("Hello Deflated\n",
-                                new String(IOUtils.toByteArray(stream), Charset.forName("UTF-8")));
+                                new String(IOUtils.toByteArray(stream), UTF_8));
             }
-            ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
-            ResourceAlignmentExtraField storedAlignmentEx =
+            final ZipArchiveEntry storedEntry = zf.getEntry("stored.txt");
+            final ResourceAlignmentExtraField storedAlignmentEx =
                             (ResourceAlignmentExtraField)storedEntry.getExtraField(ResourceAlignmentExtraField.ID);
             assertNotEquals(-1L, storedEntry.getCompressedSize());
             assertNotEquals(-1L, storedEntry.getSize());
@@ -526,11 +544,11 @@ public class ZipFileTest {
             assertFalse(storedAlignmentEx.allowMethodChange());
             try (InputStream stream = zf.getInputStream(storedEntry)) {
                 Assert.assertEquals("Hello Stored\n",
-                                new String(IOUtils.toByteArray(stream), Charset.forName("UTF-8")));
+                                new String(IOUtils.toByteArray(stream), UTF_8));
             }
 
-            ZipArchiveEntry storedEntry2 = zf.getEntry("stored2.txt");
-            ResourceAlignmentExtraField stored2AlignmentEx =
+            final ZipArchiveEntry storedEntry2 = zf.getEntry("stored2.txt");
+            final ResourceAlignmentExtraField stored2AlignmentEx =
                             (ResourceAlignmentExtraField)storedEntry2.getExtraField(ResourceAlignmentExtraField.ID);
             assertNotEquals(-1L, storedEntry2.getCompressedSize());
             assertNotEquals(-1L, storedEntry2.getSize());
@@ -540,11 +558,11 @@ public class ZipFileTest {
             assertFalse(stored2AlignmentEx.allowMethodChange());
             try (InputStream stream = zf.getInputStream(storedEntry2)) {
                 Assert.assertEquals("Hello overload-alignment Stored\n",
-                                new String(IOUtils.toByteArray(stream), Charset.forName("UTF-8")));
+                                new String(IOUtils.toByteArray(stream), UTF_8));
             }
 
-            ZipArchiveEntry storedEntry3 = zf.getEntry("stored3.txt");
-            ResourceAlignmentExtraField stored3AlignmentEx =
+            final ZipArchiveEntry storedEntry3 = zf.getEntry("stored3.txt");
+            final ResourceAlignmentExtraField stored3AlignmentEx =
                             (ResourceAlignmentExtraField)storedEntry3.getExtraField(ResourceAlignmentExtraField.ID);
             assertNotEquals(-1L, storedEntry3.getCompressedSize());
             assertNotEquals(-1L, storedEntry3.getSize());
@@ -554,7 +572,7 @@ public class ZipFileTest {
             assertFalse(stored3AlignmentEx.allowMethodChange());
             try (InputStream stream = zf.getInputStream(storedEntry3)) {
                 Assert.assertEquals("Hello copy-alignment Stored\n",
-                                new String(IOUtils.toByteArray(stream), Charset.forName("UTF-8")));
+                                new String(IOUtils.toByteArray(stream), UTF_8));
             }
         }
     }
@@ -562,23 +580,22 @@ public class ZipFileTest {
     /**
      * Test too big alignment, resulting into exceeding extra field limit.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testEntryAlignmentExceed() throws Exception {
-        SeekableInMemoryByteChannel zipContent = new SeekableInMemoryByteChannel();
+        final SeekableInMemoryByteChannel zipContent = new SeekableInMemoryByteChannel();
         try (ZipArchiveOutputStream zipOutput = new ZipArchiveOutputStream(zipContent)) {
-            ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
+            final ZipArchiveEntry inflatedEntry = new ZipArchiveEntry("inflated.txt");
             inflatedEntry.setMethod(ZipEntry.STORED);
-            inflatedEntry.setAlignment(0x20000);
+            assertThrows(IllegalArgumentException.class, () -> inflatedEntry.setAlignment(0x20000));
         }
     }
 
     /**
      * Test non power of 2 alignment.
      */
-    @Test(expected = IllegalArgumentException.class)
-    public void testInvalidAlignment() throws Exception {
-        ZipArchiveEntry entry = new ZipArchiveEntry("dummy");
-        entry.setAlignment(3);
+    @Test
+    public void testInvalidAlignment() {
+        assertThrows(IllegalArgumentException.class, () -> new ZipArchiveEntry("dummy").setAlignment(3));
     }
 
     @Test
@@ -605,12 +622,12 @@ public class ZipFileTest {
     public void readDeflate64CompressedStream() throws Exception {
         final File input = getFile("COMPRESS-380/COMPRESS-380-input");
         final File archive = getFile("COMPRESS-380/COMPRESS-380.zip");
-        try (FileInputStream in = new FileInputStream(input);
+        try (InputStream in = Files.newInputStream(input.toPath());
              ZipFile zf = new ZipFile(archive)) {
-            byte[] orig = IOUtils.toByteArray(in);
-            ZipArchiveEntry e = zf.getEntry("input2");
+            final byte[] orig = IOUtils.toByteArray(in);
+            final ZipArchiveEntry e = zf.getEntry("input2");
             try (InputStream s = zf.getInputStream(e)) {
-                byte[] fromZip = IOUtils.toByteArray(s);
+                final byte[] fromZip = IOUtils.toByteArray(s);
                 assertArrayEquals(orig, fromZip);
             }
         }
@@ -646,9 +663,9 @@ public class ZipFileTest {
         singleByteReadConsistentlyReturnsMinusOneAtEof(getFile("bzip2-zip.zip"));
     }
 
-    private void singleByteReadConsistentlyReturnsMinusOneAtEof(File file) throws Exception {
+    private void singleByteReadConsistentlyReturnsMinusOneAtEof(final File file) throws Exception {
         try (ZipFile archive = new ZipFile(file)) {
-            ZipArchiveEntry e = archive.getEntries().nextElement();
+            final ZipArchiveEntry e = archive.getEntries().nextElement();
             try (InputStream is = archive.getInputStream(e)) {
                 IOUtils.toByteArray(is);
                 assertEquals(-1, is.read());
@@ -687,10 +704,148 @@ public class ZipFileTest {
         multiByteReadConsistentlyReturnsMinusOneAtEof(getFile("bzip2-zip.zip"));
     }
 
-    private void multiByteReadConsistentlyReturnsMinusOneAtEof(File file) throws Exception {
-        byte[] buf = new byte[2];
+    @Test
+    public void extractFileLiesAcrossSplitZipSegmentsCreatedByZip() throws Exception {
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
+        final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
+        zf = new ZipFile(channel);
+
+        // the compressed content of UnsupportedCompressionAlgorithmException.java lies between .z01 and .z02
+        ZipArchiveEntry zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/archivers/dump/UnsupportedCompressionAlgorithmException.java");
+        File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/file_to_compare_1");
+        assertFileEqualsToEntry(fileToCompare, zipEntry, zf);
+
+        // the compressed content of DeflateParameters.java lies between .z02 and .zip
+        zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/compressors/deflate/DeflateParameters.java");
+        fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/file_to_compare_2");
+        assertFileEqualsToEntry(fileToCompare, zipEntry, zf);
+    }
+
+    @Test
+    public void extractFileLiesAcrossSplitZipSegmentsCreatedByZipOfZip64() throws Exception {
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip_zip64.zip");
+        final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
+        zf = new ZipFile(channel);
+
+        // the compressed content of UnsupportedCompressionAlgorithmException.java lies between .z01 and .z02
+        ZipArchiveEntry zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/archivers/dump/UnsupportedCompressionAlgorithmException.java");
+        File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/file_to_compare_1");
+        assertFileEqualsToEntry(fileToCompare, zipEntry, zf);
+
+        // the compressed content of DeflateParameters.java lies between .z02 and .zip
+        zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/compressors/deflate/DeflateParameters.java");
+        fileToCompare = getFile("COMPRESS-477/split_zip_created_by_zip/file_to_compare_2");
+        assertFileEqualsToEntry(fileToCompare, zipEntry, zf);
+    }
+
+    @Test
+    public void extractFileLiesAcrossSplitZipSegmentsCreatedByWinrar() throws Exception {
+        final File lastFile = getFile("COMPRESS-477/split_zip_created_by_winrar/split_zip_created_by_winrar.zip");
+        final SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
+        zf = new ZipFile(channel);
+
+        // the compressed content of ZipArchiveInputStream.java lies between .z01 and .z02
+        final ZipArchiveEntry zipEntry = zf.getEntry("commons-compress/src/main/java/org/apache/commons/compress/archivers/zip/ZipArchiveInputStream.java");
+        final File fileToCompare = getFile("COMPRESS-477/split_zip_created_by_winrar/file_to_compare_1");
+        assertFileEqualsToEntry(fileToCompare, zipEntry, zf);
+    }
+
+    @Test
+    public void testSetLevelTooSmallForZipArchiveOutputStream() {
+        final ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream());
+        assertThrows(IllegalArgumentException.class, () -> fixture.setLevel(Deflater.DEFAULT_COMPRESSION - 1));
+    }
+
+    @Test
+    public void testSetLevelTooBigForZipArchiveOutputStream() {
+        final ZipArchiveOutputStream fixture = new ZipArchiveOutputStream(new ByteArrayOutputStream());
+        assertThrows(IllegalArgumentException.class, () -> fixture.setLevel(Deflater.BEST_COMPRESSION + 1));
+    }
+
+    @Test
+    public void throwsExceptionWhenWritingPreamble() throws IOException {
+        final ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(new ByteArrayOutputStream());
+        outputStream.putArchiveEntry(new ZipArchiveEntry());
+        assertThrows(IllegalStateException.class, () -> outputStream.writePreamble(ByteUtils.EMPTY_BYTE_ARRAY));
+    }
+
+    @Test
+    public void testSelfExtractingZipUsingUnzipsfx() throws IOException, InterruptedException {
+        final File unzipsfx = new File("/usr/bin/unzipsfx");
+        if (!unzipsfx.exists()) {
+            return;
+        }
+
+        final File testZip = File.createTempFile("commons-compress-selfExtractZipTest", ".zip");
+        testZip.deleteOnExit();
+
+        final String testEntryName = "test_self_extract_zip/foo";
+        final File extractedFile = new File(testZip.getParentFile(), testEntryName);
+        extractedFile.deleteOnExit();
+
+        OutputStream outputStream = null;
+        InputStream inputStream = null;
+        final byte[] testData = new byte[]{1, 2, 3, 4};
+        final byte[] buffer = new byte[512];
+        int bytesRead;
+        try (InputStream unzipsfxInputStream = Files.newInputStream(unzipsfx.toPath())) {
+            outputStream = Files.newOutputStream(testZip.toPath());
+            final ZipArchiveOutputStream zo = new ZipArchiveOutputStream(outputStream);
+
+            while ((bytesRead = unzipsfxInputStream.read(buffer)) > 0) {
+                zo.writePreamble(buffer, 0, bytesRead);
+            }
+
+            final ZipArchiveEntry ze = new ZipArchiveEntry(testEntryName);
+            ze.setMethod(ZipEntry.STORED);
+            ze.setSize(4);
+            ze.setCrc(0xb63cfbcdL);
+            zo.putArchiveEntry(ze);
+            zo.write(testData);
+            zo.closeArchiveEntry();
+            zo.close();
+            outputStream.close();
+            outputStream = null;
+
+            final ProcessBuilder pbChmod = new ProcessBuilder("chmod", "+x", testZip.getPath());
+            pbChmod.redirectErrorStream(true);
+            final Process processChmod = pbChmod.start();
+            assertEquals(new String(IOUtils.toByteArray(processChmod.getInputStream())), 0, processChmod.waitFor());
+
+            final ProcessBuilder pb = new ProcessBuilder(testZip.getPath());
+            pb.redirectOutput(ProcessBuilder.Redirect.PIPE);
+            pb.directory(testZip.getParentFile());
+            pb.redirectErrorStream(true);
+            final Process process = pb.start();
+            assertEquals(new String(IOUtils.toByteArray(process.getInputStream())), 0, process.waitFor());
+
+            if (!extractedFile.exists()) {
+                // fail if extracted file does not exist
+                fail("Can not find the extracted file");
+            }
+
+            inputStream = Files.newInputStream(extractedFile.toPath());
+            bytesRead = IOUtils.readFully(inputStream, buffer);
+            assertEquals(testData.length, bytesRead);
+            assertArrayEquals(testData, Arrays.copyOfRange(buffer, 0, bytesRead));
+        } finally {
+            if (outputStream != null) {
+                outputStream.close();
+            }
+            if (inputStream != null) {
+                inputStream.close();
+            }
+
+            testZip.delete();
+            extractedFile.delete();
+            extractedFile.getParentFile().delete();
+        }
+    }
+
+    private void multiByteReadConsistentlyReturnsMinusOneAtEof(final File file) throws Exception {
+        final byte[] buf = new byte[2];
         try (ZipFile archive = new ZipFile(file)) {
-            ZipArchiveEntry e = archive.getEntries().nextElement();
+            final ZipArchiveEntry e = archive.getEntries().nextElement();
             try (InputStream is = archive.getInputStream(e)) {
                 IOUtils.toByteArray(is);
                 assertEquals(-1, is.read(buf));
@@ -699,71 +854,65 @@ public class ZipFileTest {
         }
     }
 
-    private void assertAllReadMethods(byte[] expected, ZipFile zipFile, ZipArchiveEntry entry) {
-        // simple IOUtil read
-        try (InputStream stream = zf.getInputStream(entry)) {
-            byte[] full = IOUtils.toByteArray(stream);
-            assertArrayEquals(expected, full);
-        }
-        catch (IOException ex) {
-            throw new RuntimeException(ex);
-        }
+	private void assertAllReadMethods(final byte[] expected, final ZipFile zipFile, final ZipArchiveEntry entry) {
+		// simple IOUtil read
+		try (InputStream stream = zf.getInputStream(entry)) {
+			final byte[] full = IOUtils.toByteArray(stream);
+			assertArrayEquals(expected, full);
+		} catch (final IOException ex) {
+			throw new AssertionError(ex);
+		}
 
-        // big buffer at the beginning and then chunks by IOUtils read
-        try (InputStream stream = zf.getInputStream(entry)) {
-            byte[] full;
-            byte[] bytes = new byte[0x40000];
-            int read = stream.read(bytes);
-            if (read < 0) {
-                full = new byte[0];
-            }
-            else {
-                full = readStreamRest(bytes, read, stream);
-            }
-            assertArrayEquals(expected, full);
-        }
-        catch (IOException ex) {
-            throw new RuntimeException(ex);
-        }
+		// big buffer at the beginning and then chunks by IOUtils read
+		try (InputStream stream = zf.getInputStream(entry)) {
+			byte[] full;
+			final byte[] bytes = new byte[0x40000];
+			final int read = stream.read(bytes);
+			if (read < 0) {
+				full = ByteUtils.EMPTY_BYTE_ARRAY;
+			} else {
+				full = readStreamRest(bytes, read, stream);
+			}
+			assertArrayEquals(expected, full);
+		} catch (final IOException ex) {
+			throw new AssertionError(ex);
+		}
 
-        // small chunk / single byte and big buffer then
-        try (InputStream stream = zf.getInputStream(entry)) {
-            byte[] full;
-            int single = stream.read();
-            if (single < 0) {
-                full = new byte[0];
-            }
-            else {
-                byte[] big = new byte[0x40000];
-                big[0] = (byte)single;
-                int read = stream.read(big, 1, big.length-1);
-                if (read < 0) {
-                    full = new byte[]{ (byte)single };
-                }
-                else {
-                    full = readStreamRest(big, read+1, stream);
-                }
-            }
-            assertArrayEquals(expected, full);
-        }
-        catch (IOException ex) {
-            throw new RuntimeException(ex);
-        }
-    }
+		// small chunk / single byte and big buffer then
+		try (InputStream stream = zf.getInputStream(entry)) {
+			byte[] full;
+			final int single = stream.read();
+			if (single < 0) {
+				full = ByteUtils.EMPTY_BYTE_ARRAY;
+			} else {
+				final byte[] big = new byte[0x40000];
+				big[0] = (byte) single;
+				final int read = stream.read(big, 1, big.length - 1);
+				if (read < 0) {
+					full = new byte[] { (byte) single };
+				} else {
+					full = readStreamRest(big, read + 1, stream);
+				}
+			}
+			assertArrayEquals(expected, full);
+		} catch (final IOException ex) {
+			throw new AssertionError(ex);
+		}
+	}
 
     /**
      * Utility to append the rest of the stream to already read data.
      */
-    private byte[] readStreamRest(byte[] beginning, int length, InputStream stream) throws IOException {
-        byte[] rest = IOUtils.toByteArray(stream);
-        byte[] full = new byte[length+rest.length];
+    private byte[] readStreamRest(final byte[] beginning, final int length, final InputStream stream) throws IOException {
+        final byte[] rest = IOUtils.toByteArray(stream);
+        final byte[] full = new byte[length+rest.length];
         System.arraycopy(beginning, 0, full, 0, length);
         System.arraycopy(rest, 0, full, length, rest.length);
         return full;
     }
 
-    private long calculateCrc32(byte[] content) {
-        CRC32 crc = new CRC32();
+    private long calculateCrc32(final byte[] content) {
+        final CRC32 crc = new CRC32();
         crc.update(content);
         return crc.getValue();
     }
@@ -792,11 +941,44 @@ public class ZipFileTest {
                      ze.getName());
     }
 
-    private static void nameSource(String archive, String entry, ZipArchiveEntry.NameSource expected) throws Exception {
+    private static void nameSource(final String archive, final String entry, final ZipArchiveEntry.NameSource expected) throws Exception {
         try (ZipFile zf = new ZipFile(getFile(archive))) {
-            ZipArchiveEntry ze = zf.getEntry(entry);
+            final ZipArchiveEntry ze = zf.getEntry(entry);
             assertEquals(entry, ze.getName());
             assertEquals(expected, ze.getNameSource());
         }
     }
+
+    private void assertFileEqualsToEntry(final File fileToCompare, final ZipArchiveEntry entry, final ZipFile zipFile) throws IOException {
+        final byte[] buffer = new byte[10240];
+        final File tempFile = File.createTempFile("temp","txt");
+        final OutputStream outputStream = Files.newOutputStream(tempFile.toPath());
+        final InputStream inputStream = zipFile.getInputStream(entry);
+        int readLen;
+        while((readLen = inputStream.read(buffer)) > 0) {
+            outputStream.write(buffer, 0, readLen);
+        }
+
+        outputStream.close();
+        inputStream.close();
+
+        assertFileEqualIgnoreEndOfLine(fileToCompare, tempFile);
+    }
+
+    private void assertFileEqualIgnoreEndOfLine(final File file1, final File file2) throws IOException {
+        final List<String> linesOfFile1 = Files.readAllLines(Paths.get(file1.getCanonicalPath()), UTF_8);
+        final List<String> linesOfFile2 = Files.readAllLines(Paths.get(file2.getCanonicalPath()), UTF_8);
+
+        if(linesOfFile1.size() != linesOfFile2.size()) {
+            fail("files not equal : " + file1.getName() + " , " + file2.getName());
+        }
+
+        String tempLineInFile1;
+        String tempLineInFile2;
+        for(int i = 0;i < linesOfFile1.size();i++) {
+            tempLineInFile1 = linesOfFile1.get(i).replace("\r\n", "\n");
+            tempLineInFile2 = linesOfFile2.get(i).replace("\r\n", "\n");
+            Assert.assertEquals(tempLineInFile1, tempLineInFile2);
+        }
+    }
 }
