@@ -18,39 +18,40 @@
 
 package org.apache.commons.compress.archivers.zip;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.fail;
+import junit.framework.TestCase;
 
 import java.math.BigInteger;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Date;
-import java.util.TimeZone;
 
-import org.junit.Before;
-import org.junit.Test;
-
-public class ZipUtilTest {
+public class ZipUtilTest extends TestCase {
 
     private Date time;
     private ZipLong zl;
 
-    @Before
-    public void setUp() throws Exception {
+    /**
+     * Constructor
+     */
+    public ZipUtilTest(String name) {
+        super(name);
+    }
+
+    @Override
+    protected void setUp() throws Exception {
         time = new Date();
-        final Calendar cal = Calendar.getInstance();
+        Calendar cal = Calendar.getInstance();
         cal.setTime(time);
-        final int year = cal.get(Calendar.YEAR);
-        final int month = cal.get(Calendar.MONTH) + 1;
-        final long value =  ((year - 1980) << 25)
+        int year = cal.get(Calendar.YEAR);
+        int month = cal.get(Calendar.MONTH) + 1;
+        long value =  ((year - 1980) << 25)
             |         (month << 21)
             |         (cal.get(Calendar.DAY_OF_MONTH) << 16)
             |         (cal.get(Calendar.HOUR_OF_DAY) << 11)
             |         (cal.get(Calendar.MINUTE) << 5)
             |         (cal.get(Calendar.SECOND) >> 1);
 
-        final byte[] result = new byte[4];
+        byte[] result = new byte[4];
         result[0] = (byte) ((value & 0xFF));
         result[1] = (byte) ((value & 0xFF00) >> 8);
         result[2] = (byte) ((value & 0xFF0000) >> 16);
@@ -58,13 +59,16 @@ public class ZipUtilTest {
         zl = new ZipLong(result);
     }
 
-    @Test
+    @Override
+    protected void tearDown() throws Exception {
+        super.tearDown();
+    }
+
     public void testZipLong() throws Exception {
-        final ZipLong test = ZipUtil.toDosTime(time);
+        ZipLong test = ZipUtil.toDosTime(time);
         assertEquals(test.getValue(), zl.getValue());
     }
 
-    @Test
     public void testAdjustToLong() {
         assertEquals(Integer.MAX_VALUE,
                      ZipUtil.adjustToLong(Integer.MAX_VALUE));
@@ -74,38 +78,16 @@ public class ZipUtilTest {
                      ZipUtil.adjustToLong(2 * Integer.MAX_VALUE));
     }
 
-    @Test
     public void testMinTime(){
-        final byte[] b1 = ZipUtil.toDosTime(0);
-        final byte b10 = b1[0]; // Save the first byte
+        byte[] b1 = ZipUtil.toDosTime(0);
+        byte b10 = b1[0]; // Save the first byte
         b1[0]++; // change it
-        final byte[] b2 = ZipUtil.toDosTime(0); // get the same time
+        byte[] b2 = ZipUtil.toDosTime(0); // get the same time
         assertEquals(b10,b2[0]); // first byte should still be the same
     }
 
-    @Test
-    public void testOutsideCalendar(){
-        final byte[] b1 = ZipUtil.toDosTime(160441200000L); // 1.1..1975
-        assertEquals(0, b1[0]);
-        assertEquals(33, b1[1]);
-        assertEquals(0, b1[2]);
-        assertEquals(0, b1[3]);
-    }
-
-    @Test
-    public void testInsideCalendar(){
-        final TimeZone tz = TimeZone.getDefault();
-        final long date = 476096400000L; // 1.1.1985, 10:00 am GMT
-        final byte[] b1 = ZipUtil.toDosTime(date - tz.getOffset(date));
-        assertEquals(0, b1[0]);
-        assertEquals(72, b1[1]);
-        assertEquals(65, b1[2]);
-        assertEquals(10, b1[3]);
-    }
-
-    @Test
     public void testReverse() {
-        final byte[][] bTest = new byte[6][];
+        byte[][] bTest = new byte[6][];
         bTest[0] = new byte[]{};
         bTest[1] = new byte[]{1};
         bTest[2] = new byte[]{1, 2};
@@ -113,7 +95,7 @@ public class ZipUtilTest {
         bTest[4] = new byte[]{1, 2, 3, 4};
         bTest[5] = new byte[]{1, 2, 3, 4, 5};
 
-        final byte[][] rTest = new byte[6][];
+        byte[][] rTest = new byte[6][];
         rTest[0] = new byte[]{};
         rTest[1] = new byte[]{1};
         rTest[2] = new byte[]{2, 1};
@@ -124,53 +106,51 @@ public class ZipUtilTest {
         assertEquals("test and result arrays are same length", bTest.length, rTest.length);
 
         for (int i = 0; i < bTest.length; i++) {
-            final byte[] result = ZipUtil.reverse(bTest[i]);
-            assertSame("reverse mutates in-place", bTest[i], result);
-            assertArrayEquals("reverse actually reverses", rTest[i], result);
+            byte[] result = ZipUtil.reverse(bTest[i]);
+            assertTrue("reverse mutates in-place", bTest[i] == result);
+            assertTrue("reverse actually reverses", Arrays.equals(rTest[i], result));
         }
     }
 
-    @Test
     public void testBigToLong() {
-        final BigInteger big1 = BigInteger.valueOf(1);
-        final BigInteger big2 = BigInteger.valueOf(Long.MAX_VALUE);
-        final BigInteger big3 = BigInteger.valueOf(Long.MIN_VALUE);
+        BigInteger big1 = BigInteger.valueOf(1);
+        BigInteger big2 = BigInteger.valueOf(Long.MAX_VALUE);
+        BigInteger big3 = BigInteger.valueOf(Long.MIN_VALUE);
 
         assertEquals(1L, ZipUtil.bigToLong(big1));
         assertEquals(Long.MAX_VALUE, ZipUtil.bigToLong(big2));
         assertEquals(Long.MIN_VALUE, ZipUtil.bigToLong(big3));
 
-        final BigInteger big4 = big2.add(big1);
+        BigInteger big4 = big2.add(big1);
         try {
             ZipUtil.bigToLong(big4);
             fail("Should have thrown IllegalArgumentException");
-        } catch (final IllegalArgumentException iae) {
+        } catch (IllegalArgumentException iae) {
             // All is good.
         }
 
-        final BigInteger big5 = big3.subtract(big1);
+        BigInteger big5 = big3.subtract(big1);
         try {
             ZipUtil.bigToLong(big5);
             fail("ZipUtil.bigToLong(BigInteger) should have thrown IllegalArgumentException");
-        } catch (final IllegalArgumentException iae) {
+        } catch (IllegalArgumentException iae) {
             // All is good.
         }
     }
 
-    @Test
     public void testLongToBig() {
-        final long l0 = 0;
-        final long l1 = 1;
-        final long l2 = -1;
-        final long l3 = Integer.MIN_VALUE;
-        final long l4 = Long.MAX_VALUE;
-        final long l5 = Long.MIN_VALUE;
+        long l0 = 0;
+        long l1 = 1;
+        long l2 = -1;
+        long l3 = Integer.MIN_VALUE;
+        long l4 = Long.MAX_VALUE;
+        long l5 = Long.MIN_VALUE;
 
-        final BigInteger big0 = ZipUtil.longToBig(l0);
-        final BigInteger big1 = ZipUtil.longToBig(l1);
-        final BigInteger big2 = ZipUtil.longToBig(l2);
-        final BigInteger big3 = ZipUtil.longToBig(l3);
-        final BigInteger big4 = ZipUtil.longToBig(l4);
+        BigInteger big0 = ZipUtil.longToBig(l0);
+        BigInteger big1 = ZipUtil.longToBig(l1);
+        BigInteger big2 = ZipUtil.longToBig(l2);
+        BigInteger big3 = ZipUtil.longToBig(l3);
+        BigInteger big4 = ZipUtil.longToBig(l4);
 
         assertEquals(0, big0.longValue());
         assertEquals(1, big1.longValue());
@@ -181,17 +161,16 @@ public class ZipUtilTest {
         try {
             ZipUtil.longToBig(l5);
             fail("ZipUtil.longToBig(long) should have thrown IllegalArgumentException");
-        } catch (final IllegalArgumentException iae) {
+        } catch (IllegalArgumentException iae) {
 
         }
     }
 
-    @Test
     public void testSignedByteToUnsignedInt() {
         // Yay, we can completely test all possible input values in this case!
         int expectedVal = 128;
         for (int i = Byte.MIN_VALUE; i <= Byte.MAX_VALUE; i++) {
-            final byte b = (byte) i;
+            byte b = (byte) i;
             assertEquals(expectedVal, ZipUtil.signedByteToUnsignedInt(b));
             expectedVal++;
             if (expectedVal == 256) {
@@ -200,11 +179,10 @@ public class ZipUtilTest {
         }
     }
 
-    @Test
     public void testUnsignedIntToSignedByte() {
         int unsignedVal = 128;
         for (int i = Byte.MIN_VALUE; i <= Byte.MAX_VALUE; i++) {
-            final byte expectedVal = (byte) i;
+            byte expectedVal = (byte) i;
             assertEquals(expectedVal, ZipUtil.unsignedIntToSignedByte(unsignedVal));
             unsignedVal++;
             if (unsignedVal == 256) {
@@ -215,50 +193,18 @@ public class ZipUtilTest {
         try {
             ZipUtil.unsignedIntToSignedByte(-1);
             fail("ZipUtil.unsignedIntToSignedByte(-1) should have thrown IllegalArgumentException");
-        } catch (final IllegalArgumentException iae) {
+        } catch (IllegalArgumentException iae) {
             // All is good.
         }
 
         try {
             ZipUtil.unsignedIntToSignedByte(256);
             fail("ZipUtil.unsignedIntToSignedByte(256) should have thrown IllegalArgumentException");
-        } catch (final IllegalArgumentException iae) {
+        } catch (IllegalArgumentException iae) {
             // All is good.
         }
 
     }
 
-    @Test
-    public void testFromDosTime() {
-        ZipLong testDosTime = new ZipLong(1 << 21);
-        final Calendar cal = Calendar.getInstance();
-        cal.set(Calendar.YEAR, 1980);
-        cal.set(Calendar.MONTH, 0);
-        cal.set(Calendar.DATE, 0);
-        cal.set(Calendar.HOUR_OF_DAY, 0);
-        cal.set(Calendar.MINUTE, 0);
-        cal.set(Calendar.SECOND, 0);
-        cal.set(Calendar.MILLISECOND, 0);
-        Date testDate = ZipUtil.fromDosTime(testDosTime);
-        assertEquals(testDate.getTime(), cal.getTime().getTime());
 
-        testDosTime = ZipUtil.toDosTime(time);
-        testDate = ZipUtil.fromDosTime(testDosTime);
-        // the minimal time unit for dos time is 2 seconds
-        assertEquals(testDate.getTime() / 2000, (time.getTime() / 2000));
-    }
-
-    @Test(expected = UnsupportedZipFeatureException.class)
-    public void testUnsupportedMethod() throws Exception {
-        final ZipArchiveEntry ze = new ZipArchiveEntry();
-        ze.setMethod(ZipMethod.EXPANDING_LEVEL_1.getCode());
-        ZipUtil.checkRequestedFeatures(ze);
-    }
-
-    @Test(expected = UnsupportedZipFeatureException.class)
-    public void testUnknownMethod() throws Exception {
-        final ZipArchiveEntry ze = new ZipArchiveEntry();
-        ze.setMethod(100);
-        ZipUtil.checkRequestedFeatures(ze);
-    }
 }
