@@ -18,17 +18,15 @@
  */
 package org.apache.commons.compress.changes;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.FileReader;
 import java.io.InputStream;
+import java.nio.file.Files;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.commons.compress.AbstractTestCase;
@@ -41,7 +39,7 @@ import org.apache.commons.compress.archivers.jar.JarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipFile;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Checks several ChangeSet business logics.
@@ -50,24 +48,13 @@ public final class ChangeSetTestCase extends AbstractTestCase {
 
     // Delete a directory tree
     private void archiveListDeleteDir(final String prefix){
-        final Iterator<String> it = archiveList.iterator();
-        while(it.hasNext()){
-            final String entry = it.next();
-            if (entry.startsWith(prefix+"/")){ // TODO won't work with folders
-                it.remove();
-            }
-        }
+        // TODO won't work with folders
+        archiveList.removeIf(entry -> entry.startsWith(prefix + "/"));
     }
 
     // Delete a single file
     private void archiveListDelete(final String prefix){
-        final Iterator<String> it = archiveList.iterator();
-        while(it.hasNext()){
-            final String entry = it.next();
-            if (entry.equals(prefix)){
-                it.remove();
-            }
-        }
+        archiveList.removeIf(entry -> entry.equals(prefix));
     }
 
     /**
@@ -82,8 +69,8 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         InputStream in = null;
         InputStream in2 = null;
         try {
-            in = new FileInputStream(getFile("test.txt"));
-            in2 = new FileInputStream(getFile("test2.xml"));
+            in = Files.newInputStream(getFile("test.txt").toPath());
+            in2 = Files.newInputStream(getFile("test2.xml").toPath());
 
             final ArchiveEntry e = new ZipArchiveEntry("test.txt");
             final ArchiveEntry e2 = new ZipArchiveEntry("test.txt");
@@ -117,8 +104,8 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         InputStream in = null;
         InputStream in2 = null;
         try {
-            in = new FileInputStream(getFile("test.txt"));
-            in2 = new FileInputStream(getFile("test2.xml"));
+            in = Files.newInputStream(getFile("test.txt").toPath());
+            in2 = Files.newInputStream(getFile("test2.xml").toPath());
 
             final ArchiveEntry e = new ZipArchiveEntry("test.txt");
             final ArchiveEntry e2 = new ZipArchiveEntry("test.txt");
@@ -159,11 +146,11 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.deleteDir("bla");
@@ -201,11 +188,11 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.deleteDir("la");
@@ -243,11 +230,11 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.deleteDir("test.txt");
@@ -285,11 +272,11 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.delete("bla/test5.xml");
@@ -328,11 +315,11 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.delete("bla");
@@ -374,10 +361,10 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         File testtxt = null;
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.delete("test/test3.xml");
@@ -386,7 +373,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             // Add a file
             testtxt = getFile("test.txt");
             final ArchiveEntry entry = out.createArchiveEntry(testtxt, "test/test3.xml");
-            changes.add(entry, new FileInputStream(testtxt));
+            changes.add(entry, Files.newInputStream(testtxt.toPath()));
             archiveList.add("test/test3.xml");
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
@@ -406,14 +393,14 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         ArchiveInputStream in = null;
         File check = null;
         try {
-            final InputStream is = new FileInputStream(result);
+            final InputStream is = Files.newInputStream(result.toPath());
             final BufferedInputStream buf = new BufferedInputStream(is);
             in = factory.createArchiveInputStream(buf);
             check = this.checkArchiveContent(in, archiveList, false);
             final File test3xml = new File(check,"result/test/test3.xml");
             assertEquals(testtxt.length(), test3xml.length());
 
-            final BufferedReader reader = new BufferedReader(new FileReader(test3xml));
+            final BufferedReader reader = new BufferedReader(Files.newBufferedReader(test3xml.toPath()));
             String str;
             while ((str = reader.readLine()) != null) {
                 // All lines look like this
@@ -444,10 +431,10 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.deleteDir("bla");
@@ -456,7 +443,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             // Add a file
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = out.createArchiveEntry(file1, "bla/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("bla/test.txt");
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
@@ -508,10 +495,10 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
             changes.deleteDir("bla");
@@ -520,7 +507,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             // Add a file
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = out.createArchiveEntry(file1, "bla/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("bla/test.txt");
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
@@ -555,16 +542,16 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new ZipArchiveEntry("blub/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("blub/test.txt");
 
             changes.delete("testdata/test1.xml");
@@ -604,13 +591,13 @@ public final class ChangeSetTestCase extends AbstractTestCase {
 
             ais = new ZipFile(input);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new ZipArchiveEntry("blub/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("blub/test.txt");
 
             changes.delete("testdata/test1.xml");
@@ -648,16 +635,16 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new CpioArchiveEntry("blub/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("blub/test.txt");
 
             changes.deleteDir("blub");
@@ -697,10 +684,10 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
@@ -708,7 +695,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new CpioArchiveEntry("bla/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("bla/test.txt");
 
             changes.deleteDir("bla");
@@ -746,13 +733,13 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             changes.delete("test2.xml");
 
             final File input = getFile("bla.zip");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("zip", is);
 
             temp = File.createTempFile("test", ".zip");
             temp.deleteOnExit();
             out = factory.createArchiveOutputStream("zip",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -787,12 +774,12 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             changes.delete("test2.xml");
 
             final File input = getFile("bla.tar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("tar", is);
 
             temp = new File(dir, "bla.tar");
             out = factory.createArchiveOutputStream("tar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -828,12 +815,12 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             changes.delete(".project");
 
             final File input = getFile("bla.jar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("jar", is);
 
             temp = new File(dir, "bla.jar");
             out = factory.createArchiveOutputStream("jar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -872,15 +859,15 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             entry.setGroupName("excalibur");
             entry.setMode(0100000);
 
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
 
             final File input = getFile("bla.tar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("tar", is);
 
             temp = new File(dir, "bla.tar");
             out = factory.createArchiveOutputStream("tar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -896,7 +883,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         final List<String> expected = new ArrayList<>();
         expected.add("test1.xml");
         expected.add("testdata/test.txt");
-        final ArchiveInputStream in = factory.createArchiveInputStream("tar", new FileInputStream(temp));
+        final ArchiveInputStream in = factory.createArchiveInputStream("tar", Files.newInputStream(temp.toPath()));
         this.checkArchiveContent(in, expected);
     }
 
@@ -919,15 +906,15 @@ public final class ChangeSetTestCase extends AbstractTestCase {
 
             final File file1 = getFile("test.txt");
             final JarArchiveEntry entry = new JarArchiveEntry("testdata/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
 
             final File input = getFile("bla.jar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("jar", is);
 
             temp = new File(dir, "bla.jar");
             out = factory.createArchiveOutputStream("jar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -961,12 +948,12 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             changes.delete("test2.xml");
 
             final File input = getFile("bla.ar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("ar", is);
 
             temp = new File(dir, "bla.ar");
             out = factory.createArchiveOutputStream("ar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -1004,15 +991,15 @@ public final class ChangeSetTestCase extends AbstractTestCase {
             final ArArchiveEntry entry = new ArArchiveEntry("test.txt", file1
                     .length());
 
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
 
             final File input = getFile("bla.ar");
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream("ar", is);
 
             temp = new File(dir, "bla.ar");
             out = factory.createArchiveOutputStream("ar",
-                    new FileOutputStream(temp));
+                    Files.newOutputStream(temp.toPath()));
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -1075,15 +1062,15 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         final ChangeSet changes = new ChangeSet();
         try {
 
-            is = new FileInputStream(input);
+            is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new ZipArchiveEntry("bla/test.txt");
-            changes.add(entry, new FileInputStream(file1));
+            changes.add(entry, Files.newInputStream(file1.toPath()));
             archiveList.add("bla/test.txt");
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             performer.perform(ais, out);
@@ -1121,17 +1108,17 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         final ChangeSet changes = new ChangeSet();
         try {
 
-            is = new FileInputStream(input);
+            is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
             changes.delete("test1.xml");
             archiveListDelete("test1.xml");
 
             final File file = getFile("test.txt");
             final ArchiveEntry entry = out.createArchiveEntry(file,"bla/test.txt");
-            changes.add(entry, new FileInputStream(file));
+            changes.add(entry, Files.newInputStream(file.toPath()));
             archiveList.add("bla/test.txt");
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
@@ -1170,14 +1157,14 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         final ChangeSet changes = new ChangeSet();
         try {
 
-            is = new FileInputStream(input);
+            is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
 
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
             final File file = getFile("test.txt");
             final ArchiveEntry entry = out.createArchiveEntry(file,"bla/test.txt");
-            changes.add(entry, new FileInputStream(file));
+            changes.add(entry, Files.newInputStream(file.toPath()));
             archiveList.add("bla/test.txt");
 
             changes.delete("test1.xml");
@@ -1218,16 +1205,16 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new ZipArchiveEntry("testdata/test1.xml");
-            changes.add(entry, new FileInputStream(file1), true);
+            changes.add(entry, Files.newInputStream(file1.toPath()), true);
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             final ChangeSetResults results = performer.perform(ais, out);
@@ -1263,16 +1250,16 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         result.deleteOnExit();
         try {
 
-            final InputStream is = new FileInputStream(input);
+            final InputStream is = Files.newInputStream(input.toPath());
             ais = factory.createArchiveInputStream(archivename, is);
             out = factory.createArchiveOutputStream(archivename,
-                    new FileOutputStream(result));
+                    Files.newOutputStream(result.toPath()));
 
             final ChangeSet changes = new ChangeSet();
 
             final File file1 = getFile("test.txt");
             final ArchiveEntry entry = new ZipArchiveEntry("testdata/test1.xml");
-            changes.add(entry, new FileInputStream(file1), false);
+            changes.add(entry, Files.newInputStream(file1.toPath()), false);
 
             final ChangeSetPerformer performer = new ChangeSetPerformer(changes);
             final ChangeSetResults results = performer.perform(ais, out);
