@@ -23,7 +23,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 import org.apache.commons.compress.compressors.bzip2.BZip2Utils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class BZip2UtilsTestCase {
 
