@@ -18,16 +18,16 @@
  */
 package org.apache.commons.compress.compressors;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.Files;
 import java.util.zip.Deflater;
 import java.util.zip.GZIPInputStream;
 
@@ -37,7 +37,7 @@ import org.apache.commons.compress.compressors.gzip.GzipCompressorOutputStream;
 import org.apache.commons.compress.compressors.gzip.GzipParameters;
 import org.apache.commons.compress.utils.IOUtils;
 import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public final class GZipTestCase extends AbstractTestCase {
 
@@ -45,10 +45,10 @@ public final class GZipTestCase extends AbstractTestCase {
     public void testGzipCreation()  throws Exception {
         final File input = getFile("test1.xml");
         final File output = new File(dir, "test1.xml.gz");
-        try (OutputStream out = new FileOutputStream(output)) {
+        try (OutputStream out = Files.newOutputStream(output.toPath())) {
             try (CompressorOutputStream cos = new CompressorStreamFactory()
                     .createCompressorOutputStream("gz", out)) {
-                IOUtils.copy(new FileInputStream(input), cos);
+                IOUtils.copy(Files.newInputStream(input.toPath()), cos);
             }
         }
     }
@@ -57,18 +57,11 @@ public final class GZipTestCase extends AbstractTestCase {
     public void testGzipUnarchive() throws Exception {
         final File input = getFile("bla.tgz");
         final File output = new File(dir, "bla.tar");
-        try (InputStream is = new FileInputStream(input)) {
-            final CompressorInputStream in = new CompressorStreamFactory()
+        try (InputStream is = Files.newInputStream(input.toPath())) {
+            try (CompressorInputStream in = new CompressorStreamFactory()
                     .createCompressorInputStream("gz", is);
-            FileOutputStream out = null;
-            try {
-                out = new FileOutputStream(output);
+                    OutputStream out = Files.newOutputStream(output.toPath())) {
                 IOUtils.copy(in, out);
-            } finally {
-                if (out != null) {
-                    out.close();
-                }
-                in.close();
             }
         }
     }
@@ -76,7 +69,7 @@ public final class GZipTestCase extends AbstractTestCase {
     @Test
     public void testConcatenatedStreamsReadFirstOnly() throws Exception {
         final File input = getFile("multiple.gz");
-        try (InputStream is = new FileInputStream(input)) {
+        try (InputStream is = Files.newInputStream(input.toPath())) {
             try (CompressorInputStream in = new CompressorStreamFactory()
                     .createCompressorInputStream("gz", is)) {
                 assertEquals('a', in.read());
@@ -88,7 +81,7 @@ public final class GZipTestCase extends AbstractTestCase {
     @Test
     public void testConcatenatedStreamsReadFully() throws Exception {
         final File input = getFile("multiple.gz");
-        try (InputStream is = new FileInputStream(input)) {
+        try (InputStream is = Files.newInputStream(input.toPath())) {
             try (CompressorInputStream in = new GzipCompressorInputStream(is, true)) {
                 assertEquals('a', in.read());
                 assertEquals('b', in.read());
@@ -107,7 +100,7 @@ public final class GZipTestCase extends AbstractTestCase {
         OutputStream out = null;
         CompressorInputStream cin = null;
         try {
-            in = new FileInputStream(getFile("bla.tgz"));
+            in = Files.newInputStream(getFile("bla.tgz").toPath());
             out = new ByteArrayOutputStream();
             IOUtils.copy(in, out);
             in.close();
@@ -141,8 +134,8 @@ public final class GZipTestCase extends AbstractTestCase {
 
     @Test
     public void testInteroperabilityWithGzipCompressorInputStream() throws Exception {
-        byte[] content;
-        try (FileInputStream fis = new FileInputStream(getFile("test3.xml"))) {
+        final byte[] content;
+        try (InputStream fis = Files.newInputStream(getFile("test3.xml").toPath())) {
             content = IOUtils.toByteArray(fis);
         }
 
@@ -167,8 +160,8 @@ public final class GZipTestCase extends AbstractTestCase {
 
     @Test
     public void testInteroperabilityWithGZIPInputStream() throws Exception {
-        byte[] content;
-        try (FileInputStream fis = new FileInputStream(getFile("test3.xml"))) {
+        final byte[] content;
+        try (InputStream fis = Files.newInputStream(getFile("test3.xml").toPath())) {
             content = IOUtils.toByteArray(fis);
         }
 
@@ -209,9 +202,27 @@ public final class GZipTestCase extends AbstractTestCase {
         }
     }
 
-    private void testExtraFlags(final int compressionLevel, final int flag) throws Exception {
-        byte[] content;
-        try (FileInputStream fis = new FileInputStream(getFile("test3.xml"))) {
+    @Test
+    public void testInvalidBufferSize() {
+        final GzipParameters parameters = new GzipParameters();
+        try {
+            parameters.setBufferSize(0);
+            fail("IllegalArgumentException not thrown");
+        } catch (final IllegalArgumentException e) {
+            // expected
+        }
+
+        try {
+            parameters.setBufferSize(-1);
+            fail("IllegalArgumentException not thrown");
+        } catch (final IllegalArgumentException e) {
+            // expected
+        }
+    }
+
+    private void testExtraFlags(final int compressionLevel, final int flag, final int bufferSize) throws Exception {
+        final byte[] content;
+        try (InputStream fis = Files.newInputStream(getFile("test3.xml").toPath())) {
             content = IOUtils.toByteArray(fis);
         }
 
@@ -219,6 +230,7 @@ public final class GZipTestCase extends AbstractTestCase {
 
         final GzipParameters parameters = new GzipParameters();
         parameters.setCompressionLevel(compressionLevel);
+        parameters.setBufferSize(bufferSize);
         final GzipCompressorOutputStream out = new GzipCompressorOutputStream(bout, parameters);
         IOUtils.copy(new ByteArrayInputStream(content), out);
         out.flush();
@@ -229,17 +241,17 @@ public final class GZipTestCase extends AbstractTestCase {
 
     @Test
     public void testExtraFlagsFastestCompression() throws Exception {
-        testExtraFlags(Deflater.BEST_SPEED, 4);
+        testExtraFlags(Deflater.BEST_SPEED, 4, 128);
     }
 
     @Test
     public void testExtraFlagsBestCompression() throws Exception {
-        testExtraFlags(Deflater.BEST_COMPRESSION, 2);
+        testExtraFlags(Deflater.BEST_COMPRESSION, 2, 1024);
     }
 
     @Test
     public void testExtraFlagsDefaultCompression() throws Exception {
-        testExtraFlags(Deflater.DEFAULT_COMPRESSION, 0);
+        testExtraFlags(Deflater.DEFAULT_COMPRESSION, 0, 4096);
     }
 
     @Test
@@ -264,8 +276,8 @@ public final class GZipTestCase extends AbstractTestCase {
         parameters.setOperatingSystem(13);
         parameters.setFilename("test3.xml");
         parameters.setComment("Umlaute möglich?");
-        try (GzipCompressorOutputStream out = new GzipCompressorOutputStream(bout, parameters); FileInputStream fis = new FileInputStream(getFile("test3" +
-                ".xml"))) {
+        try (GzipCompressorOutputStream out = new GzipCompressorOutputStream(bout, parameters); InputStream fis = Files.newInputStream(getFile("test3" +
+                ".xml").toPath())) {
             IOUtils.copy(fis, out);
         }
 
@@ -283,7 +295,7 @@ public final class GZipTestCase extends AbstractTestCase {
     @Test
     public void singleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
         final File input = getFile("bla.tgz");
-        try (InputStream is = new FileInputStream(input)) {
+        try (InputStream is = Files.newInputStream(input.toPath())) {
             final GzipCompressorInputStream in =
                     new GzipCompressorInputStream(is);
             IOUtils.toByteArray(in);
@@ -296,8 +308,8 @@ public final class GZipTestCase extends AbstractTestCase {
     @Test
     public void multiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
         final File input = getFile("bla.tgz");
-        byte[] buf = new byte[2];
-        try (InputStream is = new FileInputStream(input)) {
+        final byte[] buf = new byte[2];
+        try (InputStream is = Files.newInputStream(input.toPath())) {
             final GzipCompressorInputStream in =
                     new GzipCompressorInputStream(is);
             IOUtils.toByteArray(in);
