@@ -18,13 +18,14 @@
  */
 package org.apache.commons.compress.compressors;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -40,7 +41,7 @@ import org.apache.commons.compress.compressors.pack200.Pack200CompressorInputStr
 import org.apache.commons.compress.compressors.pack200.Pack200CompressorOutputStream;
 import org.apache.commons.compress.compressors.pack200.Pack200Strategy;
 import org.apache.commons.compress.utils.IOUtils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public final class Pack200TestCase extends AbstractTestCase {
 
@@ -67,12 +68,10 @@ public final class Pack200TestCase extends AbstractTestCase {
     private void jarUnarchiveAll(final boolean useFile, final Pack200Strategy mode)
         throws Exception {
         final File input = getFile("bla.pack");
-        try (InputStream is = useFile
-                ? new Pack200CompressorInputStream(input, mode)
-                : new Pack200CompressorInputStream(new FileInputStream(input),
-                mode)) {
-            final ArchiveInputStream in = new ArchiveStreamFactory()
-                    .createArchiveInputStream("jar", is);
+        try (
+            InputStream is = useFile ? new Pack200CompressorInputStream(input, mode)
+                : new Pack200CompressorInputStream(Files.newInputStream(input.toPath()), mode);
+            ArchiveInputStream in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("jar", is)) {
 
             ArchiveEntry entry = in.getNextEntry();
             while (entry != null) {
@@ -83,13 +82,9 @@ public final class Pack200TestCase extends AbstractTestCase {
                     entry = in.getNextEntry();
                     continue;
                 }
-                final OutputStream out = new FileOutputStream(archiveEntry);
-                IOUtils.copy(in, out);
-                out.close();
+                Files.copy(in, archiveEntry.toPath());
                 entry = in.getNextEntry();
             }
-
-            in.close();
         }
     }
 
@@ -109,36 +104,34 @@ public final class Pack200TestCase extends AbstractTestCase {
         final File file1 = getFile("test1.xml");
         final File file2 = getFile("test2.xml");
 
-        try (OutputStream out = new Pack200CompressorOutputStream(new FileOutputStream(output),
-                mode)) {
-            final ArchiveOutputStream os = new ArchiveStreamFactory()
-                    .createArchiveOutputStream("jar", out);
+        try (OutputStream out = new Pack200CompressorOutputStream(Files.newOutputStream(output.toPath()), mode);
+             ArchiveOutputStream os = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("jar", out)) {
 
             os.putArchiveEntry(new ZipArchiveEntry("testdata/test1.xml"));
-            IOUtils.copy(new FileInputStream(file1), os);
+            try (InputStream inputStream = Files.newInputStream(file1.toPath())) {
+                IOUtils.copy(inputStream, os);
+            }
             os.closeArchiveEntry();
 
             os.putArchiveEntry(new ZipArchiveEntry("testdata/test2.xml"));
-            IOUtils.copy(new FileInputStream(file2), os);
+            try (InputStream inputStream = Files.newInputStream(file2.toPath())) {
+                IOUtils.copy(inputStream, os);
+            }
             os.closeArchiveEntry();
-
-            os.close();
         }
 
-        try (InputStream is = new Pack200CompressorInputStream(output)) {
-            final ArchiveInputStream in = new ArchiveStreamFactory()
-                    .createArchiveInputStream("jar", is);
+        try (InputStream is = new Pack200CompressorInputStream(output);
+            final ArchiveInputStream in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("jar", is)) {
             final List<String> files = new ArrayList<>();
             files.add("testdata/test1.xml");
             files.add("testdata/test2.xml");
             checkArchiveContent(in, files);
-            in.close();
         }
     }
 
     @Test
     public void testGoodSignature() throws Exception {
-        try (InputStream is = new FileInputStream(getFile("bla.pack"))) {
+        try (InputStream is = Files.newInputStream(getFile("bla.pack").toPath())) {
             final byte[] sig = new byte[4];
             is.read(sig);
             assertTrue(Pack200CompressorInputStream.matches(sig, 4));
@@ -147,7 +140,7 @@ public final class Pack200TestCase extends AbstractTestCase {
 
     @Test
     public void testBadSignature() throws Exception {
-        try (InputStream is = new FileInputStream(getFile("bla.jar"))) {
+        try (InputStream is = Files.newInputStream(getFile("bla.jar").toPath())) {
             final byte[] sig = new byte[4];
             is.read(sig);
             assertFalse(Pack200CompressorInputStream.matches(sig, 4));
@@ -156,7 +149,7 @@ public final class Pack200TestCase extends AbstractTestCase {
 
     @Test
     public void testShortSignature() throws Exception {
-        try (InputStream is = new FileInputStream(getFile("bla.pack"))) {
+        try (InputStream is = Files.newInputStream(getFile("bla.pack").toPath())) {
             final byte[] sig = new byte[2];
             is.read(sig);
             assertFalse(Pack200CompressorInputStream.matches(sig, 2));
@@ -167,7 +160,7 @@ public final class Pack200TestCase extends AbstractTestCase {
     public void testInputStreamMethods() throws Exception {
         final Map<String, String> m = new HashMap<>();
         m.put("foo", "bar");
-        try (InputStream is = new Pack200CompressorInputStream(new FileInputStream(getFile("bla.jar")),
+        try (InputStream is = new Pack200CompressorInputStream(Files.newInputStream(getFile("bla.jar").toPath()),
                 m)) {
             // packed file is a jar, which is a zip so it starts with
             // a local file header
@@ -191,11 +184,10 @@ public final class Pack200TestCase extends AbstractTestCase {
         final File output = new File(dir, "bla.pack");
         final Map<String, String> m = new HashMap<>();
         m.put("foo", "bar");
-        try (OutputStream out = new FileOutputStream(output)) {
-            final OutputStream os = new Pack200CompressorOutputStream(out, m);
+        try (OutputStream out = Files.newOutputStream(output.toPath());
+             OutputStream os = new Pack200CompressorOutputStream(out, m)) {
             os.write(1);
-            os.write(new byte[] { 2, 3 });
-            os.close();
+            os.write(new byte[] {2, 3});
         }
     }
 
@@ -209,13 +201,12 @@ public final class Pack200TestCase extends AbstractTestCase {
         singleByteReadConsistentlyReturnsMinusOneAtEof(Pack200Strategy.TEMP_FILE);
     }
 
-    private void singleByteReadConsistentlyReturnsMinusOneAtEof(Pack200Strategy s) throws Exception {
+    private void singleByteReadConsistentlyReturnsMinusOneAtEof(final Pack200Strategy s) throws Exception {
         final File input = getFile("bla.pack");
         try (final Pack200CompressorInputStream in = new Pack200CompressorInputStream(input, s)) {
             IOUtils.toByteArray(in);
             assertEquals(-1, in.read());
             assertEquals(-1, in.read());
-            in.close();
         }
     }
 
@@ -229,14 +220,13 @@ public final class Pack200TestCase extends AbstractTestCase {
         multiByteReadConsistentlyReturnsMinusOneAtEof(Pack200Strategy.TEMP_FILE);
     }
 
-    private void multiByteReadConsistentlyReturnsMinusOneAtEof(Pack200Strategy s) throws Exception {
+    private void multiByteReadConsistentlyReturnsMinusOneAtEof(final Pack200Strategy s) throws Exception {
         final File input = getFile("bla.pack");
-        byte[] buf = new byte[2];
+        final byte[] buf = new byte[2];
         try (final Pack200CompressorInputStream in = new Pack200CompressorInputStream(input, s)) {
             IOUtils.toByteArray(in);
             assertEquals(-1, in.read(buf));
             assertEquals(-1, in.read(buf));
-            in.close();
         }
     }
 
