@@ -18,12 +18,12 @@
  */
 package org.apache.commons.compress.compressors.deflate;
 
-import org.junit.Assert;
-import org.junit.Test;
-
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 
+import org.junit.Assert;
+import org.junit.jupiter.api.Test;
+
 public class DeflateCompressorOutputStreamTest {
 
     @Test
