@@ -23,37 +23,26 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.file.Files;
-import java.util.Arrays;
-import java.util.Collection;
+import java.util.stream.Stream;
+
 import org.apache.commons.compress.AbstractTestCase;
 import org.apache.commons.compress.compressors.lz77support.Parameters;
 import org.apache.commons.compress.utils.IOUtils;
 import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runners.Parameterized;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
-@RunWith(Parameterized.class)
 public final class BlockLZ4CompressorRoundtripTest extends AbstractTestCase {
 
-    @org.junit.runners.Parameterized.Parameters(name = "using {0}")
-    public static Collection<Object[]> factory() {
-        return Arrays.asList(new Object[] { "default", BlockLZ4CompressorOutputStream.createParameterBuilder().build() },
-                new Object[] { "tuned for speed",
-                    BlockLZ4CompressorOutputStream.createParameterBuilder().tunedForSpeed().build() },
-                new Object[] { "tuned for compression ratio",
-                    BlockLZ4CompressorOutputStream.createParameterBuilder().tunedForCompressionRatio().build() });
+    public static Stream<Arguments> factory() {
+        return Stream.of(
+                Arguments.of("default", BlockLZ4CompressorOutputStream.createParameterBuilder().build()),
+                Arguments.of("tuned for speed", BlockLZ4CompressorOutputStream.createParameterBuilder().tunedForSpeed().build()),
+                Arguments.of("tuned for compression ratio", BlockLZ4CompressorOutputStream.createParameterBuilder().tunedForCompressionRatio().build()));
     }
 
-    private final String config;
-    private final Parameters params;
-
-    public BlockLZ4CompressorRoundtripTest(final String config, final Parameters params) {
-        this.config = config;
-        this.params = params;
-    }
-
-    private void roundTripTest(final String testFile) throws IOException {
+    private void roundTripTest(final String testFile, final String config, final Parameters params) throws IOException {
         final File input = getFile(testFile);
         long start = System.currentTimeMillis();
         final File outputSz = new File(dir, input.getName() + ".block.lz4");
@@ -62,9 +51,9 @@ public final class BlockLZ4CompressorRoundtripTest extends AbstractTestCase {
              BlockLZ4CompressorOutputStream los = new BlockLZ4CompressorOutputStream(os, params)) {
             IOUtils.copy(is, los);
         }
-        System.err.println("Configuration: " + config);
-        System.err.println(input.getName() + " written, uncompressed bytes: " + input.length()
-            + ", compressed bytes: " + outputSz.length() + " after " + (System.currentTimeMillis() - start) + "ms");
+        // System.err.println("Configuration: " + config);
+        // System.err.println(input.getName() + " written, uncompressed bytes: " + input.length()
+        //    + ", compressed bytes: " + outputSz.length() + " after " + (System.currentTimeMillis() - start) + "ms");
         start = System.currentTimeMillis();
         try (InputStream is = Files.newInputStream(input.toPath());
              BlockLZ4CompressorInputStream sis = new BlockLZ4CompressorInputStream(Files.newInputStream(outputSz.toPath()))) {
@@ -72,25 +61,28 @@ public final class BlockLZ4CompressorRoundtripTest extends AbstractTestCase {
             final byte[] actual = IOUtils.toByteArray(sis);
             Assert.assertArrayEquals(expected, actual);
         }
-        System.err.println(outputSz.getName() + " read after " + (System.currentTimeMillis() - start) + "ms");
+        // System.err.println(outputSz.getName() + " read after " + (System.currentTimeMillis() - start) + "ms");
     }
 
     // should yield decent compression
-    @Test
-    public void blaTarRoundtrip() throws IOException {
-        roundTripTest("bla.tar");
+    @ParameterizedTest
+    @MethodSource("factory")
+    public void blaTarRoundtrip(final String config, final Parameters params) throws IOException {
+        roundTripTest("bla.tar", config, params);
     }
 
     // yields no compression at all
-    @Test
-    public void gzippedLoremIpsumRoundtrip() throws IOException {
-        roundTripTest("lorem-ipsum.txt.gz");
+    @ParameterizedTest
+    @MethodSource("factory")
+    public void gzippedLoremIpsumRoundtrip(final String config, final Parameters params) throws IOException {
+        roundTripTest("lorem-ipsum.txt.gz", config, params);
     }
 
     // yields no compression at all
-    @Test
-    public void biggerFileRoundtrip() throws IOException {
-        roundTripTest("COMPRESS-256.7z");
+    @ParameterizedTest
+    @MethodSource("factory")
+    public void biggerFileRoundtrip(final String config, final Parameters params) throws IOException {
+        roundTripTest("COMPRESS-256.7z", config, params);
     }
 
 }
