@@ -18,9 +18,10 @@
  */
 package org.apache.commons.compress.compressors.lz77support;
 
-import org.junit.Test;
-
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
+
+import org.junit.jupiter.api.Test;
 
 public class ParametersTest {
 
@@ -109,14 +110,14 @@ public class ParametersTest {
         assertEquals(7, p.getMaxLiteralLength());
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void windowSizeMustNotBeSmallerThanMinBackReferenceLength() {
-        newParameters(128, 200, 300, 400, 500);
+        assertThrows(IllegalArgumentException.class, () -> newParameters(128, 200, 300, 400, 500));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void windowSizeMustBeAPowerOfTwo() {
-        newParameters(100, 200, 300, 400, 500);
+        assertThrows(IllegalArgumentException.class, () -> newParameters(100, 200, 300, 400, 500));
     }
 
     private static Parameters newParameters(final int windowSize) {
