@@ -19,31 +19,33 @@
 package org.apache.commons.compress.compressors.snappy;
 
 import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
+import java.nio.file.Files;
+
 import org.apache.commons.compress.AbstractTestCase;
+import org.apache.commons.compress.archivers.zip.ZipFile;
 import org.apache.commons.compress.compressors.gzip.GzipCompressorInputStream;
 import org.apache.commons.compress.utils.IOUtils;
+import org.junit.jupiter.api.Test;
 
 public final class FramedSnappyCompressorInputStreamTest
     extends AbstractTestCase {
 
+    @Test
     public void testMatches() throws IOException {
         assertFalse(FramedSnappyCompressorInputStream.matches(new byte[10], 10));
-        byte[] b = new byte[12];
-        final File input = getFile("bla.tar.sz");
-        FileInputStream in = new FileInputStream(input);
-        try {
-            IOUtils.readFully(in, b);
-        } finally {
-            in.close();
-        }
+        final byte[] b = new byte[12];
+        IOUtils.read(getFile("bla.tar.sz"), b);
         assertFalse(FramedSnappyCompressorInputStream.matches(b, 9));
         assertTrue(FramedSnappyCompressorInputStream.matches(b, 10));
         assertTrue(FramedSnappyCompressorInputStream.matches(b, 12));
@@ -52,15 +54,15 @@ public final class FramedSnappyCompressorInputStreamTest
     /**
      * Something big enough to make buffers slide.
      */
+    @Test
     public void testLoremIpsum() throws Exception {
-        final FileInputStream isSz = new FileInputStream(getFile("lorem-ipsum.txt.sz"));
         final File outputSz = new File(dir, "lorem-ipsum.1");
         final File outputGz = new File(dir, "lorem-ipsum.2");
-        try {
+        try (InputStream isSz = Files.newInputStream(getFile("lorem-ipsum.txt.sz").toPath())) {
             InputStream in = new FramedSnappyCompressorInputStream(isSz);
-            FileOutputStream out = null;
+            OutputStream out = null;
             try {
-                out = new FileOutputStream(outputSz);
+                out = Files.newOutputStream(outputSz.toPath());
                 IOUtils.copy(in, out);
             } finally {
                 if (out != null) {
@@ -68,11 +70,10 @@ public final class FramedSnappyCompressorInputStreamTest
                 }
                 in.close();
             }
-            final FileInputStream isGz = new FileInputStream(getFile("lorem-ipsum.txt.gz"));
-            try {
+            try (InputStream isGz = Files.newInputStream(getFile("lorem-ipsum.txt.gz").toPath())) {
                 in = new GzipCompressorInputStream(isGz);
                 try {
-                    out = new FileOutputStream(outputGz);
+                    out = Files.newOutputStream(outputGz.toPath());
                     IOUtils.copy(in, out);
                 } finally {
                     if (out != null) {
@@ -80,36 +81,24 @@ public final class FramedSnappyCompressorInputStreamTest
                     }
                     in.close();
                 }
-            } finally {
-                isGz.close();
             }
-        } finally {
-            isSz.close();
         }
 
-        final FileInputStream sz = new FileInputStream(outputSz);
-        try {
-            FileInputStream gz = new FileInputStream(outputGz);
-            try {
+        try (InputStream sz = Files.newInputStream(outputSz.toPath())) {
+            try (InputStream gz = Files.newInputStream(outputGz.toPath())) {
                 assertArrayEquals(IOUtils.toByteArray(sz),
-                                  IOUtils.toByteArray(gz));
-            } finally {
-                gz.close();
+                        IOUtils.toByteArray(gz));
             }
-        } finally {
-            sz.close();
         }
     }
 
+    @Test
     public void testRemainingChunkTypes() throws Exception {
-        final FileInputStream isSz = new FileInputStream(getFile("mixed.txt.sz"));
-        ByteArrayOutputStream out = new ByteArrayOutputStream();
-        try {
-            FramedSnappyCompressorInputStream in = new FramedSnappyCompressorInputStream(isSz);
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+        try (InputStream isSz = Files.newInputStream(getFile("mixed.txt.sz").toPath())) {
+            final FramedSnappyCompressorInputStream in = new FramedSnappyCompressorInputStream(isSz);
             IOUtils.copy(in, out);
             out.close();
-        } finally {
-            isSz.close();
         }
 
         assertArrayEquals(new byte[] { '1', '2', '3', '4',
@@ -123,52 +112,112 @@ public final class FramedSnappyCompressorInputStreamTest
             }, out.toByteArray());
     }
 
+    @Test
     public void testAvailable() throws Exception {
-        final FileInputStream isSz = new FileInputStream(getFile("mixed.txt.sz"));
-        try {
-            FramedSnappyCompressorInputStream in = new FramedSnappyCompressorInputStream(isSz);
+        try (InputStream isSz = Files.newInputStream(getFile("mixed.txt.sz").toPath())) {
+            final FramedSnappyCompressorInputStream in = new FramedSnappyCompressorInputStream(isSz);
             assertEquals(0, in.available()); // no chunk read so far
             assertEquals('1', in.read());
             assertEquals(3, in.available()); // remainder of first uncompressed block
             assertEquals(3, in.read(new byte[5], 0, 3));
             assertEquals('5', in.read());
-            assertEquals(4, in.available()); // remainder of literal
+            assertEquals(0, in.available()); // end of chunk, must read next one
             assertEquals(4, in.read(new byte[5], 0, 4));
             assertEquals('5', in.read());
-            assertEquals(19, in.available()); // remainder of copy
             in.close();
-        } finally {
-            isSz.close();
         }
     }
 
+    @Test
     public void testUnskippableChunk() {
-        byte[] input = new byte[] {
+        final byte[] input = new byte[] {
             (byte) 0xff, 6, 0, 0, 's', 'N', 'a', 'P', 'p', 'Y',
             2, 2, 0, 0, 1, 1
         };
         try {
-            FramedSnappyCompressorInputStream in =
+            final FramedSnappyCompressorInputStream in =
                 new FramedSnappyCompressorInputStream(new ByteArrayInputStream(input));
             in.read();
             fail("expected an exception");
-        } catch (IOException ex) {
-            assertTrue(ex.getMessage().indexOf("unskippable chunk") > -1);
+            in.close();
+        } catch (final IOException ex) {
+            assertTrue(ex.getMessage().contains("Unskippable chunk"));
         }
     }
 
+    @Test
     public void testChecksumUnmasking() {
-        testChecksumUnmasking(0xc757l);
-        testChecksumUnmasking(0xffffc757l);
+        testChecksumUnmasking(0xc757L);
+        testChecksumUnmasking(0xffffc757L);
     }
 
-    public void testChecksumUnmasking(long x) {
+    @Test
+    public void readIWAFile() throws Exception {
+        try (ZipFile zip = new ZipFile(getFile("testNumbersNew.numbers"))) {
+            try (InputStream is = zip.getInputStream(zip.getEntry("Index/Document.iwa"))) {
+                try (FramedSnappyCompressorInputStream in =
+                        new FramedSnappyCompressorInputStream(is, FramedSnappyDialect.IWORK_ARCHIVE);
+                        OutputStream out = Files.newOutputStream(new File(dir, "snappyIWATest.raw").toPath())) {
+                    IOUtils.copy(in, out);
+                }
+            }
+        }
+    }
+
+    /**
+     * @see "https://issues.apache.org/jira/browse/COMPRESS-358"
+     */
+    @Test
+    public void readIWAFileWithBiggerOffset() throws Exception {
+        final File o = new File(dir, "COMPRESS-358.raw");
+        try (InputStream is = Files.newInputStream(getFile("COMPRESS-358.iwa").toPath());
+             FramedSnappyCompressorInputStream in =
+                 new FramedSnappyCompressorInputStream(is, 1<<16, FramedSnappyDialect.IWORK_ARCHIVE);
+            OutputStream out = Files.newOutputStream(o.toPath())) {
+            IOUtils.copy(in, out);
+        }
+        try (InputStream a = Files.newInputStream(o.toPath());
+             InputStream e = Files.newInputStream(getFile("COMPRESS-358.uncompressed").toPath())) {
+            final byte[] expected = IOUtils.toByteArray(e);
+            final byte[] actual = IOUtils.toByteArray(a);
+            assertArrayEquals(expected, actual);
+        }
+    }
+
+    @Test
+    public void singleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+        final File input = getFile("bla.tar.sz");
+        try (InputStream is = Files.newInputStream(input.toPath())) {
+            final FramedSnappyCompressorInputStream in =
+                    new FramedSnappyCompressorInputStream(is);
+            IOUtils.toByteArray(in);
+            assertEquals(-1, in.read());
+            assertEquals(-1, in.read());
+            in.close();
+        }
+    }
+
+    @Test
+    public void multiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+        final File input = getFile("bla.tar.sz");
+        final byte[] buf = new byte[2];
+        try (InputStream is = Files.newInputStream(input.toPath())) {
+            final FramedSnappyCompressorInputStream in =
+                    new FramedSnappyCompressorInputStream(is);
+            IOUtils.toByteArray(in);
+            assertEquals(-1, in.read(buf));
+            assertEquals(-1, in.read(buf));
+            in.close();
+        }
+    }
+
+    private void testChecksumUnmasking(final long x) {
         assertEquals(Long.toHexString(x),
                      Long.toHexString(FramedSnappyCompressorInputStream
                                       .unmask(mask(x))));
     }
 
-    private long mask(long x) {
+    private long mask(final long x) {
         return (((x >>> 15) | (x << 17))
                 + FramedSnappyCompressorInputStream.MASK_OFFSET)
              & 0xffffFFFFL;
