@@ -31,12 +31,12 @@ import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 import java.util.jar.JarOutputStream;
 
-import junit.framework.TestCase;
-
 import org.apache.commons.compress.harmony.pack200.Archive;
 import org.apache.commons.compress.harmony.pack200.Pack200Exception;
 import org.apache.commons.compress.harmony.pack200.PackingOptions;
 
+import junit.framework.TestCase;
+
 /**
  * Test different options for packing a Jar file
  */
@@ -81,13 +81,13 @@ public class PackingOptionsTest extends TestCase {
         JarFile jarFile2 = new JarFile(compareFile);
 
         // Check that both jars have the same entries in the same order
-        Enumeration entries = jarFile.entries();
-        Enumeration entries2 = jarFile2.entries();
+        Enumeration<JarEntry> entries = jarFile.entries();
+        Enumeration<JarEntry> entries2 = jarFile2.entries();
         while (entries.hasMoreElements()) {
 
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
-            JarEntry entry2 = (JarEntry) entries2.nextElement();
+            JarEntry entry2 = entries2.nextElement();
             String name = entry.getName();
             String name2 = entry2.getName();
             assertEquals(name, name2);
@@ -128,9 +128,9 @@ public class PackingOptionsTest extends TestCase {
         entries2 = jarFile2.entries();
         boolean inOrder = true;
         while (entries.hasMoreElements()) {
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
-            JarEntry entry2 = (JarEntry) entries2.nextElement();
+            JarEntry entry2 = entries2.nextElement();
             String name = entry.getName();
             String name2 = entry2.getName();
             if (!name.equals(name2)) {
@@ -198,13 +198,13 @@ public class PackingOptionsTest extends TestCase {
         JarFile jarFile2 = new JarFile(compareFile);
 
         // Check that both jars have the same entries in the same order
-        Enumeration entries = jarFile.entries();
-        Enumeration entries2 = jarFile2.entries();
+        Enumeration<JarEntry> entries = jarFile.entries();
+        Enumeration<JarEntry> entries2 = jarFile2.entries();
         while (entries.hasMoreElements()) {
 
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
-            JarEntry entry2 = (JarEntry) entries2.nextElement();
+            JarEntry entry2 = entries2.nextElement();
             String name = entry.getName();
             String name2 = entry2.getName();
             assertEquals(name, name2);
@@ -245,9 +245,9 @@ public class PackingOptionsTest extends TestCase {
         long modtime = -1;
         boolean sameAsOriginal = true;
         while (entries.hasMoreElements()) {
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
-            JarEntry entry2 = (JarEntry) entries2.nextElement();
+            JarEntry entry2 = entries2.nextElement();
             String name = entry.getName();
             if (!name.startsWith("META-INF")) {
                 if (modtime == -1) {
@@ -637,12 +637,11 @@ public class PackingOptionsTest extends TestCase {
     // compareFiles(in, new JarFile(file));
     // }
 
-    private void compareJarEntries(JarFile jarFile, JarFile jarFile2)
-            throws IOException {
-        Enumeration entries = jarFile.entries();
+    private void compareJarEntries(JarFile jarFile, JarFile jarFile2) {
+        Enumeration<JarEntry> entries = jarFile.entries();
         while (entries.hasMoreElements()) {
 
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
 
             String name = entry.getName();
@@ -653,10 +652,10 @@ public class PackingOptionsTest extends TestCase {
 
     private void compareFiles(JarFile jarFile, JarFile jarFile2)
             throws IOException {
-        Enumeration entries = jarFile.entries();
+        Enumeration<JarEntry> entries = jarFile.entries();
         while (entries.hasMoreElements()) {
 
-            JarEntry entry = (JarEntry) entries.nextElement();
+            JarEntry entry = entries.nextElement();
             assertNotNull(entry);
 
             String name = entry.getName();
