@@ -19,26 +19,27 @@
 package org.apache.commons.compress.utils;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.nio.ByteOrder;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class BitInputStreamTest {
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void shouldNotAllowReadingOfANegativeAmountOfBits() throws IOException {
         try (final BitInputStream bis = new BitInputStream(getStream(), ByteOrder.LITTLE_ENDIAN)) {
-            bis.readBits(-1);
+            assertThrows(IOException.class, () -> bis.readBits(-1));
         }
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void shouldNotAllowReadingOfMoreThan63BitsAtATime() throws IOException {
         try (final BitInputStream bis = new BitInputStream(getStream(), ByteOrder.LITTLE_ENDIAN)) {
-            bis.readBits(64);
+            assertThrows(IOException.class, () -> bis.readBits(64));
         }
     }
 
@@ -123,7 +124,7 @@ public class BitInputStreamTest {
      */
     @Test
     public void littleEndianWithOverflow() throws Exception {
-        ByteArrayInputStream in = new ByteArrayInputStream(new byte[] {
+        final ByteArrayInputStream in = new ByteArrayInputStream(new byte[] {
                 87, // 01010111
                 45, // 00101101
                 66, // 01000010
@@ -138,7 +139,7 @@ public class BitInputStreamTest {
         try (final BitInputStream bin = new BitInputStream(in, ByteOrder.LITTLE_ENDIAN)) {
             assertEquals(23, // 10111
                          bin.readBits(5));
-            assertEquals(714595605644185962l, // 0001-00111101-01011000-00011101-01011010-00001111-01000010-00101101-010
+            assertEquals(714595605644185962L, // 0001-00111101-01011000-00011101-01011010-00001111-01000010-00101101-010
                          bin.readBits(63));
             assertEquals(1186, // 01001010-0010
                          bin.readBits(12));
@@ -148,7 +149,7 @@ public class BitInputStreamTest {
 
     @Test
     public void bigEndianWithOverflow() throws Exception {
-        ByteArrayInputStream in = new ByteArrayInputStream(new byte[] {
+        final ByteArrayInputStream in = new ByteArrayInputStream(new byte[] {
                 87, // 01010111
                 45, // 00101101
                 66, // 01000010
@@ -163,7 +164,7 @@ public class BitInputStreamTest {
         try (final BitInputStream bin = new BitInputStream(in, ByteOrder.BIG_ENDIAN)) {
             assertEquals(10, // 01010
                          bin.readBits(5));
-            assertEquals(8274274654740644818l, //111-00101101-01000010-00001111-01011010-00011101-01011000-00111101-0010
+            assertEquals(8274274654740644818L, //111-00101101-01000010-00001111-01011010-00011101-01011000-00111101-0010
                     bin.readBits(63));
             assertEquals(330, // 0001-01001010
                          bin.readBits(12));
