@@ -18,23 +18,25 @@
 
 package org.apache.commons.compress.utils;
 
+import static org.apache.commons.compress.utils.ByteUtils.fromLittleEndian;
+import static org.apache.commons.compress.utils.ByteUtils.toLittleEndian;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.DataInput;
 import java.io.DataInputStream;
 import java.io.DataOutput;
 import java.io.DataOutputStream;
+import java.io.EOFException;
 import java.io.IOException;
 import java.util.Arrays;
 
-import org.junit.Test;
-
-import static org.apache.commons.compress.utils.ByteUtils.InputStreamByteSupplier;
-import static org.apache.commons.compress.utils.ByteUtils.OutputStreamByteConsumer;
-import static org.apache.commons.compress.utils.ByteUtils.fromLittleEndian;
-import static org.apache.commons.compress.utils.ByteUtils.toLittleEndian;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
+import org.apache.commons.compress.utils.ByteUtils.InputStreamByteSupplier;
+import org.apache.commons.compress.utils.ByteUtils.OutputStreamByteConsumer;
+import org.junit.jupiter.api.Test;
 
 public class ByteUtilsTest {
 
@@ -50,9 +52,9 @@ public class ByteUtilsTest {
         assertEquals(2 + 3 * 256 + 4 * 256 * 256 + 128L * 256 * 256 * 256, fromLittleEndian(b));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void fromLittleEndianFromArrayOneArgThrowsForLengthTooBig() {
-        fromLittleEndian(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8, 9 });
+        assertThrows(IllegalArgumentException.class, () -> fromLittleEndian(new byte[] { 1, 2, 3, 4, 5, 6, 7, 8, 9 }));
     }
 
     @Test
@@ -67,9 +69,9 @@ public class ByteUtilsTest {
         assertEquals(2 + 3 * 256 + 4 * 256 * 256 + 128L * 256 * 256 * 256, fromLittleEndian(b, 1, 4));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void fromLittleEndianFromArrayThrowsForLengthTooBig() {
-        fromLittleEndian(ByteUtils.EMPTY_BYTE_ARRAY, 0, 9);
+        assertThrows(IllegalArgumentException.class, () -> fromLittleEndian(ByteUtils.EMPTY_BYTE_ARRAY, 0, 9));
     }
 
     @Test
@@ -84,15 +86,15 @@ public class ByteUtilsTest {
         assertEquals(2 + 3 * 256 + 4 * 256 * 256 + 128L * 256 * 256 * 256, fromLittleEndian(bin, 4));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void fromLittleEndianFromStreamThrowsForLengthTooBig() throws IOException {
-        fromLittleEndian(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), 9);
+        assertThrows(IllegalArgumentException.class, () -> fromLittleEndian(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY), 9));
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void fromLittleEndianFromStreamThrowsForPrematureEnd() throws IOException {
         final ByteArrayInputStream bin = new ByteArrayInputStream(new byte[] { 2, 3 });
-        fromLittleEndian(bin, 3);
+        assertThrows(IOException.class, () -> fromLittleEndian(bin, 3));
     }
 
     @Test
@@ -108,15 +110,15 @@ public class ByteUtilsTest {
             fromLittleEndian(new InputStreamByteSupplier(bin), 4));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void fromLittleEndianFromSupplierThrowsForLengthTooBig() throws IOException {
-        fromLittleEndian(new InputStreamByteSupplier(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY)), 9);
+        assertThrows(IllegalArgumentException.class, () -> fromLittleEndian(new InputStreamByteSupplier(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY)), 9));
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void fromLittleEndianFromSupplierThrowsForPrematureEnd() throws IOException {
         final ByteArrayInputStream bin = new ByteArrayInputStream(new byte[] { 2, 3 });
-        fromLittleEndian(new InputStreamByteSupplier(bin), 3);
+        assertThrows(IOException.class, () -> fromLittleEndian(new InputStreamByteSupplier(bin), 3));
     }
 
     @Test
@@ -131,16 +133,16 @@ public class ByteUtilsTest {
         assertEquals(2 + 3 * 256 + 4 * 256 * 256 + 128L * 256 * 256 * 256, fromLittleEndian(din, 4));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void fromLittleEndianFromDataInputThrowsForLengthTooBig() throws IOException {
         final DataInput din = new DataInputStream(new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY));
-        fromLittleEndian(din, 9);
+        assertThrows(IllegalArgumentException.class, () -> fromLittleEndian(din, 9));
     }
 
-    @Test(expected = java.io.EOFException.class)
+    @Test
     public void fromLittleEndianFromDataInputThrowsForPrematureEnd() throws IOException {
         final DataInput din = new DataInputStream(new ByteArrayInputStream(new byte[] { 2, 3 }));
-        fromLittleEndian(din, 3);
+        assertThrows(EOFException.class, () -> fromLittleEndian(din, 3));
     }
 
     @Test
@@ -195,14 +197,14 @@ public class ByteUtilsTest {
 
 
     @Test
-    public void toLittleEndianToByteArray() throws IOException {
+    public void toLittleEndianToByteArray() {
         final byte[] b = new byte[4];
         toLittleEndian(b, 2 + 3 * 256 + 4 * 256 * 256, 1, 3);
         assertArrayEquals(new byte[] { 2, 3, 4 }, Arrays.copyOfRange(b, 1, 4));
     }
 
     @Test
-    public void toLittleEndianToByteArrayUnsignedInt32() throws IOException {
+    public void toLittleEndianToByteArrayUnsignedInt32() {
         final byte[] b = new byte[4];
         toLittleEndian(b, 2 + 3 * 256 + 4 * 256 * 256 + 128L * 256 * 256 * 256, 0, 4);
         assertArrayEquals(new byte[] { 2, 3, 4, (byte) 128 }, b);
