@@ -16,15 +16,16 @@
  */
 package org.apache.commons.compress.utils;
 
-import org.junit.Test;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertThrows;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.util.zip.Adler32;
 import java.util.zip.CRC32;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
+import org.junit.jupiter.api.Test;
 
 /**
  * Unit tests for class {@link ChecksumVerifyingInputStream org.apache.commons.compress.utils.ChecksumVerifyingInputStream}.
@@ -34,53 +35,36 @@ import static org.junit.Assert.assertEquals;
  **/
 public class ChecksumVerifyingInputStreamTest {
 
-
-
-    @Test(expected = IOException.class)
+    @Test
     public void testReadTakingByteArrayThrowsIOException() throws IOException {
-
         final Adler32 adler32 = new Adler32();
         final byte[] byteArray = new byte[3];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
         final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(adler32, byteArrayInputStream, (-1859L), (byte) (-68));
-
-        checksumVerifyingInputStream.read(byteArray);
-
+        assertThrows(IOException.class, () -> checksumVerifyingInputStream.read(byteArray));
     }
 
-
-    @Test(expected = IOException.class)
+    @Test
     public void testReadTakingNoArgumentsThrowsIOException() throws IOException {
-
         final CRC32 cRC32_ = new CRC32();
         final byte[] byteArray = new byte[9];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
         final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte)1, (byte)1);
-
-        checksumVerifyingInputStream.read();
-
+        assertThrows(IOException.class, () -> checksumVerifyingInputStream.read());
     }
 
-
     @Test
     public void testSkip() throws IOException {
-
         final CRC32 cRC32_ = new CRC32();
         final byte[] byteArray = new byte[4];
         final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(byteArray);
         final ChecksumVerifyingInputStream checksumVerifyingInputStream = new ChecksumVerifyingInputStream(cRC32_, byteArrayInputStream, (byte)33, 2303L);
         final int intOne = checksumVerifyingInputStream.read(byteArray);
-
         final long skipReturnValue = checksumVerifyingInputStream.skip((byte)1);
-
         assertEquals(558161692L, cRC32_.getValue());
         assertEquals(0, byteArrayInputStream.available());
-
         assertArrayEquals(new byte[] {(byte)0, (byte)0, (byte)0, (byte)0}, byteArray);
         assertEquals(0L, skipReturnValue);
-
     }
 
-
-
 }
\ No newline at end of file
