@@ -18,21 +18,21 @@
 
 package org.apache.commons.compress.utils;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.Assert.assertThrows;
+
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.channels.ClosedChannelException;
 import java.nio.channels.NonWritableChannelException;
 import java.nio.channels.SeekableByteChannel;
-import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
 import org.junit.Assert;
-import org.junit.Ignore;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 /**
  * Initially based on <a
@@ -40,29 +40,24 @@ import org.junit.rules.ExpectedException;
  * by Tim Underwood.
  */
 public class MultiReadOnlySeekableByteChannelTest {
-    @Rule
-    public ExpectedException thrown = ExpectedException.none();
 
     @Test
     public void constructorThrowsOnNullArg() {
-        thrown.expect(NullPointerException.class);
-        new MultiReadOnlySeekableByteChannel(null);
+        assertThrows(NullPointerException.class, () -> new MultiReadOnlySeekableByteChannel(null));
     }
 
     @Test
-    public void forSeekableByteChannelsThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        MultiReadOnlySeekableByteChannel.forSeekableByteChannels(null);
+    public void forSeekableByteChannelsThrowsOnNullArg() {
+        assertThrows(NullPointerException.class, () -> MultiReadOnlySeekableByteChannel.forSeekableByteChannels(null));
     }
 
     @Test
     public void forFilesThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        MultiReadOnlySeekableByteChannel.forFiles(null);
+        assertThrows(NullPointerException.class, () -> MultiReadOnlySeekableByteChannel.forFiles(null));
     }
 
     @Test
-    public void forSeekableByteChannelsReturnsIdentityForSingleElement() throws IOException {
+    public void forSeekableByteChannelsReturnsIdentityForSingleElement() {
         final SeekableByteChannel e = makeEmpty();
         final SeekableByteChannel m = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(e);
         Assert.assertSame(e, m);
@@ -86,7 +81,7 @@ public class MultiReadOnlySeekableByteChannelTest {
     @Test
     public void checkForString() throws IOException {
         check("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
-            .getBytes(StandardCharsets.UTF_8));
+            .getBytes(UTF_8));
     }
 
     @Test
@@ -107,16 +102,16 @@ public class MultiReadOnlySeekableByteChannelTest {
     }
 
     @Test
-    public void closesAllAndThrowsExceptionIfCloseThrows() throws IOException {
-        SeekableByteChannel[] ts = new ThrowingSeekableByteChannel[] {
+    public void closesAllAndThrowsExceptionIfCloseThrows() {
+        final SeekableByteChannel[] ts = new ThrowingSeekableByteChannel[] {
             new ThrowingSeekableByteChannel(),
             new ThrowingSeekableByteChannel()
         };
-        SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(ts);
+        final SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(ts);
         try {
             s.close();
             Assert.fail("IOException expected");
-        } catch (IOException expected) {
+        } catch (final IOException expected) {
         }
         Assert.assertFalse(ts[0].isOpen());
         Assert.assertFalse(ts[1].isOpen());
@@ -124,43 +119,40 @@ public class MultiReadOnlySeekableByteChannelTest {
 
     @Test
     public void cantTruncate() throws IOException {
-        SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
-        thrown.expect(NonWritableChannelException.class);
-        s.truncate(1);
+        final SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
+        assertThrows(NonWritableChannelException.class, () -> s.truncate(1));
     }
 
     @Test
     public void cantWrite() throws IOException {
-        SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
-        thrown.expect(NonWritableChannelException.class);
-        s.write(ByteBuffer.allocate(10));
+        final SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
+        assertThrows(NonWritableChannelException.class, () -> s.write(ByteBuffer.allocate(10)));
     }
 
     @Test
     public void cantPositionToANegativePosition() throws IOException {
-        SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
-        thrown.expect(IllegalArgumentException.class);
-        s.position(-1);
+        final SeekableByteChannel s = MultiReadOnlySeekableByteChannel.forSeekableByteChannels(makeEmpty(), makeEmpty());
+        assertThrows(IOException.class, () -> s.position(-1));
     }
 
     private SeekableByteChannel makeEmpty() {
-        return makeSingle(new byte[0]);
+        return makeSingle(ByteUtils.EMPTY_BYTE_ARRAY);
     }
 
-    private SeekableByteChannel makeSingle(byte[] arr) {
+    private SeekableByteChannel makeSingle(final byte[] arr) {
         return new SeekableInMemoryByteChannel(arr);
     }
 
-    private SeekableByteChannel makeMulti(byte[][] arr) throws IOException {
-        SeekableByteChannel[] s = new SeekableByteChannel[arr.length];
+    private SeekableByteChannel makeMulti(final byte[][] arr) {
+        final SeekableByteChannel[] s = new SeekableByteChannel[arr.length];
         for (int i = 0; i < s.length; i++) {
             s[i] = makeSingle(arr[i]);
         }
         return MultiReadOnlySeekableByteChannel.forSeekableByteChannels(s);
     }
 
-    private void checkEmpty(SeekableByteChannel channel) throws IOException {
-        ByteBuffer buf = ByteBuffer.allocate(10);
+    private void checkEmpty(final SeekableByteChannel channel) throws IOException {
+        final ByteBuffer buf = ByteBuffer.allocate(10);
 
         Assert.assertTrue(channel.isOpen());
         Assert.assertEquals(0, channel.size());
@@ -176,12 +168,12 @@ public class MultiReadOnlySeekableByteChannelTest {
         try {
             channel.read(buf);
             Assert.fail("expected a ClosedChannelException");
-        } catch (ClosedChannelException expected) {
+        } catch (final ClosedChannelException expected) {
         }
         try {
             channel.position(100);
             Assert.fail("expected a ClosedChannelException");
-        } catch (ClosedChannelException expected) {
+        } catch (final ClosedChannelException expected) {
         }
     }
 
@@ -194,7 +186,7 @@ public class MultiReadOnlySeekableByteChannelTest {
         }
     }
 
-    private void check(final byte[] expected, SeekableByteChannel channel) throws IOException {
+    private void check(final byte[] expected, final SeekableByteChannel channel) throws IOException {
         for (int readBufferSize = 1; readBufferSize <= expected.length + 5; readBufferSize++) {
             check(expected, channel, readBufferSize);
         }
@@ -218,7 +210,7 @@ public class MultiReadOnlySeekableByteChannelTest {
         int bytesRead = channel.read(buf);
 
         while (bytesRead != -1) {
-            int remaining = buf.remaining();
+            final int remaining = buf.remaining();
 
             buf.flip();
             resultBuffer.put(buf);
@@ -239,13 +231,13 @@ public class MultiReadOnlySeekableByteChannelTest {
         }
 
         resultBuffer.flip();
-        byte[] arr = new byte[resultBuffer.remaining()];
+        final byte[] arr = new byte[resultBuffer.remaining()];
         resultBuffer.get(arr);
         Assert.assertArrayEquals("readBufferSize " + readBufferSize, expected, arr);
     }
 
     private byte[][] grouped(final byte[] input, final int chunkSize) {
-        List<byte[]> groups = new ArrayList<>();
+        final List<byte[]> groups = new ArrayList<>();
         int idx = 0;
         for (; idx + chunkSize <= input.length; idx += chunkSize) {
             groups.add(Arrays.copyOfRange(input, idx, idx + chunkSize));
@@ -268,19 +260,19 @@ public class MultiReadOnlySeekableByteChannelTest {
             throw new IOException("foo");
         }
         @Override
-        public int read(ByteBuffer dst) throws IOException {
+        public int read(final ByteBuffer dst) throws IOException {
             return -1;
         }
         @Override
-        public int write(ByteBuffer src) throws IOException {
+        public int write(final ByteBuffer src) throws IOException {
             return 0;
         }
         @Override
-        public long position() throws IOException {
+        public long position() {
             return 0;
         }
         @Override
-        public SeekableByteChannel position(long newPosition) throws IOException {
+        public SeekableByteChannel position(final long newPosition) {
             return this;
         }
         @Override
@@ -288,7 +280,7 @@ public class MultiReadOnlySeekableByteChannelTest {
             return 0;
         }
         @Override
-        public SeekableByteChannel truncate(long size) throws IOException {
+        public SeekableByteChannel truncate(final long size) {
             return this;
         }
     }
@@ -321,9 +313,8 @@ public class MultiReadOnlySeekableByteChannelTest {
      * <q>ClosedChannelException - If this channel is closed</q>
      */
     @Test
-    @Ignore("we deliberately violate the spec")
+    @Disabled("we deliberately violate the spec")
     public void throwsClosedChannelExceptionWhenPositionIsReadOnClosedChannel() throws Exception {
-        thrown.expect(ClosedChannelException.class);
         try (SeekableByteChannel c = testChannel()) {
             c.close();
             c.position();
@@ -337,10 +328,9 @@ public class MultiReadOnlySeekableByteChannelTest {
      */
     @Test
     public void throwsClosedChannelExceptionWhenSizeIsReadOnClosedChannel() throws Exception {
-        thrown.expect(ClosedChannelException.class);
         try (SeekableByteChannel c = testChannel()) {
             c.close();
-            c.size();
+            assertThrows(ClosedChannelException.class, () -> c.size());
         }
     }
 
@@ -351,10 +341,9 @@ public class MultiReadOnlySeekableByteChannelTest {
      */
     @Test
     public void throwsClosedChannelExceptionWhenPositionIsSetOnClosedChannel() throws Exception {
-        thrown.expect(ClosedChannelException.class);
         try (SeekableByteChannel c = testChannel()) {
             c.close();
-            c.position(0);
+            assertThrows(ClosedChannelException.class, () -> c.position(0));
         }
     }
 
@@ -368,19 +357,18 @@ public class MultiReadOnlySeekableByteChannelTest {
         try (SeekableByteChannel c = testChannel()) {
             c.position(2);
             Assert.assertEquals(2, c.position());
-            ByteBuffer readBuffer = ByteBuffer.allocate(5);
+            final ByteBuffer readBuffer = ByteBuffer.allocate(5);
             Assert.assertEquals(-1, c.read(readBuffer));
         }
     }
 
     /*
-     * <q>IllegalArgumentException - If the new position is negative</q>
+     * <q>IOException - If the new position is negative</q>
      */
     @Test
-    public void throwsIllegalArgumentExceptionWhenPositionIsSetToANegativeValue() throws Exception {
-        thrown.expect(IllegalArgumentException.class);
+    public void throwsIOExceptionWhenPositionIsSetToANegativeValue() throws Exception {
         try (SeekableByteChannel c = testChannel()) {
-            c.position(-1);
+            assertThrows(IOException.class, () -> c.position(-1));
         }
     }
 
