@@ -19,7 +19,7 @@
 package org.apache.commons.compress.utils;
 
 import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class OsgiUtilsTest {
 
