@@ -18,23 +18,24 @@
  */
 package org.apache.commons.compress.utils;
 
-import org.junit.Ignore;
-import org.junit.Test;
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertThrows;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.channels.ClosedChannelException;
 import java.nio.channels.SeekableByteChannel;
-import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 public class SeekableInMemoryByteChannelTest {
 
-    private final byte[] testData = "Some data".getBytes(StandardCharsets.UTF_8);
+    private final byte[] testData = "Some data".getBytes(UTF_8);
 
     @Test
     public void shouldReadContentsProperly() throws IOException {
@@ -74,7 +75,7 @@ public class SeekableInMemoryByteChannelTest {
         final int readCount = c.read(readBuffer);
         //then
         assertEquals(4L, readCount);
-        assertEquals("data", new String(readBuffer.array(), StandardCharsets.UTF_8));
+        assertEquals("data", new String(readBuffer.array(), UTF_8));
         assertEquals(testData.length, c.position());
         c.close();
     }
@@ -94,13 +95,13 @@ public class SeekableInMemoryByteChannelTest {
         c.close();
     }
 
-    @Test(expected = ClosedChannelException.class)
+    @Test
     public void shouldThrowExceptionOnReadingClosedChannel() throws IOException {
         //given
         final SeekableInMemoryByteChannel c = new SeekableInMemoryByteChannel();
         //when
         c.close();
-        c.read(ByteBuffer.allocate(1));
+        assertThrows(ClosedChannelException.class, () -> c.read(ByteBuffer.allocate(1)));
     }
 
     @Test
@@ -135,24 +136,24 @@ public class SeekableInMemoryByteChannelTest {
     }
 
 
-    @Test(expected = ClosedChannelException.class)
+    @Test
     public void shouldThrowExceptionOnWritingToClosedChannel() throws IOException {
         //given
         final SeekableInMemoryByteChannel c = new SeekableInMemoryByteChannel();
         //when
         c.close();
-        c.write(ByteBuffer.allocate(1));
+        assertThrows(ClosedChannelException.class, () -> c.write(ByteBuffer.allocate(1)));
     }
 
     @Test
-    public void shouldTruncateContentsProperly() throws IOException {
+    public void shouldTruncateContentsProperly() {
         //given
         final SeekableInMemoryByteChannel c = new SeekableInMemoryByteChannel(testData);
         //when
         c.truncate(4);
         //then
         final byte[] bytes = Arrays.copyOf(c.array(), (int) c.size());
-        assertEquals("Some", new String(bytes, StandardCharsets.UTF_8));
+        assertEquals("Some", new String(bytes, UTF_8));
         c.close();
     }
 
@@ -184,21 +185,21 @@ public class SeekableInMemoryByteChannelTest {
         c.close();
     }
 
-    @Test(expected = IOException.class)
+    @Test
     public void shouldThrowExceptionWhenSettingIncorrectPosition() throws IOException {
         //given
         final SeekableInMemoryByteChannel c = new SeekableInMemoryByteChannel();
         //when
-        c.position(Integer.MAX_VALUE + 1L);
+        assertThrows(IOException.class, () -> c.position(Integer.MAX_VALUE + 1L));
         c.close();
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void shouldThrowExceptionWhenTruncatingToIncorrectSize() throws IOException {
+    @Test
+    public void shouldThrowExceptionWhenTruncatingToIncorrectSize() {
         //given
         final SeekableInMemoryByteChannel c = new SeekableInMemoryByteChannel();
         //when
-        c.truncate(Integer.MAX_VALUE + 1L);
+        assertThrows(IllegalArgumentException.class, () -> c.truncate(Integer.MAX_VALUE + 1L));
         c.close();
     }
 
@@ -224,8 +225,8 @@ public class SeekableInMemoryByteChannelTest {
     /*
      * <q>ClosedChannelException - If this channel is closed</q>
      */
-    @Test(expected = ClosedChannelException.class)
-    @Ignore("we deliberately violate the spec")
+    @Test
+    @Disabled("we deliberately violate the spec")
     public void throwsClosedChannelExceptionWhenPositionIsReadOnClosedChannel() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
             c.close();
@@ -238,8 +239,8 @@ public class SeekableInMemoryByteChannelTest {
     /*
      * <q>ClosedChannelException - If this channel is closed</q>
      */
-    @Test(expected = ClosedChannelException.class)
-    @Ignore("we deliberately violate the spec")
+    @Test
+    @Disabled("we deliberately violate the spec")
     public void throwsClosedChannelExceptionWhenSizeIsReadOnClosedChannel() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
             c.close();
@@ -252,11 +253,11 @@ public class SeekableInMemoryByteChannelTest {
     /*
      * <q>ClosedChannelException - If this channel is closed</q>
      */
-    @Test(expected = ClosedChannelException.class)
+    @Test
     public void throwsClosedChannelExceptionWhenPositionIsSetOnClosedChannel() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
             c.close();
-            c.position(0);
+            assertThrows(ClosedChannelException.class, () -> c.position(0));
         }
     }
 
@@ -299,10 +300,10 @@ public class SeekableInMemoryByteChannelTest {
     /*
      * <q>IOException - If the new position is negative</q>
      */
-    @Test(expected = IOException.class)
+    @Test
     public void throwsIOExceptionWhenPositionIsSetToANegativeValue() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
-            c.position(-1);
+            assertThrows(IOException.class, () -> c.position(-1));
         }
     }
 
@@ -393,18 +394,18 @@ public class SeekableInMemoryByteChannelTest {
     /*
      * <q>IllegalArgumentException - If the new position is negative</q>
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void throwsIllegalArgumentExceptionWhenTruncatingToANegativeSize() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
-            c.truncate(-1);
+            assertThrows(IllegalArgumentException.class, () -> c.truncate(-1));
         }
     }
 
     /*
      * <q>ClosedChannelException - If this channel is closed</q>
      */
-    @Test(expected = ClosedChannelException.class)
-    @Ignore("we deliberately violate the spec")
+    @Test
+    @Disabled("we deliberately violate the spec")
     public void throwsClosedChannelExceptionWhenTruncateIsCalledOnClosedChannel() throws Exception {
         try (SeekableByteChannel c = new SeekableInMemoryByteChannel()) {
             c.close();
