@@ -18,11 +18,12 @@
  */
 package org.apache.commons.compress.utils;
 
-import org.junit.Test;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertThrows;
 
 import java.util.NoSuchElementException;
 
-import static org.junit.Assert.assertFalse;
+import org.junit.jupiter.api.Test;
 
 /**
  * Unit tests for class {@link ServiceLoaderIterator org.apache.commons.compress.utils.ServiceLoaderIterator}.
@@ -32,42 +33,26 @@ import static org.junit.Assert.assertFalse;
  **/
 public class ServiceLoaderIteratorTest {
 
-
-
-    @Test(expected = NoSuchElementException.class)
+    @Test
     public void testNextThrowsNoSuchElementException() {
-
         final Class<String> clasz = String.class;
         final ServiceLoaderIterator<String> serviceLoaderIterator = new ServiceLoaderIterator<>(clasz);
-
-        serviceLoaderIterator.next();
-
+        assertThrows(NoSuchElementException.class, () -> serviceLoaderIterator.next());
     }
 
-
     @Test
     public void testHasNextReturnsFalse() {
-
         final Class<Object> clasz = Object.class;
         final ServiceLoaderIterator<Object> serviceLoaderIterator = new ServiceLoaderIterator<>(clasz);
         final boolean result = serviceLoaderIterator.hasNext();
-
         assertFalse(result);
-
     }
 
-
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void testRemoveThrowsUnsupportedOperationException() {
-
         final Class<Integer> clasz = Integer.class;
         final ServiceLoaderIterator<Integer> serviceLoaderIterator = new ServiceLoaderIterator<>(clasz);
-
-        serviceLoaderIterator.remove();
-
-
+        assertThrows(UnsupportedOperationException.class, () -> serviceLoaderIterator.remove());
     }
 
-
-
-}
\ No newline at end of file
+}
