@@ -18,40 +18,37 @@
 
 package org.apache.commons.compress.utils;
 
-import org.apache.commons.compress.archivers.zip.ZipSplitReadOnlySeekableByteChannel;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import static org.apache.commons.compress.AbstractTestCase.getFile;
+import static org.apache.commons.compress.AbstractTestCase.getPath;
+import static org.junit.Assert.assertThrows;
 
 import java.io.File;
 import java.io.IOException;
 import java.nio.channels.SeekableByteChannel;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.StandardOpenOption;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Random;
 
-import static org.apache.commons.compress.AbstractTestCase.getFile;
+import org.apache.commons.compress.archivers.zip.ZipSplitReadOnlySeekableByteChannel;
+import org.junit.Assert;
+import org.junit.jupiter.api.Test;
 
 public class ZipSplitReadOnlySeekableByteChannelTest {
-    @Rule
-    public final ExpectedException thrown = ExpectedException.none();
 
     @Test
     public void constructorThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        new ZipSplitReadOnlySeekableByteChannel(null);
+        assertThrows(NullPointerException.class, () -> new ZipSplitReadOnlySeekableByteChannel(null));
     }
 
     @Test
     public void constructorThrowsOnNonSplitZipFiles() throws IOException {
-        thrown.expect(IOException.class);
         final List<SeekableByteChannel> channels = new ArrayList<>();
         final File file = getFile("COMPRESS-189.zip");
         channels.add(Files.newByteChannel(file.toPath(), StandardOpenOption.READ));
-        new ZipSplitReadOnlySeekableByteChannel(channels);
+        assertThrows(IOException.class, () -> new ZipSplitReadOnlySeekableByteChannel(channels));
     }
 
     @Test
@@ -65,14 +62,12 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
 
     @Test
     public void forOrderedSeekableByteChannelsThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null);
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null));
     }
 
     @Test
     public void forOrderedSeekableByteChannelsOfTwoParametersThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null, null);
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forOrderedSeekableByteChannels(null, null));
     }
 
     @Test
@@ -106,14 +101,12 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
 
     @Test
     public void forFilesThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        ZipSplitReadOnlySeekableByteChannel.forFiles(null);
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null));
     }
 
     @Test
     public void forFilesOfTwoParametersThrowsOnNullArg() throws IOException {
-        thrown.expect(NullPointerException.class);
-        ZipSplitReadOnlySeekableByteChannel.forFiles(null, null);
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forFiles(null, null));
     }
 
     @Test
@@ -135,9 +128,8 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
 
     @Test
     public void buildFromLastSplitSegmentThrowsOnNotZipFile() throws IOException {
-        thrown.expect(IllegalArgumentException.class);
         final File lastFile = getFile("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
-        ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile);
+        assertThrows(IllegalArgumentException.class, () -> ZipSplitReadOnlySeekableByteChannel.buildFromLastSplitSegment(lastFile));
     }
 
     @Test
@@ -178,4 +170,31 @@ public class ZipSplitReadOnlySeekableByteChannelTest {
 
         return channels;
     }
+
+    @Test
+    public void forPathsThrowsOnNullArg() throws IOException {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null));
+    }
+
+    @Test
+    public void forPathsOfTwoParametersThrowsOnNullArg() throws IOException {
+        assertThrows(NullPointerException.class, () -> ZipSplitReadOnlySeekableByteChannel.forPaths(null, null));
+    }
+
+    @Test
+    public void forPathsReturnCorrectClass() throws IOException {
+        final Path firstFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z01");
+        final Path secondFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.z02");
+        final Path lastFile = getPath("COMPRESS-477/split_zip_created_by_zip/split_zip_created_by_zip.zip");
+
+        final ArrayList<Path> list = new ArrayList<>();
+        list.add(firstFile);
+        list.add(secondFile);
+
+        SeekableByteChannel channel = ZipSplitReadOnlySeekableByteChannel.forPaths(lastFile, list);
+        Assert.assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+
+        channel = ZipSplitReadOnlySeekableByteChannel.forPaths(firstFile, secondFile, lastFile);
+        Assert.assertTrue(channel instanceof ZipSplitReadOnlySeekableByteChannel);
+    }
 }
